Package: scpdata
Type: Package
Title: Single-Cell Proteomics Data Package
Version: 1.21.2
Authors@R: 
    c(person("Christophe", "Vanderaa",
              email = "vanderaa.christophe@gmail.com",
              comment = c(ORCID = "0000-0001-7443-5427"),
              role = c("aut", "cre")),
      person("Laurent", "Gatto",
              email = "laurent.gatto@uclouvain.be",
              comment = c(ORCID = "0000-0002-1520-2268"),
              role = "aut"),
      person("Enes", "Ayar",
              email = "enes.ayar@uclouvain.be",
              comment = c(ORCID = "0000-0001-8881-9800"),
              role = "dtc"),
      person("Samuel", "Grégoire",
              email = "samuel.gregoire@uclouvain.be",
              comment = c(ORCID = "0000-0002-0900-7677"),
              role = "dtc"))
Description: The package disseminates mass spectrometry (MS)-based
    single-cell proteomics (SCP) datasets. The data were collected
    from published work and formatted using the `scp` data structure.
    The data sets contain quantitative information at spectrum,
    peptide and/or protein level for single cells or minute sample
    amounts.
Depends: R (>= 4.2.0), QFeatures, ExperimentHub
Imports: utils, AnnotationHub, SingleCellExperiment, S4Vectors
Suggests: scp, magrittr, dplyr, knitr, BiocStyle, BiocCheck, rmarkdown,
        testthat
biocViews: ExperimentData, ExpressionData, ExperimentHub,
        ReproducibleResearch, MassSpectrometryData, Proteome,
        SingleCellData, PackageTypeData
License: GPL-3
Encoding: UTF-8
VignetteBuilder: knitr
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.3
git_url: https://git.bioconductor.org/packages/scpdata
git_branch: devel
git_last_commit: c2d8a76
git_last_commit_date: 2026-08-27
Repository: Bioconductor 3.24
Date/Publication: 2026-08-27
NeedsCompilation: no
Packaged: 2026-08-27 15:37:04 UTC; biocbuild
Author: Christophe Vanderaa [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7443-5427>),
  Laurent Gatto [aut] (ORCID: <https://orcid.org/0000-0002-1520-2268>),
  Enes Ayar [dtc] (ORCID: <https://orcid.org/0000-0001-8881-9800>),
  Samuel Grégoire [dtc] (ORCID: <https://orcid.org/0000-0002-0900-7677>)
Maintainer: Christophe Vanderaa <vanderaa.christophe@gmail.com>

# Generated by roxygen2: do not edit by hand

export(leduc2022)
export(scpdata)
import(ExperimentHub)
import(QFeatures)
import(SingleCellExperiment)
importFrom(AnnotationHub,query)
importFrom(S4Vectors,mcols)
importFrom(utils,packageVersion)
importFrom(utils,read.csv)

# Single Cell Proteomics Data Package

[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![R-CMD-check-bioc](https://github.com/UCLouvain-CBIO/scpdata/workflows/R-CMD-check-bioc/badge.svg)](https://github.com/UCLouvain-CBIO/scpdata/actions?query=workflow%3AR-CMD-check-bioc)
[![Bioconductor-devel Build Status](https://bioconductor.org/shields/build/devel/data-experiment/scpdata.svg)](http://bioconductor.org/checkResults/devel/data-experiment-LATEST/scpdata/)
[![license](https://img.shields.io/badge/license-Artistic--2.0-brightgreen.svg)](https://opensource.org/licenses/Artistic-2.0)

<img
src="https://raw.githubusercontent.com/UCLouvain-CBIO/scpdata/master/sticker/sticker.png"
height="150">

This package contains standardized and annotated single-cell proteomics data.

# Installation instruction 

To install the stable version from Bioconductor:

```r
if (!requireNamespace("BiocManager"))
	install.packages("BiocManager")
BiocManager::install("scpdata")
```

To install the development version from GitHub:

```r
BiocManager::install("UCLouvain-CBIO/scpdata")
```

# Loading a data set 

The available datasets can be accessed through `ExperimentHub`. Use 
`scpdata()` to display the table with available datasets.

```r
library(scpdata)
scpdata()
```

You can either use the `ExperimentHub` interface or use the functions
provided `scpdata` to retrieve the data set of interest. 

## Loading data using the `ExperimentHub` interface

You first need to set up a connection with `ExperimentHub`. You can 
browse and query the database to look up a data set of interest (see
`?ExperimentHub` for more information).

```r
eh <- ExperimentHub()
query(eh, "scpdata")
```

Suppose you are interested in the `specht2019v2` data set, you can 
retrieve the data using the corresponding `ExperimentHub` ID. In this
case the ID is `EH3899`.

```r
scp <- eh[["EH3899"]]
```

## Loading data using the `scpdata` functions

`scpdata` exports a function for each of the data sets. Retrieving the
`specht2019v2` is performed by simply running the `specht2019v2()` 
function. 

```r
scp <- specht2019v2()
```

The documentation of each function contains information 
about its corresponding data set. The information includes a 
description of the data content, the acquisition protocol, the data 
collection procedure, and some associated references and data sources.

```r
?specht2019v2
```

# Available data

We collected the associated data that usually contains 3 levels of :

* **PSM data** is the data obtained after running feature 
  identification and quantification from the raw data. PSM stands for 
  peptide to spectrum match. The rows in the data are PSMs and columns
  are samples.
* **Peptide data** is the expression data where rows are peptides and 
  columns are samples.
* **Protein data** is the expression data where rows are proteins and 
  columns are samples.

Please refer to the documentation and original papers for a thorough 
description of the data processing. 

# Contributing to `scpdata`

Suggestions and bug reports are warmly welcome! You can submit them 
by creating an issue on the the 
[`scpdata` GitHub repository](https://github.com/UCLouvain-CBIO/scpdata/issues).

## License

The `scpdata` code is provided under a permissive 
[Artistic 2.0 license](https://opensource.org/licenses/Artistic-2.0). 
The documentation, including the manual pages and the vignettes, are
distributed under a 
[CC BY-SA license](https://creativecommons.org/licenses/by-sa/2.0/).

# Methodology used for collecting the data


1. Identify the data source and the annotations from the article, ask authors 
   for data if needed. 
2. Create a new R script that converts the data using the `scp` framework
3. Add data documentation and the data collection procedure in 
   `scpdata/R/data.R`
4. Add the dataset information in the `make-metadata.R` and update the 
   `metadata.csv`
5. Test the new data set by running 
  `ExperimentHubData::makeExperimentHubMetadata("scpdata")`. 
6. Contact Bioc team and upload Rda to Microsoft Azure: 
   hubs@bioconductor.org
   Then upload the files using the provided link:
   `azcopy copy --recursive scpdata/
   'https://bioconductorhubs.blob.core.windows.net/staginghub?<sas-url>'`
   or more easily, use the R script. See the 
   [help page](https://bioconductor.org/packages/devel/bioc/vignettes/HubPub/inst/doc/CreateAHubPackage.html#uploading-data-to-microsoft-azure-genomic-data-lake)
   for more information
7. Compile the documentation with roxygen2 and check package.
8. Update the NEWS.md file and bump package version

####---- Bubis et al. 2025 ---####

libPath <- "/storage/research/dduv/cbio-lg/user/samgregoire/2022-phd-samuel-gregoire/libs/"

library("SingleCellExperiment")
library("QFeatures", lib.loc = libPath)
library("scp", lib.loc = libPath)
library("dplyr")
library("tidyr")
library("purrr")
library("stringr")

# All files were downloaded from the proteomeXchange plateform
# ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2025/06/PXD064564

dataDir <-
  "/storage/research/dduv/cbio-lg/cluster/DataSets/SCPCBIO/bubis2025_astral/"

fileNames <- sub("\\.tsv", "", dir(dataDir))

####---- PSM data ----####

## Read data
PSMFileNames <- fileNames[grepl("Peptides|Precursors", fileNames)]
PSMList <- vector("list", length(PSMFileNames))
PSMList <- map(dir(dataDir, full.names = TRUE)[grepl("Peptides|Precursors", fileNames)],
               read.delim)

names(PSMList) <- PSMFileNames

## Keep only relevant cols
PSMKeepCols <-
  PSMList |>
  map(colnames) |>
  map(grepl, pattern = "EG.PrecursorId|PEP.MS1Quantity")

PSMKeepCols <- map2(map(PSMList, colnames), PSMKeepCols, `[`)
PSMList <- map2(PSMList, PSMKeepCols, select)

## Remove characters from quant cols
for (i in seq_along(PSMList)) {
  PSMList[[i]][PSMList[[i]] == "Filtered"] <- NaN
}

## Convert all quant cols to numeric
for (i in seq_along(PSMList)) {
  PSMList[[i]][, -(which(colnames(PSMList[[i]]) == "EG.PrecursorId"))] <-
    as.data.frame(
      sapply(PSMList[[i]][, -(which(colnames(PSMList[[i]]) == "EG.PrecursorId"))], as.numeric))
}

## Manual annotation of the search strategy
## Based on the README.xslx file

for (i in grep("_MBR|all_ME", names(PSMList))) {
  PSMList[[i]]$searchStrategy <- "directDIA+"
}

for (i in grep("_noMBR|method_eval", names(PSMList))) {
  PSMList[[i]]$searchStrategy <- "method evaluation"
}

for (i in grep("MM_Astral_paper_A549_Figure7_MBR_perGroup_directDIA_strictFDR|JB_250pgK562_50SPD_MBR_OS|JB_250pgHeLa_50SPD_SO_MBR", names(PSMList))) {
  PSMList[[i]]$searchStrategy <- "directDIA+ OS"
}

for (i in grep("JB_HeLa250pg_240k_20Th_40ms_50SPD_L10ng|MM_Astral_paper_K562_50SPD_library_search", names(PSMList))) {
  PSMList[[i]]$searchStrategy <- "library search 10ng"
}

PSMList[[grep("MM_AstralPaper_LibrarySearch_20x", names(PSMList))]]$searchStrategy <-
  "library search 20SC"

PSMList[[grep("MM_AstralPaper_LibrarySearch_40x", names(PSMList))]]$searchStrategy <-
  "library search 40SC"

for (i in grep("L100SC", names(PSMList))) {
  PSMList[[i]]$searchStrategy <- "library search 100SC"
}

## Pivot in long format

PSMList <-
  map(.x = PSMList, .f = pivot_longer,
      names_to = "file", values_to = "PEP.MS1Quantity",
      -c(EG.PrecursorId, searchStrategy))

## Bind list into one dataframe

PSM <- do.call("rbind", PSMList)
rm(PSMList)

## Remove PSMs without quantification

PSM <- PSM[!is.na(PSM$PEP.MS1Quantity), ]

## Clean cols

PSM$Stripped.Sequence <- gsub("_", "", PSM$EG.PrecursorId)
PSM$Stripped.Sequence <- sub("\\..", "", PSM$Stripped.Sequence)
PSM$Stripped.Sequence <- gsub("\\[.*\\]", "", PSM$Stripped.Sequence)

PSM$file <- sub("X\\.\\d+\\.\\.", "", PSM$file)
PSM$file <- sub("\\.raw\\..*", ".raw", PSM$file)

PSM$key <- paste(PSM$file, gsub(" ", "_", PSM$searchStrategy), sep = "_")

####---- Create sample annotation ----####

sa <- data.frame(runCol = unique(PSM$key),
                 cellType = rep(NA, length(unique(PSM$key))),
                 fig = rep(NA, length(unique(PSM$key))))

## File
sa$file <- sub("\\.raw_.*", ".raw", sa$runCol)

## Search strategy
sa$searchStrategy <- sub(".*\\.raw_", "", sa$runCol)

## Cell type
sa$cellType[grepl("HeLa", sa$runCol)] <- "HeLa"
sa$cellType[grepl("A549", sa$runCol)] <- "A549"
sa$cellType[grepl("blank", sa$runCol)] <- "blank"
sa$cellType[grepl("K562", sa$runCol)] <- "K562"
sa$cellType[grepl("H460", sa$runCol)] <- "H460"
sa$cellType[grepl("_SC_TE", sa$runCol)] <- "TE"
sa$cellType[grepl("_SC_hPSC", sa$runCol)] <- "hPSC"

## Throughput
sa$throughput <- str_extract(sa$runCol, "\\d+SPD")

## CV
sa$FAIMS_CV <- "-48V"
sa$FAIMS_CV[grep("FAIMSCV.38", sa$runCol)] <- "-38V"
sa$FAIMS_CV[grep("FAIMSCV.58", sa$runCol)] <- "-58V"
sa$FAIMS_CV[grep("FAIMSCV.68", sa$runCol)] <- "-68V"
sa$FAIMS_CV[grep("FAIMSCV.78", sa$runCol)] <- "-78V"
sa$FAIMS_CV[grep("FAIMSCV.88", sa$runCol)] <- "-88V"
sa$FAIMS_CV[grep("noFAIMS", sa$runCol)] <- "no FAIMS"

## Figure
sa$fig <- NA
sa$fig[grep("DDM|Nov_col", sa$runCol)] <- "fig 1"
sa$fig[grep("_CV\\..8|noFAIMS", sa$runCol)] <- "fig 2"
sa$fig[grep("A549|H460|50SPD_blank|blank_50SPD", sa$file)] <- "fig 4"
sa$fig[grep("gas3p8_blank|gas3p8_SC_TE|gas3p8_SC_hPSC", sa$file)] <- "fig 5"

####---- Build scp object ----####

bubis2025 <- readSCP(
  assayData = PSM,
  colData = sa,
  runCol = "key",
  quantCols = "PEP.MS1Quantity")
rm(PSM)

####---- Generate peptide data ----####

## Aggregate
bubis2025 <-
  aggregateFeatures(bubis2025,
                    i = 1:length(bubis2025),
                    fcol = "Stripped.Sequence",
                    fun = colMedians,
                    name = paste0("peptide_", names(bubis2025)))

## Join assays
bubis2025 <- joinAssays(bubis2025,
                  i = grep("peptide_", names(bubis2025))[bubis2025$fig == "fig 1"],
                  name = "peptides_fig1")
colData(bubis2025[["peptides_fig1"]]) <- colData(bubis2025)[bubis2025$fig == "fig 1", ]

bubis2025 <- joinAssays(bubis2025,
                  i = grep("peptide_", names(bubis2025))[bubis2025$fig == "fig 2"],
                  name = "peptides_fig2")
colData(bubis2025[["peptides_fig2"]]) <- colData(bubis2025)[bubis2025$fig == "fig 2", ]

bubis2025 <- joinAssays(bubis2025,
                  i = grep("peptide_", names(bubis2025))[bubis2025$fig == "fig 4"],
                  name = "peptides_fig4")
colData(bubis2025[["peptides_fig4"]]) <- colData(bubis2025)[bubis2025$fig == "fig 4", ]

bubis2025 <- joinAssays(bubis2025,
                  i = grep("peptide_", names(bubis2025))[bubis2025$fig == "fig 5"],
                  name = "peptides_fig5")
colData(bubis2025[["peptides_fig5"]]) <- colData(bubis2025)[bubis2025$fig == "fig 5", ]

## Remove individual peptide sets

bubis2025 <- bubis2025[, , !grepl("peptide_", names(bubis2025))]

####---- Retrieve Protein data ----####

## Read files
protFileNames <- fileNames[grepl("Protein", fileNames)]
protList <- vector("list", length(protFileNames))
protList <- map(dir(dataDir, full.names = TRUE)[grepl("Protein", fileNames)],
                read.delim)

names(protList) <- protFileNames

## Keep only relevant cols

protKeepCols <-
  protList |>
  map(colnames) |>
  map(grepl, pattern = "PG.Quantity|PG.ProteinGroups")

protKeepCols <- map2(map(protList, colnames), protKeepCols, `[`)

protList <- map2(protList, protKeepCols, select)

## Convert all quant cols to numeric

for (i in seq_along(protList)) {
  protList[[i]][, -(which(colnames(protList[[i]]) == "PG.ProteinGroups"))] <-
    as.data.frame(
      sapply(protList[[i]][, -(which(colnames(protList[[i]]) == "PG.ProteinGroups"))], as.numeric))
}

## Manual annotation of the search strategy
## Based on the README.xslx file

for (i in grep("_MBR|all_ME", names(protList))) {
  protList[[i]]$searchStrategy <- "directDIA+"
}

for (i in grep("_noMBR|method_eval", names(protList))) {
  protList[[i]]$searchStrategy <- "method evaluation"
}

for (i in grep("MM_Astral_paper_A549_Figure7_MBR_perGroup_directDIA_strictFDR|JB_250pgK562_50SPD_MBR_OS|JB_250pgHeLa_50SPD_SO_MBR", names(protList))) {
  protList[[i]]$searchStrategy <- "directDIA+ OS"
}

for (i in grep("JB_HeLa250pg_240k_20Th_40ms_50SPD_L10ng|MM_Astral_paper_K562_50SPD_library_search", names(protList))) {
  protList[[i]]$searchStrategy <- "library search 10ng"
}

protList[[grep("MM_AstralPaper_LibrarySearch_20x", names(protList))]]$searchStrategy <-
  "library search 20SC"

protList[[grep("MM_AstralPaper_LibrarySearch_40x", names(protList))]]$searchStrategy <-
  "library search 40SC"

for (i in grep("L100SC", names(protList))) {
  protList[[i]]$searchStrategy <- "library search 100SC"
}

## Pivot into long format

protList <-
  map(.x = protList, .f = pivot_longer,
      names_to = "file", values_to = "PG.Quantity",
      -c(PG.ProteinGroups, searchStrategy))

## Bind into one dataframe

prot <- do.call("rbind", protList)
rm(protList)

## Remove PSMs without quantification

prot <- prot[!is.na(prot$PG.Quantity), ]

## Clean cols

prot$file <- sub("X\\.\\d+\\.\\.", "", prot$file)
prot$file <- sub("\\.raw\\..*", ".raw", prot$file)

prot$key <- paste(prot$file, gsub(" ", "_", prot$searchStrategy), sep = "_")

####---- Build scp object for proteins ----####

## readSCP
bubis2025_prot <- readSCP(assayData = prot,
                          colData = sa,
                          runCol = "key",
                          quantCols = "PG.Quantity")
rm(prot)

## Add rownames

for (i in seq_along(bubis2025_prot)) {
  rownames(bubis2025_prot[[i]]) <- rowData(bubis2025_prot[[i]])$PG.ProteinGroups
  }

## Join assays
bubis2025_prot <- joinAssays(bubis2025_prot,
                  i = names(bubis2025_prot)[bubis2025_prot$fig == "fig 1"],
                  name = "proteins_fig1")
colData(bubis2025_prot[["proteins_fig1"]]) <- colData(bubis2025_prot)[bubis2025_prot$fig == "fig 1", ]

bubis2025_prot <- joinAssays(bubis2025_prot,
                       i = names(bubis2025_prot)[bubis2025_prot$fig == "fig 2"],
                       name = "proteins_fig2")
colData(bubis2025_prot[["proteins_fig2"]]) <- colData(bubis2025_prot)[bubis2025_prot$fig == "fig 2", ]

bubis2025_prot <- joinAssays(bubis2025_prot,
                       i = names(bubis2025_prot)[bubis2025_prot$fig == "fig 4"],
                       name = "proteins_fig4")
colData(bubis2025_prot[["proteins_fig4"]]) <- colData(bubis2025_prot)[bubis2025_prot$fig == "fig 4", ]

bubis2025_prot <- joinAssays(bubis2025_prot,
                       i = names(bubis2025_prot)[bubis2025_prot$fig == "fig 5"],
                       name = "proteins_fig5")
colData(bubis2025_prot[["proteins_fig5"]]) <- colData(bubis2025_prot)[bubis2025_prot$fig == "fig 5", ]

####---- Add protein data ----####

bubis2025 <- addAssay(bubis2025, bubis2025_prot[["proteins_fig1"]], "proteins_fig1")
bubis2025 <- addAssay(bubis2025, bubis2025_prot[["proteins_fig2"]], "proteins_fig2")
bubis2025 <- addAssay(bubis2025, bubis2025_prot[["proteins_fig4"]], "proteins_fig4")
bubis2025 <- addAssay(bubis2025, bubis2025_prot[["proteins_fig5"]], "proteins_fig5")

# save as rda file
save(bubis2025,
     file = file.path("../data/bubis2025.rda"),
     compress = "xz",
     compression_level = 9)

##' Krull et al, 2024 (Nature Communications): IFN-\eqn{\gamma} response
##'
##' They develop a new strategy for data-independent acquisition (DIA) that 
##' leverages the co-analysis of low-input samples alongside a corresponding 
##' enhancer (ME) of higher input. Using DIA-ME, they investigate the 
##' proteomic response of U-2 OS cells to interferon gamma (IFN-\eqn{\gamma}) at 
##' the single-cell level.
##'
##' @format A [QFeatures] object with 159 assays, each assay being a
##' [SingleCellExperiment] object.
##'
##' - Assay 1-158: DIA-NN main output report table split for each
##'   acquisition run. First 15 run acquires 10 single cells (MEs) and, 
##'   remaining 143 run acquires 1 single cell. It contains the results
##'   of the spectrum identification and quantification.
##' - `proteins`: DIA-NN protein group matrix, containing normalised
##'   quantities for 1553 protein groups in 143 single cells. Proteins
##'   are filtered at (Q.Value <= 0.01), (Lib.Q.Value <= 0.01), and 
##'   (Lib.PG.Q.Value <= 0.01).
##'   
##' The `colData(krull2024())` contains cell type annotations. The description 
##' of the `rowData` fields for the different assays can be found in the
##' [`DIA-NN` documentation](https://github.com/vdemichev/DiaNN#readme).
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: cells were detached with trypsin digestion, followed 
##'   by dilution in 1.5 mL PBS, and isolated using BD FACSAria III instrument.
##' - **Sample preparation**: Sorted single cells were collected in lysis 
##'   buffer (50 mM TEAB, pH 8.5, and 0.025% DDM), denatured at 70 degrees 
##'   Celsius for 30 minutes. Samples were acidified with 0.5% FA and 
##'   transferred to auto sampler plates for mass spectrometry analysis.
##' - **Separation**: Peptides were injected in a 2 microliter volume onto 
##'   a (25 cm x 75  micrometer) ID column at a flow rate of 300 nL/min, 
##'   separated using a gradient of ACN in water with 0.1% FA over 15 minutes, 
##'   connected to a nano-ESI source.
##' - **Ionization**: Ionization was performed using a 1,500 V capillary 
##'   voltage with 3.0 L/min dry gas and a dry temperature of 180 degrees 
##'   Celsius. MS data acquisition was conducted in diaPASEF mode using a 
##'   timsTOF Pro mass spectrometer.
##' - **Mass spectrometry**: MS1 scans covered a range of 200-1,700 m/z, 
##'   while DIA window isolation targeted 475-1,000 m/z with eight DIA scans 
##'   per cycle. Fragmentation was triggered by collision energy ranging from 
##'   45 eV to 27 eV depending on the ion mobility.
##' - **Data analysis**: Data was processed using DIA-NN (v1.8.0) and 
##'   Spectronaut 18 in a library-free approach, using deep learning 
##'   for spectrum prediction, retention times, and ion mobility.
##'
##' @section Data collection:
##'
##' The data were collected from the PRIDE
##' [repository](https://www.ebi.ac.uk/pride/archive/projects/PXD053464)
##' in the `03_SingleCell_Searches.zip` file.
##'
##' We loaded the DIA-NN main report table and generated a sample
##' annotation table based on the MS file names. We next combined the
##' sample annotation and the DIANN tables into a [QFeatures] object
##' following the `scp` data structure. We loaded the proteins group
##' matrix as a [SingleCellExperiment] object, and added the protein data 
##' as a new assay and link the precursors to proteins using the 
##' `Protein.Group` variable from the `rowData`.
##'
##' @source
##' The data were downloaded from PRIDE
##' [repository](https://www.ebi.ac.uk/pride/archive/projects/PXD053464)
##' with accession ID `PXD053464`.
##'
##' @references
##' Krull, K. K., Ali, S. A., & Krijgsveld, J. 2024. "Enhanced feature matching
##' in single-cell proteomics characterizes IFN-\eqn{\gamma} response and co-existence of
##' Cell States." Nature Communications, 15(1). 
##' [Link to article](https://doi.org/10.1038/s41467-024-52605-x) 
##' 
##' @examples
##' \donttest{
##' krull2024()
##' }
##'
##' @keywords datasets
##'
"krull2024"

##' Khan et al, 2023 (biorRxiv): Epithelial–Mesenchymal Transition
##'
##' @description
##'
##' Single-cell samples were prepared using the nPOP sample
##' preparation method.  Proteomics data were acquired using the
##' SCoPE2 protocol on a Thermo Scientific Q-Exactive mass
##' spectrometer. The dataset contains quantitative information on 421
##' MCF-10A single cells undergoing epithelial–mesenchymal transition
##' (EMT) triggered by TGF beta. The data are available at the PSM,
##' and protein levels. The paper investigates the dynamics of
##' correlation modules at the protein level.
##'
##' @format A [QFeatures] object with 47 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - Assay 1-44: PSM data acquired with a TMTPro 16plex protocol, hence
##'   those assays contain 16 columns. Columns hold quantitative information
##'   from single-cell channels, carrier channels, reference channels,
##'   empty (negative control) channels and unused channels.
##' - `peptides`: peptide data containing quantitative data for 10055
##'   peptides and 421 single-cells.
##' - `proteins_imputed`: protein data containing quantitative data for 4571
##'   proteins and 420 single-cells with k-nearest neighbors (KNN) imputation.
##' - `proteins_unimputed`: protein data containing quantitative data for 4571
##'   proteins and 420 single-cells without imputation.
##'
##' The `colData(khan2023())` contains cell type and batch annotations that
##' are common to all assays. The description of the `rowData` fields for the
##' PSM data can be found in the
##' [`MaxQuant` documentation](https://cox-labs.github.io/coxdocs/output_tables.html).
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: CellenONE cell sorting.
##' - **Sample preparation** performed using the SCoPE2 protocol. nPOP
##'   cell lysis (DMSO) + trypsin digestion + TMTPro 16plex protocol.
##' - **Separation**: online nLC (DionexUltiMate 3000 UHPLC with a
##'   25cm x 75um IonOpticks Odyssey Series column (ODY3-25075C18); 200nL/min).
##' - **Ionization**: ESI (1,700 V).
##' - **Mass spectrometry**: Thermo Scientific Q-Exactive (MS1
##'   resolution = 70,000; MS1 accumulation time = 300ms; MS2
##'   resolution = 70,000).
##' - **Data analysis**: MaxQuant(2.4.13.0) + DART-ID.
##'
##' @section Data collection:
##'
##' The PSM data were collected from a shared Google Drive folder that
##' is accessible from the SlavovLab website (see `Source` section).
##' The folder ('/002-singleCellDataGeneration') contains the following
##' files of interest:
##'
##' - `ev_updated_NS.DIA.txt`: the MaxQuant/DART-ID output file
##' - `annotation.csv`: sample annotation
##' - `batch.csv`: batch annotation
##'
##' We combined the sample annotation and the batch annotation in
##' a single table. We also formatted the quantification table so that
##' columns match with those of the annotation and filter only for
##' single-cell runs. Both table are then combined in a single
##' [QFeatures] object using the [scp::readSCP()] function.
##'
##' The peptide data were taken from the same google drive folder
##' (`EpiToMesen.TGFB.nPoP_trial1_pepByCellMatrix_NSThreshDART_medIntCrNorm.txt`).
##' The data were formatted to a [SingleCellExperiment] object and the sample
##' metadata were matched to the column names (mapping is retrieved
##' after running the SCoPE2 R script, `EMTTGFB_singleCellProcessing.R`) and
##' stored in the `colData`. The object is then added to the [QFeatures] object
##' and the rows of the PSM data are linked to the rows of the peptide data
##' based on the peptide sequence information through an `AssayLink` object.
##'
##' The imputed protein data were taken from the same google drive folder
##' (`EpiToMesen.TGFB.nPoP_trial1_1PercDartFDRTMTBulkDIA.WallE_imputed.txt`).
##' The data were formatted to a [SingleCellExperiment] object and the sample
##' metadata were matched to the column names (mapping is retrieved
##' after running the SCoPE2 R script, `EMTTGFB_singleCellProcessing.R`) and
##' stored in the `colData`. The object is then added to the [QFeatures] object
##' and the rows of the peptide data are linked to the rows of the protein data
##' based on the protein sequence information through an `AssayLink` object.
##'
##' The unimputed protein data were taken from the same google drive folder
##' (`EpiToMesen.TGFB.nPoP_trial1_1PercDartFDRTMTBulkDIA.WallE_unimputed.txt`).
##' The data were formatted and added exactly as imputed data.
##'
##' @source
##' The data were downloaded from the
##' [Slavov Lab](https://scp.slavovlab.net/Khan_et_al_2023) website via a
##' shared Google Drive
##' [folder](https://drive.google.com/drive/folders/1zCsRKWNQuAz5msxx0DfjDrIe6pUjqQmj).
##' The raw data and the quantification data can also be found in the
##' MassIVE repository `MSV000092872`:
##' ftp://MSV000092872@massive.ucsd.edu/.
##'
##' @references
##' Saad Khan, Rachel Conover, Anand R. Asthagiri, Nikolai Slavov. 2023.
##' "Dynamics of single-cell protein covariation during epithelial–mesenchymal
##' transition." Journal of Proteome Research.
##' ([link to article](https://pubs.acs.org/doi/10.1021/acs.jproteome.4c00277)).
##'
##' @examples
##' \donttest{
##' khan2023()
##' }
##'
##' @keywords datasets
##'
"khan2023"

####---- Liang et al. 2020 ---####


## Liang, Yiran, Hayden Acor, Michaela A. McCown, Andikan J. Nwosu, 
## Hannah Boekweg, Nathaniel B. Axtell, Thy Truong, Yongzheng Cong, 
## Samuel H. Payne, and Ryan T. Kelly. 2020. “Fully Automated Sample 
## Processing and Analysis Workflow for Low-Input Proteome Profiling.”
##  Analytical Chemistry, December. 
##  https://doi.org/10.1021/acs.analchem.0c04240.

library(SingleCellExperiment)
library(scp)
library(tidyverse)
dataDir <- "~/PhD/.localdata/SCP/liang2020/"

## All data files were retrieved from the FTP links provided in the PRIDE 
## repository PXD021882
## https://www.ebi.ac.uk/pride/archive/projects/PXD021882

####---- Load sample annotation ----####

## Sample annotations were collected in a table from the methods 
## section and from table S3 in the paper
meta <- read.csv(paste0(dataDir, "HeLa_annotations.csv"))

####---- Load PSM data ----####

psms <- read.table(paste0(dataDir, "evidence.txt"), 
                   sep = "\t", 
                   header = TRUE)
    

####---- Create the QFeatures object ----####

liang2020_hela <- readSCP(featureData = psms, 
                             colData = meta, 
                             channelCol = "QuantificationColumn", 
                             batchCol = "Raw.file", 
                             suffix = "_sample")

####---- Load peptide data ----####

## Load the quantification data
pep <- read.table(paste0(dataDir, "peptides.txt"),
                  sep = "\t", 
                  header = TRUE)

## Rename columns so they match with the PSM data
colnames(pep) <- sub(pattern = "^Intensity.(.*)$", 
                     replacement = "HeLa_\\1_sample",
                     colnames(pep))
## Create the SingleCellExperiment object
pep <- readSingleCellExperiment(pep, 
                                ecol = grep("sample$", colnames(pep)))
## Name rows with peptide sequence
rownames(pep) <- rowData(pep)$Sequence
## Include the peptide data in the QFeatures object
liang2020_hela <- addAssay(liang2020_hela, 
                              pep, 
                              name = "peptides")
## Link the PSMs and the peptides
liang2020_hela <- addAssayLink(liang2020_hela, 
                                  from = 1:15, 
                                  to = "peptides", 
                                  varFrom = rep("Sequence", 15),
                                  varTo = "Sequence")

####---- Protein data ----####

## Load the quantification data
read.table(paste0(dataDir, "proteinGroups.txt"),
           sep = "\t",
           header = TRUE) %>% 
    ## Get a unique protein ID
    mutate(Protein = sub("^([^;]*);.*$", "\\1", 
                         Majority.protein.IDs)) ->
    prot

## Rename columns so they math with the PSM data
colnames(prot) <- sub(pattern = "^Intensity.(.*)$", 
                      replacement = "HeLa_\\1_sample", 
                      colnames(prot)) 

## Create the SingleCellExperiment object
prot <- readSingleCellExperiment(prot, 
                                 ecol = grep("sample$", colnames(prot)))
## Name rows with peptide sequence
rownames(prot) <- rowData(prot)$Protein

## Include the protein data in the QFeatures object
liang2020_hela <- addAssay(liang2020_hela, 
                              prot, 
                              name = "proteins")
## Link the PSMs and the peptides
liang2020_hela <- addAssayLink(liang2020_hela, 
                                  from = "peptides", 
                                  to = "proteins", 
                                  varFrom = "Leading.razor.protein",
                                  varTo = "Protein")

# Save data as Rda file
save(liang2020_hela, 
     file = "~/PhD/.localdata/scpdata/liang2020_hela.Rda",
     compress = "xz", 
     compression_level = 9)

##' Bubis et al. 2023 (Nat Methods): Challenging the Astral mass analyzer.
##'
##' Single-cell (or single-cell range peptide dilution) proteomics data acquired
##' on the Thermo Scientific Orbitrap Astral mass spectrometer.  The dataset
##' contains single-cell range peptide dilution from Hela or K562 cell lines,
##' single-cell data from A549 and H460 cell lines (epithelial-like human lung
##' cancer cells), as well as trophectoderm- like (TE-like) and naive human
##' pluripotent stem (hPS) cells. The dataset contains quantitative information
##' at the PSM, peptide and protein levels. The raw data were analysed using
##' Spectronaut version 18.
##'
##' @format A [QFeatures] object with 602 sets, each set being a
##'     [SingleCellExperiment] object.
##'
##' - Sets 1-594: PSM data from the Spectronaut peptides report files with LFQ
##'   quantities from the `PEP.MS1Quantity` column.
##'
##' - Sets 595-598: Peptide data resulting from the PSM to peptide aggregation
##'   of the 594 PSM set. Resulting peptide sets were joined into assay sets
##'   based on the figure they were used for (1, 2, 4 or 5).
##'
##' - Sets 599-602: Protein data from the Spectronaut protein report files with
##'   LFQ quantities from the `PG.Quantity` column.
##'
##' The `colData(bubis2025())` contains cell type annotation, search strategy,
##' LC method throughput, FAIMS compensation voltage and figure in which the
##' sample was used. The description of the `rowData` fields can be found in the
##' [`Spectronaut` user
##' manual](https://biognosys.com/content/uploads/2025/06/Spectronaut-20-Manual.pdf).
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information can be
##' found in the source article (see *References*).
##'
##' - **Cell isolation**: A549 and H460 cells were isolated into 384-well plates
##'   using the cellenONE robot. TE-like cells and hSP cells were sorted into
##'   384-well plates using the FACS Aria III (BD) controlled by the DiVa
##'   software version 9.0.1. TE-like cells were selected based on their TROP2
##'   positivity while naive hPS cells were selected based on their SUSD2
##'   positivity. Whether cells were sorted using cellenONE or FACS, the wells
##'   were pre-filled with 1 microL of lysis/digestion buffer.
##'
##' - **Sample preparation** Lysis and digestion were performed in the plates
##'   for 30 min at 50°C, then stopped by adding 0.1% TFA. Liquid dispensing was
##'   performed using the cellenONE robot. The plates were stored at -20°C until
##'   injection.
##'
##' - **Liquid chromatography**: Samples were injected directly from the
##'   384-well plate. Chromatographic separation of peptides was performed on a
##'   vanquish Neo UHPLC system connected to an Aurora Ultimate TS 25-cm
##'   nanoflow UHPLC column with an integrated emitter (Ion Optics) at 50 °C in
##'   direct injection mode. Peptide separation was performed at 30-80 SPD, with
##'   details provided in the `colData` for each sample.
##'
##' - **Mass spectrometry**: Acquisition was conducted using an Orbitrap Astral
##'   mass spectrometer equipped with the FAIMS Pro or FAIMS Pro Duo interface
##'   and an EASY-Spray source. FAIMS compensation voltage (CV) was set to -48 V
##'   except for the samples used in fig. 2, for which different CV were
##'   tested. The exact CV used for each sample is specified in the
##'   `colData`. MS1 spectra were recorded using the Orbitrap analyser at a
##'   resolution of 240,000, from m/z 400 to 900, using an automated gain
##'   control (AGC) target of 500 % and a maximum injection time of 100 ms. For
##'   MS2 in DIA mode using the Astral analyzer, non-overlapping isolation
##'   windows of 20 m/z. A scan range of m/z 400 to 800 was selected. Precursor
##'   accumulation time was set to 60 ms and the AGC target to 800%.
##'
##' - **Raw data processing**: Raw files were processed using Spectronaut
##'   version 18.6.231227.55695. For results marked as ‘method evaluation’,
##'   DirectDIA+ was used in method evaluation mode without
##'   cross-normalisation. ‘DirectDIA+’ indicates that results were analyzed in
##'   DirectDIA+ mode. For library searches, higher- input DIA recorded results
##'   were first analyzed in DirectDIA+ mode, and a library was created from
##'   those files using Spectronaut.  Quantification was performed at the MS1
##'   level. Carbamidomethylation of cysteines as a static modification was
##'   removed for single-cell searches. Factory settings were used for all
##'   analyses and for library generation unless otherwise indicated. ‘Optimized
##'   settings’ (OS) indicates that searches were performed with a more
##'   stringent cutoff value of 0.01. The search strategy used for each sample
##'   is specified in the `colData`. Searches were performed against the human
##'   proteome (UniProt proteome UP000005640) and the CRAPome.
##'
##' @section Data collection:
##'
##' The MS raw proteomics data, Spectronaut search results and fasta files used
##' are available on the ProteomeXchange Consortium via the PRIDE partner
##' repository with the dataset identifier
##' [PXD049412](https://proteomecentral.proteomexchange.org/cgi/GetDataset?ID=PXD049412).
##' Only files related to single-cells or single-cell range peptide dilutions
##' were used for this dataset (fig. 1, 2, 4 and 5). Sample annotations were
##' manually generated using the file names and descriptions from the source
##' article.
##'
##' PSM and proteins data were extracted from the
##' `_Report_Peptides_JB_Pivot.tsv` and `_Report_Protein_JB_Pivot.tsv` files
##' respectively.
##'
##' Sample annotations and PSM features tables were combined in a single
##' [QFeatures] object using the [scp::readSCP()] function. Peptide data were
##' obtained by aggregating PSM data to the peptide level. Resulting peptides
##' sets were joined according to the figure for which they were used in the
##' source article. Individual peptides sets were discarded.  Protein data were
##' made in a separate [QFeatures] object, and sets were joined based on the
##' figure they are related to. Combined sets were added to the first
##' [QFeatures] object containing PSM and peptide data, and links between
##' peptide and protein sets were set manually.
##'
##' Note that the [QFeatures] object has not been further processed and has
##' therefore not been normalized, log-transformed or batch- corrected.
##'
##' @source The PSM and protein data, as well as sample annotations, can be
##'     downloaded on the ProteomeXchange Consortium via the PRIDE partner
##'     repository with the dataset identifier
##'     [PXD049412](https://proteomecentral.proteomexchange.org/cgi/GetDataset?ID=PXD049412).
##'
##' @references
##'
##' Julia A. Bubis, Tabiwang N. Arrey, Eugen Damoc, Bernard Delanghe, Jana
##' Slovakova, Theresa M. Sommer, Harunobu Kagawa, Peter Pichler, Nicolas
##' Rivron, Karl Mechtler and Manuel Matzinger (2025). *Challenging the Astral
##' mass analyzer to quantify up to 5,300 proteins per single cell at unseen
##' accuracy to uncover cellular heterogeneity* Nature Methods
##' https://doi.org/10.1038/s41592-024-02559-1 DOI:10.1038/s41592-024-02559-1.
##'
##' @examples
##' \donttest{
##' bubis2025
##' }
##'
##' @keywords datasets
##'
"bubis2025"

####---- Leduc et al. 2022 ---####


## Leduc, Andrew, R. Gray Huffman, and Nikolai Slavov. 2021. “Droplet
## Sample Preparation for Single-Cell Proteomics Applied to the Cell
## Cycle.” bioRxiv. https://doi.org/10.1101/2021.04.24.441211.

## This is the script for generating the pSCoPE dataset

library("SingleCellExperiment")
library("scp")
library("tidyverse")


# All files were downloaded from
# https://drive.google.com/drive/folders/117ZUG5aFIJt0vrqIxpKXQJorNtekO-BV

datadir <- "~/Documents/.localData/SCP/leduc2022/pSCoPE/"

####---- Prepare sample annotations ----####

# Get LC and MS annotations with sample type annotations
design <- read.csv(paste0(datadir, "CellenONE_data/annotation_18plex_well.csv"))
batch <- read.csv(paste0(datadir, "batch.csv"))

# Clean the sample metadata so that it meets the requirements for
# `scp::readSCP`. We first need to transform the design (set x
# reporter ion) to a long table so that one line is one sample.
design <- pivot_longer(design, -c(Set, well), names_to = "Channel",
                       values_to = "SampleAnnotation")
design$SampleType <- recode(design$SampleAnnotation,
                            neg = "Negative",
                            u = "Monocyte",
                            m = "Melanoma",
                            unused = "Unused",
                            reference = "Reference",
                            carrier = "Carrier")

# We then make some slight corrections to the batch data
colnames(batch)[1] <- "Set" ## consistent naming with design
batch$digest <- as.character(batch$digest)

# We can now combine the two tables in a single annotation table
sampleAnnotation <- inner_join(design, batch, by = "Set")

# Add melanoma subpopulation information
index <- read.csv(paste0(datadir, "misc/sample_index.csv"), row.names = 1)
meta <- read.csv(paste0(datadir, "misc/meta.csv"), row.names = 1)
meta <- inner_join(index, meta, by = "id")

idAnnot <- paste0(sampleAnnotation$Set, sub("RI", "", sampleAnnotation$Channel))
idMeta <- paste0(sub("^X", "", meta$rawfile), meta$channel.x)

sampleAnnotation$MelanomaSubCluster <- meta$sub[match(idAnnot, idMeta)]
sampleAnnotation$MelanomaSubCluster <- recode(sampleAnnotation$MelanomaSubCluster, C1 = "A", C2 = "B")

# Add cellenONE information = sample prep annotations
# 2 utility functions:
parseCellenoneFieldData <- function(file, ...) {
    out <- read.table(
        file, sep = "\t", fill = TRUE, header = FALSE,
        col.names = c("position", "well","volume"),  quote = "", ...
    )
    containsFieldData <- grepl("\\[\\d", out$position)
    fieldData <- out$position[containsFieldData]
    out$Field[containsFieldData] <- sub("\\[(\\d*),.*$", "\\1", fieldData)
    out$Field <- as.numeric(out$Field) + 1
    out <- fill(out, Field, .direction = "down")
    out <- out[out$well != "", ]
    out$YPos <- as.numeric(sub("^(.*)/.*$", "\\1", out$position))
    out$XPos <- as.numeric(sub("^.*/(.*)$", "\\1", out$position))
    out
}
matchLayoutToPickup <- function(layout, pickup,
                                coords = c("XPos","YPos")) {
    require("yaImpute")
    out <- lapply(split(layout, layout$Field), function(x) {
        field <- unique(x$Field)
        ref <- unique(pickup[pickup$Field == field, coords])
        target <- x[, coords]
        ann <- ann(
            ref = as.matrix(ref), target = as.matrix(target), k = 1
        )
        pickupIndex <- ann$knnIndexDist[, 1]
        x$XPosPickup <- ref[pickupIndex,]$XPos
        x$YPosPickup <- ref[pickupIndex,]$YPos
        x$PickupIndex <- as.character(pickupIndex)
        x
    })
    do.call(rbind, out)
}

# Parse cell isolation files
macrophage <- read.table(
    file = paste0(datadir, "CellenONE_data/M_isolated.csv"),
    sep = ",", header = TRUE
)
macrophage$Condition <- "macrophage"
monocyte <- read.table(
    file = paste0(datadir, "CellenONE_data/U_isolated.csv"),
    sep = ",", header = TRUE
)
monocyte$Condition <- "monocyte"
cellenoneData <- rbind(macrophage, monocyte)
isOdd <- 1:nrow(cellenoneData) %% 2 == 1
cellenoneData <- cbind(
    cellenoneData[!isOdd, 1:7],
    cellenoneData[isOdd, 8:ncol(cellenoneData)]
)
cellenoneData$IsolationTimeStamp <- paste(cellenoneData$Date, cellenoneData$Time)
cellenoneData$IsolationTimeStamp <- sub(
    "/21[ ]", "/2021 ", cellenoneData$IsolationTimeStamp
)
cellenoneData$IsolationTimeStamp <- strptime(
    cellenoneData$IsolationTimeStamp, "%m/%d/%Y %I:%M:%S %p"
)

# Parse labelling information
label <- parseCellenoneFieldData(
    paste0(datadir, "CellenONE_data/Labels.txt"), skip = 22
)
label$Label <- as.numeric(sub("^.*[A-Z](.*),", "\\1", label$well)) + 4
label$Label <- paste0("RI", label$Label)
label <- dplyr::rename(label, WellLabel = well)
label$WellLabel <- gsub("^1|,", "", label$WellLabel)
cellenoneData <- left_join(
    cellenoneData, label, by = join_by(XPos, YPos, Field)
)

# Parse sample pick-up for LC-MS information
pickup <- parseCellenoneFieldData(
    paste0(datadir, "CellenONE_data/SamplePickup.txt"), skip = 27
)
pickup$Target <- 5 - ceiling(pickup$Field / 4)
pickup$Field <- rep(c(1,2,3,4), each = 9)
pickup$well <- sub("^.*([A-Z].*),", "\\1", pickup$well)
pickup <- dplyr::rename(pickup, WellPooled = well)
cellenoneData <- matchLayoutToPickup(cellenoneData, pickup)
cellenoneData <- left_join(
    cellenoneData, pickup,
    join_by(XPosPickup == XPos, YPosPickup == YPos, Field, Target)
)
cellenoneData <- dplyr::select(
    cellenoneData,
    IsolationTimeStamp, Diameter, Elongation ,Target, Field, XPos, YPos,
    XPosPickup, YPosPickup, WellPooled, Label
)
cellenoneData <- dplyr::rename(
    cellenoneData, GlassSlide = Target, XPosDrop = XPos, YPosDrop = YPos,
    Channel = Label,
)

# Combine all sample annotations
sampleAnnotation <- left_join(
    sampleAnnotation, cellenoneData,
    by = join_by(well == WellPooled, Channel)
)
sampleAnnotation <- dplyr::rename(sampleAnnotation, WellPooled = well)

sampleAnnotation |>
    filter(!is.na(Field) & !is.na(GlassSlide)) |>
    ggplot() +
    ggforce::geom_circle(aes(x0 = XPosPickup,
                    y0 = YPosPickup,
                    fill = lcbatch,
                    r = 10),
                color = "transparent") +
    geom_point(aes(x = XPosDrop,
                   y = YPosDrop,
                   colour = SampleType
                   )) +
    geom_text(aes(x = XPosPickup,
                  y = YPosPickup,
                  label = WellPooled),
              size = 3, colour = "white") +
    facet_grid(GlassSlide ~ Field, labeller = label_both) +
    theme_minimal() +
    scale_fill_manual(values = c("palegreen", "lightgoldenrod"))

####---- Prepare PSM data ----####

ev <- read.delim(paste0(datadir, "ev_updated.txt"))
colnames(ev) <- gsub("^Reporter.intensity.(\\d*)$", "RI\\1", colnames(ev))
colnames(ev)[colnames(ev) == "Raw.file"] <- "Set"
ev$modseq <- paste0(ev$Modified.sequence, ev$Charge)
## This removes DIA runs
ev <- ev[ev$Set %in% sampleAnnotation$Set, ]

## Create the QFeatures object
leduc2022_pSCoPE <- readSCP(ev, sampleAnnotation,
                            channelCol = "Channel",
                            batchCol = "Set")

## Clean protein names
rdList <- lapply(rowData(leduc2022_pSCoPE), function(rd) {
    rd$Leading.razor.protein.id <-
        gsub("^.*\\|(.*)\\|.*", "\\1", rd$Leading.razor.protein)
    rd$Leading.razor.protein.symbol <-
        gsub("^.*\\|.*\\|(.*)_.*", "\\1", rd$Leading.razor.protein)
    rd
})
rowData(leduc2022_pSCoPE) <- rdList

####---- Retrieve processed data ----####

## Retrieve the data processed by Leduc et al.
sampleInd <- read.csv(paste0(datadir, "misc/sample_index.csv"), row.names = 2)
files <- c("t0.csv", "t3.csv", "t4b.csv", "t6.csv")
processedData <- lapply(files, function(f) {
    ## Read data
    dat <- read.csv(paste0(datadir, "processed_data/", f), row.names = 1)
    dat <- as.matrix(dat)
    ## Convert column names
    fileID <- sub("X", "", sampleInd[colnames(dat), "rawfile"])
    channel <- sampleInd[colnames(dat), "channel"]
    colnames(dat) <- paste0(fileID, "RI", channel)
    ## Convert to a SCE
    dat <- SingleCellExperiment(dat)
    ## Add colData
    colData(dat) <- colData(leduc2022_pSCoPE)[colnames(dat), ]
    dat
})
names(processedData) <- c("peptides", "peptides_log", "proteins_norm2", "proteins_processed")

## Generate the peptide to protein table
pep2prot <- rbindRowData(leduc2022_pSCoPE, names(leduc2022_pSCoPE)) %>%
    data.frame %>%
    group_by(modseq) %>%
    summarise(Leading.razor.protein = paste(unique(Leading.razor.protein),
                                            collapse = ";"),
              Leading.razor.protein.id = paste(unique(Leading.razor.protein.id),
                                               collapse = ";"),
              Leading.razor.protein.symbol = paste(unique(Leading.razor.protein.symbol),
                                                   collapse = ";")) %>%
    data.frame
rownames(pep2prot) <- pep2prot$modseq

## Add `peptides` data
rowData(processedData$peptides) <- pep2prot[rownames(processedData$peptides), ]
leduc2022_pSCoPE <- addAssay(leduc2022_pSCoPE, processedData$peptides, name = "peptides")
leduc2022_pSCoPE <- addAssayLink(leduc2022_pSCoPE, from = 1:134, to = "peptides",
                      varFrom = rep("modseq", 134), varTo = "modseq")

## Add `peptides_log` data
rowData(processedData$peptides_log) <- pep2prot[rownames(processedData$peptides_log), ]
leduc2022_pSCoPE <- addAssay(leduc2022_pSCoPE, processedData$peptides_log, name = "peptides_log")
leduc2022_pSCoPE <- addAssayLink(leduc2022_pSCoPE, from = "peptides", to = "peptides_log",
                      varFrom = "modseq", varTo = "modseq")

## Add `proteins_norm2` data
prots <- select(pep2prot, Leading.razor.protein, Leading.razor.protein.id, Leading.razor.protein.symbol)
prots <- prots[!duplicated(prots$Leading.razor.protein.id), ]
rownames(prots) <- prots$Leading.razor.protein.id
rowData(processedData$proteins_norm2) <- prots[rownames(processedData$proteins_norm2), ]
leduc2022_pSCoPE <- addAssay(leduc2022_pSCoPE, processedData$proteins_norm2, name = "proteins_norm2")
leduc2022_pSCoPE <- addAssayLink(leduc2022_pSCoPE, from = "peptides_log", to = "proteins_norm2",
                      varFrom = "Leading.razor.protein.id",
                      varTo = "Leading.razor.protein.id")

## Add `proteins_processed` data
rowData(processedData$proteins_processed) <- prots[rownames(processedData$proteins_processed), ]
leduc2022_pSCoPE <- addAssay(leduc2022_pSCoPE, processedData$proteins_processed, name = "proteins_processed")
leduc2022_pSCoPE <- addAssayLinkOneToOne(leduc2022_pSCoPE, from = "proteins_norm2", to = "proteins_processed")

## Create more informative TMT labels
tmtlabs <- c(
    "TMT126", paste0(
        "TMT", rep(127:134, each = 2), rep(c("N", "C"), 8)
    ), "TMT135N"
)
leduc2022_pSCoPE$Channel <- factor(
    tmtlabs[as.numeric(sub("RI", "", leduc2022_pSCoPE$Channel))],
    levels = tmtlabs
)

# Save data as Rda file
save(leduc2022_pSCoPE,
     file = "~/Documents/.localData/scpdata/leduc2022_pSCoPE.Rda",
     compress = "xz",
     compression_level = 9)

##' Derks et al. 2022 - plexDIA (Nat. Biotechnol.): PDAC vs melanoma
##' cells vs monocytes
##'
##' Single cell proteomics data acquired by the Slavov Lab using the
##' plexDIA protocol. It contains quantitative information from
##' pancreatic ductal acinar cells (PDAC; HPAF-II), melanoma cells
##' (WM989-A6-G3) and monocytes (U-937) at precursor and protein
##' level. The each run acquired 3 samples thanks to mTRAQ
##' multiplexing.
##'
##' @format A [QFeatures] object with 66 assays, each assay being a
##' [SingleCellExperiment] object. The assays either hold the DIA-NN
##' main output report table or the DIA-NN MS1 extracted signal table.
##' The DIA-NN main output report table contains the results of the spectrum
##' identification and quantification. The DIA-NN MS1 extracted
##' signal table contains quantification for all mTRAQ channels if its
##' precursors was identified in at least one of the channels,
##' regardless of whether there is sufficient evidence in those
##' channels at 1% FDR.
##'
##' The data is composed of three datasets
##'
##' 1. **Bulk**: dataset containing bulk (100-cell) data acquired
##'    using a Q-Exactive mass spectrometer. Assays 1-3 contain data
##'    from the DIA-NN main output report; assay 4 is the DIA-NN MS1
##'    extracted signal.
##' 2. **tims**: dataset containing single-cell data acquired using a
##'    timsTOF-SCP mass spectrometer. Assays 5-15  contain data
##'    from the DIA-NN main output report; assay 16 is the DIA-NN MS1
##'    extracted signal.
##' 3. **qe**: dataset containing single-cell data acquired
##'    using a Q-Exactive mass spectrometer. Assays 17-64 contain data
##'    from the DIA-NN main output report; assay 65 is the DIA-NN MS1
##'    extracted signal.
##'
##' The last assay `proteins` contains the processed protein data
##' table generated by the authors.
##'
##' The `colData(derks2022())` contains cell type annotations and
##' batch annotations. The description of the `rowData` fields for the
##' different assays can be found in the
##' [`DIA-NN` documentation](https://github.com/vdemichev/DiaNN#readme).
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: CellenONE cell sorting.
##' - **Sample preparation** performed using the improved SCoPE2
##'   protocol using the CellenONE liquid handling system. nPOP cell
##'   lysis (DMSO) + trypsin digestion + mTRAQ (3plex) labelling and
##'   pooling. A target library was generated as well to
##'   perform prioritized DDA (Huffman et al. 2022) using MaxQuant.Live
##'   (2.0.3).
##' - **Separation**: `bulk` - online nLC (Dionex UltiMate 3000 UHPLC)
##'   with a 25 cm × 75 µm IonOpticks Aurora Series UHPLC column
##'   (AUR2-25075C18A), 200nL/min. `qe` - online nLC (Dionex UltiMate
##'   3000 UHPLC) with a 15 cm × 75 µm IonOpticks Aurora Series UHPLC
##'   column (AUR2-15075C18A), 200nL/min. `tims` - nanoElute liquid
##'   chromatography system (Bruker Daltonics) using a 25 cm × 75 µm,
##'   1.6-µm C18 (AUR2-25075C18A-CSI, IonOpticks).
##' - **Ionization**: ESI.
##' - **Mass spectrometry**: cf article.
##' - **Data analysis**: DIA-NN (1.8.1 beta 16).
##'
##' @section Data collection:
##'
##' The data were collected from a shared Google Drive
##' [folder](https://drive.google.com/drive/folders/1pUC2zgXKtKYn22mlor0lmUDK0frgwL)
##' that is accessible from the SlavovLab website (see `Source` section).
##'
##' For each dataset separately, we combined the sample annotation
##' and the DIANN tables in a [QFeatures] object following the `scp`
##' data structure. We then combined the three datasets in a single
##' `QFeatures` object. We load the proteins table processed by the
##' authors as a [SingleCellExperiment] object and adapted the sample
##' names to match those in the `QFeatures` object. We added the
##' protein data as a new assay and link the precursors to proteins
##' using the `Protein.Group` variable from the `rowData`.
##'
##' @source
##' The data were downloaded from the
##' [Slavov Lab](https://scp.slavovlab.net/Derks_et_al_2022) website.
##' The raw data and the quantification data can also be found in the
##' massIVE repository `MSV000089093`.
##'
##' @references
##' Derks, Jason, Andrew Leduc, Georg Wallmann, R. Gray Huffman,
##' Matthew Willetts, Saad Khan, Harrison Specht, Markus Ralser,
##' Vadim Demichev, and Nikolai Slavov. 2022. "Increasing the
##' Throughput of Sensitive Proteomics by plexDIA." Nature
##' Biotechnology, July.
##' [Link to article](http://dx.doi.org/10.1038/s41587-022-01389-w)
##'
##' @examples
##' \donttest{
##' derks2022()
##' }
##'
##' @keywords datasets
##'
"derks2022"

##' Zhu et al. 2018 (Nat. Comm.): HeLa titration
##'
##' Near single-cell proteomics data of HeLa samples containing
##' different number of cells. There are three groups of cell
##' concentrations: low (10-14 cells), medium (35-45 cells) and high
##' (137-141 cells). The data also contain measures for blanks, HeLa
##' lysates (50 cell equivalent) and 2 cancer cell line lysates (MCF7
##' and THP1, 50 cell equivalent).
##'
##' @format A [QFeatures] object with 4 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - `peptides`: quantitative information for 37,795 peptides from
##'   21 samples
##' - `proteins_intensity`: protein intensities for 3,984 proteins
##'   from 21 samples
##' - `proteins_LFQ`: LFQ intensities for 3,984 proteins from 21
##'   samples
##' - `proteins_iBAQ`: iBAQ values for 3,984 proteins from 21 samples
##'
##' Sample annotation is stored in `colData(zhu2018NC_hela())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the original article (see `References`).
##'
##' - **Cell isolation**: HeLa cell concentration was adjusted by
##'   serial dilution and cell counting was performed manually using
##'   an inverted microscope.
##' - **Sample preparation** performed using the nanoPOTs device.
##'   Protein extraction using RapiGest (+ DTT) + alkylation (IAA) +
##'   Lys-C digestion + cleave RapiGest (formic acid).
##' - **Separation**: nanoACQUITY UPLC pump (60nL/min) with an
##'   Self-Pack PicoFrit 70cm x 30um LC columns.
##' - **Ionization**: ESI (1,900V).
##' - **Mass spectrometry**: Thermo Fisher Orbitrap Fusion Lumos
##'   Tribrid. MS1 settings: accumulation time = 246ms; resolution =
##'   120,000; AGC = 1E6. MS/MS settings, depend on the sample size,
##'   excepted for the AGC = 1E5. Blank and approx. 10 cells (time = 502ms;
##'   resolution = 240,000), approx. 40 cells (time = 246ms; resolution =
##'   120,000), approx. 140 cells (time = 118ms; resolution = 60,000).
##' - **Data analysis**: MaxQuant (v1.5.3.30) + Perseus + OriginLab
##'   2017
##'
##' @section Data collection:
##'
##' The data were collected from the PRIDE repository (accession
##' ID: PXD006847).  We downloaded the `CulturedCells_peptides.txt`
##' and the `CulturedCells_proteinGroups.txt` files containing the
##' combined identification and quantification
##' results. The sample annotations were inferred from the names of
##' columns holding the quantification data and the information in the
##' article. The peptides data were converted to a [SingleCellExperiment]
##' object. We split the protein table to separate the three types of
##' quantification: protein intensity, label-free quantitification
##' (LFQ) and intensity based absolute quantification (iBAQ). Each
##' table is converted to a [SingleCellExperiment] object along with
##' the remaining protein annotations. The 4 objects are combined in
##' a single [QFeatures] object and feature links are created based on
##' the peptide leading razor protein ID and the protein ID.
##'
##' @source
##' The PSM data can be downloaded from the PRIDE repository
##' PXD006847. FTP link:
##' ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/01/PXD006847
##'
##' @references
##'
##' Zhu, Ying, Paul D. Piehowski, Rui Zhao, Jing Chen, Yufeng Shen,
##' Ronald J. Moore, Anil K. Shukla, et al. 2018. “Nanodroplet
##' Processing Platform for Deep and Quantitative Proteome Profiling
##' of 10-100 Mammalian Cells.” Nature Communications 9 (1): 882
##' ([link to article](http://dx.doi.org/10.1038/s41467-018-03367-w)).
##'
##' @seealso The same experiment was conducted on HeLa lysates:
##' [zhu2018NC_lysates].
##'
##' @examples
##' \donttest{
##' zhu2018NC_hela()
##' }
##'
##' @keywords datasets
##'
"zhu2018NC_hela"

##' Woo et al. 2022 (Cell Syst.): 26 primary human lung cells
##'
##' Single-cell proteomics data from dissociated primary human lung
##' cells. The data were
##' acquired using the TIFF (transfer identification based on FAIMS
##' filtering) acquisition method. The data contain 26 single cells.
##'
##' @format A [QFeatures] object with 5 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - `peptides_[intensity or LFQ]`: 2 assays containing peptide
##'   quantities or normalized quantities using the maxLFQ method
##'   as computed by MaxQuant.
##' - `proteins_[intensity or iBAQ or LFQ]`: 3 assays containing
##'   protein quantities or normalized proteins using the iBAQ or
##'   maxLFQ methods as computed by MaxQuant.
##'
##' Sample annotation is stored in `colData(woo_lung())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Sample isolation**: primary human lung cells were dissociated
##'   following the protocol in Bandyopadhyay et al., 2018. The cells
##'   were sorted using the Influx II cell sorter and deposited on a
##'   nanoPOTS chip.
##' - **Sample preparation**: cells are lysed using using a DDM+DTT
##'   lysis and reduction buffer. The proteins are alkylated with IAA
##'   and digested with LysC and trypsin. Samples are then acidified
##'   with FA, vacuum dried and stored in freezer until data
##'   acquisition.
##' - **Liquid chromatography**: peptides are loaded using an in-house
##'   autosampler (Williams et al. 2020). The samples are concentrated
##'   through a SPE column (4cm x 100µm i.d. packed with 5µm C18) with
##'   microflow LC pump. The peptides are then eluted from an LC
##'   column (25cm x 50 µm i.d. packed with 1.7µm C18) from a 60 min
##'   gradient (100nL/min).
##' - **Mass spectrometry**: MS/MS was performed on an Orbitrap Fusion
##'   Lumos Tribrid MS with FAIMSpro coupled to a 2.4 kV ESI. FAIMS
##'   setup: 4-CV method (-45, -55, -65, -75 V). MS1 setup: resolution
##'   = 120.000, range = 350-1500 m/z,AGC target of 1E6, accumulation
##'   of 254ms. MS2 setup: 30% HCD, resolution AGC 2E4, accumulation
##'   of 254ms.
##' - **Raw data processing**: preprocessing using Maxquant v1.6.2.10
##'   that use Andromeda search engine (with UniProtKB 2016-21-29).
##'   MBR was enabled.
##'
##' @section Data collection:
##'
##' All data were collected from the MASSIVE repository (accession ID:
##' MSV000085937).
##'
##' The peptide and protein data were extracted from the
##' `peptides_nondepleted_Lung_scProteomics.txt` or
##' `proteinGroups_nondepleted_Lung_scProteomics.txt` files,
##' respectively, in the `NonDepleted_Lung_SingleCellProteomics`
##' folders.
##'
##' The tables were split so that intensities, maxLFQ, and iBAQ
##' data are contained in separate tables. Tables are then
##' converted to [SingleCellExperiment] objects. Sample annotations
##' were inferred from the sample names. All data is combined in
##' a [QFeatures] object. [AssayLinks] were stored between peptide
##' assays and their corresponding proteins assays based on the
##' leading razor protein (hence only unique peptides are linked to
##' proteins).
##'
##' The script to reproduce the `QFeatures` object is available at
##' `system.file("scripts", "make-data_woo2022_lung.R", package = "scpdata")`
##'
##' @source
##'
##' The peptide and protein data can be downloaded from the MASSIVE
##' repository MSV000085937
##'
##' @references
##'
##' **Source article**: Woo, Jongmin, Geremy C. Clair, Sarah M.
##' Williams, Song Feng, Chia-Feng Tsai, Ronald J. Moore, William B.
##' Chrisler, et al. 2022. “Three-Dimensional Feature Matching
##' Improves Coverage for Single-Cell Proteomics Based on Ion Mobility
##' Filtering.” Cell Systems 13 (5): 426–34.e4.
##' ([link to article](http://dx.doi.org/10.1016/j.cels.2022.02.003)).
##'
##' @examples
##' \donttest{
##' woo2022_lung()
##' }
##'
##' @keywords datasets
##'
"woo2022_lung"

##' Grégoire et al. 2023 - mixCTRL (arXiv): benchmark using
##' monocytes/macrophages
##'
##' Single cell proteomics data acquired using the SCoPE2 protocol.
##' The dataset contains two monocytes cell lines (THP1 and U937) as
##' well as controled mixtures of both and macrophage-like cells
##' produced upon PMA treatment. It contains quantitative information
##' at PSM, peptide and protein levels. Data was acquired using Lumos
##' Orbitrap (mainly) and timsTOF SCP mass spectrometers.
##'
##' @format A [QFeatures] object with 119 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - Assays 1-42: PSM data acquired with a TMT-16plex protocol, hence
##'   those assays contain 16 columns. Columns hold quantitative
##'   information from single-cell channels, carrier channels,
##'   blank (negative control) channels and unused channels.
##' - Assays 43-84: peptide data resulting from the PSM to peptide
##'   aggregation of the 42 PSM assays.
##' - Assays 85-91: peptide data for each of the 7 acquisition
##'   batches. Peptide data were joined based on their respective
##'   acquisition batches.
##' - Assays 92-98: normalised peptide data.
##' - Assays 99-105: normalised and log-transformed peptide data.
##' - Assays 106-112: protein data for each of the 7 acquisition
##'   batches. Normalised and log-transformed peptide data were
##'   agreggated to protein.
##' - Assays 113-119: Batch corrected protein data. Normalised and
##'   log-transformed protein data were batch corrected to remove
##'   technical variability induced by runs and channels.
##'
##' All the data has been filtered to keep high quality features and
##' samples.
##'
##' The `colData(gregoire2023_mixCTRL())` contains cell type annotation and
##' batch annotation that are common to all assays. The description of
##' the `rowData` fields for the PSM data can be found in the
##' [`sage` documentation](https://sage-docs.vercel.app/docs/results/search).
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see *References*).
##'
##' - **Cell isolation**: BD FACSAria III cell sorting.
##' - **Sample preparation** performed using the SCoPE2 protocol: mPOP
##'   cell lysis + trypsin digestion + TMT-16plex labeling and
##'   pooling.
##' - **Separation**: online nLC (Ultimate 3000 LC System or Vanquish
##'   Neo UHPLC System) with a BioZen Peptide Polar C18 250 x 0.0075mm
##'   column.
##' - **Mass spectrometry**:  Orbitrap Fusion Lumos Tribrid (MS1
##'   resolution = 70,000; MS2 accumulation time = 120ms; MS2
##'   resolution = 70,000) and timsTOF SCP.
##' - **Data preprocessing**: Sage.
##'
##' @section Data collection:
##'
##' The PSM data were collected from a Zenodo archive (see `Source`
##' section). The folder contains the following files of interest:
##'
##' - `results.sage.cbio.tsv`: the sage identification output file for
##'   batches acquired on the Lumos MS.
##' - `results.sage.giga.tsv`: the sage identification output file for
##'   batches acquired on the timsTOF SCP MS.
##' - `quant.cbio.tsv`: the sage quantification output file for
##'   batches acquired on the Lumos MS.
##' - `quant.giga.tsv`: the sage quantification output file for
##'   batches acquired on the timsTOF SCP MS.
##' - `sampleAnnotation_batch.csv`: sample annotation for each
##'   acquisition batch. There are in total 8 different annotation
##'   files.
##'
##' We combined the sample annotations in a single table. We also
##' combined `cbio` and `giga` tables together and merged resulting
##' identification and quantification tables. Both annotation and
##' features tables are then combined in a single [QFeatures] object
##' using the [scp::readSCP()] function.
##'
##' The [QFeatures] object was processed as described in the author's
##' manuscript (see `source`). Note that the imputed assays were used
##' in the paper for illustrative purposes only and have not been
##' reproduced here.
##'
##' @source
##' The data were downloaded from the [Zenodo
##' repository](https://zenodo.org/records/8417228).  The raw data and
##' the quantification data can also be found in the ProteomeXchange
##' Consortium via the [PRIDE partner
##' repository](https://www.ebi.ac.uk/pride/archive/projects/PXD046211),
##' project `PXD046211`.
##'
##' @references
##' Samuel Grégoire, Christophe Vanderaa, Sébastien Pyr dit Ruys,
##' Gabriel Mazzucchelli, Christopher Kune, Didier Vertommen and
##' Laurent Gatto. 2023. *Standardised workflow for mass spectrometry-
##' based single-cell proteomics data processing and analysis using
##' the scp package.*
##' arXiv. DOI:[10.48550/arXiv.2310.13598](https://doi.org/10.48550/arXiv.2310.13598)
##'
##' @examples
##' \donttest{
##' gregoire2023_mixCTRL()
##' }
##'
##' @keywords datasets
##'
"gregoire2023_mixCTRL"

####---- Specht et al. 2019 ---####


## Specht, Harrison, Edward Emmott, Toni Koller, and Nikolai Slavov. 2019. 
## “High-Throughput Single-Cell Proteomics Quantifies the Emergence of Macrophage 
## Heterogeneity.” bioRxiv. https://doi.org/10.1101/665307.

## NOTE: the script is version 2 because the data set was updated by the authors

library(SingleCellExperiment)
library(scp)
library(tidyverse)
dataDir <- "~/PhD/.localdata/SCP/specht2019/v2/"

####---- Load PSM data ----####

## The files were downloaded from 
## https://drive.google.com/drive/folders/1VzBfmNxziRYqayx3SP-cOe2gu129Obgx
## ev = the MaxQuant output file for all batches with the PSM data
ev <- read.csv(paste0(dataDir, "evidence_unfiltered.csv"), 
               sep = ",", header = TRUE)
## design = the cell annotation
design <- read.csv(paste0(dataDir, "annotation.csv"), 
                   check.names = FALSE)
## batch = the batch annotation 
batch <- read.csv(paste0(dataDir, "batch.csv"), 
                  check.names = FALSE)

## Clean the sample metadata so that it meets the requirements for
## `scp::readSCP`. The cell annotation and batch annotation are merge into a 
## table
inner_join(x = design %>% 
             pivot_longer(-Set, 
                          names_to = "Channel", 
                          values_to = "SampleAnnotation") %>%
             mutate(SampleType = recode(SampleAnnotation, 
                                        sc_0 = "Blank",
                                        sc_u = "Monocyte",
                                        sc_m0 = "Macrophage",
                                        unused = "Unused",
                                        norm = "Reference",
                                        reference = "Reference",
                                        carrier_mix = "Carrier")) %>%
             mutate_all(as.character), 
           y = batch %>% rename(Set = set) %>%
             mutate_all(as.character),
           by = "Set") -> 
  meta

## Clean quantitative data
ev %>%
  ## Remove variable not related to PSM info
  select(-c("X", "X1", "lcbatch", "sortday",  "digest")) %>%
  ## channel naming should be consistent with metadata
  rename_all(gsub, 
             pattern = "^Reporter[.]intensity[.](\\d*)$", 
             replacement = "RI\\1") %>%
  ## MS set should be consistent with metadata and other data
  rename(Set = Raw.file, 
         peptide = modseq,
         protein = Leading.razor.protein) %>%
  ## Remove "X" at start of batch 
  mutate(Set = gsub("^X", "", Set)) %>%
  ## keep only single cell runs 
  filter(!grepl("col\\d{2}|arrier|Ref|Master|SQC|blank", Set)) %>%
  ## remove experimental sets concurrent with low mass spec performance
  filter(!grepl("FP9[56]|FP103", Set)) %>%
  ## Make sure all runs are described in design, if not, remove them
  filter(Set %in% meta$Set) %>%
  ## Keep only useful information 
  select(Set, peptide, protein, matches("RI[0-9]*$"), Sequence, Length, 
         Modified.sequence, Charge, m.z, Mass, Resolution, Missed.cleavages, 
         Gene.names, Protein.names, PIF, Score, PEP, dart_PEP, dart_qval) ->
  ev
  
## Create the QFeatures object
specht2019v2 <- readSCP(ev, 
                        meta, 
                        channelCol = "Channel", 
                        batchCol = "Set",
                        removeEmptyCols = TRUE)

####---- Include the peptide data ----####

## The `Peptides-raw.csv` and `Cells.csv` files were downloaded from 
## https://scope2.slavovlab.net/docs/data.
## The `id_to_channel.RData` file was generated using the `SCoPE2_analysis.R`
## script from https://github.com/cvanderaa/SCoPE2/tree/1483b8e4e5e55a77ed2813133f89f415c0403437/code

## Get batch annotation
read.csv(paste0(dataDir, "Cells.csv"), row.names = 1) %>%
  t %>%
  as.data.frame %>%
  rownames_to_column("id") %>%
  rename(Set = raw.file, SampleAnnotation = celltype, digest = batch_digest, 
         sortday = batch_sort, lcbatch = batch_chromatography) %>%
  mutate(Channel = NA, 
         Set = sub("^X", "", Set),
         SampleType = recode(SampleAnnotation, 
                             sc_0 = "Blank",
                             sc_u = "Monocyte",
                             sc_m0 = "Macrophage",
                             unused = "Unused",
                             norm = "Reference",
                             reference = "Reference",
                             carrier_mix = "Carrier")) %>%
  column_to_rownames("id") %>%
  as("DataFrame") ->
  annot
## Get cell to add to reference channel annotation
## `IDtoChannel.csv` contains the id to channel index mapping
read.csv(paste0(dataDir, "IDtoChannel.csv")) %>%
  filter(celltype %in% rownames(annot)) %>%
  mutate(channel = sub("Reporter[.]intensity[.]", "RI", channel)) ->
  idMap
## Add channel info 
annot[idMap$celltype, "Channel"] <- idMap$channel

## Get the peptide data
pep <- readSingleCellExperiment(paste0(dataDir, "Peptides-raw.csv"), 
                                ecol = -c(1,2), fnames = "peptide")
colData(pep) <- annot[colnames(pep), ]
colnames(pep) <- paste0(annot[colnames(pep), "Set"], annot[colnames(pep), "Channel"])
## Include the peptide data in the QFeatures object
specht2019v2 <- addAssay(specht2019v2, pep, name = "peptides")

## Link the PSMs and the peptides
## First find which PSM assays were included
sel <- sapply(grep("19", names(specht2019v2), value = TRUE), function(name) {
  x <- specht2019v2[[name]]
  ## Does the current PSM data have at least 1 colname in common with pep?
  inColnames <- any(colnames(x) %in% colnames(pep))
  ## Does the current PSM data have at least 1 peptide sequence in common with pep?
  inSequence <- any(rowData(x)$peptide %in% rowData(pep)$peptide)
  return(inColnames && inSequence) ## The PSM assay must fulfill both conditions
})
## Add an AssayLink that bridges the PSM assays and the peptide assay
specht2019v2 <- addAssayLink(specht2019v2, from = which(sel), to = "peptides", 
                             varFrom = rep("peptide", sum(sel)), varTo = "peptide")

####---- Include the protein data ----####

## The `Proteins-processed.csv` and `Cells.csv` file was downloaded from 
## https://scope2.slavovlab.net/docs/data 
read.csv(paste0(dataDir, "Proteins-processed.csv")) %>%
  rename(protein = X) %>%
  readSingleCellExperiment(ecol = -1, fnames = "protein") ->
  prot
colData(prot) <- annot[colnames(prot), ]
colnames(prot) <- paste0(annot[colnames(prot), "Set"],
                         annot[colnames(prot), "Channel"])
specht2019v2 <- addAssay(specht2019v2, prot, name = "proteins")
specht2019v2 <- addAssayLink(specht2019v2, from = "peptides", to = "proteins", 
                             varFrom = "protein", varTo = "protein")

## Save data
save(specht2019v2, 
     file = file.path("~/PhD/.localdata/scpdata/specht2019v2.Rda"),
     compress = "xz", 
     compression_level = 9)

## Put onload and onAttach functionality

##' @importFrom utils packageVersion
.onAttach <- function(libname, pkgname) {
    msg <- paste0("\nThis is scpdata version ", 
                    packageVersion("scpdata"),
                    ".\nUse 'scpdata()' to list available data sets.")
    packageStartupMessage(msg)  
}

##' @importFrom utils read.csv
.onLoad <- function(libname, pkgname) {
    ## exports each resource name (i.e., title) into a function
    fl <- system.file("extdata", "metadata.csv", package = pkgname)
    titles <- read.csv(fl, stringsAsFactors = FALSE)$Title
    createHubAccessors(pkgname, titles)
}

####---- Petrosius et al. 2023 ---####

library(SingleCellExperiment)
library(scp)
library(tidyverse)
dataDir <- "https://dataverse.uclouvain.be/api/access/datafile/"

####---- Create sample annotation ----####

## Retrieve annotation files
## index_map.tab file
facs <- read.delim(url(paste0(dataDir, "24337")))
## msRuns_overview.csv file
map <- read.csv(url(paste0(dataDir, "24339")), row.names = "X")

## Map FACS data with MS runs
facs_mapped <- inner_join(map, facs, by = "Well")

## Create metadata
meta <-
  facs_mapped |>
  mutate(filename = sub(".*RunSummaries/", "", filename),
         filename = sub(".raw.*", "", filename),
         fileID = paste(CellType, Cell.Number, sep = "_"),
         quant = "quant") |>
  select(-Cell.Type) |>
  arrange(by_group = CellType, Cell.Number)

colnames(meta) <- gsub("_$" , "", gsub("\\.+", "_", colnames(meta)))

####---- PSM data ----####

## PSM data has been shared by the authors in PEPQuant file from
## spectronaut

## Retrieve ID/quant file
## '20240201_130747_PEPQuant (Normal).tsv' file
psm <-
  read.delim(paste0(dataDir, "24335"))

psm$fileID <- sub(".*sc8227_" , "", psm$R.FileName)

colnames(psm)[colnames(psm) == "FG.MS1Quantity"] <- "quant"

## QFeatures object
petrosius2023_AstralAML <-
  readSCP(featureData = psm,
          colData = meta,
          batchCol = "fileID",
          channelCol = "quant",
          sep = "_")

####---- Generate peptide data ----####

## Peptide data is generated by aggregation of the psm data

petrosius2023_AstralAML <-
  aggregateFeatures(petrosius2023_AstralAML,
                    i = 1:length(petrosius2023_AstralAML),
                    fcol = "PEP.StrippedSequence",
                    fun = colMedians,
                    name = paste0("peptide_", names(petrosius2023_AstralAML)))

petrosius2023_AstralAML <-
  joinAssays(petrosius2023_AstralAML,
             i = grep("peptide", names(petrosius2023_AstralAML)),
             name = "peptides")

petrosius2023_AstralAML <-
  petrosius2023_AstralAML[, , !grepl("peptide_", names(petrosius2023_AstralAML))]


####---- Retrieve protein data ----####

## Protein data has been shared by the authors in a PGQuant file from
## spectronaut
## 20240201_130747_PGQuant (Normal).tsv file
prot <-
  read.delim(paste0(dataDir, "24334"))

prot$R.FileName <- sub(".*Bremen/" , "", prot$R.Raw.File.Name)
prot$R.FileName <- sub(".raw" , "", prot$R.FileName)
prot$fileID <- sub(".*sc8227_" , "", prot$R.FileName)

colnames(prot)[colnames(prot) == "PG.Quantity"] <- "quant"

## Pivot to wide format
prot <- prot |>
  select(PG.Genes, PG.ProteinAccessions, PG.ProteinDescriptions,
         quant, fileID) |>
  pivot_wider(names_from = fileID,
              values_from = quant,
              names_glue = "{fileID}_quant")

## Read as SingleCellExperiment object
prot_assay <-
  readSingleCellExperiment(prot,
                           ecol = colnames(prot)[grep("quant",
                                                      colnames(prot))],
                           fnames = "PG.ProteinAccessions")

## Add assay to petrosius2023_AstralAML object
petrosius2023_AstralAML <-
  addAssay(petrosius2023_AstralAML,
           prot_assay,
           name = "proteins")

## Add link from peptide data to protein data
petrosius2023_AstralAML <- addAssayLink(petrosius2023_AstralAML,
                              from = "peptides",
                              to = "proteins",
                              varFrom = "PG.ProteinAccessions",
                              varTo = "PG.ProteinAccessions")

# Save data as Rda file
save(petrosius2023_AstralAML,
     file = "~/2022-phd-samuel-gregoire/petrosius2023_AstralAML.Rda",
     compress = "xz",
     compression_level = 9)

####---- Zhu et al. 2018, Molecular & Cellular Proteomics ----####

# Zhu, Ying, Maowei Dou, Paul D. Piehowski, Yiran Liang, Fangjun Wang, Rosalie 
# K. Chu, William B. Chrisler, et al. 2018. “Spatially Resolved Proteome Mapping 
# of Laser Capture Microdissected Tissue with Automated Sample Transfer to 
# Nanodroplets.” Molecular & Cellular Proteomics: MCP 17 (9): 1864–74.

library(scp)
library(mzR)
library(tidyverse)
dataDir <- "~/PhD/.localdata/SCP/zhu2018MCP/"

# The data was downloaded from ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/07/PXD008844

####---- Peptide data ----####

## Load the peptide data
peps <- read.table(paste0(dataDir, "MaxQuant_Peptides.txt"),
                   sep = "\t", header = TRUE)
peps <- readSingleCellExperiment(peps,
                                 ecol = grep("^Intensity.", colnames(peps)),
                                 fnames = "Sequence")
colnames(peps) <- gsub("Intensity.", "", colnames(peps))

####---- Sample annotations ----####

## Create the sample annotation table
annot <- DataFrame(row.names = colnames(peps))
annot$SectionWidth <- sub("^([0-9]*um)_.*$", "\\1", rownames(annot))
annot$SampleType <- str_extract(rownames(annot), "CC|CP|Mix")
annot$SampleType <- ifelse(is.na(annot$SampleType), "CTX", annot$SampleType)
annot$Prep <- str_match(rownames(annot), "08.*Prep$")[, 1]
annot$Replicate <- str_match(rownames(annot), "(_|Mix)(\\d)(_|$)")[, 3]

####---- Protein data ----####

## Load the quantification data
prots <- read.table(paste0(dataDir, "MaxQuant_ProteinGroups.txt"),
                    sep = "\t", header = TRUE)
## Remove unnecessary columns
sel <- !grepl("Peptides.*\\d|^Identif|^Razor.*\\d|Sequence.*\\d|Unique.*\\d|MS.MS.*\\d",
              colnames(prots))
prots <- prots[, sel]
## Split protein data based on the quantification method:
## 1. Protein intensity
protsInt <- prots[, !grepl("^iBAQ|^LFQ", colnames(prots))]
protsInt <- readSingleCellExperiment(protsInt, 
                                     ecol = grep("^Intensity.", colnames(protsInt)),
                                     fnames = "Protein.IDs")
colnames(protsInt) <- gsub("Intensity.", "", colnames(protsInt))
## 2. LFQ
protsLFQ <- prots[, !grepl("^iBAQ|^Intensity", colnames(prots))]
protsLFQ <- readSingleCellExperiment(protsLFQ, 
                                     ecol = grep("^LFQ.", colnames(protsLFQ)),
                                     fnames = "Protein.IDs")
colnames(protsLFQ) <- gsub("LFQ.intensity.", "", colnames(protsLFQ))
## 3. iBAQ
protsIBAQ <- prots[, !grepl("^LFQ|^Intensity", colnames(prots))]
protsIBAQ <- readSingleCellExperiment(protsIBAQ, 
                                      ecol = grep("^iBAQ.", colnames(protsIBAQ)),
                                      fnames = "Protein.IDs")
colnames(protsIBAQ) <- gsub("iBAQ.", "", colnames(protsIBAQ))

####---- Create the QFeatures object ----####

el <- ExperimentList(peptides = peps,
                     proteins_intensity = protsInt,
                     proteins_LFQ = protsLFQ,
                     proteins_iBAQ = protsIBAQ)
zhu2018MCP <- QFeatures(el, colData = annot)

## Create assay links
zhu2018MCP <- addAssayLink(zhu2018MCP, 
                                  from = "peptides", to = "proteins_intensity",
                                  varFrom = "Leading.razor.protein", 
                                  varTo = "Majority.protein.IDs")
zhu2018MCP <- addAssayLink(zhu2018MCP, 
                                  from = "peptides", to = "proteins_LFQ",
                                  varFrom = "Leading.razor.protein", 
                                  varTo = "Majority.protein.IDs")
zhu2018MCP <- addAssayLink(zhu2018MCP, 
                                  from = "peptides", to = "proteins_iBAQ",
                                  varFrom = "Leading.razor.protein", 
                                  varTo = "Majority.protein.IDs")

### Save data as Rda file
## Note: saving is assumed to occur in "scpdata/inst/scripts"
save(zhu2018MCP, 
     file = file.path("~/PhD/.localdata/scpdata/zhu2018MCP.Rda"),
     compress = "xz", 
     compression_level = 9)

## Core packages of this workflow
library("scp")
library("SCP.replication")
library("tidyverse")

## All data files were retrieved from this Google Drive repository:
## https://drive.google.com/drive/folders/1pUC2zgXKtKYn22mlor0lmUDK0frgwL_-
datadir <- "~/PhD/.localdata/SCP/derks2022/"

## Sample annotations


sampleAnnot <- read.delim(paste0(datadir, "Meta_SingleCell_updated_1.tsv"))
## Add which dataset each sample is part of
sampleAnnot$dataset <- sampleAnnot$Instrument
sampleAnnot$dataset[!sampleAnnot$Real_single_cell &
                        sampleAnnot$Instrument == "Q-Exactive"] <- "bulk"
## Adapt variable to better match the DIANN output data
sampleAnnot$Label <- as.character(sampleAnnot$Label)
timsPath <- make.names("F:\\JD\\plexDIA\\Bruker\\OneDrive_1_3-9-2022\\")
qePath <- make.names("F:\\JD\\plexDIA\\nPOP\\")
sampleAnnot$File.Name <- ifelse(sampleAnnot$Instrument == "timsTOFSCP",
                                paste0(timsPath, sampleAnnot$Raw, ".d"),
                                paste0(qePath, sampleAnnot$Raw, ".raw"))

## Bulk data

## cf https://drive.google.com/drive/folders/1yRzuIXnMbt-_8_skOgiVkJksqc20RoLK

# We load the DIA-NN main output table and the MS1 extracted report table.
# These are read and combined in a `QFeatures`object.
extractedDataBulk <- read.delim(paste0(datadir, "qe_bulk/Report.pr_matrix_channels_ms1_extracted.tsv"))
reportDataBulk <- read.delim(paste0(datadir, "qe_bulk/Report.tsv"))
reportDataBulk$File.Name <- make.names(reportDataBulk$File.Name)
bulk <- readSCPfromDIANN(colData = sampleAnnot,
                         reportData = reportDataBulk,
                         extractedData = extractedDataBulk,
                         multiplexing = "mTRAQ")
## Rename the MS1Extracted assay
names(bulk)[length(bulk)] <- "bulk_prec_extracted"

## Load timsTOF-SCP data

## cf https://drive.google.com/drive/folders/1RosRkMdYfhbQ-XtUNKly0TdCrZrUQVmO

# We load the DIA-NN main output table and the MS1 extracted report table.
# These are read and combined in a `QFeatures`object.
extractedDataTims <- read.delim(paste0(datadir, "tims_sc/Report.pr_matrix_channels_ms1_extracted.tsv"))
reportDataTims <- read.delim(paste0(datadir, "tims_sc/Report.tsv"))
reportDataTims$File.Name <- make.names(reportDataTims$File.Name)
# We modify the `Run` variable to match the `Run` variables in the other tables
reportDataTims$Run <- make.names(reportDataTims$Run)
tims <- readSCPfromDIANN(colData = sampleAnnot,
                         reportData = reportDataTims,
                         extractedData = extractedDataTims,
                         multiplexing = "mTRAQ")
names(tims)[length(tims)] <- "tims_prec_extracted"

## Load Q-Exactive data

## cf https://drive.google.com/drive/folders/1b_pavZ2sufR3oYBy2z9fVepCRDKXGvyF

# We load the DIA-NN main output table and the MS1 extracted report table.
# These are read and combined in a `QFeatures`object.
extractedDataQE <- read.delim(paste0(datadir, "qe_sc/Report.pr_matrix_channels_ms1_extracted.tsv"))
reportDataQE <- read.delim(paste0(datadir, "qe_sc/Report.tsv"))
reportDataQE$File.Name <- make.names(reportDataQE$File.Name)
qe <- readSCPfromDIANN(colData = sampleAnnot,
                       reportData = reportDataQE,
                       extractedData = extractedDataQE,
                       multiplexing = "mTRAQ")
names(qe)[length(qe)] <- "qe_prec_extracted"

## Load protein data

prots <- read.delim(paste0(datadir, "Proteins_SC_IDs.txt"))
prots <- readSingleCellExperiment(prots, fname = "prot",
                                  ecol = grep("id", colnames(prots)))
## sample id order fixed.
orderedAnnot <- sampleAnnot[match(colnames(prots), sampleAnnot$id), ]

colData(prots) <- DataFrame(orderedAnnot)
colnames(prots) <- paste0(prots$File.Name, ".", prots$Label)

## Combine all datasets
derks2022 <- c(bulk, tims, qe)
derks2022 <- addAssay(derks2022, prots, name = "proteins")
derks2022 <- addAssayLink(derks2022,
                          from = grep("extracted$", names(derks2022)),
                          to = "proteins",
                          varFrom = rep("Protein.Group", 3),
                          varTo = "prot")

## Save data
save(derks2022,
     file = "~/PhD/.localdata/scpdata/derks2022.Rda",
     compress = "xz",
     compression_level = 9)

####---- Zhu et al. 2018, Nature Communications - HeLa lysates ----####

## Zhu, Ying, Paul D. Piehowski, Rui Zhao, Jing Chen, Yufeng Shen, Ronald J. 
## Moore, Anil K. Shukla, et al. 2018. “Nanodroplet Processing Platform for Deep 
## and Quantitative Proteome Profiling of 10-100 Mammalian Cells.” Nature 
## Communications 9 (1): 882.

library(SingleCellExperiment)
library(scp)
library(tidyverse)
dataDir <- "~/PhD/.localdata/SCP/zhu2018NC_lysates/"

## The data was downloaded from ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/01/PXD006847

####---- Peptide data ----####

## Load the quantification data
peps <- read.table(paste0(dataDir, "Vail_Prep_Vail_peptides.txt"),
                   sep = "\t", header = TRUE)
peps <- readSingleCellExperiment(peps,
                                 ecol = grep("^Intensity.", colnames(peps)),
                                 fnames = "Sequence")
colnames(peps) <- gsub("Intensity.", "", colnames(peps))

####---- Sample annotations ----####

## Create the sample annotation table
annot <- DataFrame(row.names = colnames(peps))
annot$CellEquivalent <- sub("^([0-9]*)HeLa.*$", "\\1", rownames(annot))
annot$Replicate <- sub("^.*([0-9])$", "\\1", rownames(annot))
annot$Digestion <- sub("^.*HeLa_(.*)_08.*$", "\\1", rownames(annot))
annot$Date <- as.Date(sub("^.*p_(.*)_.$", "\\1", rownames(annot)), "%d%m%y")

####---- Protein data ----####

## Load the quantification data
prots <- read.table(paste0(dataDir, "Vail_Prep_Vail_proteinGroups.txt"),
                    sep = "\t", header = TRUE)
## Remove unnecessary columns
sel <- !grepl("Peptides.*HeLa|^Identif|^Razor.*HeLa|Sequence.*HeLa|Unique.*HeLa|MS.MS.*HeLa",
              colnames(prots))
prots <- prots[, sel]
## Split protein data based on the quantification method:
## 1. Protein intensity
protsInt <- prots[, !grepl("^iBAQ|^LFQ", colnames(prots))]
protsInt <- readSingleCellExperiment(protsInt, 
                                     ecol = grep("^Intensity.", colnames(protsInt)),
                                     fnames = "Protein.IDs")
colnames(protsInt) <- gsub("Intensity.", "", colnames(protsInt))
## 2. LFQ
protsLFQ <- prots[, !grepl("^iBAQ|^Intensity", colnames(prots))]
protsLFQ <- readSingleCellExperiment(protsLFQ, 
                                     ecol = grep("^LFQ.", colnames(protsLFQ)),
                                     fnames = "Protein.IDs")
colnames(protsLFQ) <- gsub("LFQ.intensity.", "", colnames(protsLFQ))
## 3. iBAQ
protsIBAQ <- prots[, !grepl("^LFQ|^Intensity", colnames(prots))]
protsIBAQ <- readSingleCellExperiment(protsIBAQ, 
                                      ecol = grep("^iBAQ.", colnames(protsIBAQ)),
                                      fnames = "Protein.IDs")
colnames(protsIBAQ) <- gsub("iBAQ.", "", colnames(protsIBAQ))

####---- Create the QFeatures object ----####

el <- ExperimentList(peptides = peps,
                     proteins_intensity = protsInt,
                     proteins_LFQ = protsLFQ,
                     proteins_iBAQ = protsIBAQ)
zhu2018NC_lysates <- QFeatures(el, colData = annot)

## Create assay links
zhu2018NC_lysates <- addAssayLink(zhu2018NC_lysates, 
                                  from = "peptides", to = "proteins_intensity",
                                  varFrom = "Leading.razor.protein", 
                                  varTo = "Majority.protein.IDs")
zhu2018NC_lysates <- addAssayLink(zhu2018NC_lysates, 
                                  from = "peptides", to = "proteins_LFQ",
                                  varFrom = "Leading.razor.protein", 
                                  varTo = "Majority.protein.IDs")
zhu2018NC_lysates <- addAssayLink(zhu2018NC_lysates, 
                                  from = "peptides", to = "proteins_iBAQ",
                                  varFrom = "Leading.razor.protein", 
                                  varTo = "Majority.protein.IDs")

# Save data as Rda file
save(zhu2018NC_lysates, 
     file = file.path("~/PhD/.localdata/scpdata/zhu2018NC_lysates.Rda"),
     compress = "xz", 
     compression_level = 9)

####---- Williams et al. 2020 ---####


## Williams, Sarah M., Andrey V. Liyu, Chia-Feng Tsai, Ronald J. Moore,
## Daniel J. Orton, William B. Chrisler, Matthew J. Gaffrey, et al. 
## 2020. “Automated Coupling of Nanodroplet Sample Preparation with
## Liquid Chromatography-Mass Spectrometry for High-Throughput 
## Single-Cell Proteomics.” Analytical Chemistry 92 (15): 10588–96.

## The data was downloaded from the MASSIVE repo: MSV000085230. 

## This script formats the TMT dataset with AML single cells

library(SingleCellExperiment)
library(scp)
library(tidyverse)
dataDir <-"~/PhD/.localdata/SCP/williams2020/"

####---- Load peptide data ----####

f <- list.files(dataDir, pattern = "Peptides_AML_SingleCell.txt", 
                recursive = TRUE, full.names = TRUE)
peps <- read.delim(f)
## Remove unnecessary columns
peps <- peps[, !grepl("count|^Inten|[yd].\\d*$", colnames(peps))]
## Get RI intensities
pepsIntensity <- peps[, !grepl("corrected", colnames(peps))]
pepsIntensity <- readSingleCellExperiment(pepsIntensity,
                                          ecol = grep("^Repo.*intensity.", colnames(pepsIntensity)),
                                          fnames = "Sequence")
colnames(pepsIntensity) <- gsub("Rep.*intensity.", "", colnames(pepsIntensity))
## Get corrected RI intensities
pepsCorrected <- peps[, !grepl("intensity.\\d", colnames(peps))]
pepsCorrected <- readSingleCellExperiment(pepsCorrected,
                                          ecol = grep("^Repo.*intensity.", colnames(pepsCorrected)),
                                          fnames = "Sequence")
colnames(pepsCorrected) <- gsub("Rep.*corrected.", "", colnames(pepsCorrected))

####---- Load protein data ----####

f <- list.files(dataDir, pattern = "ProteinGroups_AML_SingleCell.txt", 
                recursive = TRUE, full.names = TRUE)
prots <- read.delim(f)
## Remove unnecessary columns
prots <- prots[, !grepl("nique.peptides.|^Peptides.[A-C]|^Identif|^Intensity.|y.count|Sequence.coverage", colnames(prots))]
## Get RI intensities
protsIntensity <- prots[, !grepl("corrected", colnames(prots))]
protsIntensity <- readSingleCellExperiment(protsIntensity,
                                           ecol = grep("^Repo.*intensity.", colnames(protsIntensity)),
                                           fnames = "Protein.IDs")
colnames(protsIntensity) <- gsub("Rep.*intensity.", "", colnames(protsIntensity))
## Get corrected RI intensities
protsCorrected <- prots[, !grepl("intensity.\\d", colnames(prots))]
protsCorrected <- readSingleCellExperiment(protsCorrected,
                                           ecol = grep("^Repo.*intensity.", colnames(protsCorrected)),
                                           fnames = "Protein.IDs")
colnames(protsCorrected) <- gsub("Rep.*corrected.", "", colnames(protsCorrected))

####---- Load sample annotations ----####

f <- list.files(dataDir, pattern = "TMT_Labelling.txt", 
                recursive = TRUE, full.names = TRUE)
annot <- read.table(f, sep = ":", header = FALSE)
colnames(annot) <- c("Channel", "SampleType")
annot$ChannelIndex <- rownames(annot)
## Add sample amounts (from table S2)
annot$Amount <- c("10ng", "0.2ng", "0", rep("1cell", 8))
## Match sample names
runs <- unique(sub("^\\d*[.]?", "", colnames(pepsIntensity)))
annot <- lapply(runs, function(run) {
    rownames(annot) <- paste0(annot$ChannelIndex, ".", run)
    annot
})
annot <- DataFrame(do.call(rbind, annot))
annot$Batch <- sub("^\\d*.", "", rownames(annot))

####---- Create the QFeatures object ----####

el <- ExperimentList(peptides_intensity = pepsIntensity,
                     peptides_corrected = pepsCorrected,
                     proteins_intensity = protsIntensity,
                     proteins_corrected = protsCorrected)
williams2020_tmt <- QFeatures(el, colData = annot)

## Create assay links
williams2020_tmt <- addAssayLink(williams2020_tmt, 
                             from = "peptides_intensity", 
                             to = "proteins_intensity",
                             varFrom = "Leading.razor.protein", 
                             varTo = "Majority.protein.IDs")
williams2020_tmt <- addAssayLink(williams2020_tmt, 
                             from = "peptides_corrected", 
                             to = "proteins_corrected",
                             varFrom = "Leading.razor.protein", 
                             varTo = "Majority.protein.IDs")

### Save data as Rda file
## Note: saving is assumed to occur in "scpdata/inst/scripts"
save(williams2020_tmt, 
     file = file.path("~/PhD/.localdata/scpdata/williams2020_tmt.Rda"),
     compress = "xz", 
     compression_level = 9)

##' Cong et al. 2020 (Ana. Chem.): HeLa single cells
##'
##' Single-cell proteomics using the nanoPOTS sample processing device
##' in combination with ultranarrow-bore (20um i.d.) packed-column LC
##' separations and the Orbitrap Eclipse Tribrid MS. The dataset
##' contains label-free quantitative information at PSM, peptide and
##' protein level. The samples are single Hela cells. Bulk samples
##' (100 and 20 cells) were also included in the experiment to
##' increase the idendtification rate thanks to between-run matching
##' (cf MaxQuant).
##'
##' @format A [QFeatures] object with 9 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - `100/20 HeLa cells`: 2 assays containing PSM data for a bulk
##'   of 100 or 20 HeLa cells, respectively.
##' - `Blank`: assay containing the PSM data for a blank sample
##' - `Single cell X`: 4 assays containing PSM data for a single cell.
##'   The `X` indicates the replicate number.
##' - `peptides`: quantitative data for 12590 peptides in 7 samples
##'   (all runs combined).
##' - `proteins`: quantitative data for 1801 proteins in 7 samples
##'   (all runs combined).
##'
##' Sample annotation is stored in `colData(cong2020AC())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: The HeLa cells were diluted and aspired
##'   using a microcapillary with a pulled tip.
##' - **Sample preparation** performed using the nanoPOTs device.
##'   Protein extraction using RapiGest (+ DTT) + alkylation (IAA) +
##'   Lys-C digestion + cleave RapiGest (formic acid)
##' - **Separation**: UltiMate 3000 RSLCnano pump with a home-packed
##'   nanoLC column (60cm x 20um i.d.; approx. 20 nL/min)
##' - **Ionization**: ESI (2,000V; Nanospray Flex)
##' - **Mass spectrometry**: Thermo Fisher Orbitrap Fusion Eclipse.
##'   MS1 settings: accumulation time = 246ms; resolution = 120,000;
##'   AGC = 1E6. MS/MS settings depend on quantity. All: AGC = 1E5.
##'   20-100 cels: accumulation time = 246ms; resolution = 120,000.
##'   Single cells: accumulation time = 500ms; resolution = 240,000.
##' - **Data analysis**: MaxQuant (v1.6.3.3) + Excel
##'
##' @section Data collection:
##'
##' The PSM, peptide and protein data were collected from the PRIDE
##' repository (accession ID: PXD016921).  We downloaded the
##' `evidence.txt` file containing the PSM identification and
##' quantification results. The sample annotation was inferred from
##' the samples names. The data were then converted to a [QFeatures]
##' object using the [scp::readSCP()] function.
##'
##' The peptide data were processed similarly from the `peptides.txt`
##' file. The quantitative column names were adpated to match the PSM
##' data. The peptide data were added to [QFeatures] object and link
##' between the features were stored.
##'
##' The protein data were similarly processed from the
##' `proteinGroups.txt` file. The quantitative column names were
##' adapted to match the PSM data. The peptide data were added to
##' [QFeatures] object and link between the features were stored.
##'
##' @source
##' All files can be downloaded from the PRIDE repository PXD016921.
##' The source link is:
##' ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2020/02/PXD016921
##'
##' @references
##'
##' Cong, Yongzheng, Yiran Liang, Khatereh Motamedchaboki, Romain
##' Huguet, Thy Truong, Rui Zhao, Yufeng Shen, Daniel Lopez-Ferrer,
##' Ying Zhu, and Ryan T. Kelly. 2020. “Improved Single-Cell Proteome
##' Coverage Using Narrow-Bore Packed NanoLC Columns and
##' Ultrasensitive Mass Spectrometry.” Analytical Chemistry, January.
##' ([link to article](https://doi.org/10.1021/acs.analchem.9b04631)).
##'
##' @examples
##' \donttest{
##' cong2020AC()
##' }
##'
##' @keywords datasets
##'
"cong2020AC"

####---- Specht et al. 2019 ---####


## Specht, Harrison, Edward Emmott, Toni Koller, and Nikolai Slavov. 2019. 
## “High-Throughput Single-Cell Proteomics Quantifies the Emergence of Macrophage 
## Heterogeneity.” bioRxiv. https://doi.org/10.1101/665307.

## NOTE: the script is version 2 because the data set was updated by the authors

library(SingleCellExperiment)
library(scp)
library(tidyverse)
setwd("../.localdata/SCP/specht2019/v3/")

####---- Load PSM data ----####

## The `raw.RData` files was downloaded from 
## https://drive.google.com/drive/folders/1Zhjik_JFjCQNIVjg63-fooJ4K0HZxWjV
## It contains 3 datasets
## ev = the MaxQuant output file for all batches with the PSM data
## design = the cell annotation
## batch = the batch annotation 
load("raw.RData")

## Clean the sample metadata so that it meets the requirements for
## `scp::readSCP`. The cell annotation and batch annotation are merge into a 
## table
inner_join(x = design %>% 
               pivot_longer(-Set, 
                            names_to = "Channel", 
                            values_to = "SampleAnnotation") %>%
               mutate(SampleType = recode(SampleAnnotation, 
                                          sc_0 = "Blank",
                                          sc_u = "Monocyte",
                                          sc_m0 = "Macrophage",
                                          unused = "Unused",
                                          norm = "Reference",
                                          reference = "Reference",
                                          carrier_mix = "Carrier")), 
           y = batch %>% 
               rename(Set = set) %>%
               mutate_all(as.character),
           by = "Set") %>%
    mutate(Set = sub("^X", "", Set)) ->
    meta

## Clean quantitative data
ev %>%
    ## Variable names should be consistent with metadata
    rename_all(gsub, 
               pattern = "^Reporter[.]intensity[.](\\d*)$", 
               replacement = "RI\\1") %>%
    rename(Set = Raw.file, 
           protein = Leading.razor.protein) %>%
    ## Remove "X" at start of batch 
    mutate(Set = gsub("^X", "", Set),
           ## Create a modified sequence + charge variable
           peptide = paste0(Modified.sequence, Charge)) %>%
    ## keep only single cell runs 
    filter(!grepl("col\\d{2}|arrier|Ref|Master|SQC|blank", Set)) %>%
    ## remove experimental sets concurrent with low mass spec performance
    filter(!grepl("FP9[56]|FP103", Set)) %>%
    ## Make sure all runs are described in design, if not, remove them
    filter(Set %in% meta$Set) ->
    evproc


## Create the QFeatures object
specht2019v3 <- readSCP(evproc, 
                        meta, 
                        channelCol = "Channel", 
                        batchCol = "Set",
                        removeEmptyCols = TRUE)

####---- Get the SCoPE2 annotation table ----####

## The protein and peptide data contain features by single-cells. The 
## columns are named after an arbitrary indexing that must be 
## converted before adding the assay to the QFeatures object to 
## preserve consistency across assays.

## The `Cells.csv` file was downloaded from 
## https://scope2.slavovlab.net/docs/data and contains the cell IDs 
## and annotations. Some processing is preserve consistency with the 
## PSM data.
read.csv("Cells.csv", 
         row.names = 1) %>%
    t %>%
    as.data.frame %>%
    rownames_to_column("id") %>%
    rename(Set = raw.file, 
           SampleAnnotation = celltype, 
           digest = batch_digest, 
           sortday = batch_sort, 
           lcbatch = batch_chromatography) %>%
    mutate(Channel = NA, 
           Set = sub("^X", "", Set),
           SampleType = recode(SampleAnnotation, 
                               sc_0 = "Blank",
                               sc_u = "Monocyte",
                               sc_m0 = "Macrophage",
                               unused = "Unused",
                               norm = "Reference",
                               reference = "Reference",
                               carrier_mix = "Carrier")) %>%
    column_to_rownames("id") %>%
    as("DataFrame") ->
    annot
## The `IDtoChannel.csv` file was generated using the `SCoPE2_analysis.R`
## script from https://github.com/cvanderaa/SCoPE2/tree/master/code.
## The csv contains the data of the `c2q` variable that maps the cell
## id to the RI channel
read.csv("IDtoChannel.csv", )[, -1] %>%
    filter(celltype %in% rownames(annot)) %>%
    mutate(channel = sub("Reporter[.]intensity[.]", "RI", channel)) ->
    idMap
## Add channel info 
annot[idMap$celltype, "Channel"] <- idMap$channel


####---- Add the peptide data ----####


## The `Peptides-raw.csv` file was downloaded from 
## https://scope2.slavovlab.net/docs/data 
pep <- readSingleCellExperiment("Peptides-raw.csv", 
                                ecol = -c(1,2), 
                                fnames = "peptide")
colData(pep) <- annot[colnames(pep), ]
colnames(pep) <- paste0(annot[colnames(pep), "Set"],  annot[colnames(pep), "Channel"])
## Include the peptide data in the QFeatures object
specht2019v3 <- addAssay(specht2019v3, pep, name = "peptides")

## Link the PSMs and the peptides
## First find which PSM assays were included
sel <- sapply(grep("19", names(specht2019v3), value = TRUE), function(name) {
    x <- specht2019v3[[name]]
    ## Does the current PSM data have at least 1 colname in common with pep?
    inColnames <- any(colnames(x) %in% colnames(pep))
    ## Does the current PSM data have at least 1 peptide sequence in common with pep?
    inSequence <- any(rowData(x)$peptide %in% rowData(pep)$peptide)
    return(inColnames && inSequence) ## The PSM assay must fulfill both conditions
})
## Add an AssayLink that bridges the PSM assays and the peptide assay
specht2019v3 <- addAssayLink(specht2019v3, from = which(sel), to = "peptides", 
                             varFrom = rep("peptide", sum(sel)), varTo = "peptide")

####---- Add the protein data ----####

## The `Proteins-processed.csv` and `Cells.csv` file was downloaded from 
## https://scope2.slavovlab.net/docs/data
read.csv("Proteins-processed.csv") %>%
    select(-X) %>%
    readSingleCellExperiment(ecol = 1:1490, fnames = "protein") ->
    prot
colData(prot) <- annot[colnames(prot), ]
colnames(prot) <- paste0(annot[colnames(prot), "Set"],  
                         annot[colnames(prot), "Channel"])
specht2019v3 <- addAssay(specht2019v3, prot, name = "proteins")
specht2019v3 <- addAssayLink(specht2019v3, from = "peptides", to = "proteins", 
                             varFrom = "protein", varTo = "protein")

## Save data
save(specht2019v3,
     file = file.path("~/PhD/.localdata/scpdata/specht2019v3.Rda"),
     compress = "xz", 
     compression_level = 9)

####---- Schoof et al. 2021 ---####


## Schoof, Erwin M., Benjamin Furtwängler, Nil Üresin, Nicolas Rapin,
## Simonas Savickas, Coline Gentil, Eric Lechman, Ulrich auf Dem 
## Keller, John E. Dick, and Bo T. Porse. 2021. “Quantitative 
## Single-Cell Proteomics as a Tool to Characterize Cellular 
## Hierarchies.” Nature Communications 12 (1): 745679.

library(SingleCellExperiment)
library(scp)
library(tidyverse)

## The data files were retrieved from the `SCeptre_FINAL.zip` file 
## provided in the PRIDE repository PXD020586
## https://www.ebi.ac.uk/pride/archive/projects/PXD020586
## We unziped the file and retrieved the data folder located at 
## `SCeptre/Schoof_et_al/data` (here renamed`.../schoof2021/`)

dataDir <- "~/PhD/.localdata/SCP/schoof2021/bulk/"
dataDir <- "~/PhD/tmp/SCeptre/Schoof_et_al/data/bulk/"
## Load protein data (to get sample names)
list.files(path = dataDir, pattern = "Proteins.txt", full.names = TRUE) %>% 
    read.table(header = TRUE, sep = "\t") ->
    prot


####---- Create sample annotation ----####

## Extract annotations from the sample names
data.frame(Colname = colnames(prot)) %>%
    filter(grepl("^Abundances",  Colname)) %>%
    mutate(File.ID = sub("^.*(F[0-9]*)[.].*$", "\\1", Colname),
           Channel = sub("^.*[.](.*)$", "\\1", Colname)) %>%
    select(-Colname) ->
    meta

## Get the ProteomeDiscoverer metadata
list.files(path = dataDir, pattern = "InputFiles.txt", full.names = TRUE) %>%
    read.table(header = TRUE, 
               sep = "\t") %>%
    mutate(File.Name = sub("^.*[\\](.*)$",  "\\1",  File.Name)) ->
    pdData
## Add to the metadata table
meta <- left_join(meta, pdData, by = "File.ID")

## Get the file to plate mapping
list.files(path = dataDir, 
           pattern = "file_sample",
           full.names = TRUE) %>% 
    read.table(header = TRUE, sep = "\t") ->
    fileMap
## Add to the metadata table
meta <- left_join(meta, fileMap, by = "File.Name")

## Get the plate to layouts mappings
list.files(path = dataDir, pattern = "plate_layout", full.names = TRUE) %>% 
    read.table(header = TRUE, sep = "\t") ->
    plateLayouts

## Get the sample labelling layouts
lapply(list.files(path = dataDir, pattern = "sample_layout"), 
       function(file) {
           df <- read.table(paste0(dataDir, file), header = TRUE, sep = "\t",
                            check.names = FALSE)
           colnames(df)[1] <- "Row"
           df <- pivot_longer(df, -Row, names_to = "Col", values_to = "Sample")
           df$Sample.Layout <- file
           df
       }) %>% 
    do.call(what = rbind) ->
    sampleLayouts
## Add to the plate data
plateLayouts <- merge(plateLayouts, sampleLayouts, by = "Sample.Layout")

## Get the sample sorting layouts
lapply(list.files(path = dataDir, pattern = "sort_layout"), 
       function(file) {
           df <- read.table(paste0(dataDir, file), header = TRUE, sep = "\t",
                            check.names = FALSE)
           colnames(df)[1] <- "Row"
           df <- pivot_longer(df, -Row, names_to = "Col", values_to = "SortedPopulation")
           df$Sort.Layout <- file
           df
       }) %>% 
    do.call(what = rbind) ->
    sortLayouts
## Add to the plate data
plateLayouts <- merge(plateLayouts, sortLayouts, by = c("Row", "Col", "Sort.Layout"))

## Get the sample labelling layouts
lapply(list.files(path = dataDir, pattern = "label_layout"), 
       function(file) {
           df <- read.table(paste0(dataDir, file), header = TRUE, sep = "\t",
                            check.names = FALSE)
           colnames(df)[1] <- "Row"
           df <- pivot_longer(df, -Row, names_to = "Col", values_to = "Channel")
           df$Channel[df$Channel == ""] <- NA
           df$Label.Layout <- file
           df
       }) %>% 
    do.call(what = rbind) ->
    labelLayouts
## Add to the plate data
plateLayouts <- merge(plateLayouts, labelLayouts, by = c("Row", "Col", "Label.Layout"))

## Get the FACS data and combine in a single table
lapply(list.files(path = dataDir, pattern = "facs"), 
       function(file) {
           df <- read.table(paste0(dataDir, file), header = TRUE, sep = "\t")   
           df$Facs.Data <- file
           df
       }) %>% 
    do.call(what = rbind) %>%
    select(-Row, -Column) %>% 
    dplyr::rename(CD34_APC.Cy7.A = APC.Cy7.A,
                  CD38_PE.A = PE.A) ->
    facsData
## Add to the plate data
plateLayouts$Well <- paste0(plateLayouts$Row, plateLayouts$Col)
plateLayouts <- merge(plateLayouts, facsData, by = c("Well", "Facs.Data"))

## Add all the layouts to the metadata table
## Note we here use left_join because some Sample are NA, but we still
## want to keep them. 
meta <- left_join(meta, plateLayouts, by = c("Channel", "Plate", "Sample"))

## Add further info retrieved from the article
meta$SampleType <- "empty"
meta$SampleType[meta$Channel == "126" & grepl("bulk_c", meta$Plate)] <- "booster_1:1:1"
meta$SampleType[meta$Channel == "126" & !grepl("bulk_c", meta$Plate)] <- "booster_bulk"
meta$SampleType[meta$Channel == "127N"] <- "norm"
meta$SampleType[meta$SortedPopulation == "BULK"] <- "sc"
meta$SampleType <- ifelse(meta$SampleType == "empty" & meta$Channel != "127C",
                          "neg control", meta$SampleType)
meta$nbCells <- 0
meta$nbCells[meta$SampleType == "sc"] <- 1
meta$nbCells[meta$SampleType == "norm"] <- 10
meta$nbCells[meta$SampleType == "booster"] <- 200

## Data cleaning
## Some columns are converted to factors
meta$Col <- factor(meta$Col, levels = 1:24)
meta$File.ID <- factor(meta$File.ID, levels = paste0("F", 1:192))
channelOrder <- c("126", "127N", "127C", "128N", "128C", "129N", "129C",
                  "130N", "130C", "131N", "131C", "132N", "132C", "133N",
                  "133C", "134N")
meta$Channel <- factor(meta$Channel, levels = channelOrder)


####---- PSM data ----####

## Load the PSM quantitative data
list.files(path = dataDir, pattern = "PSMs.txt", full.names = TRUE) %>%
    read.table(header = TRUE, sep = "\t") %>%
    ## Rename columns with the TMT label names only
    setNames(gsub("Abundance.", "", colnames(.))) ->
    psms

## Include contaminant info
cont <- read.table(paste0(dataDir, "../contaminants.txt"), header = TRUE)   
psms$isContaminant <- sapply(psms$Master.Protein.Accessions, 
                             function(x) any(strsplit(x, "; ")[[1]] %in% cont$Accession))

## Create the QFeatures object 
schoof2021 <- readSCP(featureData = psms,
                      colData = meta, 
                      batchCol = "File.ID",
                      channelCol = "Channel")


####---- Protein data ----####


## The protein data was loaded at the start of the script as `prot`
## Adapt column names so they match with PSM data
colnames(prot) %>%
    sub(pattern = "Abundances.Grouped.", replacement = "") %>%
    sub(pattern = "[.]", replacement = "") ->
    colnames(prot)

## Remove unnecessary columns
prot <- prot[, !grepl("^Foundin", colnames(prot))]

## Create protein rownames as in SCeptre, that is use the gene symbol,
## use the accession if there is no gene symbol and append the accession
## for duplicated gene symbols
rown <- prot$GeneSymbol
isEmpty <- which(rown == "")
rown[isEmpty] <- prot$Accession[isEmpty]
isDupl <- rown %in% rown[duplicated(rown)]
rown[isDupl] <- paste0(prot$GeneSymbol[isDupl], "_", prot$Accession[isDupl])
prot$rowname <- rown

## Include contaminant info
prot$isContaminant <- prot$Accession %in% cont$Accession

## Convert the protein data to a SCE object
prot <- readSingleCellExperiment(prot, 
                                 ecol = grep("^F\\d", colnames(prot)),
                                 fnames = "rowname")

## Add protein data to the QFeatures
schoof2021 <- addAssay(schoof2021, 
                       prot, 
                       name = "proteins")
## NOTE: could not map psms to proteins because some psms have multiple
## associated proteins (`Master.Protein.Accessions`). This is not yet
## supported in `QFeatures`.


####---- Processed protein data ----####


## We also include the protein data that has been processed by the 
## authors. These data are available from the ZIP file distributed by
## the others and is called `SCeptre/Schoof_et_al/results/bulk/bulk.h5ad`.
## Another way to retrieve this data is to run the notebook
## `SCeptre/Schoof_et_al/results/bulk/bulk.h5ad`. 

## The datasets provided by the authors is loaded from Python using 
## the reticulate interface
library(reticulate)
## To make this work, you need to install the sceptre conda 
## environment as recommended by the author's Github page, see 
## https://github.com/bfurtwa/SCeptre#installation-from-github,
## and activate the environment on the system. Once active, you can 
## call `use_condaenv`.
use_condaenv("sceptre")
dataDir <- normalizePath(dataDir)
py_run_string("
import scanpy
adata = scanpy.read_h5ad(r.dataDir + '/../../results/bulk/bulk.h5ad')
              ")
## The dataset is converted to a SingleCellExperiment object
library(zellkonverter)
logNormProt <- AnnData2SCE(py$adata)

## We match the sample names and proteins
colnames(logNormProt) <- paste0(logNormProt$`File ID`, logNormProt$Channel)

## Keep only the colData columns specific to logNormProt
sel <- c("leiden", "Root Cell", "dpt_pseudotime", "Cluster 5", 
         "Cluster 3", "Cluster 4", "Cluster 2", "Cluster 1")
colData(logNormProt) <- colData(logNormProt)[, sel]

## Insert the data in the `QFeatures` object
schoof2021 <- addAssay(schoof2021, 
                       logNormProt, 
                       name = "logNormProteins")
schoof2021 <- addAssayLink(schoof2021, 
                           from = "proteins",
                           to = "logNormProteins",
                           varFrom = "Accession",
                           varTo = "Accession")


####---- Save dataset ----####


## Save the `QFeatures` object in an Rda file that will be uploaded to
## ExperimentHub
save(schoof2021,
     compress = "xz", 
     compression_level = 9,
     file = "~/PhD/.localdata/scpdata/schoof2021.Rda")

####---- Guise et al. 2024 ---####


## Guise, Amanda J., Santosh A. Misal, Richard Carson, Jen-Hwa Chu,
## Hannah Boekweg, Daisha Van Der Watt, Nora C. Welsh, et al. 2024.
## “TDP-43-Stratified Single-Cell Proteomics of Postmortem Human
## Spinal Motor Neurons Reveals Protein Dynamics in Amyotrophic
## Lateral Sclerosis.” Cell Reports 43 (1): 113636.

## All files were downloaded from the MASSIVE repo MSV000092119

library("SingleCellExperiment")
library("scp")
library("tidyverse")
dataDir <-"~/Documents/.localData/SCP/guise2024/"

####---- Load sample annotations ----####

runInfo <- read.table(
    list.files(dataDir, "InputFiles", full.names = TRUE),
    header = TRUE, sep = "\t"
)
colAnnot <- read.table(
    list.files(dataDir, "^Groups.txt", full.names = TRUE),
    header = TRUE, sep = "\t"
)
colnames(colAnnot)[1] <- "File.ID"
colAnnot <- merge(
    colAnnot, runInfo[, c("File.ID", "File.Name", "Creation.Date")],
    by = "File.ID"
)
## Add the colum name that contains quantification columns in the PSM
## table
colAnnot$QuantCol <- "Precursor.Abundance"

####---- Load PSM data ----####

psm <- read.table(
    list.files(dataDir, "PSMs.txt", full.names = TRUE),
    header = TRUE, sep = "\t"
)
## Create QFeatures object
guise2024 <- readSCP(
    psm, colAnnot, batchCol = "File.ID", channelCol = "QuantCol",
    suffix = "", sep = ""
)
## Warning: Missing metadata. The features are removed for F61, F34,
## F42, F88, F77, F8, F21, F5

####---- Load peptide data ----####

pep <- read.table(
    list.files(dataDir, "PeptideG", full.names = TRUE),
    header = TRUE, sep = "\t"
)
pep <- readSingleCellExperiment(
    pep, ecol = grep("^Abundances..Grouped...F", colnames(pep)),
    fnames = "Peptide.Groups.Peptide.Group.ID"
)
## Adapt the column names to match those in the QFeatuers object
colnames(pep) <- sub("^Ab.*(F\\d+).*$", "\\1", colnames(pep))
## Add to QFeatures
guise2024 <- addAssay(guise2024, pep, "peptides")
## NOTE: could not map psms to peptides because I could not find a
## variable that uniquely maps the two levels.

####---- Load protein data ----####

prot <- read.table(
    list.files(dataDir, "Proteins.txt", full.names = TRUE),
    header = TRUE, sep = "\t"
)
prot <- readSingleCellExperiment(
    prot, ecol = grep("^Abundance..F", colnames(prot)),
    fnames = "Accession"
)
## Adapt the column names to match those in the QFeatuers object
colnames(prot) <- sub("^Ab.*(F\\d+).*$", "\\1", colnames(prot))
## Add to QFeatures
guise2024 <- addAssay(guise2024, prot, "proteins")
## NOTE: could not map psms to proteins because some psms have multiple
## associated proteins (`Master.Protein.Accessions`). This is not yet
## supported in `QFeatures`.

####---- Save dataset ----####


## Save the `QFeatures` object in an Rda file that will be uploaded to
## ExperimentHub
save(guise2024,
     compress = "xz",
     compression_level = 9,
     file = "~/Documents/.localData/scpdata/guise2024.rda")

##' Zhu et al. 2018 (Nat. Comm.): HeLa lysates
##'
##' Near single-cell proteomics data of HeLa lysates at different
##' concentrations (10, 40 and 140 cell equivalent). Each
##' concentration is acquired in triplicate.
##'
##' @format A [QFeatures] object with 4 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - `peptides`: quantitative information for 14,921 peptides from
##'   9 lysate samples
##' - `proteins_intensity`: quantitative information for 2,199
##'   proteins from 9 lysate samples
##' - `proteins_LFQ`: LFQ intensities for 2,199 proteins from 9 lysate
##'   samples
##' - `proteins_iBAQ`: iBAQ values for 2,199 proteins from 9 lysate
##'   samples
##'
##' Sample annotation is stored in `colData(zhu2018NC_lysates())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the original article (see `References`).
##'
##' - **Cell isolation**: HeLas were collected from cell cultures.
##' - **Sample preparation** performed in bulk (5E5 cells/mL). Protein
##'   extraction using RapiGest (+ DTT) + dilution to target
##'   concentration + alkylation (IAA) + Lys-C digestion + trypsin
##'   digestion + cleave RapiGest (formic acid).
##' - **Separation**: nanoACQUITY UPLC pump (60nL/min) with an
##'   Self-Pack PicoFrit 70cm x 30um LC columns.
##' - **Ionization**: ESI (1,900V).
##' - **Mass spectrometry**: Thermo Fisher Orbitrap Fusion Lumos
##'   Tribrid. MS1 settings: accumulation time = 246ms; resolution =
##'   120,000; AGC = 1E6. MS/MS settings, depend on the sample size,
##'   excepted for the AGC = 1E5. Blank and approx. 10 cells (time = 502ms;
##'   resolution = 240,000), approx. 40 cells (time = 246ms; resolution =
##'   120,000), approx. 140 cells (time = 118ms; resolution = 60,000).
##' - **Data analysis**: MaxQuant (v1.5.3.30) + Perseus + OriginLab
##'   2017.
##'
##' @section Data collection:
##'
##' The data were collected from the PRIDE repository (accession
##' ID: PXD006847).  We downloaded the `Vail_Prep_Vail_peptides.txt`
##' and the `Vail_Prep_Vail_proteinGroups.txt` files containing the
##' combined identification and quantification
##' results. The sample annotations were inferred from the names of
##' columns holding the quantification data and the information in the
##' article. The peptides data were converted to a [SingleCellExperiment]
##' object. We split the protein table to separate the three types of
##' quantification: protein intensity, label-free quantitification
##' (LFQ) and intensity based absolute quantification (iBAQ). Each
##' table is converted to a [SingleCellExperiment] object along with
##' the remaining protein annotations. The 4 objects are combined in
##' a single [QFeatures] object and feature links are created based on
##' the peptide leading razor protein ID and the protein ID.
##'
##' @source
##' The PSM data can be downloaded from the PRIDE repository
##' PXD006847. The source link is:
##' ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/01/PXD006847
##'
##' @references
##'
##' Zhu, Ying, Paul D. Piehowski, Rui Zhao, Jing Chen, Yufeng Shen,
##' Ronald J. Moore, Anil K. Shukla, et al. 2018. “Nanodroplet
##' Processing Platform for Deep and Quantitative Proteome Profiling
##' of 10-100 Mammalian Cells.” Nature Communications 9 (1): 882
##' ([link to article](http://dx.doi.org/10.1038/s41467-018-03367-w)).
##'
##' @seealso The same experiment was conducted directly on HeLa cells
##' samples rather than lysates. The data is available in
##' [zhu2018NC_hela].
##'
##' @examples
##' \donttest{
##' zhu2018NC_lysates()
##' }
##'
##' @keywords datasets
##'
##'
"zhu2018NC_lysates"

####---- Williams et al. 2020 ---####


## Williams, Sarah M., Andrey V. Liyu, Chia-Feng Tsai, Ronald J. Moore,
## Daniel J. Orton, William B. Chrisler, Matthew J. Gaffrey, et al. 
## 2020. “Automated Coupling of Nanodroplet Sample Preparation with
## Liquid Chromatography-Mass Spectrometry for High-Throughput 
## Single-Cell Proteomics.” Analytical Chemistry 92 (15): 10588–96.

## The data was downloaded from the MASSIVE repo: MSV000085230. 

## This script formats the LFQ dataset with MCF10A single cells

library(SingleCellExperiment)
library(scp)
library(tidyverse)
dataDir <-"~/PhD/.localdata/SCP/williams2020/"

####---- Load peptide data ----####

## 30min batch
f <- list.files(dataDir, pattern = "Pep.*30min.txt", 
                recursive = TRUE, full.names = TRUE)
peps30 <- read.delim(f)
## Get intensities
peps30Intensity <- peps30[, !grepl("^LFQ", colnames(peps30))]
peps30Intensity <- readSingleCellExperiment(peps30Intensity,
                                            ecol = grep("^Intensity.", colnames(peps30Intensity)),
                                            fnames = "Sequence")
colnames(peps30Intensity) <- gsub("Intensity.", "", colnames(peps30Intensity))
colnames(peps30Intensity) <- paste0("30min_", colnames(peps30Intensity))
## Get LFQ normalized intensities
peps30lfq <- peps30[, !grepl("^Intensity.\\d", colnames(peps30))]
peps30lfq <- readSingleCellExperiment(peps30lfq,
                                      ecol = grep("^LFQ", colnames(peps30lfq)),
                                      fnames = "Sequence")
colnames(peps30lfq) <- gsub("LFQ.intensity.", "", colnames(peps30lfq))
colnames(peps30lfq) <- paste0("30min_", colnames(peps30lfq))

## 60min batch
f <- list.files(dataDir, pattern = "Pep.*1hr.txt", 
                recursive = TRUE, full.names = TRUE)
peps60 <- read.delim(f)
## Get intensities
peps60Intensity <- readSingleCellExperiment(peps60,
                                            ecol = grep("^Intensity.", colnames(peps60)),
                                            fnames = "Sequence")
colnames(peps60Intensity) <- gsub("Intensity.", "", colnames(peps60Intensity))
colnames(peps60Intensity) <- paste0("60min_", colnames(peps60Intensity))

####---- Load protein data ----####

## 30min batch
f <- list.files(dataDir, pattern = "Prot.*30min.txt", 
                recursive = TRUE, full.names = TRUE)
prots30 <- read.delim(f)
## Remove unnecessary columns
prots30 <- prots30[, !grepl("^Identif|^MS.MS.count|^Peptides.\\d|nique.pep|^Sequence.coverage", colnames(prots30))]
## Get intensities
prots30Intensity <- prots30[, !grepl("^iBAQ|^LFQ", colnames(prots30))]
prots30Intensity <- readSingleCellExperiment(prots30Intensity,
                                             ecol = grep("^Intensity.", colnames(prots30Intensity)),
                                             fnames = "Protein.IDs")
colnames(prots30Intensity) <- gsub("Intensity.", "", colnames(prots30Intensity))
colnames(prots30Intensity) <- paste0("30min_", colnames(prots30Intensity))
## Get iBAQ normalized intensities
prots30ibaq <- prots30[, !grepl("^Intensity.|^LFQ", colnames(prots30))]
prots30ibaq <- readSingleCellExperiment(prots30ibaq,
                                        ecol = grep("^iBAQ.", colnames(prots30ibaq)),
                                        fnames = "Protein.IDs")
colnames(prots30ibaq) <- gsub("iBAQ.", "", colnames(prots30ibaq))
colnames(prots30ibaq) <- paste0("30min_", colnames(prots30ibaq))
## Get LFQ normalized intensities
prots30lfq <- prots30[, !grepl("^Intensity.|^iBAQ", colnames(prots30))]
prots30lfq <- readSingleCellExperiment(prots30lfq,
                                        ecol = grep("^LFQ.", colnames(prots30lfq)),
                                        fnames = "Protein.IDs")
colnames(prots30lfq) <- gsub("LFQ.intensity.", "", colnames(prots30lfq))
colnames(prots30lfq) <- paste0("30min_", colnames(prots30lfq))

## 60min batch
f <- list.files(dataDir, pattern = "Prot.*1hr.txt", 
                recursive = TRUE, full.names = TRUE)
prots60 <- read.delim(f)
## Remove unnecessary columns
prots60 <- prots60[, !grepl("^Identif|^MS.MS.count|^Peptides.\\d|nique.pep|^Sequence.coverage", colnames(prots60))]
## Get intensities
prots60Intensity <- prots60[, !grepl("^iBAQ|^LFQ", colnames(prots60))]
prots60Intensity <- readSingleCellExperiment(prots60Intensity,
                                             ecol = grep("^Intensity.", colnames(prots60Intensity)),
                                             fnames = "Protein.IDs")
colnames(prots60Intensity) <- gsub("Intensity.", "", colnames(prots60Intensity))
colnames(prots60Intensity) <- paste0("60min_", colnames(prots60Intensity))
## Get iBAQ normalized intensities
prots60ibaq <- prots60[, !grepl("^Intensity.|^LFQ", colnames(prots60))]
prots60ibaq <- readSingleCellExperiment(prots60ibaq,
                                        ecol = grep("^iBAQ.", colnames(prots60ibaq)),
                                        fnames = "Protein.IDs")
colnames(prots60ibaq) <- gsub("iBAQ.", "", colnames(prots60ibaq))
colnames(prots60ibaq) <- paste0("60min_", colnames(prots60ibaq))
## Get LFQ normalized intensities
prots60lfq <- prots60[, !grepl("^Intensity.|^iBAQ", colnames(prots60))]
prots60lfq <- readSingleCellExperiment(prots60lfq,
                                       ecol = grep("^LFQ.", colnames(prots60lfq)),
                                       fnames = "Protein.IDs")
colnames(prots60lfq) <- gsub("LFQ.intensity.", "", colnames(prots60lfq))
colnames(prots60lfq) <- paste0("60min_", colnames(prots60lfq))

####---- Create sample annotations ----####

## Sample annotation are infered from the paper and the sample names
sampleNames <- unique(c(colnames(peps30Intensity), 
                        colnames(prots30Intensity), 
                        colnames(peps60Intensity), 
                        colnames(prots60Intensity)))
annot <- DataFrame(row.names = sampleNames)
annot$LCgradient <- sub("_.*$", "", rownames(annot))
annot$NbCells <- as.numeric(sub(".*min_(\\d{1,2}).*$", "\\1", rownames(annot)))
annot$SampleType <- "MCF10A"

####---- Create the QFeatures object ----####

el <- ExperimentList(peptides_30min_intensity = peps30Intensity,
                     peptides_30min_LFQ = peps30lfq,
                     peptides_60min_intensity = peps60Intensity,
                     proteins_30min_intensity = prots30Intensity,
                     proteins_30min_iBAQ = prots30ibaq,
                     proteins_30min_LFQ = prots30lfq,
                     proteins_60min_intensity = prots60Intensity,
                     proteins_60min_iBAQ = prots60ibaq,
                     proteins_60min_LFQ = prots60lfq)
williams2020_lfq <- QFeatures(el, colData = annot)

## Create assay links
## 30 min batch
williams2020_lfq <- addAssayLink(williams2020_lfq, 
                                 from = c("peptides_30min_intensity", "peptides_30min_LFQ"), 
                                 to = "proteins_30min_intensity",
                                 varFrom = rep("Leading.razor.protein", 2), 
                                 varTo = "Majority.protein.IDs")
williams2020_lfq <- addAssayLink(williams2020_lfq, 
                                 from = c("peptides_30min_intensity", "peptides_30min_LFQ"), 
                                 to = "proteins_30min_iBAQ",
                                 varFrom = rep("Leading.razor.protein", 2), 
                                 varTo = "Majority.protein.IDs")
williams2020_lfq <- addAssayLink(williams2020_lfq, 
                                 from = c("peptides_30min_intensity", "peptides_30min_LFQ"), 
                                 to = "proteins_30min_LFQ",
                                 varFrom = rep("Leading.razor.protein", 2), 
                                 varTo = "Majority.protein.IDs")
## 60 min batch
williams2020_lfq <- addAssayLink(williams2020_lfq, 
                                 from = "peptides_60min_intensity", 
                                 to = "proteins_60min_intensity",
                                 varFrom = "Leading.razor.protein", 
                                 varTo = "Majority.protein.IDs")
williams2020_lfq <- addAssayLink(williams2020_lfq, 
                                 from = "peptides_60min_intensity", 
                                 to = "proteins_60min_iBAQ",
                                 varFrom = "Leading.razor.protein", 
                                 varTo = "Majority.protein.IDs")
williams2020_lfq <- addAssayLink(williams2020_lfq, 
                                 from = "peptides_60min_intensity", 
                                 to = "proteins_60min_LFQ",
                                 varFrom = "Leading.razor.protein", 
                                 varTo = "Majority.protein.IDs")

### Save data as Rda file
## Note: saving is assumed to occur in "scpdata/inst/scripts"
save(williams2020_lfq, 
     file = file.path("~/PhD/.localdata/scpdata/williams2020_lfq.Rda"),
     compress = "xz", 
     compression_level = 9)

##' Leduc et al. 2022 - plexDIA (biorRxiv): melanoma cells
##'
##' Single cell proteomics data acquired by the Slavov Lab. This is
##' the dataset associated to the fourth version of the preprint (and
##' the Genome Biology publication). It contains quantitative
##' information of melanoma cells at precursor, peptide and protein level.
##' This version of the data was acquired using the plexDIA MS
##' acquisition protocol.
##'
##' @format A [QFeatures] object with 48 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - Assay 1-45: precursor data acquired with a mTRAQ-3 protocol,
##'   hence those assays contain 3 columns. Columns hold quantitative
##'   information from single cells or negative control samples.
##' - `Ms1Extracted`: the DIA-NN MS1 extracted signal, it combines the
##'   information from assays 1-45.
##' - `peptides`: peptide data containing quantitative data for 3,608
##'   peptides and 104 single cells. The  data were filtered  to  1%
##'   protein FDR.
##' - `proteins`: protein data containing quantitative data for 508
##'   proteins and 105 single cells. Note that the peptide and protein
##'   data provided by the authors differ by 3 samples. The precursor
##'   data were aggregated to protein intensity using maxLFQ. The
##'   protein data were further median normalized by column and by row,
##'   log2 transformed, impute using KNN (k = 3), again median
##'   normalized by column and by row, batch corrected using ComBat,
##'   and median normalized by column and by row once more.
##'
##' The `colData(leduc2022_plexDIA())` contains cell type annotation and
##' batch annotation that are common to all assays. The description of
##' the `rowData` fields for the precursor data can be found in the
##' [`DIA-NN` documentation](https://github.com/vdemichev/DiaNN#readme).
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: CellenONE cell sorting.
##' - **Sample preparation** performed using the improved SCoPE2
##'   protocol using the CellenONE liquid handling system. nPOP cell
##'   lysis (DMSO) + trypsin digestion + mTRAQ-3
##'   labeling and pooling.
##' - **Separation**: online nLC (DionexUltiMate 3000 UHPLC with a
##'   25cm x 75um IonOpticks Aurora Series UHPLC column; 200nL/min).
##' - **Ionization**: ESI (1,800V).
##' - **Mass spectrometry**: Thermo Scientific Q-Exactive. The duty
##'   cycle = 1 MS1 + 4 DIA MS2 windows (120 Th, 120 Th, 200 Th and
##'   580 Th, spanning 378-1,402 m/z). Each MS1 and MS2 scan was
##'   conducted at 70,000 resolving power, 3×10E6 AGC and 300ms
##'   maximum injection time.
##' - **Data analysis**: DIA-NN.
##'
##' @section Data collection:
##'
##' The PSM data were collected from a shared Google Drive folder that
##' is accessible from the SlavovLab website (see `Source` section).
##' The folder contains the following files of interest:
##'
##' - `annotation_plexDIA.csv`: sample annotation
##' - `report_plexDIA_mel_nPOP.tsv`: the DIA-NN output file
##'   with the precursor data
##' - `report.pr_matrix_channels_ms1_extracted.tsv`: the DIA-NN
##'   output file with the combined precursor data
##' - `plexDIA_peptide.csv`: the processed data table containing the
##'   `peptide` data
##' - `plexDIA_protein_imputed.csv`: the processed data table
##'   containing the `protein` data
##'
##' We removed the failed runs as identified by the authors. We also
##' formatted the annotation and precuror quantification tables to
##' facilitate matching between corresponding columns. Both annotation
##' and quantification tables are then combined in a single [QFeatures]
##' object using `scp::readSCPfromDIANN()`.
##'
##' The `plexDIA_peptide.csv` and `plexDIA_protein_imputed.csv` files
##' were loaded and formatted as [SingleCellExperiment] objects. The
##' columns names were adapted to match those in the `QFeatures`
##' object. The `SingleCellExperiment` objects were then added to the
##' [QFeatures] object and the rows of the peptide data are linked to
##' the rows of the precursor data based on the peptide sequence or
##' the protein name through an `AssayLink` object.
##'
##' @source
##' The links to the data were found on the
##' [Slavov Lab website](https://scp.slavovlab.net/Leduc_et_al_2022).
##' The data were downloaded from the
##' [Google drive folder 1](https://drive.google.com/drive/folders/117ZUG5aFIJt0vrqIxpKXQJorNtekO-BV) and
##' [Google drive folder 2](https://drive.google.com/drive/folders/12-H2a1mfSHZUGf8O50Cr0pPZ4zIDjTac).
##' The raw data and the quantification data can also be found in the
##' massIVE repository `MSV000089159`:
##' ftp://massive.ucsd.edu/MSV000089159.
##'
##' @references
##' Andrew Leduc, Gray Huffman, and Nikolai Slavov. 2022. “Droplet
##' Sample Preparation for Single-Cell Proteomics Applied to the Cell
##' Cycle.” bioRxiv. [Link to article](https://doi.org/10.1101/2021.04.24.441211)
##'
##' Andrew Leduc, Gray Huffman, Joshua Cantlon, Saad Khan, and Nikolai
##' Slavov. 2022. “Exploring Functional Protein Covariation across
##' Single Cells Using nPOP.” Genome Biology 23 (1): 261.
##' [Link to article](http://dx.doi.org/10.1186/s13059-022-02817-5)
##'
##' Jason Derks, Andrew Leduc, Georg Wallmann, Gray Huffman, Matthew
##' Willetts, Saad Khan, Harrison Specht, Markus Ralser, Vadim
##' Demichev, and Nikolai Slavov. 2023. “Increasing the Throughput of
##' Sensitive Proteomics by plexDIA.” Nature Biotechnology 41 (1):
##' 50–59. [Link to article](http://dx.doi.org/10.1038/s41587-022-01389-w)
##'
##' @seealso
##' [leduc2022_pSCoPE]
##'
##' @examples
##' \donttest{
##' leduc2022_plexDIA()
##' }
##'
##' @keywords datasets
##'
"leduc2022_plexDIA"

##' Dou et al. 2019 (Anal. Chem.): murine cell lines
##'
##' @description
##'
##' Single-cell proteomics using nanoPOTS combined with TMT isobaric
##' labeling. It contains quantitative information at PSM and protein
##' level. The cell types are either "Raw" (macrophage cells), "C10"
##' (epihelial cells), or "SVEC" (endothelial cells). Out of the 132
##' wells, 72 contain single cells, corresponding to 24 C10 cells, 24
##' RAW cells, and 24 SVEC. The other wells are either boosting
##' channels (12), empty channels (36) or reference channels (12).
##' Boosting and reference channels are balanced (1:1:1) mixes of C10,
##' SVEC, and RAW samples at 5 ng and 0.2 ng, respectively. The
##' different cell types where evenly distributed across 4 nanoPOTS
##' chips. Samples were 11-plexed with TMT labeling.
##'
##' @format A [QFeatures] object with 13 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - `Single_Cell_Chip_X_Y`: PSM data with 11 columns corresponding
##'   to the TMT channels (see `Notes`). The `X` indicates the chip
##'   number (from 1 to 4) and `Y` indicates the row name on the chip
##'   (from A to C).
##' - `peptides`: peptide data containing quantitative data for 15,492
##'   peptides in 132 samples (run 1 and run 2 combined).
##' - `proteins`: protein data containing quantitative data for 2331
##'   proteins in 132 samples (all runs combined).
##'
##' Sample annotation is stored in `colData(dou2019_mouse())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: single-cells from the three murine cell
##'   lines were isolated using FACS (BD Influx II cell sorter ).
##' - **Sample preparation** performed using the nanoPOTs device.
##'   Protein extraction (DMM + TCEAP) + alkylation (IAA) + Lys-C
##'   digestion + trypsin digestion + TMT-10plex labeling and pooling.
##' - **Separation**: nanoLC (Dionex UltiMate with an in-house packed
##'   50cm x 30um LC columns; 50nL/min)
##' - **Ionization**: ESI (2,000V)
##' - **Mass spectrometry**: Thermo Fisher Orbitrap Fusion Lumos
##'   Tribrid (MS1 accumulation time = 50ms; MS1 resolution = 120,000;
##'   MS1 AGC = 1E6; MS2 accumulation time = 246ms; MS2 resolution =
##'   60,000; MS2 AGC = 1E5)
##' - **Data analysis**: MS-GF+ + MASIC (v3.0.7111) + RomicsProcessor
##'   (custom R package)
##'
##' @section Data collection:
##'
##' The PSM data were collected from the MassIVE repository
##' MSV000084110 (see `Source` section). The downloaded files are:
##'
##'
##' - `Single_Cell_Chip_*_*_msgfplus.mzid`: the MS-GF+ identification
##'   result files.
##' - `Single_Cell_Chip_*_*_ReporterIons.txt`: the MASIC
##'   quantification result files.
##'
##' For each batch, the quantification and identification data were
##' combined based on the scan number (common to both data sets). The
##' combined datasets for the different runs were then concatenated
##' feature-wise. To avoid data duplication due to ambiguous matching
##' of spectra to peptides or ambiguous mapping of peptides to proteins,
##' we combined ambiguous peptides to peptides groups and proteins to
##' protein groups. Feature annotations that are not common within a
##' peptide or protein group are are separated by a `;`. The sample
##' annotation table was manually created based on the available
##' information provided in the article. The data were then converted
##' to a [QFeatures] object using the [scp::readSCP()] function.
##'
##' We generated the peptide data. First, we removed PSM matched to
##' contaminants or decoy peptides and ensured a 1% FDR. We aggregated
##' the PSM to peptides based on the peptide (or peptide group)
##' sequence(s) using the median PSM instenity. The peptide data for
##' the different runs were then joined in a single assay (see
##' [QFeatures::joinAssays]), again based on the peptide sequence(s).
##' We then removed the peptide groups. Links between the peptide and
##' the PSM data were created using [QFeatures::addAssayLink]. Note
##' that links between PSM and peptide groups are not stored.
##'
##' The protein data were downloaded from `Supporting information`
##' section from the publisher's website (see `Sources`). The data is
##' supplied as an Excel file `ac9b03349_si_005.xlsx`. The file
##' contains 7 sheets from which we only took the 2nd (named
##' `01 - Raw sc protein data`) with the combined protein data for the
##' 12 runs. We converted the data to a [SingleCellExperiment] object
##' and added the object as a new assay in the [QFeatures] dataset
##' (containing the PSM data). Links between the proteins and the
##' corresponding PSM were created. Note that links to protein groups
##' are not stored.
##'
##' @note Although a TMT-10plex labeling is reported in the article,
##' the PSM data contained 11 channels for each run. Those 11th
##' channel contain mostly missing data and are hence assumed to be
##' empty channels.
##'
##' @source
##' The PSM data can be downloaded from the massIVE repository
##' MSV000084110. FTP link: ftp://massive.ucsd.edu/MSV000084110/
##'
##' The protein data can be downloaded from the
##' [ACS Publications](https://pubs.acs.org/doi/10.1021/acs.analchem.9b03349)
##' website (Supporting information section).
##'
##' @references
##' Dou, Maowei, Geremy Clair, Chia-Feng Tsai, Kerui Xu, William B.
##' Chrisler, Ryan L. Sontag, Rui Zhao, et al. 2019. “High-Throughput
##' Single Cell Proteomics Enabled by Multiplex Isobaric Labeling in a
##' Nanodroplet Sample Preparation Platform.” Analytical Chemistry,
##' September
##' ([link to article](https://doi.org/10.1021/acs.analchem.9b03349)).
##'
##' @seealso
##' [dou2019_lysates], [dou2019_boosting]
##'
##' @examples
##' \donttest{
##' dou2019_mouse()
##' }
##'
##' @keywords datasets
##'
"dou2019_mouse"

####---- EXPERIMENTHUB METADATA TABLE ----####

meta <- list(
    data.frame(
        Title = "specht2019v2",
        Description = paste0("SCP expression data for monocytes (U-937) and macrophages ",
                             "at PSM, peptide and protein level"),
        BiocVersion = "3.15",
        Genome = NA_character_,
        SourceType = "CSV",
        SourceUrl = "https://drive.google.com/drive/folders/1Zhjik_JFjCQNIVjg63-fooJ4K0HZxWjV",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "GoogleDrive",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/specht2019v2.Rda",
        PublicationDate = as.Date("2019/12/5"),
        NumberAssays = 179,
        PreprocessingSoftware = "MaxQuant,DART-ID",
        LabelingProtocol = "TMT-11,TMT-16",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "specht2019v3",
        Description = paste0("SCP expression data for more monocytes (U-937) and ",
                             "macrophages at PSM, peptide and protein level"),
        BiocVersion = "3.15",
        Genome = NA_character_,
        SourceType = "CSV",
        SourceUrl = "https://drive.google.com/drive/folders/1Zhjik_JFjCQNIVjg63-fooJ4K0HZxWjV",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "GoogleDrive",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/specht2019v3.Rda",
        PublicationDate = as.Date("2020/10/04"),
        NumberAssays = 179,
        PreprocessingSoftware = "MaxQuant,DART-ID",
        LabelingProtocol = "TMT-11,TMT-16",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "dou2019_lysates",
        Description = paste0("SCP expression data for Hela digests (0.2 or 10 ng) at ",
                             "PSM and protein level"),
        BiocVersion = "3.14",
        Genome = NA_character_,
        SourceType = "XLS/XLSX",
        SourceUrl = "ftp://massive.ucsd.edu/MSV000084110/",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "MassIVE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/dou2019_lysates.Rda",
        PublicationDate = as.Date("2019/10/15"),
        NumberAssays = 4,
        PreprocessingSoftware = "MS-GF+,MASIC",
        LabelingProtocol = "TMT-10",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = FALSE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "dou2019_mouse",
        Description = paste0("SCP expression data for C10, SVEC or Raw cells at ",
                             "PSM and protein level"),
        BiocVersion = "3.14",
        Genome = NA_character_,
        SourceType = "XLS/XLSX",
        SourceUrl = "ftp://massive.ucsd.edu/MSV000084110/",
        SourceVersion = NA_character_,
        Species = "Mus musculus",
        TaxonomyId = 10090,
        Coordinate_1_based = TRUE,
        DataProvider = "MassIVE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/dou2019_mouse.Rda",
        PublicationDate = as.Date("2019/10/15"),
        NumberAssays = 14,
        PreprocessingSoftware = "MS-GF+,MASIC",
        LabelingProtocol = "TMT-10",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "dou2019_boosting",
        Description = paste0("SCP expression data for C10, SVEC or Raw cells ",
                             "and 3 boosters (0, 5 or 50 ng) at PSM and protein level"),
        BiocVersion = "3.14",
        Genome = NA_character_,
        SourceType = "XLS/XLSX",
        SourceUrl = "ftp://massive.ucsd.edu/MSV000084110/",
        SourceVersion = NA_character_,
        Species = "Mus musculus",
        TaxonomyId = 10090,
        Coordinate_1_based = TRUE,
        DataProvider = "MassIVE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/dou2019_boosting.Rda",
        PublicationDate = as.Date("2019/10/15"),
        NumberAssays = 8,
        PreprocessingSoftware = "MS-GF+,MASIC",
        LabelingProtocol = "TMT-10",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "zhu2018MCP",
        Description = paste0("Near SCP expression data for micro-dissected rat ",
                             "brain samples (50, 100, or 200 um width) at PSM level"),
        BiocVersion = "3.15",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/07/PXD008844",
        SourceVersion = NA_character_,
        Species = "Rattus norvegicus",
        TaxonomyId = 10116,
        Coordinate_1_based = TRUE,
        DataProvider = "PRIDE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/zhu2018MCP.Rda",
        PublicationDate = as.Date("2018/09/01"),
        PreprocessingSoftware = "MaxQuant",
        LabelingProtocol = "LFQ",
        NumberAssays = 4,
        PsmsAvailable = FALSE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = FALSE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "zhu2018NC_hela",
        Description = paste0("Near SCP expression data for HeLa samples (aproximately ",
                             "12, 40, or 140 cells) at PSM level"),
        BiocVersion = "3.13",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/01/PXD006847",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "PRIDE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/zhu2018NC_hela.Rda",
        PublicationDate = as.Date("2018/02/28"),
        NumberAssays = 4,
        PreprocessingSoftware = "MaxQuant",
        LabelingProtocol = "LFQ",
        PsmsAvailable = FALSE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = FALSE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "zhu2018NC_lysates",
        Description = paste0("Near SCP expression data for HeLa lysates (10, 40 and ",
                             "140 cell equivalent) at PSM level"),
        BiocVersion = "3.13",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/01/PXD006847",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "PRIDE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/zhu2018NC_lysates.Rda",
        PublicationDate = as.Date("2018/02/28"),
        NumberAssays = 4,
        PreprocessingSoftware = "MaxQuant",
        LabelingProtocol = "LFQ",
        PsmsAvailable = FALSE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = FALSE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "zhu2018NC_islets",
        Description = paste0("Near SCP expression data for micro-dissected human ",
                             "pancreas samples (control patients or type 1 ",
                             "diabetes) at PSM level"),
        BiocVersion = "3.13",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/01/PXD006847",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "PRIDE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/zhu2018NC_islets.Rda",
        PublicationDate = as.Date("2018/02/28"),
        NumberAssays = 4,
        PreprocessingSoftware = "MaxQuant",
        LabelingProtocol = "LFQ",
        PsmsAvailable = FALSE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = FALSE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "cong2020AC",
        Description = paste0("SCP expression data for Hela cells at PSM, peptide ",
                             "and protein level"),
        BiocVersion = "3.13",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2020/02/PXD016921",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "PRIDE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/cong2020AC.Rda",
        PublicationDate = as.Date("2020/01/02"),
        NumberAssays = 9,
        PreprocessingSoftware = "MaxQuant",
        LabelingProtocol = "LFQ",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "zhu2019EL",
        Description = paste0("SCP expression data for chicken utricle samples (1, ",
                             "3, 5 or 20 cells) at PSM, peptide and protein level"),
        BiocVersion = "3.15",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2019/11/PXD014256",
        SourceVersion = NA_character_,
        Species = "Gallus gallus",
        TaxonomyId = 9031,
        Coordinate_1_based = TRUE,
        DataProvider = "PRIDE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/zhu2019EL.Rda",
        PublicationDate = as.Date("2019/11/04"),
        NumberAssays = 63,
        PreprocessingSoftware = "MaxQuant",
        LabelingProtocol = "LFQ",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "liang2020_hela",
        Description = paste0("Expression data for HeLa cells (0, 1, ",
                             "10, 150, 500 cells) at PSM, peptide and ",
                             "protein level"),
        BiocVersion = "3.13",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2020/12/PXD021882/",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "PRIDE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/liang2020_hela.Rda",
        PublicationDate = as.Date("2020/12/22"),
        NumberAssays = 17,
        PreprocessingSoftware = "MaxQuant",
        LabelingProtocol = "LFQ",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "schoof2021",
        Description = paste0("Single-cell proteomics data from ",
                             "OCI-AML8227 cell culture to reconstruct ",
                             "the cellular hierarchy."),
        BiocVersion = "3.14",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "http://ftp.pride.ebi.ac.uk/pride/data/archive/2021/05/PXD020586/",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "PRIDE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/schoof2021.Rda",
        PublicationDate = as.Date("2021/06/07"),
        NumberAssays = 194,
        PreprocessingSoftware = "ProteomeDiscoverer",
        LabelingProtocol = "TMT-16",
        PsmsAvailable = TRUE,
        PeptidesAvailable = FALSE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "williams2020_lfq",
        Description = paste0("Single-cell label free proteomics data ",
                             "from a MCF10A cell line culture."),
        BiocVersion = "3.15",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://massive.ucsd.edu/MSV000085230/",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "MassIVE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/williams2020_lfq.Rda",
        PublicationDate = as.Date("2020/08/04"),
        NumberAssays = 9,
        PreprocessingSoftware = "MaxQuant",
        LabelingProtocol = "LFQ",
        PsmsAvailable = FALSE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "williams2020_tmt",
        Description = paste0("Single-cell proteomics data ",
                             "from three acute myeloid leukemia cell ",
                             "line culture (MOLM-14, K562, CMK)."),
        BiocVersion = "3.15",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://massive.ucsd.edu/MSV000085230/",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "MassIVE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/williams2020_tmt.Rda",
        PublicationDate = as.Date("2020/08/04"),
        NumberAssays = 4,
        PreprocessingSoftware = "MaxQuant",
        LabelingProtocol = "TMT-11",
        PsmsAvailable = FALSE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "derks2022",
        Description = paste0("Single-cell and bulk (100-cell) ",
                             "proteomics data of PDAC, melanoma cells ",
                             "and monocytes."),
        BiocVersion = "3.16",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://massive.ucsd.edu/MSV000089093/",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "MassIVE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/derks2022.Rda",
        PublicationDate = as.Date("2022/07/14"),
        NumberAssays = 66,
        PreprocessingSoftware = "DIA-NN",
        LabelingProtocol = "mTRAQ",
        PsmsAvailable = TRUE,
        PeptidesAvailable = FALSE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "brunner2022",
        Description = paste0("Single-cell proteomics data of cell ",
                             "cycle stages in HeLa."),
        BiocVersion = "3.16",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "https://www.ebi.ac.uk/pride/archive/projects/PXD024043",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "PRIDE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/brunner2022.Rda",
        PublicationDate = as.Date("2022/02/08"),
        NumberAssays = 435,
        PreprocessingSoftware = "DIA-NN",
        LabelingProtocol = "LFQ",
        PsmsAvailable = TRUE,
        PeptidesAvailable = FALSE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "leduc2022_pSCoPE",
        Description = paste0("Single-cell proteomics data ",
                             "of 878 melanoma cells and 877 ",
                             "monocytes (pSCoPE)."),
        BiocVersion = "3.19",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://massive.ucsd.edu/MSV000089159/",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "MassIVE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/leduc2022_pSCoPE.Rda",
        PublicationDate = as.Date("2022/03/30"),
        NumberAssays = 138,
        PreprocessingSoftware = "MaxQuant",
        LabelingProtocol = "TMT-18",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "leduc2022_plexDIA",
        Description = paste0("Single-cell proteomics data ",
                             "of 126 melanoma cells (plexDIA)."),
        BiocVersion = "3.18",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://massive.ucsd.edu/MSV000089159/",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "MassIVE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/leduc2022_plexDIA.Rda",
        PublicationDate = as.Date("2022/12/06"),
        NumberAssays = 48,
        PreprocessingSoftware = "DIA-NN",
        LabelingProtocol = "mTRAQ-3",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "woo2022_macrophage",
        Description = paste0("Single-cell proteomics data ",
                             "from LPS-treated macrophages."),
        BiocVersion = "3.18",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://massive.ucsd.edu/MSV000085937/",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "MassIVE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/woo2022_macrophage.Rda",
        PublicationDate = as.Date("2022/05/18"),
        NumberAssays = 5,
        PreprocessingSoftware = "MaxQuant",
        LabelingProtocol = "LFQ",
        PsmsAvailable = FALSE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "woo2022_lung",
        Description = paste0("Single-cell proteomics data ",
                             "from primary human lung cells."),
        BiocVersion = "3.18",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://massive.ucsd.edu/MSV000085937/",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "MassIVE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/woo2022_lung.Rda",
        PublicationDate = as.Date("2022/05/18"),
        NumberAssays = 5,
        PreprocessingSoftware = "MaxQuant",
        LabelingProtocol = "LFQ",
        PsmsAvailable = FALSE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "gregoire2023_mixCTRL",
        Description = paste0("Single-cell proteomics data ",
                             "from two monocyte cell lines"),
        BiocVersion = "3.19",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "https://www.ebi.ac.uk/pride/archive/projects/PXD046211",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "PRIDE",
        Maintainer = "Samuel Gregoire <samuel.gregoire@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/gregoire2023_mixCTRL.Rda",
        PublicationDate = as.Date("2024/01/22"),
        NumberAssays = 119,
        PreprocessingSoftware = "Sage",
        LabelingProtocol = "TMT-16",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "khan2023",
        Description = paste0("Single-cell proteomics data ",
                             "of 421 MCF-10A cells undergoing ",
                             "EMT triggered by TGFβ"),
        BiocVersion = "3.19",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "https://drive.google.com/drive/folders/1zCsRKWNQuAz5msxx0DfjDrIe6pUjqQmj",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "MassIVE",
        Maintainer = "Enes Sefa Ayar <enes.ayar@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/khan2023.Rda",
        PublicationDate = as.Date("2023/12/21"),
        NumberAssays = 47,
        PreprocessingSoftware = "MaxQuant",
        LabelingProtocol = "TMTPro 16plex",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "guise2024",
        Description = paste0("Single-cell proteomics data ",
                             "of 108 postmortem CTL or ALS spinal ",
                             "moto neurons"),
        BiocVersion = "3.19",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "ftp://massive.ucsd.edu/v05/MSV000092119/",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "MassIVE",
        Maintainer = "Christophe Vanderaa <christophe.vanderaa@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/guise2024.rda",
        PublicationDate = as.Date("2024/01/05"),
        NumberAssays = 47,
        PreprocessingSoftware = "Proteome Discoverer",
        LabelingProtocol = "LFQ",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "petrosius2023_mES",
        Description = paste0("Mouse embryonic stem cells across ground-state (m2i) ",
                             "and differentiation-permissive (m15) culture conditions."),
        BiocVersion = "3.19",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "https://dataverse.uclouvain.be/dataset.xhtml?persistentId=doi:10.14428/DVN/EMAVLT",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "Dataverse",
        Maintainer = "Enes Sefa Ayar <enes.ayar@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/petrosius2023_mES.Rda",
        PublicationDate = as.Date("2024/04/09"),
        NumberAssays = 605,
        PreprocessingSoftware = "Spectronaut",
        LabelingProtocol = "LFQ",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
        Title = "petrosius2023_AstralAML",
        Description = paste0("Single-cell proteomics data ",
                             "of 4 cell types from the OCI-AML8227 ",
                             "model."),
        BiocVersion = "3.19",
        Genome = NA_character_,
        SourceType = "TXT",
        SourceUrl = "https://dataverse.uclouvain.be/dataset.xhtml?persistentId=doi:10.14428/DVN/4DSPJM",
        SourceVersion = NA_character_,
        Species = "Homo sapiens",
        TaxonomyId = 9606,
        Coordinate_1_based = TRUE,
        DataProvider = "Dataverse",
        Maintainer = "Samuel Gregoire <samuel.gregoire@uclouvain.be>",
        RDataClass = "QFeatures",
        DispatchClass = "Rda",
        Location_Prefix = "",
        RDataPath = "scpdata/petrosius2023_AstralAML.Rda",
        PublicationDate = as.Date("2023/06/08"),
        NumberAssays = 217,
        PreprocessingSoftware = "Spectronaut",
        LabelingProtocol = "LFQ",
        PsmsAvailable = TRUE,
        PeptidesAvailable = TRUE,
        ProteinsAvailable = TRUE,
        ContainsSingleCells = TRUE,
        Notes = NA_character_
    ),
    data.frame(
      Title = "krull2024",
      Description = paste0("Single-cell proteomics data ",
                           "IFN-γ response of U-2 OS cells"),
      BiocVersion = "3.19",
      Genome = NA_character_,
      SourceType = "TXT",
      SourceUrl = "https://www.ebi.ac.uk/pride/archive/projects/PXD053464",
      SourceVersion = NA_character_,
      Species = "Homo sapiens",
      TaxonomyId = 9606,
      Coordinate_1_based = TRUE,
      DataProvider = "PRIDE",
      Maintainer = "Enes Sefa Ayar <enes.ayar@uclouvain.be>",
      RDataClass = "QFeatures",
      DispatchClass = "Rda",
      Location_Prefix = "",
      RDataPath = "scpdata/krull2024.Rda",
      PublicationDate = as.Date("2024/10/24"),
      NumberAssays = 159,
      PreprocessingSoftware = "DIA-NN",
      LabelingProtocol = "LFQ",
      PsmsAvailable = TRUE,
      PeptidesAvailable = FALSE,
      ProteinsAvailable = TRUE,
      ContainsSingleCells = TRUE,
      Notes = NA_character_
    ),
    data.frame(
      Title = "hu2023_K562",
      Description = paste0("Single-cell proteomics data of K562 cells"),
      BiocVersion = "3.19",
      Genome = NA_character_,
      SourceType = "TXT",
      SourceUrl = "ftp://massive.ucsd.edu/MSV000089625/",
      SourceVersion = NA_character_,
      Species = "Homo sapiens",
      TaxonomyId = 9606,
      Coordinate_1_based = TRUE,
      DataProvider = "MassIVE",
      Maintainer = "Enes Sefa Ayar <enes.ayar@uclouvain.be>",
      RDataClass = "SingleCellExperiment",
      DispatchClass = "Rda",
      Location_Prefix = "",
      RDataPath = "scpdata/hu2023_K562.Rda",
      PublicationDate = as.Date("2024/10/24"),
      NumberAssays = 1,
      PreprocessingSoftware = "Proteome Discoverer",
      LabelingProtocol = "LFQ",
      PsmsAvailable = FALSE,
      PeptidesAvailable = FALSE,
      ProteinsAvailable = TRUE,
      ContainsSingleCells = TRUE,
      Notes = NA_character_
    ),
    data.frame(
      Title = "hu2023_oocyte",
      Description = paste0("Single-cell proteomics data of oocytes"),
      BiocVersion = "3.19",
      Genome = NA_character_,
      SourceType = "TXT",
      SourceUrl = "ftp://massive.ucsd.edu/MSV000089625/",
      SourceVersion = NA_character_,
      Species = "Homo sapiens",
      TaxonomyId = 9606,
      Coordinate_1_based = TRUE,
      DataProvider = "MassIVE",
      Maintainer = "Enes Sefa Ayar <enes.ayar@uclouvain.be>",
      RDataClass = "SingleCellExperiment",
      DispatchClass = "Rda",
      Location_Prefix = "",
      RDataPath = "scpdata/hu2023_oocyte.Rda",
      PublicationDate = as.Date("2024/10/24"),
      NumberAssays = 1,
      PreprocessingSoftware = "Proteome Discoverer",
      LabelingProtocol = "LFQ",
      PsmsAvailable = FALSE,
      PeptidesAvailable = FALSE,
      ProteinsAvailable = TRUE,
      ContainsSingleCells = TRUE,
      Notes = NA_character_
    ),
    data.frame(
      Title = "ai2025a",
      Description = paste0("Single-cell proteomics data of adult cardiomyocytes from Ai et al. (2025)"),
      BiocVersion = "3.21",
      Genome = NA_character_,
      SourceType = "TXT",
      SourceUrl = "ftp://massive.ucsd.edu/v07/MSV000094438/updates/2024-10-23_bineka_5deafa61/other/Supplementary%20Files/aCMs/report.tsv",
      SourceVersion = NA_character_,
      Species = "Homo sapiens",
      TaxonomyId = 9606,
      Coordinate_1_based = TRUE,
      DataProvider = "MassIVE",
      Maintainer = "Laurent Gatto <laurent.gatto@uclouvain.be>",
      RDataClass = "QFeatures",
      DispatchClass = "Rda",
      Location_Prefix = "",
      RDataPath = "scpdata/ai2025a.rda",
      PublicationDate = as.Date("2025/02/22"),
      NumberAssays = 304,
      PreprocessingSoftware = "DIA-NN",
      LabelingProtocol = "LFQ",
      PsmsAvailable = TRUE,
      PeptidesAvailable = TRUE,
      ProteinsAvailable = TRUE,
      ContainsSingleCells = TRUE,
      Notes = "DIA-NN output retrieved using MsDataHub::Ai2025_aCMs_report.tsv()"
    ),
    data.frame(
      Title = "leduc2025",
      Description = paste0("Principles of protein abundance regulation across",
                           " single cells in a mammalian tissue Leduc et al, (2025)"),
      BiocVersion = "3.23",
      Genome = NA_character_,
      SourceType = "CSV",
      SourceUrl = "https://zenodo.org/records/21904283/files/leduc2025.rda",
      SourceVersion = NA_character_,
      Species = "Mus musculus",
      TaxonomyId = 10090,
      Coordinate_1_based = TRUE,
      DataProvider = "Zenodo",
      Maintainer = "Enes Sefa Ayar <enes.ayar@uclouvain.be>",
      RDataClass = "QFeatures",
      DispatchClass = "Rda",
      Location_Prefix = "https://zenodo.org/",
      RDataPath = "records/21904283/files/leduc2025.rda",
      PublicationDate = as.Date("2026/08/12"),
      NumberAssays = 11,
      PreprocessingSoftware = "DIA-NN",
      LabelingProtocol = "mTRAQ",
      PsmsAvailable = FALSE,
      PeptidesAvailable = TRUE,
      ProteinsAvailable = TRUE,
      ContainsSingleCells = TRUE,
      Notes = NA_character_
    )
    ## data.frame(
    ##   Title = "bubis2025",
    ##   Description = paste0("Single-cell proteomics data ",
    ##                        "of HeLa, K562, A549, H460, TE-like and hPS cells ",
    ##                        "acquired on the Astral MS."),
    ##   BiocVersion = "3.23",
    ##   Genome = NA_character_,
    ##   SourceType = "TXT",
    ##   SourceUrl = "https://www.ebi.ac.uk/pride/archive/projects/PXD049412",
    ##   SourceVersion = NA_character_,
    ##   Species = "Homo sapiens",
    ##   TaxonomyId = 9606,
    ##   Coordinate_1_based = TRUE,
    ##   DataProvider = "MassIVE",
    ##   Maintainer = "Samuel Gregoire <samuel.gregoire@uclouvain.be>",
    ##   RDataClass = "QFeatures",
    ##   DispatchClass = "Rda",
    ##   Location_Prefix = "",
    ##   RDataPath = "scpdata/bubis2025.Rda",
    ##   PublicationDate = as.Date("2025/08/19"),
    ##   NumberAssays = 602,
    ##   PreprocessingSoftware = "Spectronaut",
    ##   LabelingProtocol = "LFQ",
    ##   PsmsAvailable = TRUE,
    ##   PeptidesAvailable = TRUE,
    ##   ProteinsAvailable = TRUE,
    ##   ContainsSingleCells = TRUE,
    ##   Notes = NA_character_),
    ## data.frame(
    ##     Title = "wu2026",
    ##     Description = paste0("Label-free single-cell proteomics data from prenatal human brain tissue ",
    ##                          "(gestational weeks 13, 15, and 19) from Wu et al. (2026)"),
    ##     BiocVersion = "3.23",
    ##     Genome = NA_character_,
    ##     SourceType = "TXT",
    ##     SourceUrl = "https://www.ebi.ac.uk/pride/archive/projects/PXD071075",
    ##     SourceVersion = NA_character_,
    ##     Species = "Homo sapiens",
    ##     TaxonomyId = 9606,
    ##     Coordinate_1_based = TRUE,
    ##     DataProvider = "PRIDE",
    ##     Maintainer = "Léopold Guyot <leopoldguyot@uclouvain.be>",
    ##     RDataClass = "QFeatures",
    ##     DispatchClass = "Rda",
    ##     Location_Prefix = "",
    ##     RDataPath = "scpdata/wu2026.rda",
    ##     PublicationDate = as.Date("2026/01/27"),
    ##     NumberAssays = 2313,
    ##     PreprocessingSoftware = "DIA-NN",
    ##     LabelingProtocol = "LFQ",
    ##     PsmsAvailable = TRUE,
    ##     PeptidesAvailable = TRUE,
    ##     ProteinsAvailable = TRUE,
    ##     ContainsSingleCells = TRUE,
    ##     Notes = "DIA-NN output retrieved from PRIDE repository accession PXD071075"
    ## )
)

metadata <- do.call(rbind, meta)

write.csv(metadata,
          file = here::here("inst", "extdata", "metadata.csv"),
          row.names = FALSE)

stopifnot(file.exists(pkg_source <- here::here()))

AnnotationHubData::makeAnnotationHubMetadata(pathToPackage = pkg_source,
                                             fileName = "metadata.csv")

##' Zhu et al. 2018 (Nat. Comm.): human pancreatic islets
##'
##'
##' Near single-cell proteomics data human pancreas samples. The
##' samples were collected from pancreatic tissue slices using laser
##' dissection. The pancreata were obtained from organ donors through
##' the JDRFNetwork for Pancreatic Organ Donors with Diabetes (nPOD)
##' program. The sample come either from control patients (n=9) or
##' from type 1 diabetes (T1D) patients (n=9).
##'
##' @format A [QFeatures] object with 4 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - `peptides`: quantitative information for 24,321 peptides from
##'   18 islet samples
##' - `proteins_intensity`: quantitative information for 3,278
##'   proteins from 18 islet samples
##' - `proteins_LFQ`: LFQ intensities for 3,278 proteins from 18 islet
##'   samples
##' - `proteins_iBAQ`: iBAQ values for 3,278 proteins from 18 islet
##'   samples
##'
##' Sample annotation is stored in `colData(zhu2018NC_islets())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: The islets were extracted from the pacreatic
##'   tissues using laser-capture microdissection.
##' - **Sample preparation** performed using the nanoPOTs device.
##'   Protein extraction using RapiGest (+ DTT) + alkylation (IAA) +
##'   Lys-C digestion + cleave RapiGest (formic acid)
##' - **Separation**: nanoACQUITY UPLC pump with an Self-Pack PicoFrit
##'   70cm x 30um LC columns; 60nL/min)
##' - **Ionization**: ESI (1,900V)
##' - **Mass spectrometry**: Thermo Fisher Orbitrap Fusion Lumos
##'   Tribrid. MS1 settings: accumulation time = 246ms; resolution =
##'   120,000; AGC = 1E6. MS/MS settings: accumulation time = 118ms;
##'   resolution = 60,000; AGC = 1E5.
##' - **Data analysis**: MaxQuant (v1.5.3.30) + Perseus + OriginLab
##'   2017
##'
##' @section Data collection:
##'
##' The data were collected from the PRIDE repository (accession
##' ID: PXD006847).  We downloaded the `Islet_t1d_ct_peptides.txt`
##' and the `Islet_t1d_ct_proteinGroups.txt` files containing the
##' combined identification and quantification results. The sample
##' types were inferred from the names of columns holding the
##' quantification data. The peptides data were converted to a
##' [SingleCellExperiment] object. We split the protein table to
##' separate the three types of quantification: protein intensity,
##' label-free quantitification (LFQ) and intensity based absolute
##' quantification (iBAQ). Each table is converted to a
##' [SingleCellExperiment] object along with the remaining protein
##' annotations. The 4 objects are combined in a single [QFeatures]
##' object and feature links are created based on the peptide leading
##' razor protein ID and the protein ID.
##'
##' @source
##' The PSM data can be downloaded from the PRIDE repository
##' PXD006847. The source link is:
##' ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/01/PXD006847
##'
##' @references
##'
##' Zhu, Ying, Paul D. Piehowski, Rui Zhao, Jing Chen, Yufeng Shen,
##' Ronald J. Moore, Anil K. Shukla, et al. 2018. “Nanodroplet
##' Processing Platform for Deep and Quantitative Proteome Profiling
##' of 10-100 Mammalian Cells.” Nature Communications 9 (1): 882
##' ([link to article](http://dx.doi.org/10.1038/s41467-018-03367-w)).
##'
##' @examples
##' \donttest{
##' zhu2018NC_islets()
##' }
##'
##' @keywords datasets
##'
"zhu2018NC_islets"

####---- Cong et al. 2020, An. Chem. ----####


## Cong, Yongzheng, Yiran Liang, Khatereh Motamedchaboki, Romain 
## Huguet, Thy Truong, Rui Zhao, Yufeng Shen, Daniel Lopez-Ferrer, 
## Ying Zhu, and Ryan T. Kelly. 2020. “Improved Single-Cell Proteome 
## Coverage Using Narrow-Bore Packed NanoLC Columns and Ultrasensitive 
## Mass Spectrometry.” Analytical Chemistry, January. 
## https://doi.org/10.1021/acs.analchem.9b04631.

## The data files were donwloaded from: 
## ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2020/02/PXD016921

library(scp)
library(tidyverse)
setwd("inst/scripts/")
dataDir <- "../extdata/cong2020AC/"


####---- PSM data ----####


## Load the quantification data
list.files(path = dataDir,
           pattern = "evidence", 
           full.names = TRUE) %>%
  read.table(sep = "\t", header = TRUE) %>%
  ## Rename column
  dplyr::rename(Batch = Raw.file,  
                LFQ = Intensity) %>%
  ## Create 'Idenitfication.type' field as found in the peptide data 
  mutate(Identification.type = ifelse(Type == "MULTI-MATCH", 
                                      "By matching",
                                      "By MS/MS")) ->
  psms

## Create the sample metadata
meta <- data.frame(Batch = unique(psms$Batch), 
                   Channel = "LFQ",
                   CellNumber = c(20, 100, rep(1, 4), 0)) 

## Create the QFeatures object
cong2020AC <- readSCP(psms, 
                      meta, 
                      channelCol = "Channel", 
                      batchCol = "Batch")


####---- Peptide data ----####


## Load the quantification data
list.files(path = dataDir,
           pattern = "peptide", 
           full.names = TRUE) %>%
  read.table(sep = "\t", header = TRUE) ->
  pep

## Create the SingleCellExperiment object
pep <- readSingleCellExperiment(pep, 
                                ecol = grep("^Intensity[.]", 
                                            colnames(pep)), 
                                sep = "\t")

## Rename columns so they math with the PSM data
colnames(pep) %>%
  sub(pattern = "^Intensity[.]", replacement = "") %>%
  gsub(pattern = "[.]", replacement = " ") %>%
  paste0("_LFQ") ->
  colnames(pep)
## Name rows with peptide sequence
rownames(pep) <- rowData(pep)$Sequence

## Include the peptide data in the QFeatures object
cong2020AC <- addAssay(cong2020AC, pep, name = "peptides")

## Link the PSMs and the peptides
cong2020AC <- addAssayLink(cong2020AC, 
                           from = 1:7, 
                           to = "peptides", 
                           varFrom = rep("Sequence", 7),
                           varTo = "Sequence")


####---- Protein data ----####


## Load the quantification data
list.files(path = dataDir,
           pattern = "proteinGroups", 
           full.names = TRUE) %>%
  read.table(sep = "\t", header = TRUE) %>%
  ## Get a unique protein ID
  mutate(Protein = sub("^([^;]*);.*$", 
                       "\\1", 
                       Majority.protein.IDs)) ->
  prot

## Create the SingleCellExperiment object
prot <- readSingleCellExperiment(prot, 
                                 ecol = grep("^Intensity[.]", 
                                             colnames(prot)), 
                                 sep = "\t")
## Rename columns so they math with the PSM data
colnames(prot) %>%
  sub(pattern = "^Intensity[.]", replacement = "") %>%
  gsub(pattern = "[.]", replacement = " ") %>%
  paste0("_LFQ") ->
  colnames(prot)
## Name rows with peptide sequence
rownames(prot) <- rowData(prot)$Protein

## Include the protein data in the QFeatures object
cong2020AC <- addAssay(cong2020AC, prot, name = "proteins")

## Link the PSMs and the peptides
cong2020AC <- addAssayLink(cong2020AC, 
                           from = "peptides", 
                           to = "proteins", 
                           varFrom = "Leading.razor.protein",
                           varTo = "Protein")


# Save data as Rda file
# Note: saving is assumed to occur in "scpdata/inst/scripts"
save(cong2020AC, 
     file = file.path("../extdata/scpdata/cong2020AC.Rda"),
     compress = "xz", 
     compression_level = 9)

library("SCP.replication")
library("tidyverse")
library("data.table")

report <- fread("~/PhD/.localdata/SCP/brunner2022/20210919_DIANN_SingleCellOutput.tsv")

## Build the annotation table from the run names
annot <- DataFrame(File.Name = unique(report$File.Name))
annot$Run <- gsub("^D.*[\\]|[.]d$", "", annot$File.Name)
otherVars <- strsplit(annot$Run, "_")
otherVars <- lapply(otherVars, function(x) {
    if (length(x) == 12) x <- x[-4]
    x
})
otherVars <- do.call(rbind, otherVars)
colnames(otherVars) <- c("Date", "MsInstrument", "Purification", "User",
                         "SampleAnnotation", "SampleType", "CellCycleStage", 
                         "..undetermined..", "PlatePosition", "CellNumber",
                         "RunID")
annot <- cbind(annot, otherVars)

## Format to a QFeatures object
brunner2022 <- readSCPfromDIANN(annot, report)

## The protein data 
pgTable <- read.delim("~/PhD/.localdata/SCP/brunner2022/20210919_DIANN_SingleCellOutput.pg_matrix.tsv", 
                      check.names = FALSE)
prots <- readSingleCellExperiment(pgTable, ecol = unique(report$File.Name), 
                                  fnames = "Protein.Names")
prots <- prots[rownames(prots) != ""]
rownames(prots) <- make.unique(rownames(prots))
from <- names(brunner2022)
brunner2022 <- addAssay(brunner2022, prots, "proteins")
brunner2022 <- addAssayLink(brunner2022, 
                            from = from, 
                            to = "proteins", 
                            varFrom = rep("Protein.Group", length(from)),
                            varTo = "Protein.Group")

# Save data as Rda file
save(brunner2022, 
     file = "~/PhD/.localdata/scpdata/brunner2022.Rda",
     compress = "xz", 
     compression_level = 9)

stopifnot(packageVersion("MsDataHub") >= "1.7.1")
stopifnot(packageVersion("QFeatures") >= "1.17.2")

library(tidyverse)
library(QFeatures)

ai2025iTab <- read_tsv(MsDataHub::Ai2025_iCMs_report.tsv())


tab <- tibble(File.Name = unique(ai2025iTab[[1]]))|>
    mutate(Sample = sub(".*\\\\", "",File.Name))|>
    mutate(Date = sub("^.*?(\\d{6}).*", "\\1", File.Name))|>
    mutate(Date = ymd(as.integer(Date)))|>
    mutate(Batch = sub("^.*?(Batch[0-9])_.+$", "\\1", File.Name))|>
    mutate(PlateWell = sub("^.*?([A-Z][0-9]+)_.+$", "\\1", File.Name))|>
    mutate(Position = sub("^.*?([A-Z]+[0-9]+)_1_[0-9]+\\.d$", "\\1", File.Name))|>
    mutate(Day = sub("^.*?(day[0-9]+)_.+$", "\\1", File.Name, ignore.case = T))|>
    mutate(Day = sub("\\D+", "\\1", Day))|>
    mutate(Day = as.numeric(Day))|>
    mutate(Cell_count = sub("^.*?([0-9]+cell).+$", "\\1", File.Name))

tab$runCol <- tab$File.Name

ai2025i <- readSCPfromDIANN(ai2025iTab
                            colData = DataFrame(tab),
                            fnames = "Precursor.Id")

## Setting the names of the QFeatures objects
ai2025i <- MultiAssayExperiment::renamePrimary(ai2025i, ai2025i$Sample)
names(ai2025i) <- ai2025i$Sample

## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    crop = NULL ## Related to https://stat.ethz.ch/pipermail/bioc-devel/2020-April/016656.html
)

##' Guise et al. 2020 (Cell Rep.): postmortem ALS spinal moto neurons
##'
##' Single-cell proteomics data from postmortem human spinal moto
##' neurons (MN) obtained from control donors or donors with amyotrophic
##' lateral sclerosis (ALS). The data were generated following the
##' NanoPOTS protocol. Cells were isolated from samples obtained by
##' the university of Miami Brain Bank using laser capture
##' microdissection (LCM). Additional information about the amount of
##' TDP-43 intra-cellular levels has been assigned into levels 0 to 4.
##'
##' @format A [QFeatures] object with 102 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - `F*`: 100 assays containing PSM data.
##' - `peptides`: quantitative data for 34,315 peptides in 108 samples.
##'   All samples combined, along with 8 additional unannotated
##'   samples.
##' - `proteins`: quantitative data for 4,437 protein groups in 108
##'   samples. All samples combined, along with 8 additional
##'   unannotated samples.
##'
##' Sample annotation is stored in `colData(guise2024())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: The MN were isolated from samples obtained
##'   by the university of Miami Brain Bank using LCM.
##' - **Sample preparation** performed using the nanoPOTS workflow.
##'   Cells are treated with 0.1% DDM (for lysis) added with DTT
##'   (protein reduction), then IAA (alkylation), then Lys-C and
##'   trypsin (protein digestion).
##' - **Separation**: Samples were injected on the column using an
##'   Ultimate 3000 RSLCnano pump. The in-line loading column is a
##'   home-packed SPE column (5cm x 75um) while the peptide
##'   separation is performed on a an in-house-packed analytical SPE
##'   column (50 cm x 30um), using a 20nL/min flow rate.
##' - **Ionization**: nanospray emmitter (2,000V)
##' - **Mass spectrometry**: Orbitrap Exploris 480. HCD fragmentation.
##'   MS1 settings: accumulation time = 200 ms; resolution = 120,000;
##'   AGC = 1E6. MS2 settings: exclusion duration = 90 s;
##'   accumulation time = 500 ms; resolution = 30,000; AGC = 1E5.
##' - **Data analysis**: Sequest HT in Proteome Discoverer (v2.5) and
##'   the search database is Swiss-Prot (July 2020).
##'
##' @section Data collection:
##'
##' All data were collected from the MassIVE repository (accession ID:
##' MSV000092119).
##'
##' The sample annotations were combined from the tables in
##' `Biogen_TDP43_Round2_Reanalysis_10-13-2021_InputFiles.txt` and in
##' `Groups.txt`.
##'
##' The PSM data were found in the
##' `Biogen_TDP43_Round2_Reanalysis_10-13-2021_PSMs.txt` file. The
##' data were converted to a [QFeatures] object using the [scp::readSCP()]
##' function. We could not find sample annotations for MS run ID:
##' F61, F34, F42, F88, F77, F8, F21, F5.
##'
##' The peptide data were found in the
##' `Biogen_TDP43_Round2_Reanalysis_10-13-2021_PeptideGroups.txt`
##' file. The column names holding the quantitative data were adapted
##' to match the sample names in the [QFeatures] object. The data were
##' then converted to a [SingleCellExperiment] object and then
##' inserted in the [QFeatures] object.
##'
##' A similar procedure was applied to the protein data. The data were
##' found in the
##' `Biogen_TDP43_Round2_Reanalysis_10-13-2021_Proteins.txt` file. The
##'  column names were
##' adapted, the data were converted to a [SingleCellExperiment]
##' object and then inserted in the [QFeatures] object.
##'
##' @source
##'
##' All data can be downloaded from the MassIVE repository
##' MSV000092119. The source link is:
##' ftp://massive.ucsd.edu/v05/MSV000092119/
##'
##' @references
##'
##' Guise, Amanda J., Santosh A. Misal, Richard Carson, Jen-Hwa Chu,
##' Hannah Boekweg, Daisha Van Der Watt, Nora C. Welsh, et al. 2024.
##' “TDP-43-Stratified Single-Cell Proteomics of Postmortem Human
##' Spinal Motor Neurons Reveals Protein Dynamics in Amyotrophic
##' Lateral Sclerosis.” Cell Reports 43 (1): 113636.
##' ([link to article](http://dx.doi.org/10.1016/j.celrep.2023.113636)).
##'
##' @examples
##' \donttest{
##' guise2024()
##' }
##'
##' @keywords datasets
##'
"guise2024"

####---- Krull et al, 2024 ---####

## Krull, K. K., Ali, S. A., & Krijgsveld, J. 2024. "Enhanced feature matching 
## in single-cell proteomics characterizes IFN-γ response and co-existence of 
## Cell States." Nature Communications, 15(1). https://doi.org/10.1038/s41467-024-52605-x 

library(SingleCellExperiment)
library(scp)
library(tidyverse)

root <- "~/localdata/SCP/krull2024/"

## Data downloaded from:
## https://www.ebi.ac.uk/pride/archive/projects/PXD053464, 
## look for 03_SingleCell_Searches.zip. The relevant file is 
## 03_SingleCell_Searches/10cell_DIA-ME/report.tsv

report <- read.delim(paste0(root, "report.tsv"))

## Match file names with protein assay sample names
report$File.Name <- paste0("X", report$Run)

## Build the annotation table from the run names
annot <- DataFrame(File.Name = unique(report$File.Name))
annot$Run <- sub("X", "", annot$File.Name)
otherVars <- strsplit(annot$Run, "_")
otherVars <- lapply(otherVars, function(x) {
  if (length(x) == 12) x <- x[-4]
  x
})
otherVars <- do.call(rbind, otherVars)
colnames(otherVars) <- c("Date", "..undetermined..", "SampleAnnotation", 
                         "SampleType", "..undetermined..", "..undetermined..", 
                         "..undetermined..", "RunID")
annot <- cbind(annot, otherVars)
annot <- annot[, !grepl("\\.\\.undetermined\\.\\.", colnames(annot))]
rownames(annot) <- annot$File.Name

## Format to a QFeatures object
krull2024 <- readSCPfromDIANN(report)
colData(krull2024) <- annot

####---- Add the protein data ----####
## Data downloaded from:
## Supplementary Data 8 of the paper 
## https://www.nature.com/articles/s41467-024-52605-x#Sec21
## 41467_2024_52605_MOESM12_ESM.xlsx and DIA-ME sheet exported as csv.

prot_data <- read.csv(paste0(root, "41467_2024_52605_MOESM12_ESM_DIA-ME.csv"))

## Create the SingleCellExperiment object
prots <- readSingleCellExperiment(prot_data, 
                                ecol = 3:145)

## Name rows with peptide sequence
rownames(prots) <- prot_data$Protein.Group

from <- names(krull2024)
krull2024 <- addAssay(krull2024, prots, "proteins")
krull2024 <- addAssayLink(krull2024, 
                            from = from, 
                            to = "proteins", 
                            varFrom = rep("Protein.Group", length(from)),
                            varTo = "Protein.Group")

## Save data
save(krull2024,
     file = file.path(paste0(root, "krull2024.Rda")),
     compress = "xz",
     compression_level = 9)

####---- Specht et al. 2018 ---####


# Specht, Harrison, Guillaume Harmange, David H. Perlman, Edward Emmott, Zachary 
# Niziolek, Bogdan Budnik, and Nikolai Slavov. 2018. “Automated Sample 
# Preparation for High-Throughput Single-Cell Proteomics.” bioRxiv. 
# https://doi.org/10.1101/399774.

library(scp)
library(SingleCellExperiment)
library(tidyverse)
setwd("./inst/scripts")
dataDir <- "../extdata/specht2018/"

# The data was downloaded from 
# https://drive.google.com/drive/folders/19YG70I52DH5yETcZagdUjNZWNPs0JXVr
# to scpdata/inst/extdata/specht2018/


####---- Peptide data ----####


# Load the PSM data (MaxQuant evidence file)
paste0(dataDir, "evidence.txt") %>%
  read.table(header = TRUE, sep = "\t") %>%
  rename(Set = Raw.file) ->
  ev

## Create the sample metadata
sets <- unique(ev$Set)
channels <- grep("^R.*y[.][0-9]*$", colnames(ev), value = TRUE)
data.frame(Set = rep(sets, each = length(channels)),
           Channel = rep(channels, length(sets)))
meta


## STOPED HERE: NEED THE SAMPLE ANNOTATION TABLE FOR THIS DATASET TO BE USEFUL!!




dat <- dat0
# Column names holding the TMT intensities
intensity.coln <- colnames(dat)[grepl("^Reporter[.]intensity[.]\\d+$", colnames(dat))]

# Sample data 
# TODO ask for exp design

## Filter data

# Remove the reverse hits (from decoy database) and contaminants
dat <- dat[dat$Reverse != "+", ] # sum(dat0$Reverse == "+")/nrow(dat0) * 100 # 20.02% 
dat <- dat[!grepl("^REV", dat$Leading.razor.protein), ] # sum(grepl("^REV", dat0$Leading.razor.protein))/nrow(dat0) * 100 # 20.02% 
dat <- dat[dat$Potential.contaminant != "+", ] # sum(dat0$Potential.contaminant == "+")/nrow(dat0) * 100 # 5.01% 
dat <- dat[dat$PIF > 0.8 & !is.na(dat$PIF), ] # sum(dat0$PIF <= 0.8 | is.na(dat0$PIF))/nrow(dat0) * 100 # 18.21% 

# Remove spectra with poor identification confidence
# TODO missing FDR ...
dat <- dat[dat$PEP < 0.02, ] # sum(dat0$PEP > 0.02)/nrow(dat0) * 100 # 51.00 % 

# Remove runs with insufficient peptides 
pep.t <- table(dat$Raw.file)
dat <- dat[! dat$Raw.file %in% names(pep.t[pep.t < 300]),]

# Other filters based on carrier ratio
# TODO when experiment design data is available

## Format data

# Change the table to long format by merging the 11 reporter intensities as 2 
# distinct variables (TMT channel and signal intensity)
dat <- pivot_longer(data = dat, cols = intensity.coln, 
                    names_to = "Channel", 
                    values_to = "Reporter.intensity")

# Deal with duplicate peptides (measured as differently charged ions)
# In case of duplicate peptides in the same run for the same channel, we keep the
# peptide with the lowest PEP
dat <- dat[order(dat$PEP, decreasing = FALSE),]
dat <- dat[!duplicated(dat[,c("Modified.sequence", "Raw.file", "Channel")]), ]

# Create a unique ID for samples 
dat$sample <- paste0(dat$Raw.file, "-", dat$Channel)

# Format the expression data
edat <- pivot_wider(dat, id_cols = "Modified.sequence", names_from = "sample",
                    values_from = "Reporter.intensity", 
                    values_fill = list("Reporter.intensity" = NA))
# 0 intensities are missing values
edat[edat == 0] <- NA
# Add rownames
rown <- edat[,1]
edat <- as.matrix(edat[,-1])
rownames(edat) <- rown$Modified.sequence

# Create the phenotype data 
pdat <- do.call(rbind, lapply(colnames(edat), function(x){
  x <- strsplit(x, "-")[[1]]
  data.frame(run = x[1], channel = x[2])
}))
rownames(pdat) <- colnames(edat)
# Create sample metadata description
mpdat <- data.frame(type = c("characters",
                             "characters"),
                    labelDescription = c("the id of the SCoPE-MS run set",
                                         "TMT channel id within the SCoPE-MS set"))
# Combine all phenotype data in an AnnotatedDataFrame
pdat <- AnnotatedDataFrame(data = pdat, varMetadata = mpdat)

# Create the feature data 
fdat <- do.call(rbind, lapply(rownames(edat), function(x){
  .idx <- dat$Modified.sequence == x
  .sub <- dat[.idx, , drop = FALSE]
  # Add common field 
  line <- unique(.sub[, c("Modified.sequence", "Sequence", "Length", "Proteins", 
                          "Gene.names", "Protein.names", "Mass"),])
  # Add peptide count, that is in how many samples was the peptide found
  line$Count <- sum(.idx)
  # Average the remaining fields fields
  line <- data.frame(line, 
                     as.list(apply(.sub[,c("Calibrated.retention.time", "PIF", 
                                           "PEP", "Score")], 2, median, na.rm = TRUE)))
  return(line)
}))
rownames(fdat) <- rownames(edat)
# Make data description for the feature metadata
mfdat <- data.frame(type = c("characters",
                             "characters",
                             "integer",
                             "character",
                             "character",
                             "character",
                             "double",
                             "integer",
                             "double",
                             "double",
                             "double",
                             "double"),
                    labelDescription = c("Sequence representation including the post-translational modifications (abbreviation of the modification in brackets before the modified AA). The sequence is always surrounded by underscore characters ('_').",
                                         "The identified amino acid sequence of the peptide.",
                                         "Number of amino acids of the identified peptide.",
                                         "The identifiers of the proteins a particular peptide is associated with.",
                                         "Name(s) of gene(s) the peptide is associated with.",
                                         "Name(s) of the protein(s) the peptide is associated with.",
                                         "The predicted monoisotopic mass of the identified peptide sequence.",
                                         "The number of samples where the peptide was identified.",
                                         "The recalibrated retention time in minutes in the elution profile of the precursor ion. The value is the median over all samples where the peptide was identified.",
                                         "Short for Parent Ion Fraction; indicates the fraction the target peak makes up of the total intensity in the inclusion window. The value is the median over all samples where the peptide was identified.",
                                         "Posterior Error Probability of the identification. This value essentially operates as a p-value, where smaller is more significant. The value is the median over all samples where the peptide was identified.",
                                         "Andromeda score for the best associated MS/MS spectrum. The value is the median over all samples where the peptide was identified."))
## Combine all feature data in an AnnotatedDataFrame
fdat <- AnnotatedDataFrame(data = fdat, varMetadata = mfdat)

## Create the experimental metadata
expdat <- new("MIAPE",
              title = "Automated sample preparation for high-throughputsingle-cell proteomics",
              abstract = "A major limitation to applying quantitative LC-MS/MS proteomics to small samples, suchas single cells, are the losses incured during sample cleanup. To relieve this limitation, we de-veloped a Minimal ProteOmic sample Preparation (mPOP) method for culture-grown mam-malian cells. mPOP obviates cleanup and thus eliminates cleanup-related losses while expe-diting sample preparation and simplifying its automation.  Bulk SILAC samples processedby mPOP or by conventional urea-based methods indicated that mPOP results in completecell lysis and accurate relative quantification. We integrated mPOP lysis with the Single CellProtEomics by Mass Spectrometry (SCoPE-MS) sample preparation, and benchmarked thequantification  of  such  samples  on  a  Q-exactive  instrument.   The  results  demonstrate  lownoise and high technical reproducibility. Then, we FACS sorted single U-937, HEK-293, andmouse ES cells into 96-well plates and analyzed them by automated mPOP and SCoPE-MS.The quantified proteins enabled separating the single cells by cell-type and cell-division-cyclephase.",
              url = "http://dx.doi.org/10.1101/399774",
              dateStamp = "2018-08-25",
              name = "Harrison Specht, Guillaume Harmange, David H. Perlman, Edward Emmott, Zachary Niziolek, Bogdan Budnik, Nikolai Slavov",
              lab = "Slavov Lab",
              instrumentModel = "Q-Exactive Orbitrap",
              instrumentManufacturer = "Thermo Scientific",
              softwareName = "MaxQuant",
              softwareVersion = "1.6.2.3",
              switchingCriteria = "the top 5 most intense precursors with charges 2 to 4 were selected for HCD fragmentation at resolution 70,000 with a max fill time of 300ms.",
              ionSource = "not specified",
              ionSourceDetails = "not specified",
              analyser = "orbitrap",
              analyserDetails = "a 0.7 Th isolation window was used for MS2 scans.",
              collisionEnergy = "not specified")

## Create the MSnSet object
# specht2018_peptide <- new("MSnSet", exprs = edat, 
#                           featureData = fdat,
#                           phenoData = pdat,
#                           experimentData = expdat)
## Create SingleCellExperiment object
specht2018_peptide <-
  SingleCellExperiment(assay = list(peptide = edat), 
                       rowData = DataFrame(pData(fdat)),
                       colData = DataFrame(pData(pdat)),
                       metadata = list(experimentData = expdat))
## Save data as Rda file
## Note: saving is assumed to occur in "(...)/scpdata/inst/scripts"

##' Leduc et al, 2025 (bioRxiv): Principles of protein abundance regulation
##' across single cells in a mammalian tissue
##'
##' @description
##'
##' Single-cell samples were prepared using the nPOP glass-slide sample
##' preparation method. Proteomics data were acquired using the timsControl 3.1
##' on a timsTOF SCP mass spectrometer. The dataset contains quantitative
##' information on 4,184 single cell from murine trachea. The data are available
##' at the peptide, and protein levels. The paper investigates the protein
##' regulation by translation and protein clearance using a matching single
##' cell RNA Sequencing data.
##'
##' @format A [QFeatures] object with 11 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - Assay 1-4: unprocessed peptide data containing quantitative data coming
##'   from four replicates.
##' - Assay 5-8: processed peptide data containing quantitative data coming
##'   from four replicates.
##' - `proteins_absolute`: protein data containing quantitative data for 2,339
##'   proteins and 4,184 single-cells.
##' - `proteins_relative`: protein data containing quantitative data for 2,331
##'   proteins and 4,184 single-cells. Relative abundance values against the
##'   protein mean across all samples.
##' - `proteins_imputed`: protein data containing quantitative data for 667
##'   proteins and 4,184 single-cells with k-nearest neighbors (KNN) imputation
##'   and comBat batch-correction.
##'
##' The `colData(leduc2025())` contains cell type and batch annotations that
##' are common to all assays.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: CellenONE cell sorting.
##' - **Sample preparation** performed using the nPOP sample preperation method.
##'   cell lysis (DMSO) + trypsin digestion + mTRAQ reagents.
##' - **Separation**: online nLC (Vanquish Neo UHPLC with a 25cm x 75um
##'   IonOpticks Aurora Series UHPLC column (AUR2-25075C18A).
##' - **Mass spectrometry**: timsTOF SCP mass spectrometer (MS1 scan range =
##'   100-1700 m/z; MS2 scan range = 300-1000 m/z).
##' - **Data analysis**: DIA-NN(v1.9.0).
##'
##' @section Data collection:
##'
##' The Peptide data were collected from a Zenodo folder that is accessible from
##' the SlavovLab website (see `Source` section).
##'
##' The folder ('02_raw_reptide_X_singleCell/') contains the following
##' files of interest:
##' - `r1_peptide.csv`: peptide level unprocessed quantitative data for
##' replicate 1.
##' - `r2_peptide.csv`: peptide level unprocessed quantitative data for
##' replicate 2.
##' - `r3_peptide.csv`: peptide level unprocessed quantitative data for
##' replicate 3.
##' - `r4_peptide.csv`: peptide level unprocessed quantitative data for
##' replicate 4.
##'
##' ('03_QuantQC_objects/') contains the following files of interest:
##' - `r1_5day_male.RData`: peptide level processed quantitative data for
##' replicate 1 and row data information for peptide to protein mapping.
##' - `r2_5day_female.RData`: peptide level processed quantitative data for
##' replicate 2 and row data information for peptide to protein mapping.
##' - `r3_10day_male.RData`: peptide level processed quantitative data for
##' replicate 3 and row data information for peptide to protein mapping.
##' - `r4_10day_female.RData`: peptide level processed quantitative data for
##' replicate 4 and row data information for peptide to protein mapping.
##'
##' ('04_Gene_X_SingleCell_and_annotations/') contains the following files of
##' interest:
##' `sc_protein_absolute.csv`: protein level quantitative data with absolute
##' protein concentrations.
##' `sc_protein_relative.csv`: protein level quantitative data with relative
##' protein abundance.
##' `sc_protein_annotations.csv`: sample and batch annotations.
##'
##' We also obtained imputed and batch corrected protein level data. To do that
##' we run the script `get_protein_Data.R` based on the original script
##' `02_cell_type_assign.R` in the github repository of the article.
##'
##' We formatted the peptide level quantification tables so that columns match
##' with those of the annotation and protein level data. Each peptide level
##' data for replicates turned into [SingleCellExperiment] objects including
##' row data information that is extracted from shared QuantQC objects. All
##' the peptide level assays used to generate [QFeatures] object.
##'
##' Protein level data were taken from '04_Gene_X_SingleCell_and_annotations/'
##' folder. Imputed and batch effect corrected protein level data is generated
##' using `get_protein_Data.R` script. The protein assays were formatted as
##' [SingleCellExperiment] objects and the sample metadata were matched to the
##' column names. The objects are then added to the [QFeatures] object
##' and the rows of the peptide data are linked to the rows of the corresponding
##' protein data based on the protein sequence information through an
##' `AssayLink` object.
##'
##' @source
##' The data were downloaded from the
##' [Slavov Lab](https://scp.slavovlab.net/Leduc_et_al_2025) website via a
##' shared Zenodo folder
##' [folder](https://zenodo.org/records/14902834).
##' The raw data and the quantification data can also be found in the
##' MassIVE repository `MSV000098940`:
##' ftp://massive-ftp.ucsd.edu/v10/MSV000098940/.
##'
##' The data used and generated as part of the scpdata repackaging is available
##' in the [Zenodo archive](https://doi.org/10.5281/zenodo.21904283).
##'
##' @references
##' Leduc A, et al., Principles of protein abundance regulation across single
##' cells in a mammalian tissue, bioRxiv, doi: 10.1101/2025.09.17.676955
##' ([link to article](https://www.biorxiv.org/content/10.1101/2025.09.17.676955v2)).
##'
##' @examples
##' \donttest{
##' leduc2025()
##' }
##'
##' @keywords datasets
##'
"leduc2025"

library(scp)
library(tidyr)
library(dplyr)

pep <- read.table("/mnt/disk3/leopoldguyot/PXD071075/peptide_report.tsv",
    header = TRUE,
    sep = "\t"
)
prot <- read.table("/mnt/disk3/leopoldguyot/PXD071075/protein_report.tsv",
    header = TRUE,
    sep = "\t"
)

design <- read.csv("~/dev/2025-phd-leopold-guyot/year1/scpdata_datasets/data/1.clean_meta.csv")

# Prepare peptide table
rownames(design) <- design$ID
pep <- pep %>%
    separate(Run,
        into = c("Platform", "Sample", "Number", "Unknown"),
        sep = "_",
        remove = FALSE
    ) %>%
    mutate(Precursor.Quantity = log2(Precursor.Quantity))

pep$Sample <- dplyr::recode(
    pep$Sample,
    "WLBSC"  = "S1",
    "WLBSC2" = "S2",
    "WLBSC3" = "S3"
)

pep$cellID <- paste(pep$Sample, pep$Number, sep = "_")

# Loading PSM
wu2026 <- readSCP(pep, runCol = "cellID", quantCols = c("Precursor.Quantity"), fnames = "Precursor.Id")
# add colData
colData(wu2026) <- as(design, "DataFrame")

psmNames <- names(wu2026)
pepNames <- paste0("peptides_", names(wu2026))


# Aggregate to peptide level
wu2026 <- aggregateFeatures(wu2026,
    i = psmNames,
    name = pepNames,
    fcol = "Modified.Sequence",
    fun = matrixStats::colMedians
)

wu2026 <- joinAssays(wu2026, pepNames, name = "peptides")
wu2026 <- wu2026[, , setdiff(names(wu2026), pepNames)]
wu2026 <- addAssayLink(wu2026,
    from = psmNames,
    to = "peptides",
    varFrom = rep("Modified.Sequence", length(psmNames)),
    varTo = "Modified.Sequence"
)

# Aggregate to protein level
wu2026 <- aggregateFeatures(wu2026,
    i = "peptides",
    name = "proteins",
    fcol = "Protein.Ids",
    fun = matrixStats::colMedians
)

# Add paper's protein data
protse <- readSummarizedExperiment(prot,
    quantCols = grep("Evosep", colnames(prot)),
    fnames = "Protein.Ids"
)

old_names <- colnames(protse)

mapping <- c(
    "WLBSC" = "S1",
    "WLBSC2" = "S2",
    "WLBSC3" = "S3"
)

rename_col <- function(name) {
    wbsc_type <- grep(paste(names(mapping), collapse = "|"), name, value = TRUE)
    wbsc_type <- sub(".*(WLBSC[23]?).*", "\\1", name) # extract WLBSC/WLBSC2/WLBSC3
    prefix <- mapping[wbsc_type]

    # extract first number after WLBSC
    num <- sub(".*WLBSC[23]?_([0-9]+)_.*", "\\1", name)

    paste0(prefix, "_", num)
}

colnames(protse) <- sapply(old_names, rename_col)

protse <- protse[!duplicated(rownames(protse))]

wu2026 <- addAssay(wu2026, protse, "imported_proteins")

wu2026 <- addAssayLink(wu2026, "peptides", "imported_proteins", varFrom = "Protein.Ids", varTo = "Protein.Ids")

save(wu2026,
    file = "/mnt/disk3/leopoldguyot/wu2026.rda",
    compress = "xz",
    compression_level = 9
)

##' Schoof et al. 2021 (Nat. Comm.): acute myeloid leukemia
##' differentiation
##'
##' Single-cell proteomics data from OCI-AML8227 cell culture to
##' reconstruct the cellular hierarchy. The data were acquired using
##' TMTpro multiplexing. The samples contain either no cells,
##' single cells, 10 cells (reference channel) 200 cells (booster
##' channel) or are simply empty wells. Single cells are expected to
##' be one of progenitor cells (`PROG`), leukaemia stem cells (`LSC`),
##' CD38- blast cells (`BLAST CD38-`) or CD38+ blast cells
##' (`BLAST CD38+`). Booster are either a known 1:1:1 mix of cells
##' (PROG, LSC and BLAST) or are isolated directly from the bulk
##' sample. Samples were isolated and annotated using flow cytometry.
##'
##' @format A [QFeatures] object with 194 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - `F*`: 192 assays containing PSM quantification data for 16
##'    TMT channels. The quantification data contain signal to noise
##'    ratios as computed by Proteome Discoverer.
##' - `proteins`: quantitative data for 2898 protein groups in 3072
##'   samples (all runs combined). The quantification data contain
##'   signal to noise ratios as computed by Proteome Discoverer.
##' - `logNormProteins`: quantitative data for 2723 protein groups in
##'   2025 single-cell samples. This assay is the protein datasets that
##'   was processed by the authors. Dimension reduction and clustering
##'   data are also available in the `reducedDims` and `colData` slots,
##'   respectively
##'
##' Sample annotation is stored in `colData(schoof2021())`. The cell
##' type annotation is stored in the `Population` column. The flow
##' cytometry data is also available: FSC-A, FSC-H, FSC-W, SSC-A,
##' SSC-H, SSC-W, APC-Cy7-A (= CD34) and PE-A (= CD38).
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Sample isolation**: cultured AML 8227 cells were stained with
##'   anti-CD34 and anti-CD38. The sorting was performed by FACSAria
##'   instrument and deposited in 384 well plates.
##' - **Sample preparation**: cells are lysed using freeze-boil and
##'   sonication in a lysis buffer (TFE) that also includes reduction
##'   and alkylation reagents (TCEP and CAA), followed by trypsin
##'   (protein) and benzonase (DNA) digestion, TMT-16 labeling and
##'   quenching, desalting using SOLAµ C18 plate, peptide
##'   concentration, pooling and peptide concentration again. The
##'   booster channel contains 200 cell equivalents.
##' - **Liquid chromatography**: peptides are separated using a C18
##'   reverse-phase column (50cm x 75 µm i.d., Thermo EasySpray) combined
##'   to a Thermo EasyLC 1200 for 160 minute gradient with a flowrate of
##'   100nl/min.
##' - **Mass spectrometry**: FAIMSPro interface is used. MS1 setup:
##'   resolution 60.000, AGC target of 300%, accumulation of 50ms. MS2
##'   setup: resolution 45.000, AGC target of 150, 300 or 500%,
##'   accumulation of 150, 300, 500, or 1000ms.
##' - **Raw data processing**: Proteome Discoverer 2.4 + Sequest spectral
##'   search engine and validation with Percolator
##'
##' @section Data collection:
##'
##' All data were collected from the PRIDE repository (accession ID:
##' PXD020586). The data and metadata were extracted from the
##' `SCeptre_FINAL.zip` file.
##'
##' We performed extensive data wrangling to combine al the metadata
##' available from different files into a single table available using
##' `colData(schoof2021)`.
##'
##' The PSM data were found in the `bulk_PSMs.txt` file. Contaminants
##' were defined based on the protein accessions listed in
##' `contaminant.txt`. The data were converted to a [QFeatures]
##'  object using the [scp::readSCP()] function.
##'
##' The protein data were found in the `bulk_Proteins.txt` file.
##' Contaminants were defined based on the protein accessions listed
##' in `contaminant.txt`.The column names holding the quantitative
##' data were adapted to match the sample names in the [QFeatures]
##' object. Unnecessary feature annotations (such as in which assay
##' a protein is found) were removed. Feature names were created
##' following the procedure in SCeptre: features names are the
##' protein symbol (or accession if missing) and if duplicated
##' symbols are present (protein isoforms), they are made unique by
##' appending the protein accession.  Contaminants were defined based
##' on the protein accessions listed in `contaminant.txt`. The data
##' were then converted to a [SingleCellExperiment] object and
##' inserted in the [QFeatures] object.
##'
##' The log-normalized protein data were found in the `bulk.h5ad` file.
##' This dataset was generated by the authors by running the notebook
##' called `bulk.ipynb`. The `bulk.h5ad` was loaded as an `AnnData`
##' object using the `scanpy` Python module. The object was then
##' converted to a `SingleCellExperiment` object using the
##' `zellkonverter` package. The column names holding the quantitative
##' data were adapted to match the sample names in the [QFeatures]
##' object. The data were then inserted in the [QFeatures] object.
##'
##' The script to reproduce the `QFeatures` object is available at
##' `system.file("scripts", "make-data_schoof2021.R", package = "scpdata")`
##'
##' @source
##'
##' The PSM and protein data can be downloaded from the PRIDE
##' repository PXD020586 The source link is:
##' https://www.ebi.ac.uk/pride/archive/projects/PXD020586
##'
##' @references
##'
##' Schoof, Erwin M., Benjamin Furtwängler, Nil Üresin, Nicolas Rapin,
##' Simonas Savickas, Coline Gentil, Eric Lechman, Ulrich auf Dem
##' Keller, John E. Dick, and Bo T. Porse. 2021. “Quantitative
##' Single-Cell Proteomics as a Tool to Characterize Cellular
##' Hierarchies.” Nature Communications 12 (1): 745679.
##' ([link to article](http://dx.doi.org/10.1038/s41467-021-23667-y)).
##'
##' @examples
##' \donttest{
##' schoof2021()
##' }
##'
##' @keywords datasets
##'
"schoof2021"

####---- Petrosius et al, 2023 ---####


## Petrosius, V., Aragon-Fernandez, P., Üresin, N. et al. Exploration of cell
## state heterogeneity using single-cell proteomics through sensitivity-tailored
## data-independent acquisition. Nat Commun 14, 5910 (2023). 
## https://doi.org/10.1038/s41467-023-41602-1

library(SingleCellExperiment)
library(scp)
library(tidyverse)

####---- Load PSM data ----####
## The PSM data downloaded from the https://dataverse.uclouvain.be/dataset.xhtml?persistentId=doi:10.14428/DVN/EMAVLT 
## and 'sample_facs.csv' from the https://zenodo.org/records/8146605
## '20240205_111251_PEPQuant (Normal).tsv' = contains the PSM data.
## 'sample_facs.csv' = contains the cell annotations.

root <- "https://dataverse.uclouvain.be/api/access/datafile/"
ev <- read.delim(url(paste0(root, "24333")))
design <- read.delim(url("https://zenodo.org/records/8146605/files/sample_facs.csv?download=1"))

####---- Create sample annotation ----####
design %>%
  select(-X) %>%
  distinct() %>%
  add_column(Channel = "PEP.Quantity") %>%
  rename(Set = File.Name, 
         SampleType = Plate) ->
  meta

## Clean quantitative data
ev %>%
  rename(Set = R.FileName, 
         protein = PG.ProteinAccessions) %>%
  ## Create a modified sequence + charge variable
  mutate(peptide = paste0("_", PEP.StrippedSequence, "_.", FG.Charge)) %>%
  filter(Set %in% meta$Set) ->
  evproc

## Create the QFeatures object
petrosius2023_mES <- readSCP(evproc, 
                    meta, 
                    channelCol = "Channel", 
                    batchCol = "Set",
                    removeEmptyCols = TRUE)


####---- Peptide data ----####
## The peptide data downloaded from the same Dataverse repository.
## '20240205_111251_Peptide Quant (Normal).tsv' contains the peptide data.

## Load the peptide level quantification data
pep_data <- read.delim(url(paste0(root, "24332")))

## Clean quantitative data
pep_data %>%
  pivot_wider(names_from = R.FileName, 
              values_from = PG.Quantity, 
              id_cols = c(EG.PrecursorId, PG.ProteinAccessions)) ->
  peps

## Create the SingleCellExperiment object
pep <- readSingleCellExperiment(peps, 
                                ecol = 3:605)

## Name rows with peptide sequence
rownames(pep) <- peps$EG.PrecursorId

## Rename columns so they math with the PSM data
colnames(pep) %>%
  paste0("PEP.Quantity") ->
  colnames(pep)

## Include the peptide data in the QFeatures object
petrosius2023_mES <- addAssay(petrosius2023_mES, pep, name = "peptides")

## Link the PSMs and the peptides
petrosius2023_mES <- addAssayLink(petrosius2023_mES, 
                           from = 1:603, 
                           to = "peptides",
                           varFrom = rep("EG.PrecursorId", 603),
                           varTo = "EG.PrecursorId")


####---- Add the protein data ----####
## The protein data downloaded from the same Dataverse repository.
## '20240205_111251_PGQuant (Normal).tsv' contains the protein data.

prot_data <- read.delim(url(paste0(root, "24331")))

## Clean quantitative data
prot_data %>% 
  mutate(R.FileName = sub(".*rawfiles/", "", R.Raw.File.Name)) %>%
  mutate(R.FileName = sub(".raw", "", R.FileName)) %>%
  pivot_wider(names_from = R.FileName, 
              values_from = PG.Quantity, 
              id_cols = PG.ProteinAccessions) ->
  prots

## Create the SingleCellExperiment object
pro <- readSingleCellExperiment(prots, 
                                ecol = 2:604)

## Name rows with peptide sequence
rownames(pro) <- prots$PG.ProteinAccessions

## Rename columns so they math with the PSM data
colnames(pro) %>%
  paste0("PEP.Quantity") ->
  colnames(pro)

## Include the peptide data in the QFeatures object
petrosius2023_mES <- addAssay(petrosius2023_mES, pro, name = "proteins")

## Link the PSMs and the peptides
petrosius2023_mES <- addAssayLink(petrosius2023_mES, 
                                from = "peptides", 
                                to = "proteins",
                                varFrom = "PG.ProteinAccessions",
                                varTo = "PG.ProteinAccessions")

## Save data
save(petrosius2023_mES,
     file = file.path("~/localdata/SCP/petrosiusmESC/20240205_111248_mESC_SNEcombine_m15-m2i/petrosius2023_mES.Rda"),
     compress = "xz",
     compression_level = 9)

####---- Woo et al. 2022 ---####


## Woo, Jongmin, Geremy C. Clair, Sarah M. Williams, Song Feng, 
## Chia-Feng Tsai, Ronald J. Moore, William B. Chrisler, et al. 2022.
## “Three-Dimensional Feature Matching Improves Coverage for 
## Single-Cell Proteomics Based on Ion Mobility Filtering.” Cell 
## Systems 0 (0). https://doi.org/10.1016/j.cels.2022.02.003.

## The data was downloaded from the MASSIVE repo: MSV000085937 

## This script formats the non-depleted lung dataset

library(SingleCellExperiment)
library(scp)
library(tidyverse)
dataDir <-"~/PhD/.localdata/SCP/woo2022/NonDepleted_Lung_SingleCellProteomics"

####---- Load peptide data ----####

f <- list.files(dataDir, pattern = "^pep", 
                recursive = TRUE, full.names = TRUE)
peps <- read.delim(f)
## Get "raw" intensities
pepsIntensity <- peps[, !grepl("^LFQ|Lib.$", colnames(peps))]
pepsIntensity <- readSingleCellExperiment(
    pepsIntensity,
    ecol = grep("^Intensity.", colnames(pepsIntensity)),
    fnames = "Sequence"
)
colnames(pepsIntensity) <- gsub("Intensity.", "", colnames(pepsIntensity))
## Get LFQ normalized intensities
pepsLfq <- peps[, !grepl("^Intensity.\\d", colnames(peps))]
pepsLfq <- readSingleCellExperiment(
    pepsLfq,
    ecol = grep("^LFQ", colnames(pepsLfq)),
    fnames = "Sequence"
)
colnames(pepsLfq) <- gsub("LFQ.intensity.", "", colnames(pepsLfq))

####---- Load protein data ----####

f <- list.files(dataDir, pattern = "^prot", 
                recursive = TRUE, full.names = TRUE)
prots <- read.delim(f)
## Remove unnecessary columns
prots <- prots[, !grepl("^Identif|^MS.MS.count|^Peptides[.]|nique.peptides[.]|^Sequence.coverage", colnames(prots))]
## Get intensities
protsIntensity <- prots[, !grepl("^iBAQ|^LFQ|Lib.$", colnames(prots))]
protsIntensity <- readSingleCellExperiment(
    protsIntensity,
    ecol = grep("^Intensity.", colnames(protsIntensity)),
    fnames = "Protein.IDs"
)
colnames(protsIntensity) <- gsub("Intensity.", "", colnames(protsIntensity))
## Get iBAQ normalized intensities
protsIbaq <- prots[, !grepl("^Intensity.|^LFQ|Lib.$", colnames(prots))]
protsIbaq <- readSingleCellExperiment(
    protsIbaq,
    ecol = grep("^iBAQ.", colnames(protsIbaq)),
    fnames = "Protein.IDs"
)
colnames(protsIbaq) <- gsub("iBAQ.", "", colnames(protsIbaq))
## Get LFQ normalized intensities
protsLfq <- prots[, !grepl("^Intensity.|^iBAQ", colnames(prots))]
protsLfq <- readSingleCellExperiment(
    protsLfq,
    ecol = grep("^LFQ.", colnames(protsLfq)),
    fnames = "Protein.IDs"
)
colnames(protsLfq) <- gsub("LFQ.intensity.", "", colnames(protsLfq))

####---- Get sample annotations ----####

f <- list.files(dataDir, pattern = "^summary", 
                recursive = TRUE, full.names = TRUE)
summary <- read.delim(f)

## Guess sample annotations from the spectra file name
annot <- DataFrame(row.names = colnames(protsIntensity),
                   FileName = summary$Raw.file[match(colnames(protsIntensity), summary$Experiment)])
annot$RunIndex <- sub("^(\\d*)_.*$", "\\1", annot$FileName)
annot$Well <- sub("^.*Chip1_(.*?)_.*$", "\\1", annot$FileName)
annot$WellRow <- sub("^.", "", annot$Well)
annot$WellCol <- gsub("\\d", "", annot$Well)
annot$Undocumented <- sub("^.*SC_(.*)_Chip.*$", "\\1", annot$FileName)

####---- Create the QFeatures object ----####

el <- ExperimentList(peptides_intensity = pepsIntensity,
                     peptides_LFQ = pepsLfq,
                     proteins_intensity = protsIntensity,
                     proteins_iBAQ = protsIbaq,
                     proteins_LFQ = protsLfq)
woo2022_lung <- QFeatures(el, colData = annot)

## Create assay links
woo2022_lung <- addAssayLinkOneToOne(woo2022_lung, 
                                     from = "peptides_intensity", 
                                     to = "peptides_LFQ")
woo2022_lung <- addAssayLink(woo2022_lung, 
                             from = "peptides_intensity", 
                             to = "proteins_intensity",
                             varFrom = "Leading.razor.protein", 
                             varTo = "Majority.protein.IDs")
woo2022_lung <- addAssayLink(woo2022_lung, 
                             from = "peptides_intensity", 
                             to = "proteins_iBAQ",
                             varFrom = "Leading.razor.protein", 
                             varTo = "Majority.protein.IDs")
woo2022_lung <- addAssayLink(woo2022_lung, 
                             from = "peptides_intensity", 
                             to = "proteins_LFQ",
                             varFrom = "Leading.razor.protein", 
                             varTo = "Majority.protein.IDs")
plot(woo2022_lung)

### Save data as Rda file
save(woo2022_lung, 
     file = file.path("~/PhD/.localdata/scpdata/woo2022_lung.Rda"),
     compress = "xz", 
     compression_level = 9)

##' Wu et al., 2026 (Nature Biotechnology): single-cell proteomic landscape
##' of the developing human brain
##'
##' @description
##'
##' Label-free single-cell proteomics data from prenatal human brain tissue
##' (gestational weeks 13, 15 and 19), generated to characterize cell-type
##' proteomes and developmental trajectories at single-cell resolution.
##'
##' @format A [QFeatures] object with 2313 sets, each set being a
##' [SingleCellExperiment] object:
##'
##' - Set 1-2310: log-transformed precursor-level single-cell data (one
##'   column per set) from DIA-NN reports.
##' - `peptides`: peptide-level data containing quantitative data for 17755
##'   peptides in 2310 single cells.
##' - `imported_proteins`: protein-level table imported from the authors'
##'   protein report, containing 4401 proteins in 2310 single cells.
##' - `proteins`: protein-level data containing quantitative data for 5107
##'   proteins in 2310 single cells.
##'
##' Sample annotation is stored in `colData(wu2026())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Sample isolation**: fresh prenatal human brain tissue was dissociated
##'   and single cells were sorted by FACS (Sony SH800) into 384-well low-bind
##'   plates.
##' - **Sample preparation**: cells were lysed in low-volume TEAB-based buffer,
##'   digested overnight with trypsin, acidified with trifluoroacetic acid,
##'   and desalted on EvoTip Pure.
##' - **Liquid chromatography**: peptides were separated on an IonOpticks Aurora
##'   Elite XT C18 nano-LC column (15 cm x 75 micrometer) on an Evosep One
##'   using a 31-minute gradient.
##' - **Mass spectrometry**: Orbitrap Eclipse Tribrid with FAIMS Pro was used
##'   in DIA mode.
##' - **Raw data processing**: DIA-NN against the UniProt human reference
##'   proteome.
##'
##' @section Data collection:
##'
##' The `QFeatures` object was built from the DIA-NN peptide and protein report
##' tables and a sample annotation table. PSM-level data were imported with
##' [scp::readSCP()], log-transformed, aggregated to peptide-level features, and
##' joined across single-cell runs. The protein report table was imported as a
##' [SingleCellExperiment], added as an set, and linked to peptide-level data.
##'
##' The script to reproduce the `QFeatures` object is available at
##' `inst/scripts/make-data_wu2026.R`.
##'
##' @source
##' The data were downloaded from the PRIDE repository with accession ID
##' `PXD071075`:
##' https://www.ebi.ac.uk/pride/archive/projects/PXD071075
##'
##' @references
##' Wu, T., Jiang, L., Mukhtar, T., Wang, L., Jian, R., Wang, C., Trinh, T.,
##' Kriegstein, A. R., Snyder, M., and Li, J. 2026. "Single-cell proteomic
##' landscape of the developing human brain." Nature Biotechnology.
##' [Link to article](https://doi.org/10.1038/s41587-025-02980-7)
##'
##' @examples
##' \donttest{
##' wu2026()
##' }
##'
##' @keywords datasets
##'
"wu2026"

####---- Khan et al, 2023 ---####


## Saad Khan, Rachel Conover, Anand R. Asthagiri, Nikolai Slavov. 2023. 
## “Dynamics of single-cell protein covariation during epithelial–mesenchymal 
## transition.” bioRxiv. https://doi.org/10.1101/2023.12.21.572913.

library(SingleCellExperiment)
library(scp)
library(tidyverse)

####---- Load PSM data ----####

## 3 Seperate files downloaded from the drive link:
## https://drive.google.com/drive/folders/1zCsRKWNQuAz5msxx0DfjDrIe6pUjqQmj
## 'ev_updated_NS.DIA.txt' = the MaxQuant output file for all batches with the PSM data
## 'annotation.csv' = the cell annotation (remainder operation needs to be used //16)
## 'batch.csv' = the batch annotation 

root <- "~/localdata/SCP/khan2023/002-singleCellDataGeneration/"
ev <- read.delim(paste0(root, "ev_updated_NS.DIA.txt"))
design <- read.csv(paste0(root, "annotation.csv"))
batch <- read.csv(paste0(root, "batch.csv"))

## Clean the sample metadata so that it meets the requirements for
## `scp::readSCP`. The cell annotation and batch annotation are merged into a 
## table
inner_join(x = design %>% 
             pivot_longer(-Set, 
                          names_to = "Channel", 
                          values_to = "SampleAnnotation") %>%
             mutate(SampleType = recode(SampleAnnotation,
                                        neg = "Negative",
                                        d0 = "Day_0",
                                        d3 = "Day_3",
                                        d9 = "Day_9",
                                        unused = "Unused",
                                        reference = "Reference",
                                        carrier = "Carrier")), 
           y = batch %>% 
             rename(Set = set) %>%
             mutate_all(as.character),
           by = "Set") -> meta

## Clean quantitative data
ev %>%
  ## Variable names should be consistent with metadata
  rename_all(gsub, 
             pattern = "^Reporter[.]intensity[.](\\d*)$", 
             replacement = "RI\\1") %>%
  rename(Set = Raw.file, 
         protein = Leading.razor.protein) %>%
  ## Create a modified sequence + charge variable
  mutate(peptide = paste0(Modified.sequence, Charge)) %>%
  ## keep only single cell runs 
  filter(!grepl("col\\d{2}|arrier|Ref|Master|SQC|blank", Set)) %>%
  ## remove experimental sets concurrent with low mass spec performance
  filter(!grepl("FP9[56]|FP103", Set)) %>%
  ## Make sure all runs are described in design, if not, remove them
  filter(Set %in% meta$Set) ->
  evproc


## Create the QFeatures object
khan2023 <- readSCP(evproc,
                    meta,
                    channelCol = "Channel",
                    batchCol = "Set",
                    removeEmptyCols = TRUE)

####---- Get the annotation table ----####

## The protein data contain features by single-cells. The 
## columns are named after an arbitrary indexing that must be 
## converted before adding the assay to the QFeatures object to 
## preserve consistency across assays.

## Annotation file was downloaded from 
## https://drive.google.com/drive/folders/1zCsRKWNQuAz5msxx0DfjDrIe6pUjqQmj
## 'annotation.csv': Cell annotations

## The `IDtoChannel.csv` file was generated using the `EMTTGFB_singleCellProcessing.R`
## script from https://github.com/SlavovLab/EMT_TGFB_2023/tree/main adjusted to
## obtain mapping from the cell id (i...) to the (Set + RI channel)

read.csv(paste0(root, "annotation.csv")) %>%
  pivot_longer(-Set, 
               names_to = "Channel", 
               values_to = "SampleAnnotation") %>%
  mutate(SampleType = recode(SampleAnnotation, 
                             neg = "Negative",
                             d0 = "Day_0",
                             d3 = "Day_3",
                             d9 = "Day_9",
                             unused = "Unused",
                             reference = "Reference",
                             carrier = "Carrier")) %>%
  add_column(lcbatch = "A", sortday = "B", digest = "C") %>%
  unite(rowname, Set, Channel, sep = "", remove = FALSE) %>%
  column_to_rownames() ->
  annot

idMap <- read.csv(paste0(root, "cellIDToChannel.csv"), row.names = 1)

####---- Add the peptide data ----####

## Peptide quantity matrix downloaded from:  
## https://drive.google.com/drive/folders/1zCsRKWNQuAz5msxx0DfjDrIe6pUjqQmj

peps <- read.delim(paste0(root, "EpiToMesen.TGFB.nPoP_trial1_pepByCellMatrix_NSThreshDART_medIntCrNorm.txt"))
peps %>%
  rename(peptide = pep) %>%
  readSingleCellExperiment(ecol = 1:421, fnames = "peptide") ->
  peptides

colnames(peptides) <- idMap$Channel[match(colnames(peptides), idMap$cellID)]
colData(peptides) <- DataFrame(annot[colnames(peptides), ])

khan2023 <- addAssay(khan2023, peptides, name = "peptides")

## Include rowData to peptides assay
rowData(khan2023[["peptides"]]) <- DataFrame(peptide = peps$pep, 
                                             protein = peps$prot)

## First find which PSM assays were included
sel <- sapply(grep("eSK", names(khan2023), value = TRUE), 
              function(name) {
                x <- khan2023[[name]]
                ## Does the current PSM data have at least 1 colname in common with pep?
                inColnames <- any(colnames(x) %in% colnames(peptides))
                ## Does the current PSM data have at least 1 peptide sequence in common with pep?
                inSequence <- any(rowData(x)$peptide %in% rowData(peptides)$peptide)
                return(inColnames && inSequence) ## The PSM assay must fulfill both conditions
})

## Add an AssayLink that bridges the PSM assays and the peptide assay
khan2023 <- addAssayLink(khan2023, from = which(sel), to = "peptides", 
                             varFrom = rep("peptide", sum(sel)), varTo = "peptide")

####---- Add the protein data ----####

## Imputed and un-imputed protein quantity matrices downloaded from:  
## https://drive.google.com/drive/folders/1zCsRKWNQuAz5msxx0DfjDrIe6pUjqQmj

## Add imputed protein data
data <- read.delim(paste0(root, "EpiToMesen.TGFB.nPoP_trial1_1PercDartFDRTMTBulkDIA.WallE_imputed.txt"))
data$protein <- rownames(data)
data %>% 
  readSingleCellExperiment(ecol = 1:420, fnames = 'protein') ->
  prot_imp

colnames(prot_imp) <- idMap$Channel[match(colnames(prot_imp), idMap$cellID)]
colData(prot_imp) <- DataFrame(annot[colnames(prot_imp), ])

khan2023 <- addAssay(khan2023, prot_imp, name = "proteins_imputed")

## Add an AssayLink that bridges the PSM assays and the peptide assay
khan2023 <- addAssayLink(khan2023, from = "peptides", to = "proteins_imputed",
                         varFrom = "protein", varTo = "protein")

## Add un-imputed protein data
data <- read.delim(paste0(root, "EpiToMesen.TGFB.nPoP_trial1_1PercDartFDRTMTBulkDIA.WallE_unimputed.txt"))
data$protein <- rownames(data)
data %>%
  readSingleCellExperiment(ecol = 1:420, fnames = 'protein') ->
  prot_unimp

colnames(prot_unimp) <- idMap$Channel[match(colnames(prot_unimp), idMap$cellID)]
colData(prot_unimp) <- DataFrame(annot[colnames(prot_unimp), ])

khan2023 <- addAssay(khan2023, prot_unimp, name = "proteins_unimputed")

## Add an AssayLink that bridges the PSM assays and the peptide assay
khan2023 <- addAssayLink(khan2023, from = "peptides", to = "proteins_unimputed",
                         varFrom = "protein", varTo = "protein")

## Save data
save(khan2023,
     file = file.path(paste0(root, "khan2023.Rda")),
     compress = "xz", 
     compression_level = 9)

##' Hu et al, 2023 (The Journal of Physical Chemistry B): Correlated protein
##' modules
##'
##' @description
##'
##' They demonstrate the correlations between the levels of pairs of proteins
##' in single-cell proteomics (SCP) at steady state. In measuring pairwise
##' correlations among 1000 proteins in a population of K562 cells and oocytes,
##' they observed many correlated protein modules (CPMs) that are functionally
##' involved in certain biological functions. Certain CPMs are specific to a
##' particular cell type, some common to different cell types. Additionally,
##' compared to single-cell transcriptomics and bulk proteomics,
##' protein correlations are functionally and experimentally more significant
##' in SCP than those corresponding mRNAs.
##'
##' @format Two [SingleCellExperiment] objects:
##'
##' - `proteins_K562`: protein data containing quantitative data for 1249
##'   proteins and 69 single-cells with zero imputation.
##' - `proteins_oocyte`: protein data containing quantitative data for 3422
##'   proteins and 137 single-cells with zero imputation.
##'
##' The `colData(hu2023_oocyte())` contains cell type annotation.
##' The `colData(hu2023_K562())` contains cell type annotation.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: K562 cells were re-suspended and washed in cold PBS.
##'   Single cells/10 cells were sorted into 96-well plates using a FACSAria
##'   instrument. Oocyte-cumulus complexes from C57/6J mice were collected
##'   after PMSG and HCG injections, with hyaluronidase used to remove cumulus
##'   cells. All samples stored at -80 degrees Celsius.
##' - **Sample preparation** Cells were digested with trypsin at 37 degrees
##'   Celsius for 3 hours. For label-free proteomics, digestion was terminated
##'   by adding 0.43% TFA and 1% ACN in water, followed by drying in a
##'   concentrator. Peptides were resuspended in 0.1% TFA and 1% ACN, and
##'   then transferred to sample tubes for LC-MS/MS analysis.
##' - **Separation**: 4 microliters of peptide digests were injected into a
##'   high-performance chromatography column (IonOpticks) and separated at a
##'   flow rate of 100 nL/min using a nanoflow liquid chromatography system.
##'   The effective gradient was 70 mins, allowing 16 cells per day.
##' - **Ionization**: Peptides were analyzed using an Orbitrap Eclipse mass
##'   spectrometer with a FAIMS Pro interface. FAIMS compensation voltages of
##'   -55 and -70 V were applied, with a 1-second cycle time for both voltages.
##' - **Mass spectrometry**: MS spectra were acquired with the Orbitrap
##'   analyzer, while MS/MS spectra were acquired with a linear ion trap
##'   analyzer. The maximum ion injection time for MS/MS was 200 ms.
##' - **Data analysis**: MS raw files were searched against the UniProt
##'   human protein database and an in-house contamination database
##'   using Proteome Discoverer(2.4). Label-free quantification was based on
##'   peak intensity with the match-between-runs (MBR) feature enabled.
##'
##' @section Data collection:
##'
##' The oocyte protein data shared by the author and it is accessible from the
##' [Shared File](https://biopic-my.sharepoint.cn/:x:/g/personal/humo_biopic_pku_edu_cn/EfX4CHedVopLuSx2OJNj6LABdESGNdKz4Eh8Zawvd-fNNQ?e=E5m09k&xsdata=MDV8MDJ8ZW5lcy5heWFyQHVjbG91dmFpbi5iZXxjYjY2M2MwYzNjMDY0YjZhNjc1NTA4ZGM4YzMzNjc1YXw3YWIwOTBkNGZhMmU0ZWNmYmM3YzQxMjdiNGQ1ODJlY3wxfDB8NjM4NTM5Mzk5NjI1Mzg1NDQ3fFVua25vd258VFdGcGJHWnNiM2Q4ZXlKV0lqb2lNQzR3TGpBd01EQWlMQ0pRSWpvaVYybHVNeklpTENKQlRpSTZJazFoYVd3aUxDSlhWQ0k2TW4wPXwwfHx8&sdata=Zmt4YnZFZFViTitJRkdTc0FTK2thMjdTT0EzV2JJeS83WlZmV3R6SzdvRT0%3d)
##' The K563 protein data is accessible from the
##' GitHub (https://github.com/dionezhang/CPM/blob/master/ProteinAbundance.Rdata).
##'
##' - `DataMatrix-oocyte-20240614.csv`: normalized imputed protein matrix
##' - `ProteinAbundance.Rdata`: protein matrices (normalized, log transformed)
##'
##' We initialized an empty QFeatures object and added the corresponding
##' protein assays as [SingleCellExperiment] objects.
##'
##' The oocyte protein data were exported from the shared link as
##' (`DataMatrix-oocyte-20240614.csv`). The data were formatted to a
##' [SingleCellExperiment] object and the SampleType information were added
##' as only metadata, and stored in the `colData`. The object is then added
##' to the [QFeatures] object.
##'
##' The 562 cells protein data were downloaded from the GitHub link and loaded
##' to the memory. The `Norm` object were formatted to a [SingleCellExperiment]
##' object and the SampleType information were added as only metadata, and
##' stored in the `colData`. The object is then added to the [QFeatures] object.
##'
##' @source
##'
##' The oocyte data were downloaded from the [Shared
##'     File](https://biopic-my.sharepoint.cn/:x:/g/personal/humo_biopic_pku_edu_cn/EfX4CHedVopLuSx2OJNj6LABdESGNdKz4Eh8Zawvd-fNNQ?e=E5m09k&xsdata=MDV8MDJ8ZW5lcy5heWFyQHVjbG91dmFpbi5iZXxjYjY2M2MwYzNjMDY0YjZhNjc1NTA4ZGM4YzMzNjc1YXw3YWIwOTBkNGZhMmU0ZWNmYmM3YzQxMjdiNGQ1ODJlY3wxfDB8NjM4NTM5Mzk5NjI1Mzg1NDQ3fFVua25vd258VFdGcGJHWnNiM2Q4ZXlKV0lqb2lNQzR3TGpBd01EQWlMQ0pRSWpvaVYybHVNeklpTENKQlRpSTZJazFoYVd3aUxDSlhWQ0k2TW4wPXwwfHx8&sdata=Zmt4YnZFZFViTitJRkdTc0FTK2thMjdTT0EzV2JJeS83WlZmV3R6SzdvRT0%3d)
##'     The K563 cells protein data downloaded from the GitHub
##'     (https://github.com/dionezhang/CPM/blob/master/ProteinAbundance.Rdata)
##'     The raw data and the quantification data can also be found in the
##'     MassIVE repository `MSV000089625`: ftp://MSV000089625@massive.ucsd.edu/.
##'
##' @references
##'
##' - Hu, M., Zhang, Y., Yuan, Y., Ma, W., Zheng, Y., Gu, Q., & Xie, X. S. 2023.
##'   “Correlated protein modules revealing functional coordination of
##'   interacting proteins are detected by single-cell proteomics.”. The Journal
##'   of Physical Chemistry B, ([link to
##'   article](https://doi.org/10.1021/acs.jpcb.3c00014)).
##'
##' @aliases hu2023
##' @aliases hu2023_K562
##' @aliases hu2023_oocyte
##'
##' @examples
##' \donttest{
##' hu2023_oocyte()
##' hu2023_K562()
##' }
##'
##' @keywords datasets
##'
"hu2023_K562"

##' Williams et al. 2020 (Anal. Chem.): MCF10A cell line
##'
##' Single-cell label free proteomics data from a MCF10A cell line
##' culture. The data were acquired using a label-free quantification
##' protocole based on the nanoPOTS technology. The objective was to
##' test 2 elution gradients for single-cell applications and to
##' demonstrate successful use of the new nanoPOTS autosampler
##' presented in the article. The samples contain either no cells,
##' single cells, 3 cells, 10 cells  50 cells.
##'
##' @format A [QFeatures] object with 9 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - `peptides_[30 or 60]min_[intensity or LFQ]`: 3 assays
##'   containing peptide intensities or LFQ normalized
##'   quantifications (see `References`) for either a 30min or a 60 min
##'   gradient.
##' - `proteins_[30 or 60]min_[intensity or iBAQ or LFQ]`: 6 assays
##'   containing protein intensities, iBAQ normalized or LFQ normalized
##'   quantifications (see `References`) for either a 30min or a 60 min
##'   gradient.
##'
##' Sample annotation is stored in `colData(williams2020_lfq())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Sample isolation**: cultured MCF10A cells were isolated using
##'   flow-cytometry based cell sorting and deposit on nanoPOTS
##'   microwells
##' - **Sample preparation**: cells are lysed using using a DDM+DTT
##'   lysis buffer. Alkylation was then performed using an IAA solution.
##'   Proteins are digested with Lys-C and trypsin followed by
##'   acidification with FA. Sample droplets are then dried until
##'   LC-MS/MS analysis.
##' - **Liquid chromatography**: peptides are loaded using the new
##'   autosampler described in the paper. Samples are loaded using a
##'   a homemade miniature syringe pump. The samples are then desalted
##'   and concentrated through a SPE column (4cm x 100µm i.d. packed
##'   with 5µm C18) with microflow LC pump. The peptides are then eluted
##'   from a long LC column (60cm x 50 µm i.d. packed with 3µm C18)
##'   coupled to a nanoflox LC pump at 150nL/mL with either a 30 min
##'   or a 60 min gradient.
##' - **Mass spectrometry**: MS/MS was performed on an Orbitrap Fusion
##'   Lumos Tribrid MS coupled to a 2kV ESI. MS1 setup: Orbitrap
##'   analyzer at resolution 120.000, AGC target of 1E6, accumulation
##'   of 246ms. MS2 setup: ion trap with CID at resolution 60.000, AGC
##'   target of 2E4, accumulation of 120ms (50 cells) or 250ms (0-10
##'   cells).
##' - **Raw data processing**: preprocessing using Maxquant v1.6.2.10
##'   that use Andromeda search engine (with UniProtKB 2016-21-29),
##'   MBR and LFQ normalization were enabled.
##'
##' @section Data collection:
##'
##' All data were collected from the MASSIVE repository (accession ID:
##' MSV000085230).
##'
##' The peptide and protein data were extracted from the `Peptides_[...].txt`
##' or `ProteinGroups[...].txt` files, respectively, in the
##' `MCF10A_LC_[30 or 60]minutes` folders.
##'
##' The tables were duplicated so that peptide intensisities, peptide
##' LFQ, protein intensities, protein LFQ and protein intensities are
##' contained in separate tables. Tables are then converted to
##' [SingleCellExperiment] objects. Sample annotations were infered
##' from the sample names and from the paper. All data is combined in
##' a [QFeatures] object. [AssayLinks] were stored between peptide
##' assays and their corresponding proteins assays based on the
##' leading razor protein (hence only unique peptides are linked to
##' proteins).
##'
##' The script to reproduce the `QFeatures` object is available at
##' `system.file("scripts", "make-data_williams2020_lfq.R", package = "scpdata")`
##'
##' @section Suggestion:
##'
##' See `QFeatures::joinAssays` if you want to join the 30min and
##' 60min assays in a single assay for an integrated analysis.
##'
##' @source
##'
##' The PSM and protein data can be downloaded from the MASSIVE
##' repository MSV000085230.
##'
##' @references
##'
##' **Source article**: Williams, Sarah M., Andrey V. Liyu, Chia-Feng
##' Tsai, Ronald J. Moore, Daniel J. Orton, William B. Chrisler,
##' Matthew J. Gaffrey, et al. 2020. “Automated Coupling of
##' Nanodroplet Sample Preparation with Liquid Chromatography-Mass
##' Spectrometry for High-Throughput Single-Cell Proteomics.”
##' Analytical Chemistry 92 (15): 10588–96.
##' ([link to article](http://dx.doi.org/10.1021/acs.analchem.0c01551)).
##'
##' **LFQ normalization**: Cox, Jürgen, Marco Y. Hein, Christian A. Luber,
##' Igor Paron, Nagarjuna Nagaraj, and Matthias Mann. 2014. “Accurate
##' Proteome-Wide Label-Free Quantification by Delayed Normalization
##' and Maximal Peptide Ratio Extraction, Termed MaxLFQ.” Molecular
##' & Cellular Proteomics: MCP 13 (9): 2513–26.
##' ([link to article](http://dx.doi.org/10.1074/mcp.M113.031591)).
##'
##' **iBAQ normalization**: Schwanhäusser, Björn, Dorothea Busse, Na
##' Li, Gunnar Dittmar, Johannes Schuchhardt, Jana Wolf, Wei Chen, and
##' Matthias Selbach. 2011. “Global Quantification of Mammalian Gene
##' Expression Control.” Nature 473 (7347): 337–42.
##' ([link to article](http://dx.doi.org/10.1038/nature10098)).
##'
##' @examples
##' \donttest{
##' williams2020_lfq()
##' }
##'
##' @keywords datasets
##'
"williams2020_lfq"

####---- Dou et al. 2019 - mouse cell data set ----####


## Dou, Maowei, Geremy Clair, Chia-Feng Tsai, Kerui Xu, William B. Chrisler, 
## Ryan L. Sontag, Rui Zhao, et al. 2019. “High-Throughput Single Cell Proteomics 
## Enabled by Multiplex Isobaric Labeling in a Nanodroplet Sample Preparation 
## Platform.” Analytical Chemistry, September. 
## https://doi.org/10.1021/acs.analchem.9b03349.

## This article contains 3 datasets. The script will focus on the profiling of 
## murine cell populations

library(openxlsx)
library(scp)
library(mzR)
library(tidyverse)
dataDir <- "~/PhD/.localdata/SCP/dou2019_mouse/"

####---- PSM data ----####

## Load and combine the identification and quantification data
list.files(dataDir) %>%
    sub(pattern = "_[a-z]*[.][a-z]*$", 
        replacement = "", ignore.case = TRUE) %>%
    unique %>%
    grep(pattern = "xlsx", invert = TRUE, value = TRUE)->
    batches
## For every experiment (= MS run)
lapply(batches, function(batch){
    ## Identification data (.mzid files) were downloaded from
    ## ftp://massive.ucsd.edu/MSV000084110/result/Result_Files/
    ## Read in files using `mzR`
    idFile <- openIDfile(list.files(path = dataDir, 
                                     pattern = paste0(batch, ".*mzid$"), 
                                     full.names = TRUE))
    ## Extract the identification output
    matches <- psms(idFile)
    ## Extract the identification scores
    scores <- score(idFile)
    ## Combine the two tables
    matches <- left_join(matches, scores, by = "spectrumID")
    ## Rename columns
    matches <- dplyr::rename(matches,
                             ## Match the scan number column with
                             ## the quantification data
                             ScanNumber = scan.number.s.,
                             ## Avoid names forbidden by the 
                             ## SingleCellExperiment class
                             .start = start,
                             .end = end)
    ## For some unknown reason, there can be multiple E-values and 
    ## MS.GF.PepQValue assigned to a given match (and score). To avoid
    ## this, we take the lowest highest value
    matches <- group_by(matches, spectrumID, sequence) %>% 
        mutate(MS.GF.EValue = max(MS.GF.EValue),
               MS.GF.PepQValue = max(MS.GF.PepQValue))
    ## Remove duplicate rows
    matches <- distinct(matches)
    
    ## Quantification data (.txt files) were downloaded from
    ## ftp://massive.ucsd.edu/MSV000084110/other/MASIC_ReporterIons/
    list.files(path = dataDir, 
               pattern = paste0(batch, ".*txt$"), 
               full.names = TRUE) %>%
        read.table(header = TRUE, sep = "\t") %>%
        ## Add the batch name 
        mutate(Batch = batch) ->
        quant
    ## Combine data 
    left_join(matches, quant, by = "ScanNumber")
}) %>%
    ## Bind the different batches
    bind_rows ->
    psms
## Include also contaminant information
psms$isContaminant <- grepl("Contaminant", psms$DatabaseAccess)

## PSM data is mapped to multiple peptides and peptides to multiple 
## proteins. In such cases, the PSM quantitative data is duplicated.
## To avoid this duplication, we combine all features belonging to the
## same spectra. This means we are creating peptide groups when a 
## spectrum is matched to multiple peptides, and proteins groups when 
## a peptide is mapped to multiple proteins. 

## When combining multiple lines into a single PSM, some values differ.
## If so, we concatenate those values in a single entry. Note that when
## one of the peptides is a decoy, we flag the corresponding spectra 
## as a decoy. 
combineFeatures <- function(x) {
    if (length(x) == 1) return(x)
    ## isDecoy and isContaminant are logicals. If any PSM is a decoy 
    ## or a contaminant, the spectrum is considered as decoy or contam.
    if (is.logical(x)) return(all(x)) 
    xuni <- unique(x)
    if (length(xuni) == 1) return(xuni)
    ## When a spectrum matches to multiples proteins, we combine those
    ## in a protein group
    paste0(xuni, collapse = ";")
}
## In order to concatenate some columns that are not unique for a 
## given spectra, we need to convert those columns to characters
psms$.start <- as.character(psms$.start)
psms$.end <- as.character(psms$.end)
psms$DBseqLength <- as.character(psms$DBseqLength)
psms$modNum <- as.character(psms$modNum)
psms$calculatedMassToCharge <- as.character(psms$calculatedMassToCharge)
## Combine the features as single spectrum information
psms <- group_by(psms, spectrumID, Batch)
psms <- dplyr::summarise(psms, across(.fn = combineFeatures))

####---- Sample annotation ----####

## Sample annotation provided in Table S3 in the Supplementary information
data.frame(Batch = batches,
           DatasetID = as.character(unique(psms$Dataset)),
           Ion_126.128 = c(rep("C10", 6), rep("SVEC", 6)),
           Ion_127.125 = c(rep("C10", 3), rep("SVEC", 6), rep("RAW", 3)),
           Ion_127.131 = c(rep("SVEC", 6), rep("RAW", 6)),
           Ion_128.128 = c(rep("SVEC", 3), rep("RAW", 6), rep("C10", 3)),
           Ion_128.134 = c(rep("RAW", 6), rep("C10", 6)),
           Ion_129.131 = c(rep("RAW", 3), rep("C10", 6), rep("SVEC", 3)),
           Ion_129.138 = c(rep("reference", 12)),
           Ion_130.135 = c(rep("empty", 12)),
           Ion_130.141 = c(rep("empty", 12)),
           Ion_131.138 = c(rep("boost", 12)), 
           ## Note there is a mistake in the table. The author provide 
           ## the annotation for 10 channles whereas 11 channels are recorded.
           ## The last column in the data has little signal, so sample type is 
           ## assumed to be "empty"
           Ion_131.144 = c(rep("empty", 12))) %>%
    pivot_longer(cols = matches("Ion"), 
                 names_to = "Channel", 
                 values_to = "SampleType") ->
    colDat

####---- Create the QFeatures object ----####

## Create the `QFeatures` object
dou2019_mouse <- readSCP(psms, 
                         colDat, 
                         batchCol = "Batch", 
                         channelCol = "Channel")

####---- Peptide data ----####

## We generate the peptide data ourself

## First, we filter out low quality PSM
dou2019_filt <- filterFeatures(dou2019_mouse, ~ 
                                   ! isContaminant & 
                                   ! isDecoy & 
                                   MS.GF.QValue < 0.01)
## Peptide data is computed by median aggregation of PSMs to peptides
dou2019_filt <- 
    aggregateFeaturesOverAssays(dou2019_filt, 
                                i = seq_along(dou2019_filt),
                                fcol = "sequence", 
                                name = paste0("pep_", names(dou2019_filt)),
                                fun = colMedians)
## We join the peptide data in a single assay
dou2019_filt <- joinAssays(dou2019_filt, 
                            i = grep("^pep_", names(dou2019_filt)), 
                            name = "peptides")
## We remove the peptide groups
sce <- dou2019_filt[["peptides"]]
sce <- sce[!grepl("[;]", rownames(sce)), ]
## We add the assay to the exported dataset and create the links 
## between PSM and peptide data 
dou2019_mouse <- addAssay(dou2019_mouse, sce, name = "peptides")
dou2019_mouse <- 
    addAssayLink(dou2019_mouse, from = 1:12, to = "peptides", 
                 varFrom = rep("sequence", 12), varTo = "sequence")

####---- Protein data ----####

## Load the data
## Data was downloaded from https://doi.org/10.1021/acs.analchem.9b03349.
datXlsx <- loadWorkbook(list.files(path = dataDir, 
                                   pattern = "xlsx$",  
                                   full.names = TRUE))
prots <- read.xlsx(datXlsx, sheet = 2, colNames = FALSE)

## Get the column names 
## The columns names should match the column names contained in the 
## 'dou2019_mouse' object
prots[1:2, ] %>%
    t %>% 
    as_tibble %>%
    mutate(DatasetID = sub(pattern = "Ion_.*ID_", replacement = "", `2`),
           Batch = colDat$Batch[match(DatasetID, colDat$DatasetID)],
           colname = sub(pattern = "_Dat.*$", replacement = "", `2`),
           colname = ifelse(grepl("Ion", colname),
                            paste0(Batch, colname),
                            colname)) %>%
    pull(colname) ->
    colname

## Extract and format the protein expression data 
prots[-(1:2), ] %>%
    magrittr::set_colnames(colname) %>%
    mutate_at(vars(contains("Ion")), as.numeric) %>% 
    readSingleCellExperiment(ecol = grep("Ion", colname),
                             fnames = "Protein") ->
    prots

## Add assay and AssayLinks to the dataset
dou2019_mouse <- addAssay(dou2019_mouse, prots, name = "proteins")
dou2019_mouse <- addAssayLink(dou2019_mouse,
                              from = "peptides", to = "proteins", 
                              varFrom = "DatabaseAccess", 
                              varTo = "Protein")

## Save data as Rda file
## Note: saving is assumed to occur in "scpdata/inst/scripts"
save(dou2019_mouse,
     compress = "xz", 
     compression_level = 9,
     file = file.path("~/PhD/.localdata/scpdata/dou2019_mouse.Rda"))

####---- Hu et al, 2023 ---####


## Hu, M., Zhang, Y., Yuan, Y., Ma, W., Zheng, Y., Gu, Q., & Xie, X. S. 2023. 
## “Correlated protein modules revealing functional coordination of interacting 
## proteins are detected by single-cell proteomics.”. The Journal of Physical 
## Chemistry B, https://doi.org/10.1021/acs.jpcb.3c00014 

library(SingleCellExperiment)
library(scp)
library(tidyverse)

root <- "~/localdata/SCP/hu2023/"

####---- Add the protein data ----####

## Data accessible at GitHub repository
## https://github.com/dionezhang/CPM/blob/master/ProteinAbundance.Rdata

#### Load data ####
load(paste0(root, "ProteinAbundance.Rdata"))

Norm %>% 
  mutate(X = rownames(Norm)) %>% 
  readSingleCellExperiment(ecol = 1:69, fnames = "X") ->
  K562

## Protein data for K562 cells
hu2023_K562 <- SingleCellExperiment(K562)

prots <- rownames(hu2023_K562)
rowData(hu2023_K562) <- Description[prots, ,drop = FALSE]
rowData(hu2023_K562)$protein <- prots

colData(hu2023_K562) <- DataFrame(row.names = colnames(Norm), 
                           SampleType = rep("K562", length(colnames(Norm))))

## Save data
save(hu2023_K562,
     file = file.path(paste0(root, "hu2023_K562.Rda")),
     compress = "xz",
     compression_level = 9)

##' Ai et al., Cardiomyocytes Single Cell Proteomics, MCP (2025)
##'
##' @description
##'
##' The manuscript analysed cardiomyocytes derived from iPSC cells and adult
##' hearts. This annotated `QFeatures` objects contains the complete data, as
##' analysed with the `scp` package. The re-analysis was performed as part of
##' the EuBIC 2025 developer meeting hackathon dedicated to single-cell
##' proteomics data (https://lgatto.github.io/2025-EuBIC-SCP-hackathon/).
##'
##' The data contains a total of 304 assay. The 299 first assays contain the
##' individual single cardiomyocytes acquistions. The following assays contain
##' the joined precursor data, the log-transformed precuror data, the peptide
##' data, the protein data, and the scplainer-modelled precursor data (see the
##' link above for details).
##'
##' The `QFeatures` object was generated from the DIA-NN report file, available
##' from the `MsDataHub` package (see `?MsDataHub::Ai2025_aCMs_report.tsv`). The
##' report file is downloaded from the MassIVE MSV000094438
##' (doi:10.25345/C5T727S7Q) repository.
##'
##' @references
##'
##' - Ai, Lizhuo, Aleksandra Binek, Vladimir Zhemkov, Jae Hyung Cho, Ali
##' Haghani, Simion Kreimer, Edo Israely, et al. 2025. “Single Cell Proteomics
##' Reveals Specific Cellular Subtypes in Cardiomyocytes Derived from Human
##' iPSCs and Adult Hearts.” Molecular & Cellular Proteomics: MCP, no. 100910
##' (January): 100910.
##'
##' @keywords dataset
##'
##' @examples
##'
##' \donttest{
##' ai2025a()
##' }
"ai2025a"

library("scp")
library("tidyverse")

## library("devtools")
## devtools::install_github("https://github.com/SlavovLab/QuantQC")
library("QuantQC") ## Required to access QuantQC data slots @

dir <- "/storage/research/dduv/cbio-lg/user/eayar/localdata/SCP/leduc2025/dat/"

# Processed peptide level data
load(paste0(dir, "03_QuantQC_objects/r1_5day_male.RData"))
load(paste0(dir, "03_QuantQC_objects/r2_5day_female.RData"))
load(paste0(dir, "03_QuantQC_objects/r3_10day_male.RData"))
load(paste0(dir, "03_QuantQC_objects/r4_10day_female.RData"))

## Extract peptide to protein map from data
make_pep2prot <- function(raw_data) {
  raw_data |>
    distinct(seqcharge, Stripped.Sequence, Protein.Group, Genes) |>
    as.data.frame()
}

map1 <- make_pep2prot(r1_5day_male@raw_data)
map2 <- make_pep2prot(r2_5day_female@raw_data)
map3 <- make_pep2prot(r3_10day_male@raw_data)
map4 <- make_pep2prot(r4_10day_female@raw_data)

## Combine row data with quant data into single cell experiment
make_pep_se <- function(mat, map) {
  rd <- map[match(rownames(mat), map$seqcharge), ]
  rownames(rd) <- rownames(mat)

  SummarizedExperiment(
    assays = list(quantification = as.matrix(mat)),
    rowData = DataFrame(rd)
  )
}

r1_pep <- r1_5day_male@matricies@peptide
r2_pep <- r2_5day_female@matricies@peptide
r3_pep <- r3_10day_male@matricies@peptide
r4_pep <- r4_10day_female@matricies@peptide

## Rename samples so they match to protein data
colnames(r1_pep) <- paste0(colnames(r1_pep), "_prep1")
colnames(r2_pep) <- paste0(colnames(r2_pep), "_prep2")
colnames(r3_pep) <- paste0(colnames(r3_pep), "_prep3")
colnames(r4_pep) <- paste0(colnames(r4_pep), "_prep4")

r1_pep_se <- make_pep_se(r1_pep, map1)
r2_pep_se <- make_pep_se(r2_pep, map2)
r3_pep_se <- make_pep_se(r3_pep, map3)
r4_pep_se <- make_pep_se(r4_pep, map4)

# Raw peptide level data
r1_raw <- read.csv(paste0(dir, "02_raw_reptide_X_singleCell/r1_peptide.csv"), row.names = 1)
r2_raw <- read.csv(paste0(dir, "02_raw_reptide_X_singleCell/r2_peptide.csv"), row.names = 1)
r3_raw <- read.csv(paste0(dir, "02_raw_reptide_X_singleCell/r3_peptide.csv"), row.names = 1)
r4_raw <- read.csv(paste0(dir, "02_raw_reptide_X_singleCell/r4_peptide.csv"), row.names = 1)

## Rename samples so they match to protein data
colnames(r1_raw) <- paste0(colnames(r1_raw), "_prep1")
colnames(r2_raw) <- paste0(colnames(r2_raw), "_prep2")
colnames(r3_raw) <- paste0(colnames(r3_raw), "_prep3")
colnames(r4_raw) <- paste0(colnames(r4_raw), "_prep4")

r1_raw_se <- make_pep_se(r1_raw, map1)
r2_raw_se <- make_pep_se(r2_raw, map2)
r3_raw_se <- make_pep_se(r3_raw, map3)
r4_raw_se <- make_pep_se(r4_raw, map4)

## Generate QFeatures object with peptide level data
leduc2025 <- QFeatures(list(
  pep_raw_prep1 = r1_raw_se,
  pep_raw_prep2 = r2_raw_se,
  pep_raw_prep3 = r3_raw_se,
  pep_raw_prep4 = r4_raw_se,
  pep_processed_prep1 = r1_pep_se,
  pep_processed_prep2 = r2_pep_se,
  pep_processed_prep3 = r3_pep_se,
  pep_processed_prep4 = r4_pep_se
))

# Protein Level shared data
## Absolute abundances
absolute <- read.csv(paste0(dir, "04_Gene_X_SingleCell_and_annotations/sc_protein_absolute.csv"),
                     row.names = 1)
prot_absolute_se <- SummarizedExperiment(assay = as.matrix(absolute),
                                         rowData = DataFrame(Protein = rownames(absolute)))

## Relative abundances
relative <- read.csv(paste0(dir, "04_Gene_X_SingleCell_and_annotations/sc_protein_relative.csv"),
                     row.names = 1)
prot_relative_se <- SummarizedExperiment(assay = as.matrix(relative),
                                         rowData = DataFrame(Protein = rownames(relative)))

## Imputed and comBat corrected data used in the study
imputed <- readRDS(paste0(dir, "protein_Data.rds"))
prot_imputed_se <- SummarizedExperiment(assay = as.matrix(imputed),
                                         rowData = DataFrame(Protein = rownames(imputed)))

## colData object
annot <- read.csv(paste0(dir, "04_Gene_X_SingleCell_and_annotations/sc_protein_annotations.csv"))
rownames(annot) <- annot$ID

## Add protein level assays
leduc2025 <- addAssay(leduc2025, prot_relative_se, name = "proteins_relative")
leduc2025 <- addAssay(leduc2025, prot_absolute_se, name = "proteins_absolute")
leduc2025 <- addAssay(leduc2025, prot_imputed_se, name = "proteins_imputed")

## Add sample meta data
colData(leduc2025) <- DataFrame(annot)

## Link corresponding peptide assays to protein level
leduc2025 <- addAssayLink(leduc2025,
                          from = c("pep_raw_prep1", "pep_raw_prep2",
                                   "pep_raw_prep3", "pep_raw_prep4"),
                          to = "proteins_absolute",
                          varFrom = rep("Protein.Group", 4),
                          varTo = "Protein")
leduc2025 <- addAssayLink(leduc2025,
                          from = c("pep_processed_prep1", "pep_processed_prep2",
                                   "pep_processed_prep3", "pep_processed_prep4"),
                          to = "proteins_relative",
                          varFrom = rep("Protein.Group", 4),
                          varTo = "Protein")

## Save data as Rda file
save(leduc2025,
     file = paste0(dir, "leduc2025.rda"),
     compress = "xz",
     compression_level = 9)

##' Specht et al. 2019 - SCoPE2 (biorRxiv): macrophages vs monocytes
##' (version 3)
##'
##' Single cell proteomics data acquired by the Slavov Lab. This is
##' the version 3 of the data released in October 2020. It contains
##' quantitative information of macrophages and monocytes at PSM,
##' peptide and protein level.
##'
##' @format A [QFeatures] object with 179 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - Assay 1-63: PSM data for SCoPE2 sets acquired with a TMT-11plex
##'   protocol, hence those assays contain 11 columns. Columns
##'   hold quantitative information from single-cell channels, carrier
##'   channels, reference channels, empty (blank) channels and unused
##'   channels.
##' - Assay 64-177: PSM data for SCoPE2 sets acquired with a
##'   TMT-16plex protocol, hence those assays contain 16 columns.
##'   Columns hold quantitative information from single-cell channels,
##'   carrier channels, reference channels, empty (blank) channels and
##'   unused channels.
##' - `peptides`: peptide data containing quantitative data for 9208
##'   peptides and 1018 single-cells.
##' - `proteins`: protein data containing quantitative data for 2772
##'   proteins and 1018 single-cells.
##'
##' The `colData(specht2019v2())` contains cell type annotation and
##' batch annotation that are common to all assays. The description of
##' the `rowData` fields for the PSM data can be found in the
##' [`MaxQuant` documentation](http://www.coxdocs.org/doku.php?id=maxquant:table:evidencetable).
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: flow cytometry (BD FACSAria I).
##' - **Sample preparation** performed using the SCoPE2 protocol. mPOP
##'   cell lysis + trypsin digestion + TMT-11plex or 16plex labeling
##'   and pooling.
##' - **Separation**: online nLC (DionexUltiMate 3000 UHPLC with a
##'   25cm x 75um IonOpticksAurora Series UHPLC column; 200nL/min).
##' - **Ionization**: ESI (2,200V).
##' - **Mass spectrometry**: Thermo Scientific Q-Exactive (MS1
##'   resolution = 70,000; MS2 accumulation time = 300ms; MS2
##'   resolution = 70,000).
##' - **Data analysis**: DART-ID + MaxQuant (1.6.2.3).
##'
##' @section Data collection:
##'
##' The PSM data were collected from a shared Google Drive folder that
##' is accessible from the SlavovLab website (see `Source` section).
##' The folder contains the following files of interest:
##'
##' - `ev_updated_v2.txt`: the MaxQuant/DART-ID output file
##' - `annotation_fp60-97.csv`: sample annotation
##' - `batch_fp60-97.csv`: batch annotation
##'
##' We combined the sample annotation and the batch annotation in
##' a single table. We also formatted the quantification table so that
##' columns match with those of the annotation and filter only for
##' single-cell runs. Both table are then combined in a single
##' [QFeatures] object using the [scp::readSCP()] function.
##'
##' The peptide data were taken from the Slavov lab directly
##' (`Peptides-raw.csv`). It is provided as a spreadsheet. The data
##' were formatted to a [SingleCellExperiment] object and the sample
##' metadata were matched to the column names (mapping is retrieved
##' after running the SCoPE2 R script) and stored in the `colData`.
##' The object is then added to the [QFeatures] object (containing the
##' PSM assays) and the rows of the peptide data are linked to the
##' rows of the PSM data based on the peptide sequence information
##' through an `AssayLink` object.
##'
##' The protein data (`Proteins-processed.csv`) is formatted similarly
##' to the peptide data, and the rows of the proteins were mapped onto
##' the rows of the peptide data based on the protein sequence
##' information.
##'
##' @note Since version 2, a serious bug in the data were corrected
##' for TMT channels 12 to 16. Many more cells are therefore contained
##' in the data. Version 2 is maintained for backward compatibility.
##' Although the final version of the article was published in 2021,
##' we have kept `specht2019v3` as the data set name for consistency
##' with the previous data version `specht2019v2`.
##'
##' @source
##' The data were downloaded from the
##' [Slavov Lab](https://scope2.slavovlab.net/docs/data) website via a
##' shared Google Drive
##' [folder](https://drive.google.com/drive/folders/1VzBfmNxziRYqayx3SP-cOe2gu129Obgx).
##' The raw data and the quantification data can also be found in the
##' massIVE repository `MSV000083945`:
##' ftp://massive.ucsd.edu/MSV000083945.
##'
##' @references Specht, Harrison, Edward Emmott, Aleksandra A.
##' Petelski, R. Gray Huffman, David H. Perlman, Marco Serra, Peter
##' Kharchenko, Antonius Koller, and Nikolai Slavov. 2021.
##' "Single-Cell Proteomic and Transcriptomic Analysis of Macrophage
##' Heterogeneity Using SCoPE2." Genome Biology 22 (1): 50.
##' ([link to article](http://dx.doi.org/10.1186/s13059-021-02267-5)).
##'
##' @examples
##' \donttest{
##' specht2019v3()
##' }
##'
##' @keywords datasets
##'
"specht2019v3"

####---- SCPDATA PACKAGE MAN PAGE ----####


##' Single-Cell Proteomics Data Package
##' 
##' @description
##' 
##' The `scpdata` package distributes mass spectrometry-based 
##' single-cell proteomics datasets. The datasets were collected from 
##' published work and formatted to a standardized data framework. 
##' The `scp` frameworks stores the expression data for different MS 
##' levels (identified spectrum, peptide, or protein) in separate 
##' assays. Each assay is an object of class [SingleCellExperiment] 
##' that allows easy integration with state-of-the-art single-cell 
##' analysis tools. All assays are contained in a single object of 
##' class [QFeatures]. An overview of the data structure is shown 
##' provided in the `scp` package. 
##' 
##' The `scpdata()` function returns a summary table with all 
##' currently available datasets in the package. More information 
##' about the data content and the data collection can be found in the
##' corresponding manual pages. 
##' 
##' @return A `DataFrame` table containing a summary of the available 
##' datasets.
##' 
##' @seealso More information about the data manipulation can be found
##' in the `scp` package.
##' 
##' @examples 
##' ## List available datasets and their metadata 
##' scpdata()
##' 
##' ## Load data using the ExperimentHub interface
##' hub <- ExperimentHub()
##' 
##' \dontrun{
##' ## Download the data set of interest using ExperimentHub indexing
##' hub[["EH7711"]]
##' ## Download the same data set using the build-in function
##' leduc2022()
##' }
##' 
##' @author Christophe Vanderaa
##'
##' @aliases scpdata-package scpdata
##' 
##' @import ExperimentHub
##' @import QFeatures
##' @import SingleCellExperiment
##' @importFrom AnnotationHub query
##' @importFrom S4Vectors mcols
##' @export
##' 
scpdata <- function() {
    mcols(query(ExperimentHub(), "scpdata"))
}


#' Deprecated leduc2022 dataset
#'
#' The `leduc2022` dataset has been updated to include plexDIA and
#' pSCoPE data. The new datasets names are `leduc2022_pSCoPE`
#' (previously `leduc2022`) and `leduc2022_plexDIA` (new). See the
#' respective documentation pages for more information.
#'
#' @return The `leduc2022_pSCoPE` dataset.
#' 
#' @export
leduc2022 <- function() {
    warning(
        "Deprecated dataset! The leduc2022() dataset has been ", 
        "updated to include plexDIA and pSCoPE data. Available datasets ",
        "are now: leduc2022_pSCoPE (previously leduc2022) and ",
        "leduc2022_plexDIA (new). Returning leduc2022_pSCoPE()..."
    )
    leduc2022_pSCoPE()
}

## Ensure resources are present

## code taken from
## https://github.com/waldronlab/curatedTCGAData/blob/master/tests/testthat/test-resources.R

test_that("metadata numbers match ExperimentHub", {
    metaf <- system.file("extdata", "metadata.csv",
                         package = "scpdata", mustWork = TRUE)
    meta <- read.csv(metaf, stringsAsFactors = FALSE)
    EHub <- query(ExperimentHub(), "scpdata")
    expect_identical(nrow(meta), length(EHub))
    expect_identical(meta$Title, EHub$title)
})

test_that("scpdata", {
    metaf <- system.file("extdata", "metadata.csv",
                         package = "scpdata", mustWork = TRUE)
    meta <- read.csv(metaf, stringsAsFactors = FALSE)
    res <- scpdata()
    expect_identical(meta$Title, res$title)
})

test_that("all datasets are available", {
    res <- scpdata()
    for (dataset in res$title) {
        ds <- eval(call(dataset))
        expect_true(is(ds, "QFeatures") | inherits(ds, "SummarizedExperiment"))
    }
})

test_that("leduc2022 throws a warning", {
    test <- expect_warning(leduc2022())
    expect_identical(length(test), 138L)
})

##' Liang et al. 2020 (Anal. Chem.): HeLa cells (MaxQuant preprocessing)
##'
##' Single-cell proteomics data from HeLa cells using the autoPOTS
##' acquisition workflow. The samples contain either no cells (blanks),
##' 1 cell, 10 cells, 150 cells or 500 cells. Samples containing
##' between 0 and 10 cells are isolated using micro-pipetting while
##' samples containing between 150 and 500 cells were prepared using
##' dilution of a bulk sample.
##'
##' @format A [QFeatures] object with 17 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - `HeLa_*`: 15 assays containing PSM data.
##' - `peptides`: quantitative data for 48705 peptides in 15 samples
##'   (all runs are combined).
##' - `proteins`: quantitative data for 3970 protein groups in 15
##'   samples (all runs combined).
##'
##' Sample annotation is stored in `colData(liang2020_hela())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: The HeLa cells come from a commercially
##'   available cell line. Samples containing between 0 and 10 cells
##'   were isolated using micro-manipulation and the counts were
##'   validated using a microscope. Samples containing between 150 and
##'   500 cells were prepared by diluting a bulk sample and the exact
##'   counts were evaluated by obtaining phtotmicrographs.
##' - **Sample preparation** performed using the autoPOTS worflow that
##'   relied on the OT-2 pipeting robot. Cell are lysed using
##'   sonication. Samples are then processed by successive incubation
##'   with DTT (reduction), then IAA (alkylation), then Lys-C and
##'   trypsin (protein digestion).
##' - **Separation**: Samples were injected on the column using a
##'   modified Ultimate WPS-3000 TPL autosampler coupled to an UltiMate
##'   3000 RSLCnano pump. The LC column is a home-packed nanoLC column
##'   (45cm x 30um; 40nL/min)
##' - **Ionization**: Nanospray Flex ion source (2,000V)
##' - **Mass spectrometry**: Orbitrap Exploris 480. MS1 settings:
##'   accumulation time = 250 ms (0-10 cells) or 100 ms (150-500 cells);
##'   resolution = 120,000; AGC = 100\%. MS2 settings: exlusion
##'   duration = 90 s (0-10 cells) or 60 s (150-500 cells) ; accumulation
##'   time = 500 ms (0-1 cell), 250 ms (10 cells), 100 ms (150 cells)
##'   or 50 ms (500 cells); resolution = 60,000 (0-10 cells) or 30,000
##'   (150-500 cells); AGC = 5E3 (0-1 cells) or 1E4 (10-500 cells).
##' - **Data analysis**: MaxQuant (v1.6.7.0) and the search database
##'   is Swiss-Prot (July 2020).
##'
##' @section Data collection:
##'
##' All data were collected from the PRIDE repository (accession ID:
##' PXD021882).
##'
##' The sample annotations were collected from the methods section and
##' from table S3 in the paper.
##'
##' The PSM data were found in the `evidence.txt` file. The data were
##' converted to a [QFeatures] object using the [scp::readSCP()]
##' function.
##'
##' The peptide data were found in the `peptides.txt` file. The column
##' names holding the quantitative data were adapted to match the
##' sample names in the [QFeatures] object. The data were then
##' converted to a [SingleCellExperiment] object and then inserted in
##' the [QFeatures] object. Links between the PSMs and the peptides
##' were added
##'
##' A similar procedure was applied to the protein data. The data were
##' found in the `proteinGroups.txt` file. The column names were
##' adapted, the data were converted to a [SingleCellExperiment]
##' object and then inserted in the [QFeatures] object. Links between
##' the peptides and the proteins were added
##'
##' @source
##' The PSM data can be downloaded from the PRIDE repository
##' PXD021882 The source link is:
##' http://ftp.pride.ebi.ac.uk/pride/data/archive/2020/12/PXD021882/
##'
##' @references
##'
##' Liang, Yiran, Hayden Acor, Michaela A. McCown, Andikan J. Nwosu,
##' Hannah Boekweg, Nathaniel B. Axtell, Thy Truong, Yongzheng Cong,
##' Samuel H. Payne, and Ryan T. Kelly. 2020. “Fully Automated Sample
##' Processing and Analysis Workflow for Low-Input Proteome
##' Profiling.” Analytical Chemistry, December.
##' ([link to article](https://doi.org/10.1021/acs.analchem.0c04240)).
##'
##' @examples
##' \donttest{
##' liang2020_hela()
##' }
##'
##' @keywords datasets
##'
"liang2020_hela"

####---- Hu et al, 2023 ---####


## Hu, M., Zhang, Y., Yuan, Y., Ma, W., Zheng, Y., Gu, Q., & Xie, X. S. 2023. 
## “Correlated protein modules revealing functional coordination of interacting 
## proteins are detected by single-cell proteomics.”. The Journal of Physical 
## Chemistry B, https://doi.org/10.1021/acs.jpcb.3c00014 

library(SingleCellExperiment)
library(scp)
library(tidyverse)

root <- "~/localdata/SCP/hu2023/"

####---- Add the protein data ----####

## Data shared by the author, and accessible at 
## https://biopic-my.sharepoint.cn/:x:/g/personal/humo_biopic_pku_edu_cn/EfX4CHedVopLuSx2OJNj6LABdESGNdKz4Eh8Zawvd-fNNQ?rtime=7Xzb4B303Eg

#### Load Data ####
oocyte <- read.csv(paste0(root, "DataMatrix-oocyte-20240614.csv"))
oocyte %>% 
  rename(protein = X) %>% 
  readSingleCellExperiment(ecol = 2:138, fnames = "protein") ->
  oocyte

## Protein data for oocytes
hu2023_oocyte <- SingleCellExperiment(oocyte)

colData(hu2023_oocyte) <- DataFrame(row.names = colnames(hu2023_oocyte), 
                           SampleType = rep("oocyte", length(colnames(oocyte))))

## Save data
save(hu2023_oocyte,
     file = file.path(paste0(root, "hu2023_oocyte.Rda")),
     compress = "xz",
     compression_level = 9)

##' Petrosius et al. 2023 (bioRxiv): AML hierarchy on Astral.
##'
##' Single cell proteomics data from FACS sorted cells from the
##' OCI-AML8227 model. The dataset contains leukemic stem cells (LSC;
##' CD34+, CD38-), progenitor cells (CD34+, CD38+), CD38+ blasts
##' (CD34-, CD38+) and CD38- blasts (CD34-, CD38-). It contains
##' quantitative information at PSM, peptide and protein levels. Data
##' was acquired using an Orbitrap Astral mass spectrometer. Direct DIA
##' analysis was performed with Spectronaut version 17.
##'
##' @format A [QFeatures] object with 217 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - Assays 1-215: PSM data from the Spectronaut PEPQuant file with
##'   LFQ quantities from the FG.MS1Quantity column.
##' - `peptides`: Peptide data resulting from the PSM to peptide
##'   aggregation the 215 PSM assays. Resulting peptide assays were
##'   joined into a single assay.
##' - `proteins`: Protein data from the Spectronaut PGQuant file with
##'   LFQ quantities from the PG.Quantity column.
##'
##' The `colData(petrosius2023_AstralAML())` contains cell type
##' annotation, batch annotation and FACS data. The description of the
##' `rowData` fields can be found in the
##' [`Spectronaut` user manual](https://biognosys.com/content/uploads/2023/03/Spectronaut-17_UserManual.pdf).
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see *References*).
##'
##' - **Cell isolation**: Cell sorting was done on a FACS Aria III or
##'   Aria II instrument, controlled by the DIVA software package and
##'   operated with a 100 microm nozzle. Cells were sorted at single-cell
##'   resolution, into a 384-well Eppendorf LoBind PCR plate containing
##'   1 microL of lysis buffer.
##' - **Sample preparation** Single-cell protein lysates were digested
##'   overnight at 37°C with 2 ng of Trypsin supplied in 1 microL of
##'   digestion buffer. Digestion was stopped by the addition of 1 microL
##'   1% (v/v) trifluoroacetic acid (TFA). All liquid dispensing was
##'   done using an I-DOT One instrument.
##' - **Liquid chromatography**: Chromatographic separation of peptides
##'   was conducted on a vanquish Neo UHPLC system connected to a 50 cm
##'   uPAC Neo Low-load and an EASY-spray. Autosampler and injection
##'   valves were configured to perform direct injections from a 384
##'   well plate using a 25 uL injection loop on 11.8 min gradients.
##' - **Mass spectrometry**: Acquisition was conducted with an Orbitrap
##'   Astral mass spectrometer operated in positive mode with the
##'   FAIMSPro interface compensation voltage set to -45 V.
##'   MS1 scans were acquired with the Orbitrap at a resolution of
##'   120,000 and a scan range of 400 to 900 m/z with normalized
##'   automatic gain control (AGC) target of 300 % and maximum
##'   injection time of 246 ms. Data independent acquisition of MS2
##'   spectra was performed in the Astral using loop control set to 0.7
##'   seconds per cycle with varying isolation window widths and
##'   injection times. Fragmentation of precursor ions was performed
##'   using higher energy collisional dissociation (HCD) using a
##'   normalized collision energy (NCE) of 25 %. AGC target was set to
##'   800 %.
##' - **Raw data processing**: Raw files were processed using
##'   Spectronaut version 17. Direct DIA analysis was performed in
##'   pipeline mode. Pulsar searches were performed without fixed
##'   modifications. N-terminal acetylation and methionine oxidation
##'   were set as variable modifications. Quantification level was set
##'   to MS1 and the quantity type set to area under the curve.
##'
##' @section Data collection:
##'
##' The data were provided by the authors and is accessible at the
##' [Dataverse](https://dataverse.uclouvain.be/dataset.xhtml?persistentId=doi:10.14428/DVN/EMAVLT)
##' The dataset ('Astral AML single-cell data from Petrosius et
##' al. 2023 preprint') contains the following files of interest:
##'
##' - `20240201_130747_PEPQuant (Normal).tsv`: the PSM level data
##' - `20240201_130747_PGQuant (Normal).tsv`: the protein level data
##' - `index_map.csv`: FACS data.
##' - `msRuns_overview.csv`: Sample annotations.
##'
##' We added the FACS data to the sample annotations in a single table.
##' Both annotations and PSM features tables are then combined in a
##' single [QFeatures] object using the [scp::readSCP()] function.
##'
##' The peptide data were obtained by aggregation of the PSM data to
##' the peptide level. All of the resulting peptides assays were joined
##' into a single assays. Individual peptides assays were discarded.
##'
##' The protein data were formatted from the `20240201_130747_PGQuant (Normal).tsv`
##' to a [SingleCellExperiment] object and the sample metadata were
##' matched to the column names and stored in the  `colData`. The
##' object is then added to the [QFeatures] object and the rows of the
##' peptide data are linked to the rows of the protein data based on
##' the protein sequence information through an `AssayLink` object.
##'
##' Note that the [QFeatures] object has not been further processed and
##' has therefore not been normalized, log-transformed or
##' batch-corrected.
##'
##' @source The PSM data, protein data and sample annotations can be
##'     downloaded from the dataset 'Astral AML single-cell data from
##'     Petrosius et al. 2023 preprint' in the
##'     [Dataverse](https://dataverse.uclouvain.be/dataset.xhtml?persistentId=doi:10.14428/DVN/EMAVLT).
##'
##' @references
##'
##' Valdemaras Petrosius, Pedro Aragon-Fernandez, Tabiwang N. Arrey,
##' Nil Üresin, Benjamin Furtwängler, Hamish Stewart, Eduard Denisov,
##' Johannes Petzoldt, Amelia C. Peterson, Christian Hock, Eugen
##' Damoc, Alexander Makarov, Vlad Zabrouskov, Bo T. Porse and Erwin
##' M. Schoof.
##' 2023. "Evaluating the capabilities of the Astral mass analyzer for single-cell proteomics."
##' biorxiv.  https://doi.org/10.1101/2023.06.06.543943
##' DOI:[10.1101/2023.06.06.543943](https://doi.org/10.1101/2023.06.06.543943)
##'
##' @examples
##' \donttest{
##' petrosius2023_AstralAML()
##' }
##'
##' @keywords datasets
##'
"petrosius2023_AstralAML"

##' Zhu et al. 2019 (eLife): chicken utricle cells
##'
##'
##' Single-cell proteomics data from chicken utricle acquired to
##' study the hair-cell development. The cells are isolated from
##' peeled utrical epithelium and separated into hair cells (FM1-43
##' high) and supporting cells (FM1-43 low). The sample contain either
##' 1 cell (n = 28), 3 cells (n = 7), 5 cells (n = 8) or 20 cells (n =
##' 14).
##'
##' @format A [QFeatures] object with 62 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - `XYZw`: 60 assays containing PSM data. The sample are annotated
##'   as follows. `X` indicates the experiment, either 1 or 2. `Y`
##'   indicated the FM1-43 signal, either high (H) or low (L). `Z`
##'   indicates the number of cells (0, 1, 3, 5 or 20). `w` indicates
##'   the replicate, starting from `a`, it can go up to `j`.
##' - `peptides`: quantitative data for 3444 peptides in 60 samples
##'   (all runs are combined).
##' - `proteins_intensity`: protein intensities for 840 proteins
##'   from 24 samples
##' - `proteins_iBAQ`: iBAQ values for 840 proteins from 24 samples
##'
##' Sample annotation is stored in `colData(zhu2019EL())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: The cells were taken from the utricles of
##'   E15 chick embryos. Samples were stained with FM1-43FX and the
##'   cells were dissociated using enzymatic digestion. Cells were
##'   FACS sorted (BD Influx) and split based on their FM1-43 signal,
##'   while ensuring no debris, doublets or dead cells are retained.
##' - **Sample preparation** performed using the nanoPOTs device. Cell
##'   lysis and protein extraction and reduction are performed using
##'   dodecyl beta-D-maltoside + DTT + ammonium bicarbonate. Protein
##'   were then alkylated using IAA. Protein digestion is performed
##'   using Lys-C and trypsin. Finally samples acidification is
##'   performed using formic acid.
##' - **Separation**: Dionex UltiMate pump with an C18-Packed column
##'   (50cm x 30um; 60nL/min)
##' - **Ionization**: ESI (2,000V)
##' - **Mass spectrometry**: Orbitrap Fusion Lumos Tribrid. MS1
##'   settings: accumulation time = 246ms; resolution = 120,000; AGC =
##'   3E6. MS/MS settings: accumulation time = 502ms; resolution =
##'   120,000; AGC = 2E5.
##' - **Data analysis**: Andromeda & MaxQuant (v1.5.3.30) and the
##'   search database is NCBI GRCg6a.
##'
##' @section Data collection:
##'
##' All data were collected from the PRIDE repository (accession ID:
##' PXD014256).
##'
##' The sample annotation information is provided in the
##' `Zhu_2019_chick_single_cell_samples_CORRECTED.xlsx` file. This file
##' was given during a personal discussion and is a corrected version
##' of the annotation table available on the PRIDE repository.
##'
##' The PSM data were found in the `evidence.txt` (in the
##' `Experiment 1+ 2`) folder. The PSM data were filtered so that it
##' contains only samples that are annotated. The data were then
##' converted to a [QFeatures] object using the [scp::readSCP()]
##' function.
##'
##' The peptide data were found in the `peptides.txt` file. The column
##' names holding the quantitative data were adapted to match the
##' sample names in the [QFeatures] object. The data were then
##' converted to a [SingleCellExperiment] object and then inserted in
##' the [QFeatures] object. Links between the PSMs and the peptides
##' were added
##'
##' A similar procedure was applied to the protein data. The data were
##' found in the `proteinGroups.txt` file. We split the protein table
##' to separate the two types of quantification: summed intensity and
##' intensity based absolute quantification (iBAQ). Both tables are
##' converted to [SingleCellExperiment] objects and are added to the
##' [QFeatures] object as well as the `AssayLink` between peptides and
##' proteins.
##'
##' @source
##' The PSM data can be downloaded from the PRIDE repository
##' PXD014256. The source link is:
##' ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2019/11/PXD014256
##'
##' @references
##'
##' Zhu, Ying, Mirko Scheibinger, Daniel Christian Ellwanger, Jocelyn
##' F. Krey, Dongseok Choi, Ryan T. Kelly, Stefan Heller, and Peter G.
##' Barr-Gillespie. 2019. “Single-Cell Proteomics Reveals Changes in
##' Expression during Hair-Cell Development.” eLife 8 (November).
##' ([link to article](https://doi.org/10.7554/eLife.50777)).
##'
##' @examples
##' \donttest{
##' zhu2019EL()
##' }
##'
##' @keywords datasets
##'
"zhu2019EL"

####---- Zhu et al. 2018, Nature Communications - T1D islets ----####

## Zhu, Ying, Paul D. Piehowski, Rui Zhao, Jing Chen, Yufeng Shen, Ronald J. 
## Moore, Anil K. Shukla, et al. 2018. “Nanodroplet Processing Platform for Deep 
## and Quantitative Proteome Profiling of 10-100 Mammalian Cells.” Nature 
## Communications 9 (1): 882.

library(SingleCellExperiment)
library(scp)
library(tidyverse)
dataDir <- "~/PhD/.localdata/SCP/zhu2018NC_islets/"

# The data was downloaded from ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/01/PXD006847

####---- Peptide data ----####

## Load the quantification data
paste0(dataDir, "Islet_t1d_ct_peptides.txt") %>%
    read.table(sep = "\t", header = TRUE) %>%
    mutate(Batch = "peptides") ->
    peps
peps <- readSingleCellExperiment(peps,
                                 ecol = grep("^Intensity.", colnames(peps)),
                                 fnames = "Sequence")
colnames(peps) <- gsub("Intensity.", "", colnames(peps))

####---- Sample annotations ----####

## Create the sample annoation table
annot <- DataFrame(row.names = colnames(peps))
annot$SampleType <- sub("^.*([CT]).*$", "\\1", rownames(annot))
annot$SampleType <- dplyr::recode(annot$SampleType, 
                                  `T` = "T1D",
                                  `C` = "Control")

####---- Protein data ----####

## Load the quantification data
prots <- read.table(paste0(dataDir, "Islet_t1d_ct_proteinGroups.txt"),
                    sep = "\t", header = TRUE)
## Remove unnecessary columns
sel <- !grepl("Peptides.*[CT]|^Identif|^Razor.*[CT]|Sequence.*[CT]|Unique.*[CT]|MS.MS.*[CT]",
              colnames(prots))
prots <- prots[, sel]
## Split protein data based on the quantification method:
## 1. Protein intensity
protsInt <- prots[, !grepl("^iBAQ|^LFQ", colnames(prots))]
protsInt <- readSingleCellExperiment(protsInt, 
                                     ecol = grep("^Intensity.", colnames(protsInt)),
                                     fnames = "Protein.IDs")
colnames(protsInt) <- gsub("Intensity.", "", colnames(protsInt))
## 2. LFQ
protsLFQ <- prots[, !grepl("^iBAQ|^Intensity", colnames(prots))]
protsLFQ <- readSingleCellExperiment(protsLFQ, 
                                     ecol = grep("^LFQ.", colnames(protsLFQ)),
                                     fnames = "Protein.IDs")
colnames(protsLFQ) <- gsub("LFQ.intensity.", "", colnames(protsLFQ))
## 3. iBAQ
protsIBAQ <- prots[, !grepl("^LFQ|^Intensity", colnames(prots))]
protsIBAQ <- readSingleCellExperiment(protsIBAQ, 
                                      ecol = grep("^iBAQ.", colnames(protsIBAQ)),
                                      fnames = "Protein.IDs")
colnames(protsIBAQ) <- gsub("iBAQ.", "", colnames(protsIBAQ))

####---- Create the QFeatures object ----####

el <- ExperimentList(peptides = peps,
                     proteins_intensity = protsInt,
                     proteins_LFQ = protsLFQ,
                     proteins_iBAQ = protsIBAQ)
zhu2018NC_islets <- QFeatures(el, colData = annot)

## Create assay links
zhu2018NC_islets <- addAssayLink(zhu2018NC_islets, 
                                  from = "peptides", to = "proteins_intensity",
                                  varFrom = "Leading.razor.protein", 
                                  varTo = "Majority.protein.IDs")
zhu2018NC_islets <- addAssayLink(zhu2018NC_islets, 
                                  from = "peptides", to = "proteins_LFQ",
                                  varFrom = "Leading.razor.protein", 
                                  varTo = "Majority.protein.IDs")
zhu2018NC_islets <- addAssayLink(zhu2018NC_islets, 
                                  from = "peptides", to = "proteins_iBAQ",
                                  varFrom = "Leading.razor.protein", 
                                  varTo = "Majority.protein.IDs")

# Save data as Rda file
save(zhu2018NC_islets, 
     file = file.path("~/PhD/.localdata/scpdata/zhu2018NC_islets.Rda"),
     compress = "xz", 
     compression_level = 9)

##' Williams et al. 2020 (Anal. Chem.): 3 AML cell line
##'
##' Single-cell label data from three acute myeloid
##' leukemia cell line culture (MOLM-14, K562, CMK). The data were
##' acquired using a TMT-based quantification protocole and the
##' nanoPOTS technology. The objective was to demonstrate successful
##' use of the new nanoPOTS autosampler presented in the source
##' article. The samples contain either carrier (10 ng), reference
##' (0.2ng), empty or single-cell samples..
##'
##' @format A [QFeatures] object with 4 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - `peptides_[intensity or corrected]`: 2 assays containing peptide
##'   reporter ion intensities or corrected reporter ion intensities
##'   as computed by MaxQuant.
##' - `proteins_[intensity or corrected]`: 2 assays containing protein
##'   reporter ion intensities or corrected reporter ion intensities
##'   as computed by MaxQuant.
##'
##' Sample annotation is stored in `colData(williams2020_tmt())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Sample isolation**: cultured MOLM-14, K562 or CMK cells were
##'   isolated using flow-cytometry based cell sorting and deposit on
##'   nanoPOTS microwells
##' - **Sample preparation**: cells are lysed using using a DDM lysis
##'   buffer. Proteins are digested with trypsin followed by TMT
##'   labelling and quanching with HA. The samples are then acidified
##'   with FA, pooled in a single samples (adding carrier and reference
##'   peptide mixtures), and dried until LC-MS/MS analysis.
##' - **Liquid chromatography**: peptides are loaded using the new
##'   autosampler described in the paper. Samples are loaded using a
##'   a homemade miniature syringe pump. The samples are then desalted
##'   and concentrated through a SPE column (4cm x 100µm i.d. packed
##'   with 5µm C18) with microflow LC pump. The peptides are then eluted
##'   from a long LC column (60cm x 50 µm i.d. packed with 3µm C18)
##'   coupled to a nanoflox LC pump at 150nL/mL (elution time is not
##'   expliceted).
##' - **Mass spectrometry**: MS/MS was performed on an Orbitrap Fusion
##'   Lumos Tribrid MS coupled to a 2kV ESI. MS1 setup: Orbitrap
##'   analyzer at resolution 120.000, AGC target of 1E6, accumulation
##'   of 246ms. MS2 setup: Orbitrap with HCD at resolution 120.000, AGC
##'   target of 1E6, accumulation of 246ms.
##' - **Raw data processing**: preprocessing using Maxquant v1.6.2.10
##'   that use Andromeda search engine (with UniProtKB 2016-21-29).
##'
##' @section Data collection:
##'
##' All data were collected from the MASSIVE repository (accession ID:
##' MSV000085230).
##'
##' The peptide and protein data were extracted from the
##' `Peptides_AML_SingleCell.txt` or `ProteinGroups_AML_SingleCell.txt`
##' files, respectively, in the `AML_SingleCell` folders.
##'
##' The tables were duplicated so that intensisities and corrected
##' intensities are contained in separate tables. Tables are then
##' converted to [SingleCellExperiment] objects. Sample annotations
##' were inferred from the sample names, from table S2 and from the
##' Experimental Section of the paper. All data is combined in
##' a [QFeatures] object. [AssayLinks] were stored between peptide
##' assays and their corresponding proteins assays based on the
##' leading razor protein (hence only unique peptides are linked to
##' proteins).
##'
##' The script to reproduce the `QFeatures` object is available at
##' `system.file("scripts", "make-data_williams2020_tmt.R", package = "scpdata")`
##'
##' @source
##'
##' The PSM and protein data can be downloaded from the MASSIVE
##' repository MSV000085230.
##'
##' @references
##'
##' **Source article**: Williams, Sarah M., Andrey V. Liyu, Chia-Feng
##' Tsai, Ronald J. Moore, Daniel J. Orton, William B. Chrisler,
##' Matthew J. Gaffrey, et al. 2020. “Automated Coupling of
##' Nanodroplet Sample Preparation with Liquid Chromatography-Mass
##' Spectrometry for High-Throughput Single-Cell Proteomics.”
##' Analytical Chemistry 92 (15): 10588–96.
##' ([link to article](http://dx.doi.org/10.1021/acs.analchem.0c01551)).
##'
##' @examples
##' \donttest{
##' williams2020_tmt()
##' }
##'
##' @keywords datasets
##'
"williams2020_tmt"

##' Zhu et al. 2018 (Mol. Cel. Prot.): rat brain laser dissections
##'
##' Near single-cell proteomics data of laser captured
##' micro-dissection samples. The samples are 24 brain sections from
##' rat pups (day 17). The slices are 12 um thick squares of either
##' 50, 100, or 200 um width. 5 samples were dissected from the corpus
##' callum (`CC`), 4 samples were dissected from the corpus collosum
##' (`CP`), 13 samples were extracted from the cerebral cortex
##' (`CTX`), and 2 samples are labeled as (`Mix`).
##'
##' @format A [QFeatures] object with 4 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - `peptides`: quantitative information for 13,055 peptides from
##'   24 samples
##' - `proteins_intensity`: protein intensities for 2,257 proteins
##'   from 24 samples
##' - `proteins_LFQ`: LFQ intensities for 2,257 proteins from 24 samples
##' - `proteins_iBAQ`: iBAQ values for 2,257 proteins from 24 samples
##'
##' Sample annotation is stored in `colData(zhu2018MCP())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the original article (see `References`).
##'
##' - **Cell isolation**: brain patches were collected using
##'   laser-capture microdissection (PALM MicroBeam) on flash frozen
##'   rat (*Rattus norvergicus*) brain tissues. Note that the samples
##'   were stained with H&E before dissection for histological
##'   analysis. DMSO is used as sample collection solution
##' - **Sample preparation** performed using the nanoPOTs device: DMSO
##'   evaporation + protein extraction (DMM + DTT) + alkylation (IAA)
##'   + Lys-C digestion + trypsin digestion.
##' - **Separation**: nanoLC (Dionex UltiMate with an in-house packed
##'   60cm x 30um LC columns; 50nL/min)
##' - **Ionization**: ESI (2,000V)
##' - **Mass spectrometry**: Thermo Fisher Orbitrap Fusion Lumos
##'   Tribrid (MS1 accumulation time = 246ms; MS1 resolution =
##'   120,000; MS1 AGC = 3E6). The MS/MS settings  depend on the
##'   sample size, excepted for the AGC = 1E5. 50um (time = 502ms;
##'   resolution = 240,000), 100um (time = 246ms; resolution =
##'   120,000), 200um (time = 118ms; resolution = 60,000).
##' - **Data analysis**: MaxQuant (v1.5.3.30) + Perseus (v1.5.6.0) +
##'   Origin Pro 2017
##'
##' @section Data collection:
##'
##' The data were collected from the PRIDE repository (accession
##' ID: PXD008844).  We downloaded the `MaxQuant_Peptides.txt`
##' and the `MaxQuant_ProteinGroups.txt` files containing the
##' combined identification and quantification
##' results. The sample annotations were inferred from the names of
##' columns holding the quantification data and the information in the
##' article. The peptides data were converted to a [SingleCellExperiment]
##' object. We split the protein table to separate the three types of
##' quantification: protein intensity, label-free quantitification
##' (LFQ) and intensity based absolute quantification (iBAQ). Each
##' table is converted to a [SingleCellExperiment] object along with
##' the remaining protein annotations. The 4 objects are combined in
##' a single [QFeatures] object and feature links are created based on
##' the peptide leading razor protein ID and the protein ID.
##'
##' @source
##' The PSM data can be downloaded from the PRIDE repository
##' PXD008844. FTP link
##' ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/07/PXD008844
##'
##' @references
##' Zhu, Ying, Maowei Dou, Paul D. Piehowski, Yiran Liang, Fangjun
##' Wang, Rosalie K. Chu, William B. Chrisler, et al. 2018. “Spatially
##' Resolved Proteome Mapping of Laser Capture Microdissected Tissue
##' with Automated Sample Transfer to Nanodroplets.” Molecular &
##' Cellular Proteomics: MCP 17 (9): 1864–74
##' ([link to article](http://dx.doi.org/10.1074/mcp.TIR118.000686)).
##'
##' @examples
##' \donttest{
##' zhu2018MCP()
##' }
##'
##' @keywords datasets
##'
##'
"zhu2018MCP"

####---- Gregoire et al. 2023 ---####


## Samuel Grégoire, Christophe Vanderaa, Sébastien Pyr dit Ruys,
## Gabriel Mazzucchelli, Christopher Kune, Didier Vertommen and
## Laurent Gatto. 2023. "Standardised workflow for mass spectrometry-
## based single-cell proteomics data processing and analysis using the
## scp package." arXiv. https://doi.org/10.48550/arXiv.2310.13598

## This is the script for generating the scp dataset

library(scp)
library(dplyr)
library(limma)
library(scater)

# All files were downloaded from
# https://zenodo.org/records/8417228

datadir <- "~/isilon/DataSets/SCPCBIO/MiMB_data/"

####---- Prepare sample annotations ----####

# The sample annotations are provided in separate tables for each acquisition batch:
cbio_680_annotation <- read.csv2(paste0(datadir, "sample_annotation/sampleAnnotation_cbio680.csv"))
cbio_681_annotation <- read.csv2(paste0(datadir, "sample_annotation/sampleAnnotation_cbio681.csv"))
cbio_703_annotation <- read.csv2(paste0(datadir, "sample_annotation/sampleAnnotation_cbio703.csv"))
cbio_715_annotation <- read.csv2(paste0(datadir, "sample_annotation/sampleAnnotation_cbio715.csv"))
cbio_725_annotation <- read.csv2(paste0(datadir, "sample_annotation/sampleAnnotation_cbio725.csv"))
cbio_733_annotation <- read.csv2(paste0(datadir, "sample_annotation/sampleAnnotation_cbio733.csv"))
cbio_754_annotation <- read.csv2(paste0(datadir, "sample_annotation/sampleAnnotation_cbio754bis.csv"))
giga_annotation <-  read.csv2(paste0(datadir, "sample_annotation/sampleAnnotation_GIGA.csv"))

# Bind the annotation tables into one
annotations <-
  rbind(cbio_680_annotation, cbio_681_annotation, cbio_703_annotation,
        cbio_715_annotation, cbio_725_annotation, cbio_733_annotation,
        cbio_754_annotation, giga_annotation)


####---- Prepare PSM data ----####

## Read sage id files
id_cbio <- read.delim(paste0(datadir, "sage/results.sage.cbio.tsv"))
id_giga <- read.delim(paste0(datadir, "sage/results.sage.giga.tsv"))

## Read sage quant files
quant_cbio <- read.delim(paste0(datadir, "sage/quant.cbio.tsv"))
quant_giga <- read.delim(paste0(datadir, "sage/quant.giga.tsv"))

## Bind cbio and giga data
id <- rbind(id_cbio, id_giga)
quant <- rbind(quant_cbio, quant_giga)

rm(id_cbio)
rm(id_giga)
rm(quant_cbio)
rm(quant_giga)

## Merge identification and quantification data
sage_data <- merge(quant, id,
                   by.x = c("file", "scannr"),
                   by.y = c("filename", "scannr"))

rm(quant)
rm(id)

## Add key
sage_data$.KEY <- paste(sage_data$file, sage_data$scannr, sep = ".")

## Add tmt channel name to quantitative columns
colnames(sage_data)[4:19] <- paste0(c(126, rep(127:133, each = 2), 134),
                                    rep(c("C", "N"), 8))

## Add run variable
sage_data$run <- sub(".*_1_1_", "", sage_data$file)
sage_data$run <- sub("^1", "GIGA_1", sage_data$run)
sage_data$run <- sub("\\.mzML", "", sage_data$run)

## Add experiment batches
sage_data$batch <- sub("_.*", "", sage_data$run)

## QFeatures object
gregoire2023_mixCTRL <-
  readSCP(featureData = sage_data,
          colData = annotations,
          channelCol = "channel",
          batchCol = "run",
          removeEmptyCols = TRUE,
          sep = "_")

rm(sage_data)

####---- Retrieve processed data ----####

# Replace 0s by NAs
gregoire2023_mixCTRL <- zeroIsNA(gregoire2023_mixCTRL,
                                 i = 1:length(gregoire2023_mixCTRL))

# Keep targets, ranks 1 and fdr < 0.01
gregoire2023_mixCTRL <- filterFeatures(gregoire2023_mixCTRL,
                                       ~ rank == 1 &
                                         peptide_fdr < 0.01 &
                                         label == 1)

# Highlight chimeric spectra
for (i in seq_along(gregoire2023_mixCTRL)) {
  # Extract rowData for each set
  rd <- rowData(gregoire2023_mixCTRL[[names(gregoire2023_mixCTRL)[i]]])
  # Create unique spectrum identifier .KEY
  rd$.KEY <- paste(rd$file, rd$scannr)
  # Create "chimeric" column, FALSE by default
  rd$chimeric <- FALSE
  # Change "chimeric" to TRUE for duplicated keys
  rd$chimeric[rd$.KEY %in% rd$.KEY[duplicated(rd$.KEY)]] <- TRUE
  # Store updated rowData
  rowData(gregoire2023_mixCTRL[[names(gregoire2023_mixCTRL)[i]]]) <- rd
}

# Remove chimeric spectra
gregoire2023_mixCTRL <- filterFeatures(gregoire2023_mixCTRL,
                                       ~ !chimeric)

# Compute sample to carrier ratio
gregoire2023_mixCTRL <-
  computeSCR(gregoire2023_mixCTRL,
             i = 1:length(gregoire2023_mixCTRL),
             colvar = "cell_type",
             carrierPattern = "carrier",
             samplePattern = "THP1|THP1_dif|U937|U937_dif|mix",
             rowDataName = "MeanSCR")

# Remove SCR > 1
gregoire2023_mixCTRL <-
  filterFeatures(gregoire2023_mixCTRL,
                 ~ !is.na(MeanSCR) &
                   MeanSCR < 1)

# Remove carrier and empty channel
gregoire2023_mixCTRL <-
  subsetByColData(gregoire2023_mixCTRL,
                  !gregoire2023_mixCTRL$cell_type %in% c("carrier", "empty"))

# Compute median intensity
for (i in names(gregoire2023_mixCTRL)) {
  # Extract log assay
  logAssay <- log(assay(gregoire2023_mixCTRL[[i]]))
  # Compute median RI by cell
  meds <- colMedians(logAssay, na.rm = TRUE, useNames = TRUE)
  # Store median RI in colData.
  colData(gregoire2023_mixCTRL)[names(meds), "log_medianRI"] <- meds
}

# Compute median coefficient of variation
gregoire2023_mixCTRL <-
  medianCVperCell(gregoire2023_mixCTRL,
                  i = 1:length(gregoire2023_mixCTRL),
                  groupBy = "proteins",
                  nobs = 3,
                  norm = "div.median",
                  colDataName = "medianCV")

# Count number of peptide per cell
gregoire2023_mixCTRL <-
  countUniqueFeatures(gregoire2023_mixCTRL,
                      i = 1:length(gregoire2023_mixCTRL),
                      groupBy = "peptide",
                      colDataName = "count")

# filter poor quality cells
filter_samples <-
  (gregoire2023_mixCTRL$batch == "CBIO680" & gregoire2023_mixCTRL$log_medianRI > 7.77 &
     gregoire2023_mixCTRL$count > 1250 & gregoire2023_mixCTRL$medianCV < 0.615) |
  (gregoire2023_mixCTRL$batch == "CBIO681" & gregoire2023_mixCTRL$log_medianRI > 8.5 &
     gregoire2023_mixCTRL$count > 1250 & gregoire2023_mixCTRL$medianCV < 0.79) |
  (gregoire2023_mixCTRL$batch == "CBIO703" & gregoire2023_mixCTRL$log_medianRI > 7.69 &
     gregoire2023_mixCTRL$count > 1250 & gregoire2023_mixCTRL$medianCV < 0.68) |
  (gregoire2023_mixCTRL$batch == "CBIO715" & gregoire2023_mixCTRL$log_medianRI > 7.69 &
     gregoire2023_mixCTRL$count > 1250 & gregoire2023_mixCTRL$medianCV < 0.62) |
  (gregoire2023_mixCTRL$batch == "CBIO725" & gregoire2023_mixCTRL$log_medianRI > 8.08 &
     gregoire2023_mixCTRL$count > 1250 & gregoire2023_mixCTRL$medianCV < 0.73) |
  (gregoire2023_mixCTRL$batch == "CBIO754" & gregoire2023_mixCTRL$log_medianRI > 7.39 &
     gregoire2023_mixCTRL$count > 1250 & gregoire2023_mixCTRL$medianCV < 0.67) |
  (gregoire2023_mixCTRL$batch == "GIGA" &
     gregoire2023_mixCTRL$count > 1250 & gregoire2023_mixCTRL$medianCV < 0.455)

gregoire2023_mixCTRL <-
  subsetByColData(gregoire2023_mixCTRL, filter_samples) |>
  dropEmptyAssays()

# Rmove blanks
gregoire2023_mixCTRL <-
  subsetByColData(gregoire2023_mixCTRL,
                  gregoire2023_mixCTRL$cell_type != "blank")

# Aggregate PSMs into peptides
gregoire2023_mixCTRL <-
  aggregateFeatures(gregoire2023_mixCTRL,
                    i = 1:length(gregoire2023_mixCTRL),
                    fcol = "peptide",
                    name = paste0("peptide_", names(gregoire2023_mixCTRL)),
                    fun = colMedians, na.rm = TRUE)

# Join PSM assays per acquisition batches
batches <- c("CBIO680", "CBIO681", "CBIO703",
             "CBIO715", "CBIO725", "CBIO754",
             "GIGA")

for (batch in batches) {
  gregoire2023_mixCTRL <-
    joinAssays(gregoire2023_mixCTRL,
               i = grep(paste0("peptide_", batch), names(gregoire2023_mixCTRL)),
               name = paste0("peptides_", batch))
}

# Remove highly missing peptides
gregoire2023_mixCTRL <-
  filterNA(gregoire2023_mixCTRL,
           i = grep("peptides", names(gregoire2023_mixCTRL)),
           pNA = 0.98)

pep_assay_names <-
  names(gregoire2023_mixCTRL)[grep("peptides_", names(gregoire2023_mixCTRL))]

# Normalise cells
for (i in seq_along(pep_assay_names)) {
  gregoire2023_mixCTRL <-
    sweep(gregoire2023_mixCTRL,
          i = pep_assay_names[i],
          MARGIN = 2,
          FUN = "/",
          STATS = colMedians(assay(gregoire2023_mixCTRL[[pep_assay_names[i]]]),
                             na.rm = TRUE),
          name = paste0(pep_assay_names[i], "_norm"))
}

# Log transform normalised peptide assays
pep_assay_names <-
  names(gregoire2023_mixCTRL)[grep("peptides_.*_norm", names(gregoire2023_mixCTRL))]

gregoire2023_mixCTRL <-
  logTransform(gregoire2023_mixCTRL,
               base = 2,
               i = pep_assay_names,
               name = paste0(pep_assay_names, "_log"))

pep_assay_names <-
  names(gregoire2023_mixCTRL)[grep("peptides_.*_norm_log",
                                   names(gregoire2023_mixCTRL))]

gregoire2023_mixCTRL <-
  aggregateFeatures(gregoire2023_mixCTRL,
                    i = pep_assay_names,
                    fcol = "proteins",
                    fun = colMedians, na.rm = TRUE,
                    name = sub("peptides", "proteins", pep_assay_names))

# Remove batch effects
for (i in grep("proteins.*norm_log", names(gregoire2023_mixCTRL))) {
  ## Extract set
  sce <- getWithColData(gregoire2023_mixCTRL, names(gregoire2023_mixCTRL)[i])
  ## Batch correct assay
  assay(sce) <-
    removeBatchEffect(assay(sce), group = sce$cell_type,
                      batch = sce$run, batch2 = sce$channel)
  ## Name and add batch-corrected assay
  gregoire2023_mixCTRL <-
    addAssay(gregoire2023_mixCTRL,
             y = sce,
             name = sub("_norm_log", "_batchC",
                        names(gregoire2023_mixCTRL)[i]))
  ## Add link between batch corrected and original assay
  gregoire2023_mixCTRL <-
    addAssayLinkOneToOne(gregoire2023_mixCTRL,
                         from = names(gregoire2023_mixCTRL)[i],
                         to = sub("_norm_log", "_batchC",
                                  names(gregoire2023_mixCTRL)[i]))
}

# Compute NIPALS dimensionality reduction
for (i in grep("batchC", names(gregoire2023_mixCTRL))) {
  nipals_res <-
    ## Extract assay
    assay(gregoire2023_mixCTRL[[i]]) |>
    as.data.frame() |>
    ## Encode missing values
    mutate_all(~ifelse(is.nan(.), NA, .)) |>
    ## Transpose
    t() |>
    ## PCA
    pcaMethods::pca(method="nipals", nPcs = 2)

  reducedDim(gregoire2023_mixCTRL[[i]], "NIPALS") <-
    pcaMethods::scores(nipals_res)
}

# Save data as Rda file
save(gregoire2023_mixCTRL,
     file = "~/2022-phd-samuel-gregoire/gregoire2023_mixCTRL.Rda",
     compress = "xz",
     compression_level = 9)

##' Brunner et al. 2022 (Mol. Syst. Biol.): cell cycle state study
##'
##' Single cell proteomics data acquired by the Mann Lab using a newly
##' designed timsTOF instrument, referred to as timsTOF-SCP. The
##' dataset contains quantitative information from single-cells blocked
##' at 4 cell cycle stages: G1, G1-S, G2, G2-M. The data was acquired
##' using a label-free sample preparation protocole combined to a
##' data independent (DIA) acquisition mode.
##'
##' @format A [QFeatures] object with 435 assays, each assay being a
##' [SingleCellExperiment] object.
##'
##' - Assay 1-434: DIA-NN main output report table split for each
##'   acquisition run. Since each run acquires 1 single cell, each
##'   assay contains a single column. It contains the results
##'   of the spectrum identification and quantification.
##' - `protein`: DIA-NN protein group matrix, containing normalised
##'   quantities for 2476 protein groups in 434 single cells. Proteins
##'   are filtered at 1% FDR, using global q-values for protein groups
##'   and both global and run-specific q-values for precursors.
##'
##' The `colData(brunner2022())` contains cell type annotations and
##' batch annotations. The description of the `rowData` fields for the
##' different assays can be found in the
##' [`DIA-NN` documentation](https://github.com/vdemichev/DiaNN#readme).
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: cells were detached with trypsin treatment,
##'   followed by strong pipetting, and isolate using FACS.
##' - **Sample preparation**: cell lysis by freeze-heat followed by
##'   sonication, overnight protein digestion with trypsin/lysC mix and
##'   desalting using EvoTips trap column (EvoSep)
##' - **Separation**: online EvoSep One LC system using a 5 cm x 75 µm
##'   ID column with 1.9µm C18 beads (EvoSep) at 100nL/min flow rate.
##' - **Ionization**: 10µm ID zero dead volume electrospray emitter
##'   (Bruker Daltonik) + nanoelectro-spray ion source (Captive spray,
##'   Bruker Daltonik)
##' - **Mass spectrometry**: DIA PASEF mode. Correlation between IM
##'   and m/z was used to synchronize the elution of precursors from
##'   each IM scan with the quadrupole isolation window. Five
##'   consecutive diaPASEF cycles. The collision energy was ramped
##'   linearly as a function of the IM from 59 eV at 1/K0=1.6 Vs cm^2
##'   to 20 eV at 1/K0=0.6 Vs cm^2.
##' - **Data analysis**: DIA-NN (1.8).
##'
##' @section Data collection:
##'
##' The data were collected from the PRIDE
##' [repository](https://www.ebi.ac.uk/pride/archive/projects/PXD024043)
##' in the `DIANN1.8_SingleCells_CellCycle.zip` file.
##'
##' We loaded the DIA-NN main report table and generated a sample
##' annotation table based on the MS file names. We next combined the
##' sample annotation and the DIANN tables into a [QFeatures] object
##' following the `scp` data structure. We loaded the proteins group
##' matrix as a [SingleCellExperiment] object, fixed ambiguous
##' protein group names, and added the protein data as a new assay and
##' link the precursors to proteins using the `Protein.Group` variable
##' from the `rowData`.
##'
##' @source
##' The data were downloaded from PRIDE
##' [repository](https://www.ebi.ac.uk/pride/archive/projects/PXD024043)
##' with accession ID `PXD024043`.
##'
##' @references
##' Brunner, Andreas-David, Marvin Thielert, Catherine Vasilopoulou,
##' Constantin Ammar, Fabian Coscia, Andreas Mund, Ole B. Hoerning, et
##' al. 2022. "Ultra-High Sensitivity Mass Spectrometry Quantifies
##' Single-Cell Proteome Changes upon Perturbation." Molecular Systems
##' Biology 18 (3): e10798.
##' [Link to article](http://dx.doi.org/10.15252/msb.202110798)
##'
##' @examples
##' \donttest{
##' brunner2022()
##' }
##'
##' @keywords datasets
##'
"brunner2022"

##' Leduc et al. 2022 - pSCoPE (biorRxiv): melanoma cells vs monocytes
##'
##' Single cell proteomics data acquired by the Slavov Lab. This is
##' the dataset associated to the third version of the preprint. It
##' contains quantitative information of melanoma cells and monocytes
##' at PSM, peptide and protein level. This version of the data was
##' acquired using the pSCoPE MS acquisition approach.
##'
##' @format A [QFeatures] object with 138 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - Assay 1-134: PSM data acquired with a TMT-18plex protocol, hence
##'   those assays contain 18 columns. Columns hold quantitative
##'   information from single-cell channels, carrier channels,
##'   reference channels, empty (negative control) channels and
##'   unused channels.
##' - `peptides`: peptide data containing quantitative data for 20,804
##'   peptides and 1556 single-cells. These data have been filtered
##'   to keep high-quality PSMs, all batches have been normalized to
##'   the reference channel, PSMs were aggregated to peptides, and
##'   single-cells with low median coefficient of variation were kept.
##' - `peptides_log`: peptide data containing quantitative data for
##'   12,284 peptides and 1543 single-cells. The `peptides` data was
##'   further normalized, highly missing peptides were removed and the
##'   quantifications were log-transformed.
##' - `proteins_norm2`: protein data containing quantitative data for
##'   2844 proteins and 1543 single-cells. The peptides from
##'   `peptides_log` were aggregated to proteins and normalized.
##' - `proteins_processed`: protein data containing quantitative data
##'   for 2844 proteins and 1543 single-cells. The `proteins_norm2`
##'   data were imputed, batch corrected and normalized.
##'
##' The `colData(leduc2022_pSCoPE())` contains cell type annotation,
##' LC batch information, the TMT label, the MS run ID. We also added
##' the sample prep annotations provided by the cellenONE dispensing
##' device (only for single cells): time stamp of cell isolation by the
##' device, the diameter and elongation of the cell, the ID of the
##' sample glass side (4 slides in total), the field within the glass
##' (each slide is divided in 4 field), the pooled well ID (each field
##' contains 9 pools), the x and y coordinates of each cell dropped in
##' a field and of each cell pool upon pickup. Finally, we also
##' retrieved the melanoma subpopulation generated by the authors upon
##' data analysis. The main population is encoded as `A` while the
##' small population is encoded `B`. The description of the `rowData`
##' fields for the PSM data can be found in the
##' [`MaxQuant` documentation](http://www.coxdocs.org/doku.php?id=maxquant:table:evidencetable).
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Cell isolation**: CellenONE cell sorting.
##' - **Sample preparation** performed using the improved SCoPE2
##'   protocol using the CellenONE liquid handling system. nPOP cell
##'   lysis (DMSO) + trypsin digestion + TMT-18plex
##'   labeling and pooling. A target library was generated as well to
##'   perform prioritized DDA (Huffman et al. 2022) using MaxQuant.Live
##'   (2.0.3).
##' - **Separation**: online nLC (DionexUltiMate 3000 UHPLC with a
##'   25cm x 75um IonOpticks Aurora Series UHPLC column; 200nL/min).
##' - **Ionization**: ESI (1,800V).
##' - **Mass spectrometry**: Thermo Scientific Q-Exactive (MS1
##'   resolution = 70,000; MS2 accumulation time = 300ms; MS2
##'   resolution = 70,000). Prioritized data acquisition was performed
##'   using the pSCoPE protocol (Huffman et al. 2022)
##' - **Data analysis**: MaxQuant (1.6.17.0) + DART-ID
##'
##' @section Data collection:
##'
##' The PSM data were collected from a shared Google Drive folder that
##' is accessible from the SlavovLab website (see `Source` section).
##' The folder contains the following files of interest:
##'
##' - `ev_updated.txt`: the MaxQuant/DART-ID output file
##' - `annotation.csv`: sample annotation
##' - `batch.csv`: batch annotation
##' - `t0.csv`: the processed data table containing the `peptides` data
##' - `t3.csv`: the processed data table containing the `peptides_log`
##'   data
##' - `t4b.csv`: the processed data table containing the
##'   `proteins_norm2` data
##' - `t6.csv`: the processed data table containing the
##'   `proteins_processed` data
##'
##' We combined the sample annotation and the batch annotation in
##' a single table. We also formatted the quantification table so that
##' columns match with those of the annotations. Both annotation and
##' quantification tables are then combined in a single [QFeatures]
##' object using the [scp::readSCP()] function.
##'
##' The 4 CSV files were loaded and formatted as [SingleCellExperiment]
##' objects and the sample metadata were matched to the column names
##' (mapping is retrieved after running the author's original R script)
##' and stored in the `colData`.
##' The object is then added to the [QFeatures] object (containing the
##' PSM assays) and the rows of the peptide data are linked to the
##' rows of the PSM data based on the peptide sequence information
##' through an `AssayLink` object.
##'
##' @source
##' The data were downloaded from the
##' [Slavov Lab](https://scp.slavovlab.net/Leduc_et_al_2022) website.
##' The raw data and the quantification data can also be found in the
##' massIVE repository `MSV000089159`:
##' ftp://massive.ucsd.edu/MSV000089159.
##'
##' @references
##' Andrew Leduc, Gray Huffman, and Nikolai Slavov. 2022. “Droplet
##' Sample Preparation for Single-Cell Proteomics Applied to the Cell
##' Cycle.” bioRxiv. [Link to article](https://doi.org/10.1101/2021.04.24.441211)
##'
##' Gray Huffman, Andrew Leduc, Christoph Wichmann, Marco di Gioia,
##' Francesco Borriello, Harrison Specht, Jason Derks, et al. 2022.
##' “Prioritized Single-Cell Proteomics Reveals Molecular and
##' Functional Polarization across Primary Macrophages.” bioRxiv.
##' [Link to article](https://doi.org/10.1101/2022.03.16.484655).
##'
##' @seealso
##' [leduc2022_plexDIA]
##'
##' @examples
##' \donttest{
##' leduc2022_pSCoPE()
##' }
##'
##' @keywords datasets
##'
"leduc2022_pSCoPE"

##' Petrosius et al, 2023 (Nat. Comm.): Mouse embryonic stem cell (mESC) in
##' different culture conditions
##'
##' @description
##' Profiling mouse embryonic stem cells across ground-state (m2i) and
##' differentiation-permissive (m15) culture conditions. The data were
##' acquired using orbitrap-based data-independent acquisition (DIA).
##' The objective was to demonstrate the capability of their approach
##' by profiling mouse embryonic stem cell culture conditions, showcasing
##' heterogeneity in global proteomes, and highlighting differences in
##' the expression of key metabolic enzymes in distinct cell subclusters.
##'
##' @format A [QFeatures] object with 605 assays, each assay being a
##' [SingleCellExperiment] object:
##'
##' - Assay 1-603: PSM data acquired with an orbitrap-based data-independent
##'   acquisition (DIA) protocol, hence those assays contain single column
##'   that contains the quantitative information.
##' - `peptides`: peptide data containing quantitative data for 9884
##'   peptides and 603 single-cells.
##' - `proteins`: protein data containing quantitative data for 4270
##'   proteins and 603 single-cells.
##'
##' Sample annotation is stored in `colData(petrosius2023_mES())`.
##'
##' @section Acquisition protocol:
##'
##' The data were acquired using the following setup. More information
##' can be found in the source article (see `References`).
##'
##' - **Sample isolation**: Cell sorting was done on a Sony MA900 cell sorter
##'   using a 130 microm sorting chip. Cells were sorted at single-cell resolution,
##'   into a 384-well Eppendorf LoBind PCR plate (Eppendorf AG) containing 1 microL
##'   of lysis buffer.
##' - **Sample preparation**: Single-cell protein lysates were digested with
##'   2 ng of Trypsin supplied in 1 microL of digestion buffer which was 
##'   carried out overnight at 37 °C, and subsequently acidified by the 
##'   addition of 1 microL 1% (v/v) trifluoroacetic acid (TFA). All liquid 
##'   dispensing was done using an I-DOT One instrument.
##' - **Liquid chromatography**: For the HRMS1-DIA experiments and the DIA 
##'   isolation window survey, Evosep One liquid chromatography was used.
##'   The standard 31-minute or 58-minute pre-defined Whisper gradients were 
##'   used with a flow rate of 100 nl/min for peptide elution. 
##' - **Mass spectrometry**: The mass spectrometer was operated in positive
##'   mode with the FAIMSPro interface compensation voltage set to -45 V.
##'   MS1 scans were carried out at 120,000 resolution with an automatic gain
##'   control (AGC) of 300% and maximum injection time set to auto. For the DIA
##'   isolation window survey, a scan range of 500–900 was used, and 400–1000
##'   rest of the experiments. Higher energy collisional dissociation (HCD) was
##'   used for precursor fragmentation with a normalized collision energy (NCE)
##'   of 33% and the MS2 scan AGC target was set to 1000%.
##' - **Raw data processing**: The mESC raw data files were processed with
##'   Spectronaut 17.
##'
##' @section Data collection:
##'
##' The data were provided by the Author and is accessible at the
##' [Dataverse](https://dataverse.uclouvain.be/dataset.xhtml?persistentId=doi:10.14428/DVN/EMAVLT)
##' The folder ('20240205_111248_mESC_SNEcombine_m15-m2i/') contains
##' the following files of interest:
##'
##' - `20240205_111251_PEPQuant (Normal).tsv`: the PSM level data
##' - `20240205_111251_Peptide Quant (Normal).tsv`: the peptide level data
##' - `20240205_111251_PGQuant (Normal).tsv`: the protein level data
##'
##' The metadata were downloaded from the [Zenodo repository](https://zenodo.org/records/8146605).
##'
##' - `sample_facs.csv`: the metadata
##'
##' We formatted the quantification table so that columns match with the
##' metadata. Then, both tables are then combined in a single
##' [QFeatures] object using the [scp::readSCP()] function.
##'
##' The peptide data were formated to a [SingleCellExperiment] object and the
##' sample metadata were matched to the column names and stored in the `colData`.
##' The object is then added to the [QFeatures] object and the rows of the PSM
##' data are linked to the rows of the peptide data based on the peptide sequence
##' information through an `AssayLink` object.
##'
##' The protein data were formated to a [SingleCellExperiment] object and
##' the sample metadata were matched to the column names and stored in the
##' `colData`. The object is then added to the [QFeatures] object and the rows
##' of the peptide data are linked to the rows of the protein data based on the
##' protein sequence information through an `AssayLink` object.
##'
##' @source The peptide and protein data can be downloaded from the
##'     [Dataverse](https://dataverse.uclouvain.be/dataset.xhtml?persistentId=doi:10.14428/DVN/EMAVLT)
##'     The raw data and the quantification data can also be found in
##'     the MassIVE repository `MSV000092429`:
##'     ftp://MSV000092429@massive.ucsd.edu/.
##'
##' @references
##' **Source article**: Petrosius, V., Aragon-Fernandez, P., Üresin, N. et al.
##' "Exploration of cell state heterogeneity using single-cell proteomics
##' through sensitivity-tailored data-independent acquisition."
##' Nat Commun 14, 5910 (2023).
##' ([link to article](https://doi.org/10.1038/s41467-023-41602-1)).
##'
##' @examples
##' \donttest{
##' petrosius2023_mES()
##' }
##'
##' @keywords datasets
##'
"petrosius2023_mES"

suppressPackageStartupMessages({
    library(tidyverse)
    library(QFeatures)
    library(scp)
})

stopifnot(packageVersion("MsDataHub") >= "1.7.1")
stopifnot(packageVersion("QFeatures") >= "1.17.2")


#########################################################
## Preparing the data

ai2025aTab <- read_tsv(MsDataHub::Ai2025_aCMs_report.tsv())

tab <- tibble(File.Name = unique(ai2025aTab[[1]])) |>
    mutate(Sample = sub("^.+CM_PROJECT\\\\", "", File.Name)) |>
    mutate(Sample = sub("\\\\", "_", Sample)) |>
    mutate(Date = ymd(as.integer(substring(Sample, 1, 6)))) |>
    mutate(Subject = sub("^.+_(Subject[0-9])_.+$", "\\1", Sample)) |>
    mutate(PlateWell = sub("^.+_([A-Z][0-9]+)_.+$", "\\1", Sample)) |>
    mutate(PlateRow = gsub("[0-9]*", "", PlateWell)) |>
    mutate(PlateColumn = gsub("[A-Z]*", "", PlateWell)) |>
    mutate(PlateColumn = factor(PlateColumn, levels = 1:24)) |>
    mutate(Position = sub("^.+_([A-Z]+[0-9]+)_1_[0-9]+\\.d$", "\\1", Sample)) |>
    mutate(FileIndex = sub("^.+_1_([0-9]+)\\.d$", "\\1", Sample)) |>
    mutate(FileIndex = factor(FileIndex, levels = sort(unique(FileIndex))))

## Extracting the heart locations
tab$HeartLocation <- NA
ExpectedLocations <- c("Lvendo", "Lvepi", "Lvmid", "RV", "sytox")
for (i in 1:5) {
  loc <- ExpectedLocations[i]
  tab$HeartLocation[grep(loc, tab$File.Name, ignore.case = TRUE)] <- loc
}
tab$runCol <- tab$File.Name

ai2025a <- readSCPfromDIANN(ai2025aTab,
                         colData = DataFrame(tab),
                         fnames = "Precursor.Id")

## Setting the names of the QFeatures objects
names(ai2025a) <- ai2025a$Sample

#########################################################
## Processing from the vignette
ai2025a <- zeroIsNA(ai2025a, names(ai2025a)) |>
    filterFeatures(~ abs(RT - Predicted.RT) < 0.18) |>
    filterFeatures(~ !grepl(";", Protein.Names) &
                       Proteotypic == 1)


## Add cell-level QC metrics
ai2025a$MedianIntensity <- sapply(names(ai2025a), function(i) {
    median(log2(assay(ai2025a[[i]])), na.rm = TRUE)
})
ai2025a$TotalIds <- nrows(ai2025a)

## Join, log-transform and aggregate
ai2025a <- joinAssays(ai2025a, i = names(ai2025a), name = "precursors")

ai2025a <- logTransform(ai2025a, "precursors", "precursors_log")

ai2025a <- aggregateFeatures(ai2025a,
                             i = "precursors_log",
                             name = "peptides",
                             fcol = "Modified.Sequence",
                             fun = colMedians,
                             na.rm = TRUE)

ai2025a <- aggregateFeatures(ai2025a,
                             i = "peptides",
                             name = "proteins",
                             fcol = "Protein.Ids",
                             fun = colMedians,
                             na.rm = TRUE)

ai2025a

#########################################################
## Statistical modelling

sce <- getWithColData(ai2025a, "precursors_log")

sce <- sce[, sce$HeartLocation != "sytox"]

sce <- scpModelWorkflow(
    sce,
    formula = ~ 1 + ## intercept
        ## normalisation
        MedianIntensity +
        ## batch effects
        PlateRow +
        Subject +
        ## biological variability
        HeartLocation,
    verbose = FALSE)

scpModelFilterThreshold(sce) <- 3

#########################################################
## Add sce with scplainer models
ai2025a <- addAssay(ai2025a, sce, "precursors_stats")
ai2025a <- addAssayLinkOneToOne(ai2025a, "precursors_log", "precursors_stats")

stopifnot(validObject(ai2025a))

#########################################################
## Serialise object
save(ai2025a,
     file = file.path("../extdata/ai2025a.rda"),
     compress = "xz",
     compression_level = 9)

####---- Leduc et al. 2022 ---####


## Leduc, Andrew, R. Gray Huffman, and Nikolai Slavov. 2021. “Droplet 
## Sample Preparation for Single-Cell Proteomics Applied to the Cell 
## Cycle.” bioRxiv. https://doi.org/10.1101/2021.04.24.441211.

## This is the script for generating the plexDIA dataset

library("scp")
library("SCP.replication")
library("tidyverse")

## All files were downloaded from 
## https://drive.google.com/drive/folders/117ZUG5aFIJt0vrqIxpKXQJorNtekO-BV

datadir <- "~/PhD/.localdata/SCP/leduc2022/plexDIA/"

####---- Prepare sample annotations ----####

# The sample annotations are provided in 2 separate tables:
design <- read.csv(paste0(datadir, "annotation_plexDIA.csv"))
design <- rename(design, 
                 Run = Set)

## Failed injections not to include when doing DIA-NN max LFQ
runs <-c('wAL_plexMel65', 'wAL_plexMel66', 'wAL_plexMel02',
         'wAL_plexMel04', 'wAL_plexMel06', 'wAL_plexMel08',
         'wAL_plexMel10', 'wAL_plexMel12', 'wAL_plexMel14',
         'wAL_plexMel16', 'wAL_plexMel18', 'wAL_plexMel20',
         'wAL_plexMel22', 'wAL_plexMel24', 'wAL_plexMel26',
         'wAL_plexMel28', 'wAL_plexMel30', 'wAL_plexMel32')
design <- design[!design$Run %in% runs, ]

# Clean the sample metadata so that it meets the requirements for
# `scp::readSCP`. We first need to transform the design (run x 
# reporter ion) to a long table so that one line is one sample. 
design <- pivot_longer(design, -Run, names_to = "Label", 
                       values_to = "SampleAnnotation")
design$SampleType <- recode(design$SampleAnnotation, 
                            neg = "NegativeControl",
                            M = "Melanoma")
design$Label <- sub("^X", "", design$Label)
design$File.Name <- make.names(paste0("D:\\AL\\AL\\", design$Run, ".raw"))

####---- Prepare precursor data ----####

extracted <- read.delim(paste0(datadir, "report.pr_matrix_channels_ms1_extracted.tsv"))
extracted$Stripped.Sequence.Charge <- paste0(extracted$Stripped.Sequence, extracted$Precursor.Charge)
report <- read.delim(paste0(datadir, "report_plexDIA_mel_nPOP.tsv"))
report$File.Name <- make.names(report$File.Name)
leduc2022_plexDIA <- readSCPfromDIANN(colData = design, 
                                      reportData = report,
                                      extractedData = extracted,
                                      multiplexing = "mTRAQ")

####---- Add peptide data ----####

peps <- read.csv(paste0(datadir, "plexDIA_peptide.csv"))
peps <- rename(peps, Stripped.Sequence.Charge = X)
peps <- readSingleCellExperiment(peps, fname = "Stripped.Sequence.Charge",
                                 ecol = grep("^wAL", colnames(peps)))
colnames(peps) <- make.names(paste0("D:\\AL\\AL\\", colnames(peps)))
leduc2022_plexDIA <- addAssay(leduc2022_plexDIA, peps, name = "peptides")
leduc2022_plexDIA <- addAssayLink(leduc2022_plexDIA, 
                                  from = "Ms1Extracted", to = "peptides",
                                  varFrom = "Stripped.Sequence.Charge",
                                  varTo = "Stripped.Sequence.Charge")


####---- Add protein data ----####

prots <- read.csv(paste0(datadir, "plexDIA_protein_imputed.csv"))
prots$Protein.Group <- rownames(prots)
prots <- readSingleCellExperiment(prots, fname = "Protein.Group",
                                 ecol = grep("^wAL", colnames(prots)))
colnames(prots) <- make.names(paste0("D:\\AL\\AL\\", colnames(prots)))
leduc2022_plexDIA <- addAssay(leduc2022_plexDIA, prots, name = "proteins")
leduc2022_plexDIA <- addAssayLink(leduc2022_plexDIA, 
                                  from = "Ms1Extracted", to = "proteins",
                                  varFrom = "Protein.Group",
                                  varTo = "Protein.Group")

## Save data as Rda file
save(leduc2022_plexDIA, 
     file = "~/PhD/.localdata/scpdata/leduc2022_plexDIA.Rda",
     compress = "xz", 
     compression_level = 9)

####---- Zhu et al. 2020, eLife ----####


## Zhu, Ying, Mirko Scheibinger, Daniel Christian Ellwanger, Jocelyn F. 
## Krey, Dongseok Choi, Ryan T. Kelly, Stefan Heller, and Peter G. 
## Barr-Gillespie. 2019. “Single-Cell Proteomics Reveals Changes in 
## Expression during Hair-Cell Development.” eLife 8 (November). 
## https://doi.org/10.7554/eLife.50777.

## The data files were downloaded from: 
## ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2019/11/PXD014256
## 
## PSMS, peptide and proteins data are found in
## SEARCH.zip -> SEARCH/Experiment 1 + 2/txt 2019-05-09a/
## Sample annotation is found in 
## OTHER.zip -> OTHER/Zhu_2019_chick_single_cell_samples.xlsx

library(openxlsx)
library(scp)
library(tidyverse)
dataDir <- "../.localdata/SCP/zhu2019EL/"


####---- Sample annotation ----####


list.files(path = dataDir,
           pattern = "samples_CORRECTED.xlsx",
           full.names = TRUE) %>%
    ## The annotation is in the 3rd sheet
    read.xlsx(sheet = 3, colNames = TRUE, startRow = 7) %>%
    ## Rename column to match with PSM data
    rename(Raw.file = RAW.file.name,
           ## Avoid issue with special characters
           FM1.43.signal = `FM1-43.signal`) %>%
    ## Add the column name containing the quantitative data
    mutate(QuantCol = "Intensity",
           ## Add the experimental replicate
           Experiment = sub("^(.).*$", "\\1", Sample.name)) -> 
    meta


####---- PSM data ----####


## Load the quantification data
list.files(path = dataDir,
           pattern = "evidence", 
           full.names = TRUE) %>%
    read.table(sep = "\t", header = TRUE) %>%
    ## Add file extension to file name to match metadata
    mutate(Raw.file = paste0(Raw.file, ".raw")) %>% 
    ## Select only batches that are annotated
    filter(Raw.file %in% meta$Raw.file) %>%
    ## Add the sample name
    left_join(meta[, c("Raw.file", "Sample.name")], 
              by = "Raw.file") ->
    psms
## Note that we miss annotations for the following runs: 
## - Single_Hair_Cell_OHSU_1cell_Low_030819_R10_YF30um_350bar.raw
## - Single_Hair_Cell_OHSU_1cell_High_030819_R10_YF30um_350bar.raw

## Create the QFeatures object
zhu2019EL <- readSCP(featureData = psms, 
                     colData = meta, 
                     channelCol = "QuantCol", 
                     batchCol = "Sample.name",
                     suffix = "")


####---- Peptide data ----####


## Load the quantification data
list.files(path = dataDir,
           pattern = "peptide", 
           full.names = TRUE) %>%
    read.table(sep = "\t", header = TRUE) ->
    pep

## Rename columns so they match with the PSM data
colnames(pep) <- sub(pattern = "^Intensity.", 
                     replacement = "",
                     colnames(pep))

## Create the SingleCellExperiment object
pep <- readSingleCellExperiment(pep, 
                                ecol = meta$Sample.name)

## Name rows with peptide sequence
rownames(pep) <- rowData(pep)$Sequence

## Include the peptide data in the QFeatures object
zhu2019EL <- addAssay(zhu2019EL, pep, name = "peptides")
## Link the PSMs and the peptides
zhu2019EL <- addAssayLink(zhu2019EL, 
                          from = 1:60, 
                          to = "peptides", 
                          varFrom = rep("Sequence", 60),
                          varTo = "Sequence")

####---- Protein data ----####

## Load the quantification data
prots <- list.files(path = dataDir,
                    pattern = "proteinGroups.txt",
                    full.names = TRUE) %>%
    read.table(sep = "\t", header = TRUE) %>%
    ## Get a unique protein ID
    mutate(Protein = sub("^([^;]*);.*$", 
                         "\\1", 
                         Majority.protein.IDs))
## Remove unnecessary columns
sel <- !grepl("Peptides.*\\d|^Identif|^Razor.*\\d|Sequence.cov.*\\d|Unique.*\\d",
              colnames(prots))
prots <- prots[, sel]
## Split protein data based on the quantification method:
## 1. Protein intensity
protsInt <- prots[, !grepl("^iBAQ.", colnames(prots))]
protsInt <- readSingleCellExperiment(protsInt, 
                                     ecol = grep("^Intensity.", colnames(protsInt)),
                                     fnames = "Protein")
colnames(protsInt) <- gsub("Intensity.", "", colnames(protsInt))
## 3. iBAQ
protsIBAQ <- prots[, !grepl("^Intensity", colnames(prots))]
protsIBAQ <- readSingleCellExperiment(protsIBAQ, 
                                      ecol = grep("^iBAQ.", colnames(protsIBAQ)),
                                      fnames = "Protein")
colnames(protsIBAQ) <- gsub("iBAQ.", "", colnames(protsIBAQ))

## Include the protein data in the QFeatures object
zhu2019EL <- addAssay(zhu2019EL, protsInt, name = "proteins_intensity")
zhu2019EL <- addAssay(zhu2019EL, protsIBAQ, name = "proteins_iBAQ")
## Link the PSMs and the peptides
zhu2019EL <- addAssayLink(zhu2019EL, 
                          from = "peptides", to = "proteins_intensity",
                          varFrom = "Leading.razor.protein", 
                          varTo = "Protein")
zhu2019EL <- addAssayLink(zhu2019EL, 
                          from = "peptides", to = "proteins_iBAQ",
                          varFrom = "Leading.razor.protein", 
                          varTo = "Protein")

# Save data as Rda file
# Note: saving is assumed to occur in "scpdata/inst/scripts"
save(zhu2019EL, 
     file = file.path("../.localdata/scpdata/zhu2019EL.Rda"),
     compress = "xz", 
     compression_level = 9)

---
title: "Single Cell Proteomics data sets"
author:
    - name: Laurent Gatto
    - name: Christophe Vanderaa
output:
    BiocStyle::html_document:
        self_contained: yes
        toc: true
        toc_float: true
        toc_depth: 2
        code_folding: show
date: "`r BiocStyle::doc_date()`"
package: "`r BiocStyle::pkg_ver('scpdata')`"
vignette: >
    %\VignetteIndexEntry{Data Package for Single Cell Proteomics}
    %\VignetteEngine{knitr::rmarkdown}
    %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    crop = NULL ## Related to https://stat.ethz.ch/pipermail/bioc-devel/2020-April/016656.html
)
```

# The `scpdata` package

`scpdata` disseminates mass spectrometry (MS)-based single-cell 
proteomics (SCP) data sets formatted using the `scp` data structure. 
The data structure is described in the 
[`scp` vignette](http://www.bioconductor.org/packages/release/bioc/vignettes/scp/inst/doc/scp.html).

In this vignette, we describe how to access the SCP data sets. To 
start, we load the `scpdata` package.
    
```{r load_scp, message = FALSE}
library("scpdata")
```

# Load data from `ExperimentHub`

The data is stored using the 
[`ExperimentHub`](https://bioconductor.org/packages/release/bioc/html/ExperimentHub.html) 
infrastructure. We first create a connection with `ExperimentHub`. 

```{r EH, message = FALSE}
eh <- ExperimentHub()
```

You can list all data sets available in `scpdata` using the query 
function.

```{r EH_query, message = FALSE}
query(eh, "scpdata")
```

Another way to get information about the available data sets is to 
call `scpdata()`. This will retrieve all the available metadata. For 
example, we can retrieve the data set titles along with the 
description to make an informed choice about which data set to choose.

```{r scpdata_fun}
info <- scpdata()
knitr::kable(info[, c("title", "description")])
```
To get one of the data sets (*e.g.* `dou2019_lysates`) you can either 
retrieve it using the `ExperimentHub` query function 

```{r download_EH}
scp <- eh[["EH3901"]]
scp
```

or you can the use the built-in functions from `scpdata` 

```{r download_scpdata}
scp <- dou2019_lysates()
scp
```

# Data sets information

Each data set has been extensively documented in a separate man page 
(*e.g.* `?dou2019_lysates`). You can find information about the data 
content, the acquisition protocol, the data collection procedure as 
well as the data sources and reference.

# Data manipulation 

For more information about manipulating the data sets, check the 
[`scp`](http://bioconductor.org/packages/release/bioc/html/scp.html) 
package. The `scp` 
[vignette](http://bioconductor.org/packages/release/bioc/vignettes/scp/inst/doc/scp.html) 
will guide you through a typical SCP data processing workflow. Once 
your data is loaded from `scpdata` you can skip section 2 
*Read in SCP data* of the `scp` vignette.

# Session information {-}

```{r setup2, include = FALSE}
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "",
    crop = NULL
)
```

```{r sessioninfo, echo=FALSE}
sessionInfo()
```

# License

This vignette is distributed under a
[CC BY-SA license](https://creativecommons.org/licenses/by-sa/2.0/).

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/schoof2021.R
\docType{data}
\name{schoof2021}
\alias{schoof2021}
\title{Schoof et al. 2021 (Nat. Comm.): acute myeloid leukemia
differentiation}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 194 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \verb{F*}: 192 assays containing PSM quantification data for 16
TMT channels. The quantification data contain signal to noise
ratios as computed by Proteome Discoverer.
\item \code{proteins}: quantitative data for 2898 protein groups in 3072
samples (all runs combined). The quantification data contain
signal to noise ratios as computed by Proteome Discoverer.
\item \code{logNormProteins}: quantitative data for 2723 protein groups in
2025 single-cell samples. This assay is the protein datasets that
was processed by the authors. Dimension reduction and clustering
data are also available in the \code{reducedDims} and \code{colData} slots,
respectively
}

Sample annotation is stored in \code{colData(schoof2021())}. The cell
type annotation is stored in the \code{Population} column. The flow
cytometry data is also available: FSC-A, FSC-H, FSC-W, SSC-A,
SSC-H, SSC-W, APC-Cy7-A (= CD34) and PE-A (= CD38).
}
\source{
The PSM and protein data can be downloaded from the PRIDE
repository PXD020586 The source link is:
https://www.ebi.ac.uk/pride/archive/projects/PXD020586
}
\usage{
schoof2021
}
\description{
Single-cell proteomics data from OCI-AML8227 cell culture to
reconstruct the cellular hierarchy. The data were acquired using
TMTpro multiplexing. The samples contain either no cells,
single cells, 10 cells (reference channel) 200 cells (booster
channel) or are simply empty wells. Single cells are expected to
be one of progenitor cells (\code{PROG}), leukaemia stem cells (\code{LSC}),
CD38- blast cells (\verb{BLAST CD38-}) or CD38+ blast cells
(\verb{BLAST CD38+}). Booster are either a known 1:1:1 mix of cells
(PROG, LSC and BLAST) or are isolated directly from the bulk
sample. Samples were isolated and annotated using flow cytometry.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Sample isolation}: cultured AML 8227 cells were stained with
anti-CD34 and anti-CD38. The sorting was performed by FACSAria
instrument and deposited in 384 well plates.
\item \strong{Sample preparation}: cells are lysed using freeze-boil and
sonication in a lysis buffer (TFE) that also includes reduction
and alkylation reagents (TCEP and CAA), followed by trypsin
(protein) and benzonase (DNA) digestion, TMT-16 labeling and
quenching, desalting using SOLAµ C18 plate, peptide
concentration, pooling and peptide concentration again. The
booster channel contains 200 cell equivalents.
\item \strong{Liquid chromatography}: peptides are separated using a C18
reverse-phase column (50cm x 75 µm i.d., Thermo EasySpray) combined
to a Thermo EasyLC 1200 for 160 minute gradient with a flowrate of
100nl/min.
\item \strong{Mass spectrometry}: FAIMSPro interface is used. MS1 setup:
resolution 60.000, AGC target of 300\%, accumulation of 50ms. MS2
setup: resolution 45.000, AGC target of 150, 300 or 500\%,
accumulation of 150, 300, 500, or 1000ms.
\item \strong{Raw data processing}: Proteome Discoverer 2.4 + Sequest spectral
search engine and validation with Percolator
}
}

\section{Data collection}{


All data were collected from the PRIDE repository (accession ID:
PXD020586). The data and metadata were extracted from the
\code{SCeptre_FINAL.zip} file.

We performed extensive data wrangling to combine al the metadata
available from different files into a single table available using
\code{colData(schoof2021)}.

The PSM data were found in the \code{bulk_PSMs.txt} file. Contaminants
were defined based on the protein accessions listed in
\code{contaminant.txt}. The data were converted to a \link[QFeatures:QFeatures-class]{QFeatures::QFeatures}
object using the \code{\link[scp:readSCP]{scp::readSCP()}} function.

The protein data were found in the \code{bulk_Proteins.txt} file.
Contaminants were defined based on the protein accessions listed
in \code{contaminant.txt}.The column names holding the quantitative
data were adapted to match the sample names in the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures}
object. Unnecessary feature annotations (such as in which assay
a protein is found) were removed. Feature names were created
following the procedure in SCeptre: features names are the
protein symbol (or accession if missing) and if duplicated
symbols are present (protein isoforms), they are made unique by
appending the protein accession.  Contaminants were defined based
on the protein accessions listed in \code{contaminant.txt}. The data
were then converted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object and
inserted in the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object.

The log-normalized protein data were found in the \code{bulk.h5ad} file.
This dataset was generated by the authors by running the notebook
called \code{bulk.ipynb}. The \code{bulk.h5ad} was loaded as an \code{AnnData}
object using the \code{scanpy} Python module. The object was then
converted to a \code{SingleCellExperiment} object using the
\code{zellkonverter} package. The column names holding the quantitative
data were adapted to match the sample names in the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures}
object. The data were then inserted in the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object.

The script to reproduce the \code{QFeatures} object is available at
\code{system.file("scripts", "make-data_schoof2021.R", package = "scpdata")}
}

\examples{
\donttest{
schoof2021()
}

}
\references{
Schoof, Erwin M., Benjamin Furtwängler, Nil Üresin, Nicolas Rapin,
Simonas Savickas, Coline Gentil, Eric Lechman, Ulrich auf Dem
Keller, John E. Dick, and Bo T. Porse. 2021. “Quantitative
Single-Cell Proteomics as a Tool to Characterize Cellular
Hierarchies.” Nature Communications 12 (1): 745679.
(\href{http://dx.doi.org/10.1038/s41467-021-23667-y}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/derks2022.R
\docType{data}
\name{derks2022}
\alias{derks2022}
\title{Derks et al. 2022 - plexDIA (Nat. Biotechnol.): PDAC vs melanoma
cells vs monocytes}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 66 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object. The assays either hold the DIA-NN
main output report table or the DIA-NN MS1 extracted signal table.
The DIA-NN main output report table contains the results of the spectrum
identification and quantification. The DIA-NN MS1 extracted
signal table contains quantification for all mTRAQ channels if its
precursors was identified in at least one of the channels,
regardless of whether there is sufficient evidence in those
channels at 1\% FDR.

The data is composed of three datasets
\enumerate{
\item \strong{Bulk}: dataset containing bulk (100-cell) data acquired
using a Q-Exactive mass spectrometer. Assays 1-3 contain data
from the DIA-NN main output report; assay 4 is the DIA-NN MS1
extracted signal.
\item \strong{tims}: dataset containing single-cell data acquired using a
timsTOF-SCP mass spectrometer. Assays 5-15  contain data
from the DIA-NN main output report; assay 16 is the DIA-NN MS1
extracted signal.
\item \strong{qe}: dataset containing single-cell data acquired
using a Q-Exactive mass spectrometer. Assays 17-64 contain data
from the DIA-NN main output report; assay 65 is the DIA-NN MS1
extracted signal.
}

The last assay \code{proteins} contains the processed protein data
table generated by the authors.

The \code{colData(derks2022())} contains cell type annotations and
batch annotations. The description of the \code{rowData} fields for the
different assays can be found in the
\href{https://github.com/vdemichev/DiaNN#readme}{\code{DIA-NN} documentation}.
}
\source{
The data were downloaded from the
\href{https://scp.slavovlab.net/Derks_et_al_2022}{Slavov Lab} website.
The raw data and the quantification data can also be found in the
massIVE repository \code{MSV000089093}.
}
\usage{
derks2022
}
\description{
Single cell proteomics data acquired by the Slavov Lab using the
plexDIA protocol. It contains quantitative information from
pancreatic ductal acinar cells (PDAC; HPAF-II), melanoma cells
(WM989-A6-G3) and monocytes (U-937) at precursor and protein
level. The each run acquired 3 samples thanks to mTRAQ
multiplexing.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: CellenONE cell sorting.
\item \strong{Sample preparation} performed using the improved SCoPE2
protocol using the CellenONE liquid handling system. nPOP cell
lysis (DMSO) + trypsin digestion + mTRAQ (3plex) labelling and
pooling. A target library was generated as well to
perform prioritized DDA (Huffman et al. 2022) using MaxQuant.Live
(2.0.3).
\item \strong{Separation}: \code{bulk} - online nLC (Dionex UltiMate 3000 UHPLC)
with a 25 cm × 75 µm IonOpticks Aurora Series UHPLC column
(AUR2-25075C18A), 200nL/min. \code{qe} - online nLC (Dionex UltiMate
3000 UHPLC) with a 15 cm × 75 µm IonOpticks Aurora Series UHPLC
column (AUR2-15075C18A), 200nL/min. \code{tims} - nanoElute liquid
chromatography system (Bruker Daltonics) using a 25 cm × 75 µm,
1.6-µm C18 (AUR2-25075C18A-CSI, IonOpticks).
\item \strong{Ionization}: ESI.
\item \strong{Mass spectrometry}: cf article.
\item \strong{Data analysis}: DIA-NN (1.8.1 beta 16).
}
}

\section{Data collection}{


The data were collected from a shared Google Drive
\href{https://drive.google.com/drive/folders/1pUC2zgXKtKYn22mlor0lmUDK0frgwL}{folder}
that is accessible from the SlavovLab website (see \code{Source} section).

For each dataset separately, we combined the sample annotation
and the DIANN tables in a \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object following the \code{scp}
data structure. We then combined the three datasets in a single
\code{QFeatures} object. We load the proteins table processed by the
authors as a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object and adapted the sample
names to match those in the \code{QFeatures} object. We added the
protein data as a new assay and link the precursors to proteins
using the \code{Protein.Group} variable from the \code{rowData}.
}

\examples{
\donttest{
derks2022()
}

}
\references{
Derks, Jason, Andrew Leduc, Georg Wallmann, R. Gray Huffman,
Matthew Willetts, Saad Khan, Harrison Specht, Markus Ralser,
Vadim Demichev, and Nikolai Slavov. 2022. "Increasing the
Throughput of Sensitive Proteomics by plexDIA." Nature
Biotechnology, July.
\href{http://dx.doi.org/10.1038/s41587-022-01389-w}{Link to article}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/leduc2022_plexDIA.R
\docType{data}
\name{leduc2022_plexDIA}
\alias{leduc2022_plexDIA}
\title{Leduc et al. 2022 - plexDIA (biorRxiv): melanoma cells}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 48 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item Assay 1-45: precursor data acquired with a mTRAQ-3 protocol,
hence those assays contain 3 columns. Columns hold quantitative
information from single cells or negative control samples.
\item \code{Ms1Extracted}: the DIA-NN MS1 extracted signal, it combines the
information from assays 1-45.
\item \code{peptides}: peptide data containing quantitative data for 3,608
peptides and 104 single cells. The  data were filtered  to  1\%
protein FDR.
\item \code{proteins}: protein data containing quantitative data for 508
proteins and 105 single cells. Note that the peptide and protein
data provided by the authors differ by 3 samples. The precursor
data were aggregated to protein intensity using maxLFQ. The
protein data were further median normalized by column and by row,
log2 transformed, impute using KNN (k = 3), again median
normalized by column and by row, batch corrected using ComBat,
and median normalized by column and by row once more.
}

The \code{colData(leduc2022_plexDIA())} contains cell type annotation and
batch annotation that are common to all assays. The description of
the \code{rowData} fields for the precursor data can be found in the
\href{https://github.com/vdemichev/DiaNN#readme}{\code{DIA-NN} documentation}.
}
\source{
The links to the data were found on the
\href{https://scp.slavovlab.net/Leduc_et_al_2022}{Slavov Lab website}.
The data were downloaded from the
\href{https://drive.google.com/drive/folders/117ZUG5aFIJt0vrqIxpKXQJorNtekO-BV}{Google drive folder 1} and
\href{https://drive.google.com/drive/folders/12-H2a1mfSHZUGf8O50Cr0pPZ4zIDjTac}{Google drive folder 2}.
The raw data and the quantification data can also be found in the
massIVE repository \code{MSV000089159}:
ftp://massive.ucsd.edu/MSV000089159.
}
\usage{
leduc2022_plexDIA
}
\description{
Single cell proteomics data acquired by the Slavov Lab. This is
the dataset associated to the fourth version of the preprint (and
the Genome Biology publication). It contains quantitative
information of melanoma cells at precursor, peptide and protein level.
This version of the data was acquired using the plexDIA MS
acquisition protocol.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: CellenONE cell sorting.
\item \strong{Sample preparation} performed using the improved SCoPE2
protocol using the CellenONE liquid handling system. nPOP cell
lysis (DMSO) + trypsin digestion + mTRAQ-3
labeling and pooling.
\item \strong{Separation}: online nLC (DionexUltiMate 3000 UHPLC with a
25cm x 75um IonOpticks Aurora Series UHPLC column; 200nL/min).
\item \strong{Ionization}: ESI (1,800V).
\item \strong{Mass spectrometry}: Thermo Scientific Q-Exactive. The duty
cycle = 1 MS1 + 4 DIA MS2 windows (120 Th, 120 Th, 200 Th and
580 Th, spanning 378-1,402 m/z). Each MS1 and MS2 scan was
conducted at 70,000 resolving power, 3×10E6 AGC and 300ms
maximum injection time.
\item \strong{Data analysis}: DIA-NN.
}
}

\section{Data collection}{


The PSM data were collected from a shared Google Drive folder that
is accessible from the SlavovLab website (see \code{Source} section).
The folder contains the following files of interest:
\itemize{
\item \code{annotation_plexDIA.csv}: sample annotation
\item \code{report_plexDIA_mel_nPOP.tsv}: the DIA-NN output file
with the precursor data
\item \code{report.pr_matrix_channels_ms1_extracted.tsv}: the DIA-NN
output file with the combined precursor data
\item \code{plexDIA_peptide.csv}: the processed data table containing the
\code{peptide} data
\item \code{plexDIA_protein_imputed.csv}: the processed data table
containing the \code{protein} data
}

We removed the failed runs as identified by the authors. We also
formatted the annotation and precuror quantification tables to
facilitate matching between corresponding columns. Both annotation
and quantification tables are then combined in a single \link[QFeatures:QFeatures-class]{QFeatures::QFeatures}
object using \code{scp::readSCPfromDIANN()}.

The \code{plexDIA_peptide.csv} and \code{plexDIA_protein_imputed.csv} files
were loaded and formatted as \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} objects. The
columns names were adapted to match those in the \code{QFeatures}
object. The \code{SingleCellExperiment} objects were then added to the
\link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object and the rows of the peptide data are linked to
the rows of the precursor data based on the peptide sequence or
the protein name through an \code{AssayLink} object.
}

\examples{
\donttest{
leduc2022_plexDIA()
}

}
\references{
Andrew Leduc, Gray Huffman, and Nikolai Slavov. 2022. “Droplet
Sample Preparation for Single-Cell Proteomics Applied to the Cell
Cycle.” bioRxiv. \href{https://doi.org/10.1101/2021.04.24.441211}{Link to article}

Andrew Leduc, Gray Huffman, Joshua Cantlon, Saad Khan, and Nikolai
Slavov. 2022. “Exploring Functional Protein Covariation across
Single Cells Using nPOP.” Genome Biology 23 (1): 261.
\href{http://dx.doi.org/10.1186/s13059-022-02817-5}{Link to article}

Jason Derks, Andrew Leduc, Georg Wallmann, Gray Huffman, Matthew
Willetts, Saad Khan, Harrison Specht, Markus Ralser, Vadim
Demichev, and Nikolai Slavov. 2023. “Increasing the Throughput of
Sensitive Proteomics by plexDIA.” Nature Biotechnology 41 (1):
50–59. \href{http://dx.doi.org/10.1038/s41587-022-01389-w}{Link to article}
}
\seealso{
\link{leduc2022_pSCoPE}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/khan2023.R
\docType{data}
\name{khan2023}
\alias{khan2023}
\title{Khan et al, 2023 (biorRxiv): Epithelial–Mesenchymal Transition}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 47 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item Assay 1-44: PSM data acquired with a TMTPro 16plex protocol, hence
those assays contain 16 columns. Columns hold quantitative information
from single-cell channels, carrier channels, reference channels,
empty (negative control) channels and unused channels.
\item \code{peptides}: peptide data containing quantitative data for 10055
peptides and 421 single-cells.
\item \code{proteins_imputed}: protein data containing quantitative data for 4571
proteins and 420 single-cells with k-nearest neighbors (KNN) imputation.
\item \code{proteins_unimputed}: protein data containing quantitative data for 4571
proteins and 420 single-cells without imputation.
}

The \code{colData(khan2023())} contains cell type and batch annotations that
are common to all assays. The description of the \code{rowData} fields for the
PSM data can be found in the
\href{https://cox-labs.github.io/coxdocs/output_tables.html}{\code{MaxQuant} documentation}.
}
\source{
The data were downloaded from the
\href{https://scp.slavovlab.net/Khan_et_al_2023}{Slavov Lab} website via a
shared Google Drive
\href{https://drive.google.com/drive/folders/1zCsRKWNQuAz5msxx0DfjDrIe6pUjqQmj}{folder}.
The raw data and the quantification data can also be found in the
MassIVE repository \code{MSV000092872}:
ftp://MSV000092872@massive.ucsd.edu/.
}
\usage{
khan2023
}
\description{
Single-cell samples were prepared using the nPOP sample
preparation method.  Proteomics data were acquired using the
SCoPE2 protocol on a Thermo Scientific Q-Exactive mass
spectrometer. The dataset contains quantitative information on 421
MCF-10A single cells undergoing epithelial–mesenchymal transition
(EMT) triggered by TGF beta. The data are available at the PSM,
and protein levels. The paper investigates the dynamics of
correlation modules at the protein level.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: CellenONE cell sorting.
\item \strong{Sample preparation} performed using the SCoPE2 protocol. nPOP
cell lysis (DMSO) + trypsin digestion + TMTPro 16plex protocol.
\item \strong{Separation}: online nLC (DionexUltiMate 3000 UHPLC with a
25cm x 75um IonOpticks Odyssey Series column (ODY3-25075C18); 200nL/min).
\item \strong{Ionization}: ESI (1,700 V).
\item \strong{Mass spectrometry}: Thermo Scientific Q-Exactive (MS1
resolution = 70,000; MS1 accumulation time = 300ms; MS2
resolution = 70,000).
\item \strong{Data analysis}: MaxQuant(2.4.13.0) + DART-ID.
}
}

\section{Data collection}{


The PSM data were collected from a shared Google Drive folder that
is accessible from the SlavovLab website (see \code{Source} section).
The folder ('/002-singleCellDataGeneration') contains the following
files of interest:
\itemize{
\item \code{ev_updated_NS.DIA.txt}: the MaxQuant/DART-ID output file
\item \code{annotation.csv}: sample annotation
\item \code{batch.csv}: batch annotation
}

We combined the sample annotation and the batch annotation in
a single table. We also formatted the quantification table so that
columns match with those of the annotation and filter only for
single-cell runs. Both table are then combined in a single
\link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object using the \code{\link[scp:readSCP]{scp::readSCP()}} function.

The peptide data were taken from the same google drive folder
(\code{EpiToMesen.TGFB.nPoP_trial1_pepByCellMatrix_NSThreshDART_medIntCrNorm.txt}).
The data were formatted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object and the sample
metadata were matched to the column names (mapping is retrieved
after running the SCoPE2 R script, \code{EMTTGFB_singleCellProcessing.R}) and
stored in the \code{colData}. The object is then added to the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object
and the rows of the PSM data are linked to the rows of the peptide data
based on the peptide sequence information through an \code{AssayLink} object.

The imputed protein data were taken from the same google drive folder
(\code{EpiToMesen.TGFB.nPoP_trial1_1PercDartFDRTMTBulkDIA.WallE_imputed.txt}).
The data were formatted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object and the sample
metadata were matched to the column names (mapping is retrieved
after running the SCoPE2 R script, \code{EMTTGFB_singleCellProcessing.R}) and
stored in the \code{colData}. The object is then added to the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object
and the rows of the peptide data are linked to the rows of the protein data
based on the protein sequence information through an \code{AssayLink} object.

The unimputed protein data were taken from the same google drive folder
(\code{EpiToMesen.TGFB.nPoP_trial1_1PercDartFDRTMTBulkDIA.WallE_unimputed.txt}).
The data were formatted and added exactly as imputed data.
}

\examples{
\donttest{
khan2023()
}

}
\references{
Saad Khan, Rachel Conover, Anand R. Asthagiri, Nikolai Slavov. 2023.
"Dynamics of single-cell protein covariation during epithelial–mesenchymal
transition." Journal of Proteome Research.
(\href{https://pubs.acs.org/doi/10.1021/acs.jproteome.4c00277}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hu2023.R
\docType{data}
\name{hu2023_K562}
\alias{hu2023_K562}
\alias{hu2023}
\alias{hu2023_oocyte}
\title{Hu et al, 2023 (The Journal of Physical Chemistry B): Correlated protein
modules}
\format{
Two \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} objects:
\itemize{
\item \code{proteins_K562}: protein data containing quantitative data for 1249
proteins and 69 single-cells with zero imputation.
\item \code{proteins_oocyte}: protein data containing quantitative data for 3422
proteins and 137 single-cells with zero imputation.
}

The \code{colData(hu2023_oocyte())} contains cell type annotation.
The \code{colData(hu2023_K562())} contains cell type annotation.
}
\source{
The oocyte data were downloaded from the \href{https://biopic-my.sharepoint.cn/:x:/g/personal/humo_biopic_pku_edu_cn/EfX4CHedVopLuSx2OJNj6LABdESGNdKz4Eh8Zawvd-fNNQ?e=E5m09k&xsdata=MDV8MDJ8ZW5lcy5heWFyQHVjbG91dmFpbi5iZXxjYjY2M2MwYzNjMDY0YjZhNjc1NTA4ZGM4YzMzNjc1YXw3YWIwOTBkNGZhMmU0ZWNmYmM3YzQxMjdiNGQ1ODJlY3wxfDB8NjM4NTM5Mzk5NjI1Mzg1NDQ3fFVua25vd258VFdGcGJHWnNiM2Q4ZXlKV0lqb2lNQzR3TGpBd01EQWlMQ0pRSWpvaVYybHVNeklpTENKQlRpSTZJazFoYVd3aUxDSlhWQ0k2TW4wPXwwfHx8&sdata=Zmt4YnZFZFViTitJRkdTc0FTK2thMjdTT0EzV2JJeS83WlZmV3R6SzdvRT0\%3d}{Shared File}
The K563 cells protein data downloaded from the GitHub
(https://github.com/dionezhang/CPM/blob/master/ProteinAbundance.Rdata)
The raw data and the quantification data can also be found in the
MassIVE repository \code{MSV000089625}: ftp://MSV000089625@massive.ucsd.edu/.
}
\usage{
hu2023_K562
}
\description{
They demonstrate the correlations between the levels of pairs of proteins
in single-cell proteomics (SCP) at steady state. In measuring pairwise
correlations among 1000 proteins in a population of K562 cells and oocytes,
they observed many correlated protein modules (CPMs) that are functionally
involved in certain biological functions. Certain CPMs are specific to a
particular cell type, some common to different cell types. Additionally,
compared to single-cell transcriptomics and bulk proteomics,
protein correlations are functionally and experimentally more significant
in SCP than those corresponding mRNAs.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: K562 cells were re-suspended and washed in cold PBS.
Single cells/10 cells were sorted into 96-well plates using a FACSAria
instrument. Oocyte-cumulus complexes from C57/6J mice were collected
after PMSG and HCG injections, with hyaluronidase used to remove cumulus
cells. All samples stored at -80 degrees Celsius.
\item \strong{Sample preparation} Cells were digested with trypsin at 37 degrees
Celsius for 3 hours. For label-free proteomics, digestion was terminated
by adding 0.43\% TFA and 1\% ACN in water, followed by drying in a
concentrator. Peptides were resuspended in 0.1\% TFA and 1\% ACN, and
then transferred to sample tubes for LC-MS/MS analysis.
\item \strong{Separation}: 4 microliters of peptide digests were injected into a
high-performance chromatography column (IonOpticks) and separated at a
flow rate of 100 nL/min using a nanoflow liquid chromatography system.
The effective gradient was 70 mins, allowing 16 cells per day.
\item \strong{Ionization}: Peptides were analyzed using an Orbitrap Eclipse mass
spectrometer with a FAIMS Pro interface. FAIMS compensation voltages of
-55 and -70 V were applied, with a 1-second cycle time for both voltages.
\item \strong{Mass spectrometry}: MS spectra were acquired with the Orbitrap
analyzer, while MS/MS spectra were acquired with a linear ion trap
analyzer. The maximum ion injection time for MS/MS was 200 ms.
\item \strong{Data analysis}: MS raw files were searched against the UniProt
human protein database and an in-house contamination database
using Proteome Discoverer(2.4). Label-free quantification was based on
peak intensity with the match-between-runs (MBR) feature enabled.
}
}

\section{Data collection}{


The oocyte protein data shared by the author and it is accessible from the
\href{https://biopic-my.sharepoint.cn/:x:/g/personal/humo_biopic_pku_edu_cn/EfX4CHedVopLuSx2OJNj6LABdESGNdKz4Eh8Zawvd-fNNQ?e=E5m09k&xsdata=MDV8MDJ8ZW5lcy5heWFyQHVjbG91dmFpbi5iZXxjYjY2M2MwYzNjMDY0YjZhNjc1NTA4ZGM4YzMzNjc1YXw3YWIwOTBkNGZhMmU0ZWNmYmM3YzQxMjdiNGQ1ODJlY3wxfDB8NjM4NTM5Mzk5NjI1Mzg1NDQ3fFVua25vd258VFdGcGJHWnNiM2Q4ZXlKV0lqb2lNQzR3TGpBd01EQWlMQ0pRSWpvaVYybHVNeklpTENKQlRpSTZJazFoYVd3aUxDSlhWQ0k2TW4wPXwwfHx8&sdata=Zmt4YnZFZFViTitJRkdTc0FTK2thMjdTT0EzV2JJeS83WlZmV3R6SzdvRT0\%3d}{Shared File}
The K563 protein data is accessible from the
GitHub (https://github.com/dionezhang/CPM/blob/master/ProteinAbundance.Rdata).
\itemize{
\item \verb{DataMatrix-oocyte-20240614.csv}: normalized imputed protein matrix
\item \code{ProteinAbundance.Rdata}: protein matrices (normalized, log transformed)
}

We initialized an empty QFeatures object and added the corresponding
protein assays as \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} objects.

The oocyte protein data were exported from the shared link as
(\verb{DataMatrix-oocyte-20240614.csv}). The data were formatted to a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object and the SampleType information were added
as only metadata, and stored in the \code{colData}. The object is then added
to the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object.

The 562 cells protein data were downloaded from the GitHub link and loaded
to the memory. The \code{Norm} object were formatted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment}
object and the SampleType information were added as only metadata, and
stored in the \code{colData}. The object is then added to the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object.
}

\examples{
\donttest{
hu2023_oocyte()
hu2023_K562()
}

}
\references{
\itemize{
\item Hu, M., Zhang, Y., Yuan, Y., Ma, W., Zheng, Y., Gu, Q., & Xie, X. S. 2023.
“Correlated protein modules revealing functional coordination of
interacting proteins are detected by single-cell proteomics.”. The Journal
of Physical Chemistry B, (\href{https://doi.org/10.1021/acs.jpcb.3c00014}{link to article}).
}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scpdata.R
\name{leduc2022}
\alias{leduc2022}
\title{Deprecated leduc2022 dataset}
\usage{
leduc2022()
}
\value{
The \code{leduc2022_pSCoPE} dataset.
}
\description{
The \code{leduc2022} dataset has been updated to include plexDIA and
pSCoPE data. The new datasets names are \code{leduc2022_pSCoPE}
(previously \code{leduc2022}) and \code{leduc2022_plexDIA} (new). See the
respective documentation pages for more information.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/brunner2022.R
\docType{data}
\name{brunner2022}
\alias{brunner2022}
\title{Brunner et al. 2022 (Mol. Syst. Biol.): cell cycle state study}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 435 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object.
\itemize{
\item Assay 1-434: DIA-NN main output report table split for each
acquisition run. Since each run acquires 1 single cell, each
assay contains a single column. It contains the results
of the spectrum identification and quantification.
\item \code{protein}: DIA-NN protein group matrix, containing normalised
quantities for 2476 protein groups in 434 single cells. Proteins
are filtered at 1\% FDR, using global q-values for protein groups
and both global and run-specific q-values for precursors.
}

The \code{colData(brunner2022())} contains cell type annotations and
batch annotations. The description of the \code{rowData} fields for the
different assays can be found in the
\href{https://github.com/vdemichev/DiaNN#readme}{\code{DIA-NN} documentation}.
}
\source{
The data were downloaded from PRIDE
\href{https://www.ebi.ac.uk/pride/archive/projects/PXD024043}{repository}
with accession ID \code{PXD024043}.
}
\usage{
brunner2022
}
\description{
Single cell proteomics data acquired by the Mann Lab using a newly
designed timsTOF instrument, referred to as timsTOF-SCP. The
dataset contains quantitative information from single-cells blocked
at 4 cell cycle stages: G1, G1-S, G2, G2-M. The data was acquired
using a label-free sample preparation protocole combined to a
data independent (DIA) acquisition mode.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: cells were detached with trypsin treatment,
followed by strong pipetting, and isolate using FACS.
\item \strong{Sample preparation}: cell lysis by freeze-heat followed by
sonication, overnight protein digestion with trypsin/lysC mix and
desalting using EvoTips trap column (EvoSep)
\item \strong{Separation}: online EvoSep One LC system using a 5 cm x 75 µm
ID column with 1.9µm C18 beads (EvoSep) at 100nL/min flow rate.
\item \strong{Ionization}: 10µm ID zero dead volume electrospray emitter
(Bruker Daltonik) + nanoelectro-spray ion source (Captive spray,
Bruker Daltonik)
\item \strong{Mass spectrometry}: DIA PASEF mode. Correlation between IM
and m/z was used to synchronize the elution of precursors from
each IM scan with the quadrupole isolation window. Five
consecutive diaPASEF cycles. The collision energy was ramped
linearly as a function of the IM from 59 eV at 1/K0=1.6 Vs cm^2
to 20 eV at 1/K0=0.6 Vs cm^2.
\item \strong{Data analysis}: DIA-NN (1.8).
}
}

\section{Data collection}{


The data were collected from the PRIDE
\href{https://www.ebi.ac.uk/pride/archive/projects/PXD024043}{repository}
in the \code{DIANN1.8_SingleCells_CellCycle.zip} file.

We loaded the DIA-NN main report table and generated a sample
annotation table based on the MS file names. We next combined the
sample annotation and the DIANN tables into a \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object
following the \code{scp} data structure. We loaded the proteins group
matrix as a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object, fixed ambiguous
protein group names, and added the protein data as a new assay and
link the precursors to proteins using the \code{Protein.Group} variable
from the \code{rowData}.
}

\examples{
\donttest{
brunner2022()
}

}
\references{
Brunner, Andreas-David, Marvin Thielert, Catherine Vasilopoulou,
Constantin Ammar, Fabian Coscia, Andreas Mund, Ole B. Hoerning, et
al. 2022. "Ultra-High Sensitivity Mass Spectrometry Quantifies
Single-Cell Proteome Changes upon Perturbation." Molecular Systems
Biology 18 (3): e10798.
\href{http://dx.doi.org/10.15252/msb.202110798}{Link to article}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/williams2020_tmt.R
\docType{data}
\name{williams2020_tmt}
\alias{williams2020_tmt}
\title{Williams et al. 2020 (Anal. Chem.): 3 AML cell line}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 4 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \verb{peptides_[intensity or corrected]}: 2 assays containing peptide
reporter ion intensities or corrected reporter ion intensities
as computed by MaxQuant.
\item \verb{proteins_[intensity or corrected]}: 2 assays containing protein
reporter ion intensities or corrected reporter ion intensities
as computed by MaxQuant.
}

Sample annotation is stored in \code{colData(williams2020_tmt())}.
}
\source{
The PSM and protein data can be downloaded from the MASSIVE
repository MSV000085230.
}
\usage{
williams2020_tmt
}
\description{
Single-cell label data from three acute myeloid
leukemia cell line culture (MOLM-14, K562, CMK). The data were
acquired using a TMT-based quantification protocole and the
nanoPOTS technology. The objective was to demonstrate successful
use of the new nanoPOTS autosampler presented in the source
article. The samples contain either carrier (10 ng), reference
(0.2ng), empty or single-cell samples..
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Sample isolation}: cultured MOLM-14, K562 or CMK cells were
isolated using flow-cytometry based cell sorting and deposit on
nanoPOTS microwells
\item \strong{Sample preparation}: cells are lysed using using a DDM lysis
buffer. Proteins are digested with trypsin followed by TMT
labelling and quanching with HA. The samples are then acidified
with FA, pooled in a single samples (adding carrier and reference
peptide mixtures), and dried until LC-MS/MS analysis.
\item \strong{Liquid chromatography}: peptides are loaded using the new
autosampler described in the paper. Samples are loaded using a
a homemade miniature syringe pump. The samples are then desalted
and concentrated through a SPE column (4cm x 100µm i.d. packed
with 5µm C18) with microflow LC pump. The peptides are then eluted
from a long LC column (60cm x 50 µm i.d. packed with 3µm C18)
coupled to a nanoflox LC pump at 150nL/mL (elution time is not
expliceted).
\item \strong{Mass spectrometry}: MS/MS was performed on an Orbitrap Fusion
Lumos Tribrid MS coupled to a 2kV ESI. MS1 setup: Orbitrap
analyzer at resolution 120.000, AGC target of 1E6, accumulation
of 246ms. MS2 setup: Orbitrap with HCD at resolution 120.000, AGC
target of 1E6, accumulation of 246ms.
\item \strong{Raw data processing}: preprocessing using Maxquant v1.6.2.10
that use Andromeda search engine (with UniProtKB 2016-21-29).
}
}

\section{Data collection}{


All data were collected from the MASSIVE repository (accession ID:
MSV000085230).

The peptide and protein data were extracted from the
\code{Peptides_AML_SingleCell.txt} or \code{ProteinGroups_AML_SingleCell.txt}
files, respectively, in the \code{AML_SingleCell} folders.

The tables were duplicated so that intensisities and corrected
intensities are contained in separate tables. Tables are then
converted to \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} objects. Sample annotations
were inferred from the sample names, from table S2 and from the
Experimental Section of the paper. All data is combined in
a \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object. \link[QFeatures:AssayLinks]{QFeatures::AssayLinks} were stored between peptide
assays and their corresponding proteins assays based on the
leading razor protein (hence only unique peptides are linked to
proteins).

The script to reproduce the \code{QFeatures} object is available at
\code{system.file("scripts", "make-data_williams2020_tmt.R", package = "scpdata")}
}

\examples{
\donttest{
williams2020_tmt()
}

}
\references{
\strong{Source article}: Williams, Sarah M., Andrey V. Liyu, Chia-Feng
Tsai, Ronald J. Moore, Daniel J. Orton, William B. Chrisler,
Matthew J. Gaffrey, et al. 2020. “Automated Coupling of
Nanodroplet Sample Preparation with Liquid Chromatography-Mass
Spectrometry for High-Throughput Single-Cell Proteomics.”
Analytical Chemistry 92 (15): 10588–96.
(\href{http://dx.doi.org/10.1021/acs.analchem.0c01551}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/leduc2022_pSCoPE.R
\docType{data}
\name{leduc2022_pSCoPE}
\alias{leduc2022_pSCoPE}
\title{Leduc et al. 2022 - pSCoPE (biorRxiv): melanoma cells vs monocytes}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 138 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item Assay 1-134: PSM data acquired with a TMT-18plex protocol, hence
those assays contain 18 columns. Columns hold quantitative
information from single-cell channels, carrier channels,
reference channels, empty (negative control) channels and
unused channels.
\item \code{peptides}: peptide data containing quantitative data for 20,804
peptides and 1556 single-cells. These data have been filtered
to keep high-quality PSMs, all batches have been normalized to
the reference channel, PSMs were aggregated to peptides, and
single-cells with low median coefficient of variation were kept.
\item \code{peptides_log}: peptide data containing quantitative data for
12,284 peptides and 1543 single-cells. The \code{peptides} data was
further normalized, highly missing peptides were removed and the
quantifications were log-transformed.
\item \code{proteins_norm2}: protein data containing quantitative data for
2844 proteins and 1543 single-cells. The peptides from
\code{peptides_log} were aggregated to proteins and normalized.
\item \code{proteins_processed}: protein data containing quantitative data
for 2844 proteins and 1543 single-cells. The \code{proteins_norm2}
data were imputed, batch corrected and normalized.
}

The \code{colData(leduc2022_pSCoPE())} contains cell type annotation,
LC batch information, the TMT label, the MS run ID. We also added
the sample prep annotations provided by the cellenONE dispensing
device (only for single cells): time stamp of cell isolation by the
device, the diameter and elongation of the cell, the ID of the
sample glass side (4 slides in total), the field within the glass
(each slide is divided in 4 field), the pooled well ID (each field
contains 9 pools), the x and y coordinates of each cell dropped in
a field and of each cell pool upon pickup. Finally, we also
retrieved the melanoma subpopulation generated by the authors upon
data analysis. The main population is encoded as \code{A} while the
small population is encoded \code{B}. The description of the \code{rowData}
fields for the PSM data can be found in the
\href{http://www.coxdocs.org/doku.php?id=maxquant:table:evidencetable}{\code{MaxQuant} documentation}.
}
\source{
The data were downloaded from the
\href{https://scp.slavovlab.net/Leduc_et_al_2022}{Slavov Lab} website.
The raw data and the quantification data can also be found in the
massIVE repository \code{MSV000089159}:
ftp://massive.ucsd.edu/MSV000089159.
}
\usage{
leduc2022_pSCoPE
}
\description{
Single cell proteomics data acquired by the Slavov Lab. This is
the dataset associated to the third version of the preprint. It
contains quantitative information of melanoma cells and monocytes
at PSM, peptide and protein level. This version of the data was
acquired using the pSCoPE MS acquisition approach.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: CellenONE cell sorting.
\item \strong{Sample preparation} performed using the improved SCoPE2
protocol using the CellenONE liquid handling system. nPOP cell
lysis (DMSO) + trypsin digestion + TMT-18plex
labeling and pooling. A target library was generated as well to
perform prioritized DDA (Huffman et al. 2022) using MaxQuant.Live
(2.0.3).
\item \strong{Separation}: online nLC (DionexUltiMate 3000 UHPLC with a
25cm x 75um IonOpticks Aurora Series UHPLC column; 200nL/min).
\item \strong{Ionization}: ESI (1,800V).
\item \strong{Mass spectrometry}: Thermo Scientific Q-Exactive (MS1
resolution = 70,000; MS2 accumulation time = 300ms; MS2
resolution = 70,000). Prioritized data acquisition was performed
using the pSCoPE protocol (Huffman et al. 2022)
\item \strong{Data analysis}: MaxQuant (1.6.17.0) + DART-ID
}
}

\section{Data collection}{


The PSM data were collected from a shared Google Drive folder that
is accessible from the SlavovLab website (see \code{Source} section).
The folder contains the following files of interest:
\itemize{
\item \code{ev_updated.txt}: the MaxQuant/DART-ID output file
\item \code{annotation.csv}: sample annotation
\item \code{batch.csv}: batch annotation
\item \code{t0.csv}: the processed data table containing the \code{peptides} data
\item \code{t3.csv}: the processed data table containing the \code{peptides_log}
data
\item \code{t4b.csv}: the processed data table containing the
\code{proteins_norm2} data
\item \code{t6.csv}: the processed data table containing the
\code{proteins_processed} data
}

We combined the sample annotation and the batch annotation in
a single table. We also formatted the quantification table so that
columns match with those of the annotations. Both annotation and
quantification tables are then combined in a single \link[QFeatures:QFeatures-class]{QFeatures::QFeatures}
object using the \code{\link[scp:readSCP]{scp::readSCP()}} function.

The 4 CSV files were loaded and formatted as \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment}
objects and the sample metadata were matched to the column names
(mapping is retrieved after running the author's original R script)
and stored in the \code{colData}.
The object is then added to the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object (containing the
PSM assays) and the rows of the peptide data are linked to the
rows of the PSM data based on the peptide sequence information
through an \code{AssayLink} object.
}

\examples{
\donttest{
leduc2022_pSCoPE()
}

}
\references{
Andrew Leduc, Gray Huffman, and Nikolai Slavov. 2022. “Droplet
Sample Preparation for Single-Cell Proteomics Applied to the Cell
Cycle.” bioRxiv. \href{https://doi.org/10.1101/2021.04.24.441211}{Link to article}

Gray Huffman, Andrew Leduc, Christoph Wichmann, Marco di Gioia,
Francesco Borriello, Harrison Specht, Jason Derks, et al. 2022.
“Prioritized Single-Cell Proteomics Reveals Molecular and
Functional Polarization across Primary Macrophages.” bioRxiv.
\href{https://doi.org/10.1101/2022.03.16.484655}{Link to article}.
}
\seealso{
\link{leduc2022_plexDIA}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/woo2022_lung.R
\docType{data}
\name{woo2022_lung}
\alias{woo2022_lung}
\title{Woo et al. 2022 (Cell Syst.): 26 primary human lung cells}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 5 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \verb{peptides_[intensity or LFQ]}: 2 assays containing peptide
quantities or normalized quantities using the maxLFQ method
as computed by MaxQuant.
\item \verb{proteins_[intensity or iBAQ or LFQ]}: 3 assays containing
protein quantities or normalized proteins using the iBAQ or
maxLFQ methods as computed by MaxQuant.
}

Sample annotation is stored in \code{colData(woo_lung())}.
}
\source{
The peptide and protein data can be downloaded from the MASSIVE
repository MSV000085937
}
\usage{
woo2022_lung
}
\description{
Single-cell proteomics data from dissociated primary human lung
cells. The data were
acquired using the TIFF (transfer identification based on FAIMS
filtering) acquisition method. The data contain 26 single cells.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Sample isolation}: primary human lung cells were dissociated
following the protocol in Bandyopadhyay et al., 2018. The cells
were sorted using the Influx II cell sorter and deposited on a
nanoPOTS chip.
\item \strong{Sample preparation}: cells are lysed using using a DDM+DTT
lysis and reduction buffer. The proteins are alkylated with IAA
and digested with LysC and trypsin. Samples are then acidified
with FA, vacuum dried and stored in freezer until data
acquisition.
\item \strong{Liquid chromatography}: peptides are loaded using an in-house
autosampler (Williams et al. 2020). The samples are concentrated
through a SPE column (4cm x 100µm i.d. packed with 5µm C18) with
microflow LC pump. The peptides are then eluted from an LC
column (25cm x 50 µm i.d. packed with 1.7µm C18) from a 60 min
gradient (100nL/min).
\item \strong{Mass spectrometry}: MS/MS was performed on an Orbitrap Fusion
Lumos Tribrid MS with FAIMSpro coupled to a 2.4 kV ESI. FAIMS
setup: 4-CV method (-45, -55, -65, -75 V). MS1 setup: resolution
= 120.000, range = 350-1500 m/z,AGC target of 1E6, accumulation
of 254ms. MS2 setup: 30\% HCD, resolution AGC 2E4, accumulation
of 254ms.
\item \strong{Raw data processing}: preprocessing using Maxquant v1.6.2.10
that use Andromeda search engine (with UniProtKB 2016-21-29).
MBR was enabled.
}
}

\section{Data collection}{


All data were collected from the MASSIVE repository (accession ID:
MSV000085937).

The peptide and protein data were extracted from the
\code{peptides_nondepleted_Lung_scProteomics.txt} or
\code{proteinGroups_nondepleted_Lung_scProteomics.txt} files,
respectively, in the \code{NonDepleted_Lung_SingleCellProteomics}
folders.

The tables were split so that intensities, maxLFQ, and iBAQ
data are contained in separate tables. Tables are then
converted to \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} objects. Sample annotations
were inferred from the sample names. All data is combined in
a \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object. \link[QFeatures:AssayLinks]{QFeatures::AssayLinks} were stored between peptide
assays and their corresponding proteins assays based on the
leading razor protein (hence only unique peptides are linked to
proteins).

The script to reproduce the \code{QFeatures} object is available at
\code{system.file("scripts", "make-data_woo2022_lung.R", package = "scpdata")}
}

\examples{
\donttest{
woo2022_lung()
}

}
\references{
\strong{Source article}: Woo, Jongmin, Geremy C. Clair, Sarah M.
Williams, Song Feng, Chia-Feng Tsai, Ronald J. Moore, William B.
Chrisler, et al. 2022. “Three-Dimensional Feature Matching
Improves Coverage for Single-Cell Proteomics Based on Ion Mobility
Filtering.” Cell Systems 13 (5): 426–34.e4.
(\href{http://dx.doi.org/10.1016/j.cels.2022.02.003}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/leduc2025.R
\docType{data}
\name{leduc2025}
\alias{leduc2025}
\title{Leduc et al, 2025 (bioRxiv): Principles of protein abundance regulation
across single cells in a mammalian tissue}
\format{
A \link[QFeatures:QFeatures]{QFeatures} object with 11 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment} object:
\itemize{
\item Assay 1-4: unprocessed peptide data containing quantitative data coming
from four replicates.
\item Assay 5-8: processed peptide data containing quantitative data coming
from four replicates.
\item \code{proteins_absolute}: protein data containing quantitative data for 2,339
proteins and 4,184 single-cells.
\item \code{proteins_relative}: protein data containing quantitative data for 2,331
proteins and 4,184 single-cells. Relative abundance values against the
protein mean across all samples.
\item \code{proteins_imputed}: protein data containing quantitative data for 667
proteins and 4,184 single-cells with k-nearest neighbors (KNN) imputation
and comBat batch-correction.
}

The \code{colData(leduc2025())} contains cell type and batch annotations that
are common to all assays.
}
\source{
The data were downloaded from the
\href{https://scp.slavovlab.net/Leduc_et_al_2025}{Slavov Lab} website via a
shared Zenodo folder
\href{https://zenodo.org/records/14902834}{folder}.
The raw data and the quantification data can also be found in the
MassIVE repository \code{MSV000098940}:
ftp://massive-ftp.ucsd.edu/v10/MSV000098940/.

The data used and generated as part of the scpdata repackaging is available
in the \href{https://doi.org/10.5281/zenodo.21904283}{Zenodo archive}.
}
\usage{
leduc2025
}
\description{
Single-cell samples were prepared using the nPOP glass-slide sample
preparation method. Proteomics data were acquired using the timsControl 3.1
on a timsTOF SCP mass spectrometer. The dataset contains quantitative
information on 4,184 single cell from murine trachea. The data are available
at the peptide, and protein levels. The paper investigates the protein
regulation by translation and protein clearance using a matching single
cell RNA Sequencing data.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: CellenONE cell sorting.
\item \strong{Sample preparation} performed using the nPOP sample preperation method.
cell lysis (DMSO) + trypsin digestion + mTRAQ reagents.
\item \strong{Separation}: online nLC (Vanquish Neo UHPLC with a 25cm x 75um
IonOpticks Aurora Series UHPLC column (AUR2-25075C18A).
\item \strong{Mass spectrometry}: timsTOF SCP mass spectrometer (MS1 scan range =
100-1700 m/z; MS2 scan range = 300-1000 m/z).
\item \strong{Data analysis}: DIA-NN(v1.9.0).
}
}

\section{Data collection}{


The Peptide data were collected from a Zenodo folder that is accessible from
the SlavovLab website (see \code{Source} section).

The folder ('02_raw_reptide_X_singleCell/') contains the following
files of interest:
\itemize{
\item \code{r1_peptide.csv}: peptide level unprocessed quantitative data for
replicate 1.
\item \code{r2_peptide.csv}: peptide level unprocessed quantitative data for
replicate 2.
\item \code{r3_peptide.csv}: peptide level unprocessed quantitative data for
replicate 3.
\item \code{r4_peptide.csv}: peptide level unprocessed quantitative data for
replicate 4.
}

('03_QuantQC_objects/') contains the following files of interest:
\itemize{
\item \code{r1_5day_male.RData}: peptide level processed quantitative data for
replicate 1 and row data information for peptide to protein mapping.
\item \code{r2_5day_female.RData}: peptide level processed quantitative data for
replicate 2 and row data information for peptide to protein mapping.
\item \code{r3_10day_male.RData}: peptide level processed quantitative data for
replicate 3 and row data information for peptide to protein mapping.
\item \code{r4_10day_female.RData}: peptide level processed quantitative data for
replicate 4 and row data information for peptide to protein mapping.
}

('04_Gene_X_SingleCell_and_annotations/') contains the following files of
interest:
\code{sc_protein_absolute.csv}: protein level quantitative data with absolute
protein concentrations.
\code{sc_protein_relative.csv}: protein level quantitative data with relative
protein abundance.
\code{sc_protein_annotations.csv}: sample and batch annotations.

We also obtained imputed and batch corrected protein level data. To do that
we run the script \code{get_protein_Data.R} based on the original script
\verb{02_cell_type_assign.R} in the github repository of the article.

We formatted the peptide level quantification tables so that columns match
with those of the annotation and protein level data. Each peptide level
data for replicates turned into \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment} objects including
row data information that is extracted from shared QuantQC objects. All
the peptide level assays used to generate \link[QFeatures:QFeatures]{QFeatures} object.

Protein level data were taken from '04_Gene_X_SingleCell_and_annotations/'
folder. Imputed and batch effect corrected protein level data is generated
using \code{get_protein_Data.R} script. The protein assays were formatted as
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment} objects and the sample metadata were matched to the
column names. The objects are then added to the \link[QFeatures:QFeatures]{QFeatures} object
and the rows of the peptide data are linked to the rows of the corresponding
protein data based on the protein sequence information through an
\code{AssayLink} object.
}

\examples{
\donttest{
leduc2025()
}

}
\references{
Leduc A, et al., Principles of protein abundance regulation across single
cells in a mammalian tissue, bioRxiv, doi: 10.1101/2025.09.17.676955
(\href{https://www.biorxiv.org/content/10.1101/2025.09.17.676955v2}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/zhu2018NC_islets.R
\docType{data}
\name{zhu2018NC_islets}
\alias{zhu2018NC_islets}
\title{Zhu et al. 2018 (Nat. Comm.): human pancreatic islets}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 4 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \code{peptides}: quantitative information for 24,321 peptides from
18 islet samples
\item \code{proteins_intensity}: quantitative information for 3,278
proteins from 18 islet samples
\item \code{proteins_LFQ}: LFQ intensities for 3,278 proteins from 18 islet
samples
\item \code{proteins_iBAQ}: iBAQ values for 3,278 proteins from 18 islet
samples
}

Sample annotation is stored in \code{colData(zhu2018NC_islets())}.
}
\source{
The PSM data can be downloaded from the PRIDE repository
PXD006847. The source link is:
ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/01/PXD006847
}
\usage{
zhu2018NC_islets
}
\description{
Near single-cell proteomics data human pancreas samples. The
samples were collected from pancreatic tissue slices using laser
dissection. The pancreata were obtained from organ donors through
the JDRFNetwork for Pancreatic Organ Donors with Diabetes (nPOD)
program. The sample come either from control patients (n=9) or
from type 1 diabetes (T1D) patients (n=9).
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: The islets were extracted from the pacreatic
tissues using laser-capture microdissection.
\item \strong{Sample preparation} performed using the nanoPOTs device.
Protein extraction using RapiGest (+ DTT) + alkylation (IAA) +
Lys-C digestion + cleave RapiGest (formic acid)
\item \strong{Separation}: nanoACQUITY UPLC pump with an Self-Pack PicoFrit
70cm x 30um LC columns; 60nL/min)
\item \strong{Ionization}: ESI (1,900V)
\item \strong{Mass spectrometry}: Thermo Fisher Orbitrap Fusion Lumos
Tribrid. MS1 settings: accumulation time = 246ms; resolution =
120,000; AGC = 1E6. MS/MS settings: accumulation time = 118ms;
resolution = 60,000; AGC = 1E5.
\item \strong{Data analysis}: MaxQuant (v1.5.3.30) + Perseus + OriginLab
2017
}
}

\section{Data collection}{


The data were collected from the PRIDE repository (accession
ID: PXD006847).  We downloaded the \code{Islet_t1d_ct_peptides.txt}
and the \code{Islet_t1d_ct_proteinGroups.txt} files containing the
combined identification and quantification results. The sample
types were inferred from the names of columns holding the
quantification data. The peptides data were converted to a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object. We split the protein table to
separate the three types of quantification: protein intensity,
label-free quantitification (LFQ) and intensity based absolute
quantification (iBAQ). Each table is converted to a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object along with the remaining protein
annotations. The 4 objects are combined in a single \link[QFeatures:QFeatures-class]{QFeatures::QFeatures}
object and feature links are created based on the peptide leading
razor protein ID and the protein ID.
}

\examples{
\donttest{
zhu2018NC_islets()
}

}
\references{
Zhu, Ying, Paul D. Piehowski, Rui Zhao, Jing Chen, Yufeng Shen,
Ronald J. Moore, Anil K. Shukla, et al. 2018. “Nanodroplet
Processing Platform for Deep and Quantitative Proteome Profiling
of 10-100 Mammalian Cells.” Nature Communications 9 (1): 882
(\href{http://dx.doi.org/10.1038/s41467-018-03367-w}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/specht2019v3.R
\docType{data}
\name{specht2019v3}
\alias{specht2019v3}
\title{Specht et al. 2019 - SCoPE2 (biorRxiv): macrophages vs monocytes
(version 3)}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 179 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item Assay 1-63: PSM data for SCoPE2 sets acquired with a TMT-11plex
protocol, hence those assays contain 11 columns. Columns
hold quantitative information from single-cell channels, carrier
channels, reference channels, empty (blank) channels and unused
channels.
\item Assay 64-177: PSM data for SCoPE2 sets acquired with a
TMT-16plex protocol, hence those assays contain 16 columns.
Columns hold quantitative information from single-cell channels,
carrier channels, reference channels, empty (blank) channels and
unused channels.
\item \code{peptides}: peptide data containing quantitative data for 9208
peptides and 1018 single-cells.
\item \code{proteins}: protein data containing quantitative data for 2772
proteins and 1018 single-cells.
}

The \code{colData(specht2019v2())} contains cell type annotation and
batch annotation that are common to all assays. The description of
the \code{rowData} fields for the PSM data can be found in the
\href{http://www.coxdocs.org/doku.php?id=maxquant:table:evidencetable}{\code{MaxQuant} documentation}.
}
\source{
The data were downloaded from the
\href{https://scope2.slavovlab.net/docs/data}{Slavov Lab} website via a
shared Google Drive
\href{https://drive.google.com/drive/folders/1VzBfmNxziRYqayx3SP-cOe2gu129Obgx}{folder}.
The raw data and the quantification data can also be found in the
massIVE repository \code{MSV000083945}:
ftp://massive.ucsd.edu/MSV000083945.
}
\usage{
specht2019v3
}
\description{
Single cell proteomics data acquired by the Slavov Lab. This is
the version 3 of the data released in October 2020. It contains
quantitative information of macrophages and monocytes at PSM,
peptide and protein level.
}
\note{
Since version 2, a serious bug in the data were corrected
for TMT channels 12 to 16. Many more cells are therefore contained
in the data. Version 2 is maintained for backward compatibility.
Although the final version of the article was published in 2021,
we have kept \code{specht2019v3} as the data set name for consistency
with the previous data version \code{specht2019v2}.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: flow cytometry (BD FACSAria I).
\item \strong{Sample preparation} performed using the SCoPE2 protocol. mPOP
cell lysis + trypsin digestion + TMT-11plex or 16plex labeling
and pooling.
\item \strong{Separation}: online nLC (DionexUltiMate 3000 UHPLC with a
25cm x 75um IonOpticksAurora Series UHPLC column; 200nL/min).
\item \strong{Ionization}: ESI (2,200V).
\item \strong{Mass spectrometry}: Thermo Scientific Q-Exactive (MS1
resolution = 70,000; MS2 accumulation time = 300ms; MS2
resolution = 70,000).
\item \strong{Data analysis}: DART-ID + MaxQuant (1.6.2.3).
}
}

\section{Data collection}{


The PSM data were collected from a shared Google Drive folder that
is accessible from the SlavovLab website (see \code{Source} section).
The folder contains the following files of interest:
\itemize{
\item \code{ev_updated_v2.txt}: the MaxQuant/DART-ID output file
\item \verb{annotation_fp60-97.csv}: sample annotation
\item \verb{batch_fp60-97.csv}: batch annotation
}

We combined the sample annotation and the batch annotation in
a single table. We also formatted the quantification table so that
columns match with those of the annotation and filter only for
single-cell runs. Both table are then combined in a single
\link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object using the \code{\link[scp:readSCP]{scp::readSCP()}} function.

The peptide data were taken from the Slavov lab directly
(\code{Peptides-raw.csv}). It is provided as a spreadsheet. The data
were formatted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object and the sample
metadata were matched to the column names (mapping is retrieved
after running the SCoPE2 R script) and stored in the \code{colData}.
The object is then added to the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object (containing the
PSM assays) and the rows of the peptide data are linked to the
rows of the PSM data based on the peptide sequence information
through an \code{AssayLink} object.

The protein data (\code{Proteins-processed.csv}) is formatted similarly
to the peptide data, and the rows of the proteins were mapped onto
the rows of the peptide data based on the protein sequence
information.
}

\examples{
\donttest{
specht2019v3()
}

}
\references{
Specht, Harrison, Edward Emmott, Aleksandra A.
Petelski, R. Gray Huffman, David H. Perlman, Marco Serra, Peter
Kharchenko, Antonius Koller, and Nikolai Slavov. 2021.
"Single-Cell Proteomic and Transcriptomic Analysis of Macrophage
Heterogeneity Using SCoPE2." Genome Biology 22 (1): 50.
(\href{http://dx.doi.org/10.1186/s13059-021-02267-5}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/krull2024.R
\docType{data}
\name{krull2024}
\alias{krull2024}
\title{Krull et al, 2024 (Nature Communications): IFN-\eqn{\gamma} response}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 159 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object.
\itemize{
\item Assay 1-158: DIA-NN main output report table split for each
acquisition run. First 15 run acquires 10 single cells (MEs) and,
remaining 143 run acquires 1 single cell. It contains the results
of the spectrum identification and quantification.
\item \code{proteins}: DIA-NN protein group matrix, containing normalised
quantities for 1553 protein groups in 143 single cells. Proteins
are filtered at (Q.Value <= 0.01), (Lib.Q.Value <= 0.01), and
(Lib.PG.Q.Value <= 0.01).
}

The \code{colData(krull2024())} contains cell type annotations. The description
of the \code{rowData} fields for the different assays can be found in the
\href{https://github.com/vdemichev/DiaNN#readme}{\code{DIA-NN} documentation}.
}
\source{
The data were downloaded from PRIDE
\href{https://www.ebi.ac.uk/pride/archive/projects/PXD053464}{repository}
with accession ID \code{PXD053464}.
}
\usage{
krull2024
}
\description{
They develop a new strategy for data-independent acquisition (DIA) that
leverages the co-analysis of low-input samples alongside a corresponding
enhancer (ME) of higher input. Using DIA-ME, they investigate the
proteomic response of U-2 OS cells to interferon gamma (IFN-\eqn{\gamma}) at
the single-cell level.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: cells were detached with trypsin digestion, followed
by dilution in 1.5 mL PBS, and isolated using BD FACSAria III instrument.
\item \strong{Sample preparation}: Sorted single cells were collected in lysis
buffer (50 mM TEAB, pH 8.5, and 0.025\% DDM), denatured at 70 degrees
Celsius for 30 minutes. Samples were acidified with 0.5\% FA and
transferred to auto sampler plates for mass spectrometry analysis.
\item \strong{Separation}: Peptides were injected in a 2 microliter volume onto
a (25 cm x 75  micrometer) ID column at a flow rate of 300 nL/min,
separated using a gradient of ACN in water with 0.1\% FA over 15 minutes,
connected to a nano-ESI source.
\item \strong{Ionization}: Ionization was performed using a 1,500 V capillary
voltage with 3.0 L/min dry gas and a dry temperature of 180 degrees
Celsius. MS data acquisition was conducted in diaPASEF mode using a
timsTOF Pro mass spectrometer.
\item \strong{Mass spectrometry}: MS1 scans covered a range of 200-1,700 m/z,
while DIA window isolation targeted 475-1,000 m/z with eight DIA scans
per cycle. Fragmentation was triggered by collision energy ranging from
45 eV to 27 eV depending on the ion mobility.
\item \strong{Data analysis}: Data was processed using DIA-NN (v1.8.0) and
Spectronaut 18 in a library-free approach, using deep learning
for spectrum prediction, retention times, and ion mobility.
}
}

\section{Data collection}{


The data were collected from the PRIDE
\href{https://www.ebi.ac.uk/pride/archive/projects/PXD053464}{repository}
in the \verb{03_SingleCell_Searches.zip} file.

We loaded the DIA-NN main report table and generated a sample
annotation table based on the MS file names. We next combined the
sample annotation and the DIANN tables into a \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object
following the \code{scp} data structure. We loaded the proteins group
matrix as a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object, and added the protein data
as a new assay and link the precursors to proteins using the
\code{Protein.Group} variable from the \code{rowData}.
}

\examples{
\donttest{
krull2024()
}

}
\references{
Krull, K. K., Ali, S. A., & Krijgsveld, J. 2024. "Enhanced feature matching
in single-cell proteomics characterizes IFN-\eqn{\gamma} response and co-existence of
Cell States." Nature Communications, 15(1).
\href{https://doi.org/10.1038/s41467-024-52605-x}{Link to article}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/zhu2018MCP.R
\docType{data}
\name{zhu2018MCP}
\alias{zhu2018MCP}
\title{Zhu et al. 2018 (Mol. Cel. Prot.): rat brain laser dissections}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 4 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \code{peptides}: quantitative information for 13,055 peptides from
24 samples
\item \code{proteins_intensity}: protein intensities for 2,257 proteins
from 24 samples
\item \code{proteins_LFQ}: LFQ intensities for 2,257 proteins from 24 samples
\item \code{proteins_iBAQ}: iBAQ values for 2,257 proteins from 24 samples
}

Sample annotation is stored in \code{colData(zhu2018MCP())}.
}
\source{
The PSM data can be downloaded from the PRIDE repository
PXD008844. FTP link
ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/07/PXD008844
}
\usage{
zhu2018MCP
}
\description{
Near single-cell proteomics data of laser captured
micro-dissection samples. The samples are 24 brain sections from
rat pups (day 17). The slices are 12 um thick squares of either
50, 100, or 200 um width. 5 samples were dissected from the corpus
callum (\code{CC}), 4 samples were dissected from the corpus collosum
(\code{CP}), 13 samples were extracted from the cerebral cortex
(\code{CTX}), and 2 samples are labeled as (\code{Mix}).
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the original article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: brain patches were collected using
laser-capture microdissection (PALM MicroBeam) on flash frozen
rat (\emph{Rattus norvergicus}) brain tissues. Note that the samples
were stained with H&E before dissection for histological
analysis. DMSO is used as sample collection solution
\item \strong{Sample preparation} performed using the nanoPOTs device: DMSO
evaporation + protein extraction (DMM + DTT) + alkylation (IAA)
\itemize{
\item Lys-C digestion + trypsin digestion.
}
\item \strong{Separation}: nanoLC (Dionex UltiMate with an in-house packed
60cm x 30um LC columns; 50nL/min)
\item \strong{Ionization}: ESI (2,000V)
\item \strong{Mass spectrometry}: Thermo Fisher Orbitrap Fusion Lumos
Tribrid (MS1 accumulation time = 246ms; MS1 resolution =
120,000; MS1 AGC = 3E6). The MS/MS settings  depend on the
sample size, excepted for the AGC = 1E5. 50um (time = 502ms;
resolution = 240,000), 100um (time = 246ms; resolution =
120,000), 200um (time = 118ms; resolution = 60,000).
\item \strong{Data analysis}: MaxQuant (v1.5.3.30) + Perseus (v1.5.6.0) +
Origin Pro 2017
}
}

\section{Data collection}{


The data were collected from the PRIDE repository (accession
ID: PXD008844).  We downloaded the \code{MaxQuant_Peptides.txt}
and the \code{MaxQuant_ProteinGroups.txt} files containing the
combined identification and quantification
results. The sample annotations were inferred from the names of
columns holding the quantification data and the information in the
article. The peptides data were converted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment}
object. We split the protein table to separate the three types of
quantification: protein intensity, label-free quantitification
(LFQ) and intensity based absolute quantification (iBAQ). Each
table is converted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object along with
the remaining protein annotations. The 4 objects are combined in
a single \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object and feature links are created based on
the peptide leading razor protein ID and the protein ID.
}

\examples{
\donttest{
zhu2018MCP()
}

}
\references{
Zhu, Ying, Maowei Dou, Paul D. Piehowski, Yiran Liang, Fangjun
Wang, Rosalie K. Chu, William B. Chrisler, et al. 2018. “Spatially
Resolved Proteome Mapping of Laser Capture Microdissected Tissue
with Automated Sample Transfer to Nanodroplets.” Molecular &
Cellular Proteomics: MCP 17 (9): 1864–74
(\href{http://dx.doi.org/10.1074/mcp.TIR118.000686}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/zhu2019EL.R
\docType{data}
\name{zhu2019EL}
\alias{zhu2019EL}
\title{Zhu et al. 2019 (eLife): chicken utricle cells}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 62 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \code{XYZw}: 60 assays containing PSM data. The sample are annotated
as follows. \code{X} indicates the experiment, either 1 or 2. \code{Y}
indicated the FM1-43 signal, either high (H) or low (L). \code{Z}
indicates the number of cells (0, 1, 3, 5 or 20). \code{w} indicates
the replicate, starting from \code{a}, it can go up to \code{j}.
\item \code{peptides}: quantitative data for 3444 peptides in 60 samples
(all runs are combined).
\item \code{proteins_intensity}: protein intensities for 840 proteins
from 24 samples
\item \code{proteins_iBAQ}: iBAQ values for 840 proteins from 24 samples
}

Sample annotation is stored in \code{colData(zhu2019EL())}.
}
\source{
The PSM data can be downloaded from the PRIDE repository
PXD014256. The source link is:
ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2019/11/PXD014256
}
\usage{
zhu2019EL
}
\description{
Single-cell proteomics data from chicken utricle acquired to
study the hair-cell development. The cells are isolated from
peeled utrical epithelium and separated into hair cells (FM1-43
high) and supporting cells (FM1-43 low). The sample contain either
1 cell (n = 28), 3 cells (n = 7), 5 cells (n = 8) or 20 cells (n =
14).
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: The cells were taken from the utricles of
E15 chick embryos. Samples were stained with FM1-43FX and the
cells were dissociated using enzymatic digestion. Cells were
FACS sorted (BD Influx) and split based on their FM1-43 signal,
while ensuring no debris, doublets or dead cells are retained.
\item \strong{Sample preparation} performed using the nanoPOTs device. Cell
lysis and protein extraction and reduction are performed using
dodecyl beta-D-maltoside + DTT + ammonium bicarbonate. Protein
were then alkylated using IAA. Protein digestion is performed
using Lys-C and trypsin. Finally samples acidification is
performed using formic acid.
\item \strong{Separation}: Dionex UltiMate pump with an C18-Packed column
(50cm x 30um; 60nL/min)
\item \strong{Ionization}: ESI (2,000V)
\item \strong{Mass spectrometry}: Orbitrap Fusion Lumos Tribrid. MS1
settings: accumulation time = 246ms; resolution = 120,000; AGC =
3E6. MS/MS settings: accumulation time = 502ms; resolution =
120,000; AGC = 2E5.
\item \strong{Data analysis}: Andromeda & MaxQuant (v1.5.3.30) and the
search database is NCBI GRCg6a.
}
}

\section{Data collection}{


All data were collected from the PRIDE repository (accession ID:
PXD014256).

The sample annotation information is provided in the
\code{Zhu_2019_chick_single_cell_samples_CORRECTED.xlsx} file. This file
was given during a personal discussion and is a corrected version
of the annotation table available on the PRIDE repository.

The PSM data were found in the \code{evidence.txt} (in the
\verb{Experiment 1+ 2}) folder. The PSM data were filtered so that it
contains only samples that are annotated. The data were then
converted to a \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object using the \code{\link[scp:readSCP]{scp::readSCP()}}
function.

The peptide data were found in the \code{peptides.txt} file. The column
names holding the quantitative data were adapted to match the
sample names in the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object. The data were then
converted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object and then inserted in
the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object. Links between the PSMs and the peptides
were added

A similar procedure was applied to the protein data. The data were
found in the \code{proteinGroups.txt} file. We split the protein table
to separate the two types of quantification: summed intensity and
intensity based absolute quantification (iBAQ). Both tables are
converted to \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} objects and are added to the
\link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object as well as the \code{AssayLink} between peptides and
proteins.
}

\examples{
\donttest{
zhu2019EL()
}

}
\references{
Zhu, Ying, Mirko Scheibinger, Daniel Christian Ellwanger, Jocelyn
F. Krey, Dongseok Choi, Ryan T. Kelly, Stefan Heller, and Peter G.
Barr-Gillespie. 2019. “Single-Cell Proteomics Reveals Changes in
Expression during Hair-Cell Development.” eLife 8 (November).
(\href{https://doi.org/10.7554/eLife.50777}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dou2019_lysates.R
\docType{data}
\name{dou2019_lysates}
\alias{dou2019_lysates}
\title{Dou et al. 2019 (Anal. Chem.): HeLa lysates}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 3 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \code{Hela_run_1}: PSM data with 10 columns corresponding to the
TMT-10plex channels. Columns hold quantitative information for
HeLa lysate samples (either 0, 0.2 or 10ng). This is the data
for run 1.
\item \code{Hela_run_1}: PSM data with 10 columns corresponding to the
TMT-10plex channels. Columns hold quantitative information for
HeLa lysate samples (either 0, 0.2 or 10ng). This is the data
for run 2.
\item \code{peptides}: peptide data containing quantitative data for 13,934
peptides in 20 samples (run 1 and run 2 combined).
\item \code{proteins}: protein data containing quantitative data for 1641
proteins in 20 samples (run 1 and run 2 combined).
}

Sample annotation is stored in \code{colData(dou2019_lysates())}.
}
\source{
The PSM data can be downloaded from the massIVE repository
MSV000084110. FTP link: ftp://massive.ucsd.edu/MSV000084110/

The protein data can be downloaded from the
\href{https://pubs.acs.org/doi/10.1021/acs.analchem.9b03349}{ACS Publications}
website (Supporting information section).
}
\usage{
dou2019_lysates
}
\description{
Single-cell proteomics using nanoPOTS combined with TMT
multiplexing. It contains quantitative information at PSM and
protein level. The samples are commercial Hela lysates diluted to
single-cell amounts (0.2 ng). The boosting wells contain the same
digest but at higher amount (10 ng).
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: commercially available HeLa protein digest
(Thermo Scientific).
\item \strong{Sample preparation} performed using the nanoPOTs device.
Protein extraction (DMM + TCEAP) + alkylation (IAA) + Lys-C
digestion + trypsin digestion + TMT-10plex labeling and pooling.
\item \strong{Separation}: nanoLC (Dionex UltiMate with an in-house packed
50cm x 30um LC columns; 50nL/min)
\item \strong{Ionization}: ESI (2,000V)
\item \strong{Mass spectrometry}: Thermo Fisher Orbitrap Fusion Lumos
Tribrid (MS1 accumulation time = 50ms; MS1 resolution = 120,000;
MS1 AGC = 1E6; MS2 accumulation time = 246ms; MS2 resolution =
60,000; MS2 AGC = 1E5)
\item \strong{Data analysis}: MS-GF+ + MASIC (v3.0.7111) + RomicsProcessor
(custom R package)
}
}

\section{Data collection}{


The PSM data were collected from the MassIVE repository
MSV000084110 (see \code{Source} section). The downloaded files are:
\itemize{
\item \verb{Hela_run_*_msgfplus.mzid}: the MS-GF+ identification result
files
\item \verb{Hela_run_*_ReporterIons.txt}: the MASIC quantification result
files
}

For each batch, the quantification and identification data were
combined based on the scan number (common to both data sets). The
combined datasets for the different runs were then concatenated
feature-wise. To avoid data duplication due to ambiguous matching
of spectra to peptides or ambiguous mapping of peptides to proteins,
we combined ambiguous peptides to peptides groups and proteins to
protein groups. Feature annotations that are not common within a
peptide or protein group are are separated by a \verb{;}. The sample
annotation table was manually created based on the available
information provided in the article. The data were then converted
to a \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object using the \code{\link[scp:readSCP]{scp::readSCP()}} function.

We generated the peptide data. First, we removed PSM matched to
contaminants or decoy peptides and ensured a 1\% FDR. We aggregated
the PSM to peptides based on the peptide (or peptide group)
sequence(s) using the median PSM instenity. The peptide data for
the different runs were then joined in a single assay (see
\link[QFeatures:joinAssays]{QFeatures::joinAssays}), again based on the peptide sequence(s).
We then removed the peptide groups. Links between the peptide and
the PSM data were created using \link[QFeatures:AssayLinks]{QFeatures::addAssayLink}. Note
that links between PSM and peptide groups are not stored.

The protein data were downloaded from \verb{Supporting information}
section from the publisher's website (see \code{Sources}). The data is
supplied as an Excel file \code{ac9b03349_si_003.xlsx}. The file
contains 7 sheets from which we only took the sheet 6 (named
\verb{5 - Run 1 and 2 raw data}) with the combined protein data for the
two runs. We converted the data to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment}
object and added the object as a new assay in the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures}
dataset (containing the PSM data). Links between the proteins and
the peptides were created. Note that links to protein groups are
not stored.
}

\examples{
\donttest{
dou2019_lysates()
}

}
\references{
Dou, Maowei, Geremy Clair, Chia-Feng Tsai, Kerui Xu, William B.
Chrisler, Ryan L. Sontag, Rui Zhao, et al. 2019. “High-Throughput
Single Cell Proteomics Enabled by Multiplex Isobaric Labeling in a
Nanodroplet Sample Preparation Platform.” Analytical Chemistry,
September
(\href{https://doi.org/10.1021/acs.analchem.9b03349}{link to article}).
}
\seealso{
\link{dou2019_mouse}, \link{dou2019_boosting}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scpdata.R
\name{scpdata}
\alias{scpdata}
\alias{scpdata-package}
\title{Single-Cell Proteomics Data Package}
\usage{
scpdata()
}
\value{
A \code{DataFrame} table containing a summary of the available
datasets.
}
\description{
The \code{scpdata} package distributes mass spectrometry-based
single-cell proteomics datasets. The datasets were collected from
published work and formatted to a standardized data framework.
The \code{scp} frameworks stores the expression data for different MS
levels (identified spectrum, peptide, or protein) in separate
assays. Each assay is an object of class \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment}
that allows easy integration with state-of-the-art single-cell
analysis tools. All assays are contained in a single object of
class \link[QFeatures:QFeatures-class]{QFeatures::QFeatures}. An overview of the data structure is shown
provided in the \code{scp} package.

The \code{scpdata()} function returns a summary table with all
currently available datasets in the package. More information
about the data content and the data collection can be found in the
corresponding manual pages.
}
\examples{
## List available datasets and their metadata 
scpdata()

## Load data using the ExperimentHub interface
hub <- ExperimentHub()

\dontrun{
## Download the data set of interest using ExperimentHub indexing
hub[["EH7711"]]
## Download the same data set using the build-in function
leduc2022()
}

}
\seealso{
More information about the data manipulation can be found
in the \code{scp} package.
}
\author{
Christophe Vanderaa
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/williams2020_lfq.R
\docType{data}
\name{williams2020_lfq}
\alias{williams2020_lfq}
\title{Williams et al. 2020 (Anal. Chem.): MCF10A cell line}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 9 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \verb{peptides_[30 or 60]min_[intensity or LFQ]}: 3 assays
containing peptide intensities or LFQ normalized
quantifications (see \code{References}) for either a 30min or a 60 min
gradient.
\item \verb{proteins_[30 or 60]min_[intensity or iBAQ or LFQ]}: 6 assays
containing protein intensities, iBAQ normalized or LFQ normalized
quantifications (see \code{References}) for either a 30min or a 60 min
gradient.
}

Sample annotation is stored in \code{colData(williams2020_lfq())}.
}
\source{
The PSM and protein data can be downloaded from the MASSIVE
repository MSV000085230.
}
\usage{
williams2020_lfq
}
\description{
Single-cell label free proteomics data from a MCF10A cell line
culture. The data were acquired using a label-free quantification
protocole based on the nanoPOTS technology. The objective was to
test 2 elution gradients for single-cell applications and to
demonstrate successful use of the new nanoPOTS autosampler
presented in the article. The samples contain either no cells,
single cells, 3 cells, 10 cells  50 cells.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Sample isolation}: cultured MCF10A cells were isolated using
flow-cytometry based cell sorting and deposit on nanoPOTS
microwells
\item \strong{Sample preparation}: cells are lysed using using a DDM+DTT
lysis buffer. Alkylation was then performed using an IAA solution.
Proteins are digested with Lys-C and trypsin followed by
acidification with FA. Sample droplets are then dried until
LC-MS/MS analysis.
\item \strong{Liquid chromatography}: peptides are loaded using the new
autosampler described in the paper. Samples are loaded using a
a homemade miniature syringe pump. The samples are then desalted
and concentrated through a SPE column (4cm x 100µm i.d. packed
with 5µm C18) with microflow LC pump. The peptides are then eluted
from a long LC column (60cm x 50 µm i.d. packed with 3µm C18)
coupled to a nanoflox LC pump at 150nL/mL with either a 30 min
or a 60 min gradient.
\item \strong{Mass spectrometry}: MS/MS was performed on an Orbitrap Fusion
Lumos Tribrid MS coupled to a 2kV ESI. MS1 setup: Orbitrap
analyzer at resolution 120.000, AGC target of 1E6, accumulation
of 246ms. MS2 setup: ion trap with CID at resolution 60.000, AGC
target of 2E4, accumulation of 120ms (50 cells) or 250ms (0-10
cells).
\item \strong{Raw data processing}: preprocessing using Maxquant v1.6.2.10
that use Andromeda search engine (with UniProtKB 2016-21-29),
MBR and LFQ normalization were enabled.
}
}

\section{Data collection}{


All data were collected from the MASSIVE repository (accession ID:
MSV000085230).

The peptide and protein data were extracted from the \verb{Peptides_[...].txt}
or \verb{ProteinGroups[...].txt} files, respectively, in the
\verb{MCF10A_LC_[30 or 60]minutes} folders.

The tables were duplicated so that peptide intensisities, peptide
LFQ, protein intensities, protein LFQ and protein intensities are
contained in separate tables. Tables are then converted to
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} objects. Sample annotations were infered
from the sample names and from the paper. All data is combined in
a \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object. \link[QFeatures:AssayLinks]{QFeatures::AssayLinks} were stored between peptide
assays and their corresponding proteins assays based on the
leading razor protein (hence only unique peptides are linked to
proteins).

The script to reproduce the \code{QFeatures} object is available at
\code{system.file("scripts", "make-data_williams2020_lfq.R", package = "scpdata")}
}

\section{Suggestion}{


See \code{QFeatures::joinAssays} if you want to join the 30min and
60min assays in a single assay for an integrated analysis.
}

\examples{
\donttest{
williams2020_lfq()
}

}
\references{
\strong{Source article}: Williams, Sarah M., Andrey V. Liyu, Chia-Feng
Tsai, Ronald J. Moore, Daniel J. Orton, William B. Chrisler,
Matthew J. Gaffrey, et al. 2020. “Automated Coupling of
Nanodroplet Sample Preparation with Liquid Chromatography-Mass
Spectrometry for High-Throughput Single-Cell Proteomics.”
Analytical Chemistry 92 (15): 10588–96.
(\href{http://dx.doi.org/10.1021/acs.analchem.0c01551}{link to article}).

\strong{LFQ normalization}: Cox, Jürgen, Marco Y. Hein, Christian A. Luber,
Igor Paron, Nagarjuna Nagaraj, and Matthias Mann. 2014. “Accurate
Proteome-Wide Label-Free Quantification by Delayed Normalization
and Maximal Peptide Ratio Extraction, Termed MaxLFQ.” Molecular
& Cellular Proteomics: MCP 13 (9): 2513–26.
(\href{http://dx.doi.org/10.1074/mcp.M113.031591}{link to article}).

\strong{iBAQ normalization}: Schwanhäusser, Björn, Dorothea Busse, Na
Li, Gunnar Dittmar, Johannes Schuchhardt, Jana Wolf, Wei Chen, and
Matthias Selbach. 2011. “Global Quantification of Mammalian Gene
Expression Control.” Nature 473 (7347): 337–42.
(\href{http://dx.doi.org/10.1038/nature10098}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/wu2026.R
\docType{data}
\name{wu2026}
\alias{wu2026}
\title{Wu et al., 2026 (Nature Biotechnology): single-cell proteomic landscape
of the developing human brain}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 2313 sets, each set being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item Set 1-2310: log-transformed precursor-level single-cell data (one
column per set) from DIA-NN reports.
\item \code{peptides}: peptide-level data containing quantitative data for 17755
peptides in 2310 single cells.
\item \code{imported_proteins}: protein-level table imported from the authors'
protein report, containing 4401 proteins in 2310 single cells.
\item \code{proteins}: protein-level data containing quantitative data for 5107
proteins in 2310 single cells.
}

Sample annotation is stored in \code{colData(wu2026())}.
}
\source{
The data were downloaded from the PRIDE repository with accession ID
\code{PXD071075}:
https://www.ebi.ac.uk/pride/archive/projects/PXD071075
}
\usage{
wu2026
}
\description{
Label-free single-cell proteomics data from prenatal human brain tissue
(gestational weeks 13, 15 and 19), generated to characterize cell-type
proteomes and developmental trajectories at single-cell resolution.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Sample isolation}: fresh prenatal human brain tissue was dissociated
and single cells were sorted by FACS (Sony SH800) into 384-well low-bind
plates.
\item \strong{Sample preparation}: cells were lysed in low-volume TEAB-based buffer,
digested overnight with trypsin, acidified with trifluoroacetic acid,
and desalted on EvoTip Pure.
\item \strong{Liquid chromatography}: peptides were separated on an IonOpticks Aurora
Elite XT C18 nano-LC column (15 cm x 75 micrometer) on an Evosep One
using a 31-minute gradient.
\item \strong{Mass spectrometry}: Orbitrap Eclipse Tribrid with FAIMS Pro was used
in DIA mode.
\item \strong{Raw data processing}: DIA-NN against the UniProt human reference
proteome.
}
}

\section{Data collection}{


The \code{QFeatures} object was built from the DIA-NN peptide and protein report
tables and a sample annotation table. PSM-level data were imported with
\code{\link[scp:readSCP]{scp::readSCP()}}, log-transformed, aggregated to peptide-level features, and
joined across single-cell runs. The protein report table was imported as a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment}, added as an set, and linked to peptide-level data.

The script to reproduce the \code{QFeatures} object is available at
\code{inst/scripts/make-data_wu2026.R}.
}

\examples{
\donttest{
wu2026()
}

}
\references{
Wu, T., Jiang, L., Mukhtar, T., Wang, L., Jian, R., Wang, C., Trinh, T.,
Kriegstein, A. R., Snyder, M., and Li, J. 2026. "Single-cell proteomic
landscape of the developing human brain." Nature Biotechnology.
\href{https://doi.org/10.1038/s41587-025-02980-7}{Link to article}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/liang2020_hela.R
\docType{data}
\name{liang2020_hela}
\alias{liang2020_hela}
\title{Liang et al. 2020 (Anal. Chem.): HeLa cells (MaxQuant preprocessing)}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 17 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \verb{HeLa_*}: 15 assays containing PSM data.
\item \code{peptides}: quantitative data for 48705 peptides in 15 samples
(all runs are combined).
\item \code{proteins}: quantitative data for 3970 protein groups in 15
samples (all runs combined).
}

Sample annotation is stored in \code{colData(liang2020_hela())}.
}
\source{
The PSM data can be downloaded from the PRIDE repository
PXD021882 The source link is:
http://ftp.pride.ebi.ac.uk/pride/data/archive/2020/12/PXD021882/
}
\usage{
liang2020_hela
}
\description{
Single-cell proteomics data from HeLa cells using the autoPOTS
acquisition workflow. The samples contain either no cells (blanks),
1 cell, 10 cells, 150 cells or 500 cells. Samples containing
between 0 and 10 cells are isolated using micro-pipetting while
samples containing between 150 and 500 cells were prepared using
dilution of a bulk sample.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: The HeLa cells come from a commercially
available cell line. Samples containing between 0 and 10 cells
were isolated using micro-manipulation and the counts were
validated using a microscope. Samples containing between 150 and
500 cells were prepared by diluting a bulk sample and the exact
counts were evaluated by obtaining phtotmicrographs.
\item \strong{Sample preparation} performed using the autoPOTS worflow that
relied on the OT-2 pipeting robot. Cell are lysed using
sonication. Samples are then processed by successive incubation
with DTT (reduction), then IAA (alkylation), then Lys-C and
trypsin (protein digestion).
\item \strong{Separation}: Samples were injected on the column using a
modified Ultimate WPS-3000 TPL autosampler coupled to an UltiMate
3000 RSLCnano pump. The LC column is a home-packed nanoLC column
(45cm x 30um; 40nL/min)
\item \strong{Ionization}: Nanospray Flex ion source (2,000V)
\item \strong{Mass spectrometry}: Orbitrap Exploris 480. MS1 settings:
accumulation time = 250 ms (0-10 cells) or 100 ms (150-500 cells);
resolution = 120,000; AGC = 100\\%. MS2 settings: exlusion
duration = 90 s (0-10 cells) or 60 s (150-500 cells) ; accumulation
time = 500 ms (0-1 cell), 250 ms (10 cells), 100 ms (150 cells)
or 50 ms (500 cells); resolution = 60,000 (0-10 cells) or 30,000
(150-500 cells); AGC = 5E3 (0-1 cells) or 1E4 (10-500 cells).
\item \strong{Data analysis}: MaxQuant (v1.6.7.0) and the search database
is Swiss-Prot (July 2020).
}
}

\section{Data collection}{


All data were collected from the PRIDE repository (accession ID:
PXD021882).

The sample annotations were collected from the methods section and
from table S3 in the paper.

The PSM data were found in the \code{evidence.txt} file. The data were
converted to a \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object using the \code{\link[scp:readSCP]{scp::readSCP()}}
function.

The peptide data were found in the \code{peptides.txt} file. The column
names holding the quantitative data were adapted to match the
sample names in the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object. The data were then
converted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object and then inserted in
the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object. Links between the PSMs and the peptides
were added

A similar procedure was applied to the protein data. The data were
found in the \code{proteinGroups.txt} file. The column names were
adapted, the data were converted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment}
object and then inserted in the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object. Links between
the peptides and the proteins were added
}

\examples{
\donttest{
liang2020_hela()
}

}
\references{
Liang, Yiran, Hayden Acor, Michaela A. McCown, Andikan J. Nwosu,
Hannah Boekweg, Nathaniel B. Axtell, Thy Truong, Yongzheng Cong,
Samuel H. Payne, and Ryan T. Kelly. 2020. “Fully Automated Sample
Processing and Analysis Workflow for Low-Input Proteome
Profiling.” Analytical Chemistry, December.
(\href{https://doi.org/10.1021/acs.analchem.0c04240}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/zhu2018NC_hela.R
\docType{data}
\name{zhu2018NC_hela}
\alias{zhu2018NC_hela}
\title{Zhu et al. 2018 (Nat. Comm.): HeLa titration}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 4 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \code{peptides}: quantitative information for 37,795 peptides from
21 samples
\item \code{proteins_intensity}: protein intensities for 3,984 proteins
from 21 samples
\item \code{proteins_LFQ}: LFQ intensities for 3,984 proteins from 21
samples
\item \code{proteins_iBAQ}: iBAQ values for 3,984 proteins from 21 samples
}

Sample annotation is stored in \code{colData(zhu2018NC_hela())}.
}
\source{
The PSM data can be downloaded from the PRIDE repository
PXD006847. FTP link:
ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/01/PXD006847
}
\usage{
zhu2018NC_hela
}
\description{
Near single-cell proteomics data of HeLa samples containing
different number of cells. There are three groups of cell
concentrations: low (10-14 cells), medium (35-45 cells) and high
(137-141 cells). The data also contain measures for blanks, HeLa
lysates (50 cell equivalent) and 2 cancer cell line lysates (MCF7
and THP1, 50 cell equivalent).
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the original article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: HeLa cell concentration was adjusted by
serial dilution and cell counting was performed manually using
an inverted microscope.
\item \strong{Sample preparation} performed using the nanoPOTs device.
Protein extraction using RapiGest (+ DTT) + alkylation (IAA) +
Lys-C digestion + cleave RapiGest (formic acid).
\item \strong{Separation}: nanoACQUITY UPLC pump (60nL/min) with an
Self-Pack PicoFrit 70cm x 30um LC columns.
\item \strong{Ionization}: ESI (1,900V).
\item \strong{Mass spectrometry}: Thermo Fisher Orbitrap Fusion Lumos
Tribrid. MS1 settings: accumulation time = 246ms; resolution =
120,000; AGC = 1E6. MS/MS settings, depend on the sample size,
excepted for the AGC = 1E5. Blank and approx. 10 cells (time = 502ms;
resolution = 240,000), approx. 40 cells (time = 246ms; resolution =
120,000), approx. 140 cells (time = 118ms; resolution = 60,000).
\item \strong{Data analysis}: MaxQuant (v1.5.3.30) + Perseus + OriginLab
2017
}
}

\section{Data collection}{


The data were collected from the PRIDE repository (accession
ID: PXD006847).  We downloaded the \code{CulturedCells_peptides.txt}
and the \code{CulturedCells_proteinGroups.txt} files containing the
combined identification and quantification
results. The sample annotations were inferred from the names of
columns holding the quantification data and the information in the
article. The peptides data were converted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment}
object. We split the protein table to separate the three types of
quantification: protein intensity, label-free quantitification
(LFQ) and intensity based absolute quantification (iBAQ). Each
table is converted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object along with
the remaining protein annotations. The 4 objects are combined in
a single \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object and feature links are created based on
the peptide leading razor protein ID and the protein ID.
}

\examples{
\donttest{
zhu2018NC_hela()
}

}
\references{
Zhu, Ying, Paul D. Piehowski, Rui Zhao, Jing Chen, Yufeng Shen,
Ronald J. Moore, Anil K. Shukla, et al. 2018. “Nanodroplet
Processing Platform for Deep and Quantitative Proteome Profiling
of 10-100 Mammalian Cells.” Nature Communications 9 (1): 882
(\href{http://dx.doi.org/10.1038/s41467-018-03367-w}{link to article}).
}
\seealso{
The same experiment was conducted on HeLa lysates:
\link{zhu2018NC_lysates}.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gregoire2023_mixCTRL.R
\docType{data}
\name{gregoire2023_mixCTRL}
\alias{gregoire2023_mixCTRL}
\title{Grégoire et al. 2023 - mixCTRL (arXiv): benchmark using
monocytes/macrophages}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 119 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item Assays 1-42: PSM data acquired with a TMT-16plex protocol, hence
those assays contain 16 columns. Columns hold quantitative
information from single-cell channels, carrier channels,
blank (negative control) channels and unused channels.
\item Assays 43-84: peptide data resulting from the PSM to peptide
aggregation of the 42 PSM assays.
\item Assays 85-91: peptide data for each of the 7 acquisition
batches. Peptide data were joined based on their respective
acquisition batches.
\item Assays 92-98: normalised peptide data.
\item Assays 99-105: normalised and log-transformed peptide data.
\item Assays 106-112: protein data for each of the 7 acquisition
batches. Normalised and log-transformed peptide data were
agreggated to protein.
\item Assays 113-119: Batch corrected protein data. Normalised and
log-transformed protein data were batch corrected to remove
technical variability induced by runs and channels.
}

All the data has been filtered to keep high quality features and
samples.

The \code{colData(gregoire2023_mixCTRL())} contains cell type annotation and
batch annotation that are common to all assays. The description of
the \code{rowData} fields for the PSM data can be found in the
\href{https://sage-docs.vercel.app/docs/results/search}{\code{sage} documentation}.
}
\source{
The data were downloaded from the \href{https://zenodo.org/records/8417228}{Zenodo repository}.  The raw data and
the quantification data can also be found in the ProteomeXchange
Consortium via the \href{https://www.ebi.ac.uk/pride/archive/projects/PXD046211}{PRIDE partner repository},
project \code{PXD046211}.
}
\usage{
gregoire2023_mixCTRL
}
\description{
Single cell proteomics data acquired using the SCoPE2 protocol.
The dataset contains two monocytes cell lines (THP1 and U937) as
well as controled mixtures of both and macrophage-like cells
produced upon PMA treatment. It contains quantitative information
at PSM, peptide and protein levels. Data was acquired using Lumos
Orbitrap (mainly) and timsTOF SCP mass spectrometers.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \emph{References}).
\itemize{
\item \strong{Cell isolation}: BD FACSAria III cell sorting.
\item \strong{Sample preparation} performed using the SCoPE2 protocol: mPOP
cell lysis + trypsin digestion + TMT-16plex labeling and
pooling.
\item \strong{Separation}: online nLC (Ultimate 3000 LC System or Vanquish
Neo UHPLC System) with a BioZen Peptide Polar C18 250 x 0.0075mm
column.
\item \strong{Mass spectrometry}:  Orbitrap Fusion Lumos Tribrid (MS1
resolution = 70,000; MS2 accumulation time = 120ms; MS2
resolution = 70,000) and timsTOF SCP.
\item \strong{Data preprocessing}: Sage.
}
}

\section{Data collection}{


The PSM data were collected from a Zenodo archive (see \code{Source}
section). The folder contains the following files of interest:
\itemize{
\item \code{results.sage.cbio.tsv}: the sage identification output file for
batches acquired on the Lumos MS.
\item \code{results.sage.giga.tsv}: the sage identification output file for
batches acquired on the timsTOF SCP MS.
\item \code{quant.cbio.tsv}: the sage quantification output file for
batches acquired on the Lumos MS.
\item \code{quant.giga.tsv}: the sage quantification output file for
batches acquired on the timsTOF SCP MS.
\item \code{sampleAnnotation_batch.csv}: sample annotation for each
acquisition batch. There are in total 8 different annotation
files.
}

We combined the sample annotations in a single table. We also
combined \code{cbio} and \code{giga} tables together and merged resulting
identification and quantification tables. Both annotation and
features tables are then combined in a single \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object
using the \code{\link[scp:readSCP]{scp::readSCP()}} function.

The \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object was processed as described in the author's
manuscript (see \code{source}). Note that the imputed assays were used
in the paper for illustrative purposes only and have not been
reproduced here.
}

\examples{
\donttest{
gregoire2023_mixCTRL()
}

}
\references{
Samuel Grégoire, Christophe Vanderaa, Sébastien Pyr dit Ruys,
Gabriel Mazzucchelli, Christopher Kune, Didier Vertommen and
Laurent Gatto. 2023. \emph{Standardised workflow for mass spectrometry-
based single-cell proteomics data processing and analysis using
the scp package.}
arXiv. DOI:\href{https://doi.org/10.48550/arXiv.2310.13598}{10.48550/arXiv.2310.13598}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dou2019_boosting.R
\docType{data}
\name{dou2019_boosting}
\alias{dou2019_boosting}
\title{Dou et al. 2019 (Anal. Chem.): testing boosting ratios}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 7 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \code{Boosting_X_run_Y}: PSM data with 10 columns corresponding to
the TMT-10plex channels. The \code{X} indicates the boosting amount
(0ng, 5ng or 50ng) and \code{Y} indicates the run number (1 or 2).
\item \code{peptides}: peptide data containing quantitative data for 13,462
peptides in 60 samples (run 1 and run 2 combined).
\item \code{proteins}: protein data containing quantitative data for 1436
proteins and 60 samples (all runs combined).
}

Sample annotation is stored in \code{colData(dou2019_boosting())}.
}
\source{
The PSM data can be downloaded from the massIVE repository
MSV000084110. FTP link: ftp://massive.ucsd.edu/MSV000084110/

The protein data can be downloaded from the
\href{https://pubs.acs.org/doi/10.1021/acs.analchem.9b03349}{ACS Publications}
website (Supporting information section).
}
\usage{
dou2019_boosting
}
\description{
Single-cell proteomics using nanoPOTS combined with TMT isobaric
labeling. It contains quantitative information at PSM and protein
level. The cell types are either "Raw" (macrophage cells), "C10"
(epihelial cells), or "SVEC" (endothelial cells). Each cell is
replicated 2 or 3 times. Each cell type was run using 3 levels of
boosting: 0 ng (no boosting), 5 ng or 50 ng. When boosting was
applied, 1 reference well and 1 boosting well were added,
otherwise 1 empty well was added. Each boosting setting (0ng, 5ng,
50ng) was run in duplicate.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: single-cells from the three murine cell
lines were isolated using FACS (BD Influx II cell sorter ).
Boosting sample were prepared (presumably in bulk) from 1:1:1
mix of the three cell lines.
\item \strong{Sample preparation} performed using the nanoPOTs device.
Protein extraction (DMM + TCEAP) + alkylation (IAA) + Lys-C
digestion + trypsin digestion + TMT-10plex labeling and pooling.
\item \strong{Separation}: nanoLC (Dionex UltiMate with an in-house packed
50cm x 30um LC columns; 50nL/min)
\item \strong{Ionization}: ESI (2,000V)
\item \strong{Mass spectrometry}: Thermo Fisher Orbitrap Fusion Lumos
Tribrid (MS1 accumulation time = 50ms; MS1 resolution = 120,000;
MS1 AGC = 1E6; MS2 accumulation time = 246ms; MS2 resolution =
60,000; MS2 AGC = 1E5)
\item \strong{Data analysis}: MS-GF+ + MASIC (v3.0.7111) + RomicsProcessor
(custom R package)
}
}

\section{Data collection}{


The PSM data were collected from the MassIVE repository
MSV000084110 (see \code{Source} section). The downloaded files are:
\itemize{
\item \verb{Boosting_*ng_run_*_msgfplus.mzid}: the MS-GF+ identification
result files.
\item \verb{Boosting_*ng_run_*_ReporterIons.txt}: the MASIC quantification
result files.
}

For each batch, the quantification and identification data were
combined based on the scan number (common to both data sets). The
combined datasets for the different runs were then concatenated
feature-wise. To avoid data duplication due to ambiguous matching
of spectra to peptides or ambiguous mapping of peptides to proteins,
we combined ambiguous peptides to peptides groups and proteins to
protein groups. Feature annotations that are not common within a
peptide or protein group are are separated by a \verb{;}. The sample
annotation table was manually created based on the available
information provided in the article. The data were then converted
to a \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object using the \code{\link[scp:readSCP]{scp::readSCP()}} function.

We generated the peptide data. First, we removed PSM matched to
contaminants or decoy peptides and ensured a 1\% FDR. We aggregated
the PSM to peptides based on the peptide (or peptide group)
sequence(s) using the median PSM instenity. The peptide data for
the different runs were then joined in a single assay (see
\link[QFeatures:joinAssays]{QFeatures::joinAssays}), again based on the peptide sequence(s).
We then removed the peptide groups. Links between the peptide and
the PSM data were created using \link[QFeatures:AssayLinks]{QFeatures::addAssayLink}. Note
that links between PSM and peptide groups are not stored.

The protein data were downloaded from \verb{Supporting information}
section from the publisher's website (see \code{Sources}). The data is
supplied as an Excel file \code{ac9b03349_si_004.xlsx}. The file
contains 7 sheets from which we took the 2nd, 4th and 6th sheets
(named \verb{01 - No Boost raw data}, \verb{03 - 5ng boost raw data},
\verb{05 - 50ng boost raw data}, respectively). The sheets contain the
combined protein data for the duplicate runs given the boosting
amount. We joined the data for all boosting ration based on the
protein name and converted the data to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment}
object. We then added the object as a new assay in the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures}
dataset (containing the PSM data). Links between the proteins and
the corresponding PSM were created. Note that links to protein
groups are not stored.
}

\examples{
\donttest{
dou2019_boosting()
}

}
\references{
Dou, Maowei, Geremy Clair, Chia-Feng Tsai, Kerui Xu, William B.
Chrisler, Ryan L. Sontag, Rui Zhao, et al. 2019. “High-Throughput
Single Cell Proteomics Enabled by Multiplex Isobaric Labeling in a
Nanodroplet Sample Preparation Platform.” Analytical Chemistry,
September
(\href{https://doi.org/10.1021/acs.analchem.9b03349}{link to article}).
}
\seealso{
\link{dou2019_lysates}, \link{dou2019_mouse}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/guise2024.R
\docType{data}
\name{guise2024}
\alias{guise2024}
\title{Guise et al. 2020 (Cell Rep.): postmortem ALS spinal moto neurons}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 102 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \verb{F*}: 100 assays containing PSM data.
\item \code{peptides}: quantitative data for 34,315 peptides in 108 samples.
All samples combined, along with 8 additional unannotated
samples.
\item \code{proteins}: quantitative data for 4,437 protein groups in 108
samples. All samples combined, along with 8 additional
unannotated samples.
}

Sample annotation is stored in \code{colData(guise2024())}.
}
\source{
All data can be downloaded from the MassIVE repository
MSV000092119. The source link is:
ftp://massive.ucsd.edu/v05/MSV000092119/
}
\usage{
guise2024
}
\description{
Single-cell proteomics data from postmortem human spinal moto
neurons (MN) obtained from control donors or donors with amyotrophic
lateral sclerosis (ALS). The data were generated following the
NanoPOTS protocol. Cells were isolated from samples obtained by
the university of Miami Brain Bank using laser capture
microdissection (LCM). Additional information about the amount of
TDP-43 intra-cellular levels has been assigned into levels 0 to 4.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: The MN were isolated from samples obtained
by the university of Miami Brain Bank using LCM.
\item \strong{Sample preparation} performed using the nanoPOTS workflow.
Cells are treated with 0.1\% DDM (for lysis) added with DTT
(protein reduction), then IAA (alkylation), then Lys-C and
trypsin (protein digestion).
\item \strong{Separation}: Samples were injected on the column using an
Ultimate 3000 RSLCnano pump. The in-line loading column is a
home-packed SPE column (5cm x 75um) while the peptide
separation is performed on a an in-house-packed analytical SPE
column (50 cm x 30um), using a 20nL/min flow rate.
\item \strong{Ionization}: nanospray emmitter (2,000V)
\item \strong{Mass spectrometry}: Orbitrap Exploris 480. HCD fragmentation.
MS1 settings: accumulation time = 200 ms; resolution = 120,000;
AGC = 1E6. MS2 settings: exclusion duration = 90 s;
accumulation time = 500 ms; resolution = 30,000; AGC = 1E5.
\item \strong{Data analysis}: Sequest HT in Proteome Discoverer (v2.5) and
the search database is Swiss-Prot (July 2020).
}
}

\section{Data collection}{


All data were collected from the MassIVE repository (accession ID:
MSV000092119).

The sample annotations were combined from the tables in
\verb{Biogen_TDP43_Round2_Reanalysis_10-13-2021_InputFiles.txt} and in
\code{Groups.txt}.

The PSM data were found in the
\verb{Biogen_TDP43_Round2_Reanalysis_10-13-2021_PSMs.txt} file. The
data were converted to a \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object using the \code{\link[scp:readSCP]{scp::readSCP()}}
function. We could not find sample annotations for MS run ID:
F61, F34, F42, F88, F77, F8, F21, F5.

The peptide data were found in the
\verb{Biogen_TDP43_Round2_Reanalysis_10-13-2021_PeptideGroups.txt}
file. The column names holding the quantitative data were adapted
to match the sample names in the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object. The data were
then converted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object and then
inserted in the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object.

A similar procedure was applied to the protein data. The data were
found in the
\verb{Biogen_TDP43_Round2_Reanalysis_10-13-2021_Proteins.txt} file. The
column names were
adapted, the data were converted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment}
object and then inserted in the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object.
}

\examples{
\donttest{
guise2024()
}

}
\references{
Guise, Amanda J., Santosh A. Misal, Richard Carson, Jen-Hwa Chu,
Hannah Boekweg, Daisha Van Der Watt, Nora C. Welsh, et al. 2024.
“TDP-43-Stratified Single-Cell Proteomics of Postmortem Human
Spinal Motor Neurons Reveals Protein Dynamics in Amyotrophic
Lateral Sclerosis.” Cell Reports 43 (1): 113636.
(\href{http://dx.doi.org/10.1016/j.celrep.2023.113636}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cong2020AC.R
\docType{data}
\name{cong2020AC}
\alias{cong2020AC}
\title{Cong et al. 2020 (Ana. Chem.): HeLa single cells}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 9 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \verb{100/20 HeLa cells}: 2 assays containing PSM data for a bulk
of 100 or 20 HeLa cells, respectively.
\item \code{Blank}: assay containing the PSM data for a blank sample
\item \verb{Single cell X}: 4 assays containing PSM data for a single cell.
The \code{X} indicates the replicate number.
\item \code{peptides}: quantitative data for 12590 peptides in 7 samples
(all runs combined).
\item \code{proteins}: quantitative data for 1801 proteins in 7 samples
(all runs combined).
}

Sample annotation is stored in \code{colData(cong2020AC())}.
}
\source{
All files can be downloaded from the PRIDE repository PXD016921.
The source link is:
ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2020/02/PXD016921
}
\usage{
cong2020AC
}
\description{
Single-cell proteomics using the nanoPOTS sample processing device
in combination with ultranarrow-bore (20um i.d.) packed-column LC
separations and the Orbitrap Eclipse Tribrid MS. The dataset
contains label-free quantitative information at PSM, peptide and
protein level. The samples are single Hela cells. Bulk samples
(100 and 20 cells) were also included in the experiment to
increase the idendtification rate thanks to between-run matching
(cf MaxQuant).
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: The HeLa cells were diluted and aspired
using a microcapillary with a pulled tip.
\item \strong{Sample preparation} performed using the nanoPOTs device.
Protein extraction using RapiGest (+ DTT) + alkylation (IAA) +
Lys-C digestion + cleave RapiGest (formic acid)
\item \strong{Separation}: UltiMate 3000 RSLCnano pump with a home-packed
nanoLC column (60cm x 20um i.d.; approx. 20 nL/min)
\item \strong{Ionization}: ESI (2,000V; Nanospray Flex)
\item \strong{Mass spectrometry}: Thermo Fisher Orbitrap Fusion Eclipse.
MS1 settings: accumulation time = 246ms; resolution = 120,000;
AGC = 1E6. MS/MS settings depend on quantity. All: AGC = 1E5.
20-100 cels: accumulation time = 246ms; resolution = 120,000.
Single cells: accumulation time = 500ms; resolution = 240,000.
\item \strong{Data analysis}: MaxQuant (v1.6.3.3) + Excel
}
}

\section{Data collection}{


The PSM, peptide and protein data were collected from the PRIDE
repository (accession ID: PXD016921).  We downloaded the
\code{evidence.txt} file containing the PSM identification and
quantification results. The sample annotation was inferred from
the samples names. The data were then converted to a \link[QFeatures:QFeatures-class]{QFeatures::QFeatures}
object using the \code{\link[scp:readSCP]{scp::readSCP()}} function.

The peptide data were processed similarly from the \code{peptides.txt}
file. The quantitative column names were adpated to match the PSM
data. The peptide data were added to \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object and link
between the features were stored.

The protein data were similarly processed from the
\code{proteinGroups.txt} file. The quantitative column names were
adapted to match the PSM data. The peptide data were added to
\link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object and link between the features were stored.
}

\examples{
\donttest{
cong2020AC()
}

}
\references{
Cong, Yongzheng, Yiran Liang, Khatereh Motamedchaboki, Romain
Huguet, Thy Truong, Rui Zhao, Yufeng Shen, Daniel Lopez-Ferrer,
Ying Zhu, and Ryan T. Kelly. 2020. “Improved Single-Cell Proteome
Coverage Using Narrow-Bore Packed NanoLC Columns and
Ultrasensitive Mass Spectrometry.” Analytical Chemistry, January.
(\href{https://doi.org/10.1021/acs.analchem.9b04631}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/petrosius2023_mES.R
\docType{data}
\name{petrosius2023_mES}
\alias{petrosius2023_mES}
\title{Petrosius et al, 2023 (Nat. Comm.): Mouse embryonic stem cell (mESC) in
different culture conditions}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 605 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item Assay 1-603: PSM data acquired with an orbitrap-based data-independent
acquisition (DIA) protocol, hence those assays contain single column
that contains the quantitative information.
\item \code{peptides}: peptide data containing quantitative data for 9884
peptides and 603 single-cells.
\item \code{proteins}: protein data containing quantitative data for 4270
proteins and 603 single-cells.
}

Sample annotation is stored in \code{colData(petrosius2023_mES())}.
}
\source{
The peptide and protein data can be downloaded from the
\href{https://dataverse.uclouvain.be/dataset.xhtml?persistentId=doi:10.14428/DVN/EMAVLT}{Dataverse}
The raw data and the quantification data can also be found in
the MassIVE repository \code{MSV000092429}:
ftp://MSV000092429@massive.ucsd.edu/.
}
\usage{
petrosius2023_mES
}
\description{
Profiling mouse embryonic stem cells across ground-state (m2i) and
differentiation-permissive (m15) culture conditions. The data were
acquired using orbitrap-based data-independent acquisition (DIA).
The objective was to demonstrate the capability of their approach
by profiling mouse embryonic stem cell culture conditions, showcasing
heterogeneity in global proteomes, and highlighting differences in
the expression of key metabolic enzymes in distinct cell subclusters.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \code{References}).
\itemize{
\item \strong{Sample isolation}: Cell sorting was done on a Sony MA900 cell sorter
using a 130 microm sorting chip. Cells were sorted at single-cell resolution,
into a 384-well Eppendorf LoBind PCR plate (Eppendorf AG) containing 1 microL
of lysis buffer.
\item \strong{Sample preparation}: Single-cell protein lysates were digested with
2 ng of Trypsin supplied in 1 microL of digestion buffer which was
carried out overnight at 37 °C, and subsequently acidified by the
addition of 1 microL 1\% (v/v) trifluoroacetic acid (TFA). All liquid
dispensing was done using an I-DOT One instrument.
\item \strong{Liquid chromatography}: For the HRMS1-DIA experiments and the DIA
isolation window survey, Evosep One liquid chromatography was used.
The standard 31-minute or 58-minute pre-defined Whisper gradients were
used with a flow rate of 100 nl/min for peptide elution.
\item \strong{Mass spectrometry}: The mass spectrometer was operated in positive
mode with the FAIMSPro interface compensation voltage set to -45 V.
MS1 scans were carried out at 120,000 resolution with an automatic gain
control (AGC) of 300\% and maximum injection time set to auto. For the DIA
isolation window survey, a scan range of 500–900 was used, and 400–1000
rest of the experiments. Higher energy collisional dissociation (HCD) was
used for precursor fragmentation with a normalized collision energy (NCE)
of 33\% and the MS2 scan AGC target was set to 1000\%.
\item \strong{Raw data processing}: The mESC raw data files were processed with
Spectronaut 17.
}
}

\section{Data collection}{


The data were provided by the Author and is accessible at the
\href{https://dataverse.uclouvain.be/dataset.xhtml?persistentId=doi:10.14428/DVN/EMAVLT}{Dataverse}
The folder ('20240205_111248_mESC_SNEcombine_m15-m2i/') contains
the following files of interest:
\itemize{
\item \verb{20240205_111251_PEPQuant (Normal).tsv}: the PSM level data
\item \verb{20240205_111251_Peptide Quant (Normal).tsv}: the peptide level data
\item \verb{20240205_111251_PGQuant (Normal).tsv}: the protein level data
}

The metadata were downloaded from the \href{https://zenodo.org/records/8146605}{Zenodo repository}.
\itemize{
\item \code{sample_facs.csv}: the metadata
}

We formatted the quantification table so that columns match with the
metadata. Then, both tables are then combined in a single
\link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object using the \code{\link[scp:readSCP]{scp::readSCP()}} function.

The peptide data were formated to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object and the
sample metadata were matched to the column names and stored in the \code{colData}.
The object is then added to the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object and the rows of the PSM
data are linked to the rows of the peptide data based on the peptide sequence
information through an \code{AssayLink} object.

The protein data were formated to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object and
the sample metadata were matched to the column names and stored in the
\code{colData}. The object is then added to the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object and the rows
of the peptide data are linked to the rows of the protein data based on the
protein sequence information through an \code{AssayLink} object.
}

\examples{
\donttest{
petrosius2023_mES()
}

}
\references{
\strong{Source article}: Petrosius, V., Aragon-Fernandez, P., Üresin, N. et al.
"Exploration of cell state heterogeneity using single-cell proteomics
through sensitivity-tailored data-independent acquisition."
Nat Commun 14, 5910 (2023).
(\href{https://doi.org/10.1038/s41467-023-41602-1}{link to article}).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/petrosius2023_AstralAML.R
\docType{data}
\name{petrosius2023_AstralAML}
\alias{petrosius2023_AstralAML}
\title{Petrosius et al. 2023 (bioRxiv): AML hierarchy on Astral.}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 217 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item Assays 1-215: PSM data from the Spectronaut PEPQuant file with
LFQ quantities from the FG.MS1Quantity column.
\item \code{peptides}: Peptide data resulting from the PSM to peptide
aggregation the 215 PSM assays. Resulting peptide assays were
joined into a single assay.
\item \code{proteins}: Protein data from the Spectronaut PGQuant file with
LFQ quantities from the PG.Quantity column.
}

The \code{colData(petrosius2023_AstralAML())} contains cell type
annotation, batch annotation and FACS data. The description of the
\code{rowData} fields can be found in the
\href{https://biognosys.com/content/uploads/2023/03/Spectronaut-17_UserManual.pdf}{\code{Spectronaut} user manual}.
}
\source{
The PSM data, protein data and sample annotations can be
downloaded from the dataset 'Astral AML single-cell data from
Petrosius et al. 2023 preprint' in the
\href{https://dataverse.uclouvain.be/dataset.xhtml?persistentId=doi:10.14428/DVN/EMAVLT}{Dataverse}.
}
\usage{
petrosius2023_AstralAML
}
\description{
Single cell proteomics data from FACS sorted cells from the
OCI-AML8227 model. The dataset contains leukemic stem cells (LSC;
CD34+, CD38-), progenitor cells (CD34+, CD38+), CD38+ blasts
(CD34-, CD38+) and CD38- blasts (CD34-, CD38-). It contains
quantitative information at PSM, peptide and protein levels. Data
was acquired using an Orbitrap Astral mass spectrometer. Direct DIA
analysis was performed with Spectronaut version 17.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the source article (see \emph{References}).
\itemize{
\item \strong{Cell isolation}: Cell sorting was done on a FACS Aria III or
Aria II instrument, controlled by the DIVA software package and
operated with a 100 microm nozzle. Cells were sorted at single-cell
resolution, into a 384-well Eppendorf LoBind PCR plate containing
1 microL of lysis buffer.
\item \strong{Sample preparation} Single-cell protein lysates were digested
overnight at 37°C with 2 ng of Trypsin supplied in 1 microL of
digestion buffer. Digestion was stopped by the addition of 1 microL
1\% (v/v) trifluoroacetic acid (TFA). All liquid dispensing was
done using an I-DOT One instrument.
\item \strong{Liquid chromatography}: Chromatographic separation of peptides
was conducted on a vanquish Neo UHPLC system connected to a 50 cm
uPAC Neo Low-load and an EASY-spray. Autosampler and injection
valves were configured to perform direct injections from a 384
well plate using a 25 uL injection loop on 11.8 min gradients.
\item \strong{Mass spectrometry}: Acquisition was conducted with an Orbitrap
Astral mass spectrometer operated in positive mode with the
FAIMSPro interface compensation voltage set to -45 V.
MS1 scans were acquired with the Orbitrap at a resolution of
120,000 and a scan range of 400 to 900 m/z with normalized
automatic gain control (AGC) target of 300 \% and maximum
injection time of 246 ms. Data independent acquisition of MS2
spectra was performed in the Astral using loop control set to 0.7
seconds per cycle with varying isolation window widths and
injection times. Fragmentation of precursor ions was performed
using higher energy collisional dissociation (HCD) using a
normalized collision energy (NCE) of 25 \%. AGC target was set to
800 \%.
\item \strong{Raw data processing}: Raw files were processed using
Spectronaut version 17. Direct DIA analysis was performed in
pipeline mode. Pulsar searches were performed without fixed
modifications. N-terminal acetylation and methionine oxidation
were set as variable modifications. Quantification level was set
to MS1 and the quantity type set to area under the curve.
}
}

\section{Data collection}{


The data were provided by the authors and is accessible at the
\href{https://dataverse.uclouvain.be/dataset.xhtml?persistentId=doi:10.14428/DVN/EMAVLT}{Dataverse}
The dataset ('Astral AML single-cell data from Petrosius et
al. 2023 preprint') contains the following files of interest:
\itemize{
\item \verb{20240201_130747_PEPQuant (Normal).tsv}: the PSM level data
\item \verb{20240201_130747_PGQuant (Normal).tsv}: the protein level data
\item \code{index_map.csv}: FACS data.
\item \code{msRuns_overview.csv}: Sample annotations.
}

We added the FACS data to the sample annotations in a single table.
Both annotations and PSM features tables are then combined in a
single \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object using the \code{\link[scp:readSCP]{scp::readSCP()}} function.

The peptide data were obtained by aggregation of the PSM data to
the peptide level. All of the resulting peptides assays were joined
into a single assays. Individual peptides assays were discarded.

The protein data were formatted from the \verb{20240201_130747_PGQuant (Normal).tsv}
to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object and the sample metadata were
matched to the column names and stored in the  \code{colData}. The
object is then added to the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object and the rows of the
peptide data are linked to the rows of the protein data based on
the protein sequence information through an \code{AssayLink} object.

Note that the \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object has not been further processed and
has therefore not been normalized, log-transformed or
batch-corrected.
}

\examples{
\donttest{
petrosius2023_AstralAML()
}

}
\references{
Valdemaras Petrosius, Pedro Aragon-Fernandez, Tabiwang N. Arrey,
Nil Üresin, Benjamin Furtwängler, Hamish Stewart, Eduard Denisov,
Johannes Petzoldt, Amelia C. Peterson, Christian Hock, Eugen
Damoc, Alexander Makarov, Vlad Zabrouskov, Bo T. Porse and Erwin
M. Schoof.
2023. "Evaluating the capabilities of the Astral mass analyzer for single-cell proteomics."
biorxiv.  https://doi.org/10.1101/2023.06.06.543943
DOI:\href{https://doi.org/10.1101/2023.06.06.543943}{10.1101/2023.06.06.543943}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ai2025a.R
\docType{data}
\name{ai2025a}
\alias{ai2025a}
\title{Ai et al., Cardiomyocytes Single Cell Proteomics, MCP (2025)}
\format{
An object of class \code{function} of length 1.
}
\usage{
ai2025a
}
\description{
The manuscript analysed cardiomyocytes derived from iPSC cells and adult
hearts. This annotated \code{QFeatures} objects contains the complete data, as
analysed with the \code{scp} package. The re-analysis was performed as part of
the EuBIC 2025 developer meeting hackathon dedicated to single-cell
proteomics data (https://lgatto.github.io/2025-EuBIC-SCP-hackathon/).

The data contains a total of 304 assay. The 299 first assays contain the
individual single cardiomyocytes acquistions. The following assays contain
the joined precursor data, the log-transformed precuror data, the peptide
data, the protein data, and the scplainer-modelled precursor data (see the
link above for details).

The \code{QFeatures} object was generated from the DIA-NN report file, available
from the \code{MsDataHub} package (see \code{?MsDataHub::Ai2025_aCMs_report.tsv}). The
report file is downloaded from the MassIVE MSV000094438
(doi:10.25345/C5T727S7Q) repository.
}
\examples{

\donttest{
ai2025a()
}
}
\references{
\itemize{
\item Ai, Lizhuo, Aleksandra Binek, Vladimir Zhemkov, Jae Hyung Cho, Ali
Haghani, Simion Kreimer, Edo Israely, et al. 2025. “Single Cell Proteomics
Reveals Specific Cellular Subtypes in Cardiomyocytes Derived from Human
iPSCs and Adult Hearts.” Molecular & Cellular Proteomics: MCP, no. 100910
(January): 100910.
}
}
\keyword{dataset}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/zhu2018NC_lysates.R
\docType{data}
\name{zhu2018NC_lysates}
\alias{zhu2018NC_lysates}
\title{Zhu et al. 2018 (Nat. Comm.): HeLa lysates}
\format{
A \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object with 4 assays, each assay being a
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object:
\itemize{
\item \code{peptides}: quantitative information for 14,921 peptides from
9 lysate samples
\item \code{proteins_intensity}: quantitative information for 2,199
proteins from 9 lysate samples
\item \code{proteins_LFQ}: LFQ intensities for 2,199 proteins from 9 lysate
samples
\item \code{proteins_iBAQ}: iBAQ values for 2,199 proteins from 9 lysate
samples
}

Sample annotation is stored in \code{colData(zhu2018NC_lysates())}.
}
\source{
The PSM data can be downloaded from the PRIDE repository
PXD006847. The source link is:
ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2018/01/PXD006847
}
\usage{
zhu2018NC_lysates
}
\description{
Near single-cell proteomics data of HeLa lysates at different
concentrations (10, 40 and 140 cell equivalent). Each
concentration is acquired in triplicate.
}
\section{Acquisition protocol}{


The data were acquired using the following setup. More information
can be found in the original article (see \code{References}).
\itemize{
\item \strong{Cell isolation}: HeLas were collected from cell cultures.
\item \strong{Sample preparation} performed in bulk (5E5 cells/mL). Protein
extraction using RapiGest (+ DTT) + dilution to target
concentration + alkylation (IAA) + Lys-C digestion + trypsin
digestion + cleave RapiGest (formic acid).
\item \strong{Separation}: nanoACQUITY UPLC pump (60nL/min) with an
Self-Pack PicoFrit 70cm x 30um LC columns.
\item \strong{Ionization}: ESI (1,900V).
\item \strong{Mass spectrometry}: Thermo Fisher Orbitrap Fusion Lumos
Tribrid. MS1 settings: accumulation time = 246ms; resolution =
120,000; AGC = 1E6. MS/MS settings, depend on the sample size,
excepted for the AGC = 1E5. Blank and approx. 10 cells (time = 502ms;
resolution = 240,000), approx. 40 cells (time = 246ms; resolution =
120,000), approx. 140 cells (time = 118ms; resolution = 60,000).
\item \strong{Data analysis}: MaxQuant (v1.5.3.30) + Perseus + OriginLab
2017.
}
}

\section{Data collection}{


The data were collected from the PRIDE repository (accession
ID: PXD006847).  We downloaded the \code{Vail_Prep_Vail_peptides.txt}
and the \code{Vail_Prep_Vail_proteinGroups.txt} files containing the
combined identification and quantification
results. The sample annotations were inferred from the names of
columns holding the quantification data and the information in the
article. The peptides data were converted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment}
object. We split the protein table to separate the three types of
quantification: protein intensity, label-free quantitification
(LFQ) and intensity based absolute quantification (iBAQ). Each
table is converted to a \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment::SingleCellExperiment} object along with
the remaining protein annotations. The 4 objects are combined in
a single \link[QFeatures:QFeatures-class]{QFeatures::QFeatures} object and feature links are created based on
the peptide leading razor protein ID and the protein ID.
}

\examples{
\donttest{
zhu2018NC_lysates()
}

}
\references{
Zhu, Ying, Paul D. Piehowski, Rui Zhao, Jing Chen, Yufeng Shen,
Ronald J. Moore, Anil K. Shukla, et al. 2018. “Nanodroplet
Processing Platform for Deep and Quantitative Proteome Profiling
of 10-100 Mammalian Cells.” Nature Communications 9 (1): 882
(\href{http://dx.doi.org/10.1038/s41467-018-03367-w}{link to article}).
}
\seealso{
The same experiment was conducted directly on HeLa cells
samples rather than lysates. The data is available in
\link{zhu2018NC_hela}.
}
\keyword{datasets}
